/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "MessageArgumentDescriptions.h"

#if ENABLE(IPC_TESTING_API) || !LOG_DISABLED

#include "JSIPCBinding.h"
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "GPUConnectionToWebProcessMessages.h"
#if ENABLE(WEBGL)
#include "GraphicsContextGLIdentifier.h"
#endif
#include "MediaOverridesForTesting.h"
#include "RemoteAudioHardwareListenerIdentifier.h"
#if USE(AUDIO_SESSION)
#include "RemoteAudioSessionConfiguration.h"
#endif
#include "RemoteRemoteCommandListenerIdentifier.h"
#include "RemoteRenderingBackendCreationParameters.h"
#include "RenderingBackendIdentifier.h"
#include "StreamConnectionBuffer.h"
#if USE(GRAPHICS_LAYER_WC)
#include "WCLayerTreeHostIdentifier.h"
#endif
#include "WebCoreArgumentCoders.h"
#include "WebGPUIdentifier.h"
#if HAVE(VISIBILITY_PROPAGATION_VIEW)
#include "WebPageProxyIdentifier.h"
#endif
#if ENABLE(WEBGL)
#include <WebCore/GraphicsContextGLAttributes.h>
#endif
#include <WebCore/NowPlayingInfo.h>
#if HAVE(VISIBILITY_PROPAGATION_VIEW)
#include <WebCore/PageIdentifier.h>
#endif
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "Attachment.h"
#include "GPUProcessConnectionInitializationParameters.h"
#include "GPUProcessConnectionParameters.h"
#include "GPUProcessCreationParameters.h"
#include "GPUProcessMessages.h"
#include "GPUProcessSessionParameters.h"
#if ENABLE(MEDIA_STREAM)
#include "SandboxExtension.h"
#endif
#include "ShareableBitmap.h"
#include "WebCoreArgumentCoders.h"
#if HAVE(SC_CONTENT_SHARING_SESSION)
#include <WebCore/CaptureDevice.h>
#endif
#include <WebCore/MediaPlayerIdentifier.h>
#if ENABLE(MEDIA_STREAM)
#include <WebCore/MockMediaDevice.h>
#endif
#include <WebCore/ProcessIdentifier.h>
#if PLATFORM(MAC)
#include <WebCore/ScreenProperties.h>
#endif
#if ENABLE(MEDIA_STREAM)
#include <WebCore/SecurityOriginData.h>
#endif
#include <optional>
#include <pal/SessionID.h>
#if ENABLE(MEDIA_STREAM)
#include <wtf/Vector.h>
#endif
#if ENABLE(CFPREFS_DIRECT_MODE) || ENABLE(MEDIA_STREAM)
#include <wtf/text/WTFString.h>
#endif
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "FilterReference.h"
#include "RemoteDisplayListRecorderMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/AffineTransform.h>
#include <WebCore/Color.h>
#include <WebCore/ColorSpace.h>
#include <WebCore/DisplayList.h>
#include <WebCore/FloatPoint.h>
#include <WebCore/FloatRect.h>
#include <WebCore/FloatRoundedRect.h>
#include <WebCore/FloatSize.h>
#include <WebCore/GraphicsContextFlushIdentifier.h>
#include <WebCore/GraphicsTypes.h>
#include <WebCore/ImagePaintingOptions.h>
#if ENABLE(INLINE_PATH_DATA)
#include <WebCore/InlinePathData.h>
#endif
#include <WebCore/MediaPlayerIdentifier.h>
#include <WebCore/Path.h>
#include <WebCore/RenderingResourceIdentifier.h>
#include <WebCore/WindRule.h>
#include <optional>
#include <wtf/Vector.h>
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(WEBGL)
#include "ArgumentCoders.h"
#include "ArrayReference.h"
#include "RemoteGraphicsContextGLMessages.h"
#if ENABLE(VIDEO)
#include "RemoteVideoFrameIdentifier.h"
#endif
#if ENABLE(MEDIA_STREAM)
#include "RemoteVideoFrameProxy.h"
#endif
#if USE(GRAPHICS_LAYER_WC)
#include "WCContentBufferIdentifier.h"
#endif
#include "WebCoreArgumentCoders.h"
#include <WebCore/GraphicsContextGL.h>
#include <WebCore/PixelBuffer.h>
#include <WebCore/RenderingResourceIdentifier.h>
#include <optional>
#if PLATFORM(COCOA)
#include <wtf/MachSendRight.h>
#endif
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "BufferIdentifierSet.h"
#include "FilterReference.h"
#include "FontReference.h"
#include "ImageBufferBackendHandle.h"
#include "RemoteRenderingBackendMessages.h"
#include "RenderingUpdateID.h"
#include "ShareableBitmap.h"
#include "SharedMemory.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/AlphaPremultiplication.h>
#include <WebCore/ColorSpace.h>
#include <WebCore/FloatSize.h>
#include <WebCore/ImageBufferBackend.h>
#include <WebCore/IntPoint.h>
#include <WebCore/IntRect.h>
#include <WebCore/PixelBuffer.h>
#include <WebCore/PixelBufferFormat.h>
#include <WebCore/RenderingMode.h>
#include <WebCore/RenderingResourceIdentifier.h>
#include <optional>
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "RemoteAdapterMessages.h"
#include "WebGPUDeviceDescriptor.h"
#include "WebGPUIdentifier.h"
#include "WebGPUSupportedFeatures.h"
#include "WebGPUSupportedLimits.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "RemoteBindGroupMessages.h"
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "RemoteBindGroupLayoutMessages.h"
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "RemoteBufferMessages.h"
#include <optional>
#include <pal/graphics/WebGPU/WebGPUIntegralTypes.h>
#include <pal/graphics/WebGPU/WebGPUMapMode.h>
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "RemoteCommandBufferMessages.h"
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "RemoteCommandEncoderMessages.h"
#include "WebGPUCommandBufferDescriptor.h"
#include "WebGPUComputePassDescriptor.h"
#include "WebGPUExtent3D.h"
#include "WebGPUIdentifier.h"
#include "WebGPUImageCopyBuffer.h"
#include "WebGPUImageCopyTexture.h"
#include "WebGPURenderPassDescriptor.h"
#include <optional>
#include <pal/graphics/WebGPU/WebGPUIntegralTypes.h>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "RemoteComputePassEncoderMessages.h"
#include "WebGPUIdentifier.h"
#include <optional>
#include <pal/graphics/WebGPU/WebGPUIntegralTypes.h>
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "RemoteComputePipelineMessages.h"
#include "WebGPUIdentifier.h"
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "RemoteDeviceMessages.h"
#include "WebGPUBindGroupDescriptor.h"
#include "WebGPUBindGroupLayoutDescriptor.h"
#include "WebGPUBufferDescriptor.h"
#include "WebGPUCommandEncoderDescriptor.h"
#include "WebGPUComputePipelineDescriptor.h"
#include "WebGPUError.h"
#include "WebGPUExternalTextureDescriptor.h"
#include "WebGPUIdentifier.h"
#include "WebGPUPipelineLayoutDescriptor.h"
#include "WebGPUQuerySetDescriptor.h"
#include "WebGPURenderBundleEncoderDescriptor.h"
#include "WebGPURenderPipelineDescriptor.h"
#include "WebGPUSamplerDescriptor.h"
#include "WebGPUShaderModuleDescriptor.h"
#include "WebGPUTextureDescriptor.h"
#include <optional>
#include <pal/graphics/WebGPU/WebGPUErrorFilter.h>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "RemoteExternalTextureMessages.h"
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "RemoteGPU.h"
#include "RemoteGPUMessages.h"
#include "WebGPUIdentifier.h"
#include "WebGPURequestAdapterOptions.h"
#include <optional>
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "RemotePipelineLayoutMessages.h"
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "RemoteQuerySetMessages.h"
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "RemoteQueueMessages.h"
#include "WebGPUExtent3D.h"
#include "WebGPUIdentifier.h"
#include "WebGPUImageCopyExternalImage.h"
#include "WebGPUImageCopyTexture.h"
#include "WebGPUImageCopyTextureTagged.h"
#include "WebGPUImageDataLayout.h"
#include <pal/graphics/WebGPU/WebGPUIntegralTypes.h>
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "RemoteRenderBundleMessages.h"
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "RemoteRenderBundleEncoderMessages.h"
#include "WebGPUIdentifier.h"
#include "WebGPURenderBundleDescriptor.h"
#include <optional>
#include <pal/graphics/WebGPU/WebGPUIndexFormat.h>
#include <pal/graphics/WebGPU/WebGPUIntegralTypes.h>
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "RemoteRenderPassEncoderMessages.h"
#include "WebGPUColor.h"
#include "WebGPUIdentifier.h"
#include <optional>
#include <pal/graphics/WebGPU/WebGPUIndexFormat.h>
#include <pal/graphics/WebGPU/WebGPUIntegralTypes.h>
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "RemoteRenderPipelineMessages.h"
#include "WebGPUIdentifier.h"
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "RemoteSamplerMessages.h"
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "RemoteShaderModuleMessages.h"
#include "WebGPUCompilationMessage.h"
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "RemoteTextureMessages.h"
#include "WebGPUIdentifier.h"
#include "WebGPUTextureViewDescriptor.h"
#include <optional>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "RemoteTextureViewMessages.h"
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(WEB_AUDIO)
#include "ArgumentCoders.h"
#include "IPCSemaphore.h"
#include "RemoteAudioDestinationIdentifier.h"
#include "RemoteAudioDestinationManagerMessages.h"
#if PLATFORM(COCOA)
#include "SharedMemory.h"
#endif
#if PLATFORM(COCOA)
#include "WebCoreArgumentCoders.h"
#endif
#if PLATFORM(COCOA)
#include <WebCore/CAAudioStreamDescription.h>
#endif
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS) && USE(AUDIO_SESSION)
#include "ArgumentCoders.h"
#include "RemoteAudioSessionProxyMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/AudioSession.h>
#include <optional>
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
#include "ArgumentCoders.h"
#include "RemoteCDMConfiguration.h"
#include "RemoteCDMFactoryProxyMessages.h"
#include "RemoteCDMIdentifier.h"
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
#include "ArgumentCoders.h"
#include "RemoteCDMInstanceProxyMessages.h"
#include "RemoteCDMInstanceSessionIdentifier.h"
#include "SharedBufferCopy.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/CDMInstance.h>
#include <WebCore/CDMKeySystemConfiguration.h>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
#include "ArgumentCoders.h"
#include "RemoteCDMInstanceSessionProxyMessages.h"
#include "SharedBufferCopy.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/CDMInstanceSession.h>
#include <optional>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
#include "ArgumentCoders.h"
#include "RemoteCDMInstanceConfiguration.h"
#include "RemoteCDMInstanceIdentifier.h"
#include "RemoteCDMProxyMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/CDMKeySystemConfiguration.h>
#include <WebCore/CDMPrivate.h>
#include <optional>
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(LEGACY_ENCRYPTED_MEDIA)
#include "ArgumentCoders.h"
#include "RemoteLegacyCDMFactoryProxyMessages.h"
#include "RemoteLegacyCDMIdentifier.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/MediaPlayerIdentifier.h>
#include <optional>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(LEGACY_ENCRYPTED_MEDIA)
#include "ArgumentCoders.h"
#include "RemoteLegacyCDMProxyMessages.h"
#include "RemoteLegacyCDMSessionIdentifier.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/MediaPlayerIdentifier.h>
#include <optional>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(LEGACY_ENCRYPTED_MEDIA)
#include "ArgumentCoders.h"
#include "RemoteLegacyCDMSessionProxyMessages.h"
#include "SharedBufferCopy.h"
#include <optional>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "RemoteMediaEngineConfigurationFactoryProxyMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/MediaCapabilitiesDecodingInfo.h>
#include <WebCore/MediaCapabilitiesEncodingInfo.h>
#include <WebCore/MediaDecodingConfiguration.h>
#include <WebCore/MediaEncodingConfiguration.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "RemoteMediaPlayerManagerProxyMessages.h"
#include "RemoteMediaPlayerProxyConfiguration.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/MediaPlayer.h>
#include <WebCore/MediaPlayerEnums.h>
#include <WebCore/MediaPlayerIdentifier.h>
#include <WebCore/SecurityOriginData.h>
#include <wtf/HashSet.h>
#include <wtf/Vector.h>
#include <wtf/WallTime.h>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "LayerHostingContext.h"
#if ENABLE(ENCRYPTED_MEDIA)
#include "RemoteCDMInstanceIdentifier.h"
#endif
#if ENABLE(LEGACY_ENCRYPTED_MEDIA)
#include "RemoteLegacyCDMSessionIdentifier.h"
#endif
#include "RemoteMediaPlayerConfiguration.h"
#include "RemoteMediaPlayerProxyMessages.h"
#if ENABLE(MEDIA_SOURCE)
#include "RemoteMediaSourceIdentifier.h"
#endif
#include "RemoteVideoFrameProxy.h"
#include "SandboxExtension.h"
#include "TrackPrivateRemoteIdentifier.h"
#include "WebCoreArgumentCoders.h"
#if PLATFORM(COCOA)
#include <WebCore/ColorSpace.h>
#endif
#include <WebCore/ContentType.h>
#if PLATFORM(COCOA)
#include <WebCore/FloatSize.h>
#endif
#include <WebCore/InbandTextTrackPrivate.h>
#if ENABLE(WIRELESS_PLAYBACK_TARGET)
#include <WebCore/MediaPlaybackTargetContext.h>
#endif
#include <WebCore/MediaPlayer.h>
#include <WebCore/MediaPlayerEnums.h>
#include <WebCore/PlatformScreen.h>
#include <WebCore/SecurityOriginData.h>
#include <optional>
#if PLATFORM(COCOA)
#include <wtf/MachSendRight.h>
#endif
#include <wtf/MediaTime.h>
#include <wtf/MonotonicTime.h>
#include <wtf/URLHash.h>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "RemoteMediaResourceIdentifier.h"
#include "RemoteMediaResourceManagerMessages.h"
#include "SharedMemory.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/FrameLoaderTypes.h>
#include <WebCore/NetworkLoadMetrics.h>
#include <WebCore/ResourceError.h>
#include <WebCore/ResourceRequest.h>
#include <WebCore/ResourceResponse.h>
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)
#include "ArgumentCoders.h"
#include "RemoteMediaSourceProxyMessages.h"
#include "RemoteSourceBufferIdentifier.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/ContentType.h>
#include <WebCore/MediaPlayerEnums.h>
#include <WebCore/MediaSourcePrivate.h>
#include <WebCore/PlatformTimeRanges.h>
#include <optional>
#include <wtf/MediaTime.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "RemoteRemoteCommandListenerProxyMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/PlatformMediaSession.h>
#include <wtf/Vector.h>
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)
#include "ArgumentCoders.h"
#include "RemoteSourceBufferProxyMessages.h"
#include "SharedMemory.h"
#include "TrackPrivateRemoteIdentifier.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/ContentType.h>
#include <WebCore/MediaPlayer.h>
#include <WebCore/PlatformTimeRanges.h>
#include <WebCore/SourceBufferPrivate.h>
#include <utility>
#include <wtf/MediaTime.h>
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(VIDEO)
#include "RemoteVideoFrameIdentifier.h"
#include "RemoteVideoFrameObjectHeapMessages.h"
#endif
#if USE(LIBWEBRTC) && PLATFORM(COCOA) && ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "DataReference.h"
#include "IPCSemaphore.h"
#include "LibWebRTCCodecsProxyMessages.h"
#include "RTCDecoderIdentifier.h"
#include "RTCEncoderIdentifier.h"
#include "RemoteVideoFrameIdentifier.h"
#include "SharedMemory.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/RemoteVideoSample.h>
#include <optional>
#include <utility>
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
#include "ArgumentCoders.h"
#include "AudioMediaStreamTrackRendererInternalUnitIdentifier.h"
#include "IPCSemaphore.h"
#include "RemoteAudioMediaStreamTrackRendererInternalUnitManagerMessages.h"
#include "SharedMemory.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/CAAudioStreamDescription.h>
#include <wtf/text/WTFString.h>
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
#include "ArgumentCoders.h"
#include "DataReference.h"
#include "IPCSemaphore.h"
#include "RemoteMediaRecorderMessages.h"
#include "RemoteVideoFrameIdentifier.h"
#include "SharedMemory.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/CAAudioStreamDescription.h>
#include <WebCore/RemoteVideoSample.h>
#include <optional>
#include <wtf/MediaTime.h>
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
#include "ArgumentCoders.h"
#include "MediaRecorderIdentifier.h"
#include "RemoteMediaRecorderManagerMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/ExceptionData.h>
#include <WebCore/MediaRecorderPrivateOptions.h>
#include <optional>
#include <wtf/text/WTFString.h>
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
#if !RELEASE_LOG_DISABLED
#include "ArgumentCoders.h"
#endif
#include "IPCSemaphore.h"
#include "RemoteSampleBufferDisplayLayerMessages.h"
#include "RemoteVideoFrameIdentifier.h"
#include "SharedMemory.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/MediaSample.h>
#include <WebCore/RemoteVideoSample.h>
#if !RELEASE_LOG_DISABLED
#include <wtf/text/WTFString.h>
#endif
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
#include "ArgumentCoders.h"
#include "LayerHostingContext.h"
#include "RemoteSampleBufferDisplayLayerManagerMessages.h"
#include "SampleBufferDisplayLayerIdentifier.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/IntSize.h>
#include <optional>
#endif
#include "ArgumentCoders.h"
#if USE(SOUP)
#include "SoupCookiePersistentStorageType.h"
#endif
#include "WebCookieManagerMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/Cookie.h>
#include <WebCore/HTTPCookieAcceptPolicy.h>
#include <pal/SessionID.h>
#include <wtf/URLHash.h>
#include <wtf/Vector.h>
#include <wtf/WallTime.h>
#include <wtf/text/WTFString.h>
#include "ArgumentCoders.h"
#include "WebCoreArgumentCoders.h"
#include "WebIDBServerMessages.h"
#include <WebCore/ClientOrigin.h>
#include <WebCore/IDBCursorInfo.h>
#include <WebCore/IDBGetAllRecordsData.h>
#include <WebCore/IDBGetRecordData.h>
#include <WebCore/IDBIndexInfo.h>
#include <WebCore/IDBIterateCursorData.h>
#include <WebCore/IDBKeyData.h>
#include <WebCore/IDBKeyRangeData.h>
#include <WebCore/IDBObjectStoreInfo.h>
#include <WebCore/IDBRequestData.h>
#include <WebCore/IDBResourceIdentifier.h>
#include <WebCore/IDBTransactionInfo.h>
#include <WebCore/IDBValue.h>
#include <WebCore/IndexedDB.h>
#include <wtf/text/WTFString.h>
#include "ArgumentCoders.h"
#include "NetworkBroadcastChannelRegistryMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/ClientOrigin.h>
#include <WebCore/MessageWithMessagePorts.h>
#include <wtf/text/WTFString.h>
#include "ArgumentCoders.h"
#include "DownloadID.h"
#include "NavigatingToAppBoundDomain.h"
#include "NetworkConnectionToWebProcessMessages.h"
#include "NetworkResourceLoadIdentifier.h"
#include "NetworkResourceLoadParameters.h"
#include "SandboxExtension.h"
#include "WebCoreArgumentCoders.h"
#include "WebPageProxyIdentifier.h"
#include <WebCore/BlobPart.h>
#include <WebCore/ClientOrigin.h>
#include <WebCore/Cookie.h>
#include <WebCore/CookieJar.h>
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
#include <WebCore/DocumentStorageAccess.h>
#endif
#include <WebCore/FrameIdentifier.h>
#include <WebCore/LoadSchedulingMode.h>
#include <WebCore/MessagePortIdentifier.h>
#include <WebCore/MessageWithMessagePorts.h>
#include <WebCore/NetworkLoadInformation.h>
#include <WebCore/NetworkLoadMetrics.h>
#include <WebCore/NetworkStorageSession.h>
#include <WebCore/PageIdentifier.h>
#include <WebCore/PolicyContainer.h>
#if ENABLE(SERVICE_WORKER)
#include <WebCore/ProcessQualified.h>
#endif
#if ENABLE(WEB_RTC)
#include <WebCore/RTCDataChannelIdentifier.h>
#endif
#include <WebCore/RegistrableDomain.h>
#include <WebCore/ResourceError.h>
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
#include <WebCore/ResourceLoadStatistics.h>
#endif
#include <WebCore/ResourceLoaderIdentifier.h>
#include <WebCore/ResourceRequest.h>
#include <WebCore/ResourceResponse.h>
#include <WebCore/SameSiteInfo.h>
#if ENABLE(SERVICE_WORKER)
#include <WebCore/ScriptExecutionContextIdentifier.h>
#endif
#include <WebCore/ShouldRelaxThirdPartyCookieBlocking.h>
#include <WebCore/WebSocketIdentifier.h>
#include <optional>
#include <wtf/Expected.h>
#if HAVE(COOKIE_CHANGE_LISTENER_API)
#include <wtf/HashSet.h>
#endif
#if ENABLE(SERVICE_WORKER)
#include <wtf/ObjectIdentifier.h>
#endif
#include <wtf/Seconds.h>
#include <wtf/URLHash.h>
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>
#if ENABLE(CONTENT_EXTENSIONS)
#include "ArgumentCoders.h"
#include "NetworkContentRuleListManagerMessages.h"
#include "UserContentControllerIdentifier.h"
#include "WebCompiledContentRuleListData.h"
#include <utility>
#include <wtf/URLHash.h>
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>
#endif
#include "AppPrivacyReport.h"
#include "ArgumentCoders.h"
#include "Attachment.h"
#include "CacheModel.h"
#include "DataReference.h"
#include "DownloadID.h"
#include "DownloadManager.h"
#include "FormDataReference.h"
#include "NavigatingToAppBoundDomain.h"
#include "NetworkProcessCreationParameters.h"
#include "NetworkProcessMessages.h"
#include "QuotaIncreaseRequestIdentifier.h"
#include "SandboxExtension.h"
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
#include "ShouldGrandfatherStatistics.h"
#endif
#include "WebCoreArgumentCoders.h"
#include "WebPageNetworkParameters.h"
#include "WebPageProxyIdentifier.h"
#if ENABLE(SERVICE_WORKER)
#include "WebPushMessage.h"
#endif
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
#include "WebResourceLoadStatisticsStore.h"
#endif
#include "WebsiteData.h"
#include "WebsiteDataFetchOption.h"
#include "WebsiteDataStoreParameters.h"
#include "WebsiteDataType.h"
#include <WebCore/CertificateInfo.h>
#include <WebCore/ClientOrigin.h>
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
#include <WebCore/CrossSiteNavigationDataTransfer.h>
#endif
#if USE(CURL)
#include <WebCore/CurlProxySettings.h>
#endif
#include <WebCore/HTTPCookieAcceptPolicy.h>
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
#include <WebCore/NetworkStorageSession.h>
#endif
#include <WebCore/PageIdentifier.h>
#include <WebCore/PrivateClickMeasurement.h>
#include <WebCore/ProcessIdentifier.h>
#include <WebCore/RegistrableDomain.h>
#include <WebCore/ResourceError.h>
#include <WebCore/ResourceRequest.h>
#include <WebCore/ResourceResponse.h>
#include <WebCore/SecurityOriginData.h>
#if USE(SOUP)
#include <WebCore/SoupNetworkProxySettings.h>
#endif
#include <WebCore/StoredCredentialsPolicy.h>
#include <optional>
#include <pal/SessionID.h>
#if (ENABLE(INTELLIGENT_TRACKING_PREVENTION) && ENABLE(APP_BOUND_DOMAINS))
#include <wtf/HashSet.h>
#endif
#include <wtf/OptionSet.h>
#include <wtf/Seconds.h>
#include <wtf/URLHash.h>
#include <wtf/Vector.h>
#include <wtf/WallTime.h>
#include <wtf/text/WTFString.h>
#include "NetworkResourceLoaderMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/ResourceRequest.h>
#include "ArgumentCoders.h"
#include "DataReference.h"
#include "NetworkSocketChannelMessages.h"
#include <wtf/text/WTFString.h>
#include "ArgumentCoders.h"
#include "DataReference.h"
#include "NetworkSocketStreamMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/CookieRequestHeaderFieldProxy.h>
#include <optional>
#if ENABLE(SERVICE_WORKER)
#include "FormDataReference.h"
#include "ServiceWorkerDownloadTaskMessages.h"
#include "SharedBufferCopy.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/ResourceError.h>
#endif
#if ENABLE(SERVICE_WORKER)
#include "FormDataReference.h"
#include "ServiceWorkerFetchTaskMessages.h"
#include "SharedBufferCopy.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/NetworkLoadMetrics.h>
#include <WebCore/ResourceError.h>
#include <WebCore/ResourceResponse.h>
#endif
#if ENABLE(SERVICE_WORKER)
#include "ArgumentCoders.h"
#include "WebCoreArgumentCoders.h"
#include "WebSWServerConnectionMessages.h"
#include <WebCore/ExceptionData.h>
#include <WebCore/MessageWithMessagePorts.h>
#include <WebCore/NavigationPreloadState.h>
#include <WebCore/ProcessQualified.h>
#include <WebCore/PushSubscriptionData.h>
#include <WebCore/PushSubscriptionIdentifier.h>
#include <WebCore/ScriptExecutionContextIdentifier.h>
#include <WebCore/SecurityOriginData.h>
#include <WebCore/ServiceWorkerClientData.h>
#include <WebCore/ServiceWorkerIdentifier.h>
#include <WebCore/ServiceWorkerJobData.h>
#include <WebCore/ServiceWorkerJobDataIdentifier.h>
#include <WebCore/ServiceWorkerRegistrationData.h>
#include <WebCore/ServiceWorkerRegistrationKey.h>
#include <WebCore/ServiceWorkerTypes.h>
#include <WebCore/WorkerFetchResult.h>
#include <optional>
#include <wtf/Expected.h>
#include <wtf/ObjectIdentifier.h>
#include <wtf/URLHash.h>
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(SERVICE_WORKER)
#include "ArgumentCoders.h"
#include "WebCoreArgumentCoders.h"
#include "WebSWServerToContextConnectionMessages.h"
#include <WebCore/ExceptionData.h>
#include <WebCore/MessageWithMessagePorts.h>
#include <WebCore/ProcessQualified.h>
#include <WebCore/ScriptExecutionContextIdentifier.h>
#include <WebCore/ServiceWorkerClientData.h>
#include <WebCore/ServiceWorkerClientQueryOptions.h>
#include <WebCore/ServiceWorkerContextData.h>
#include <WebCore/ServiceWorkerIdentifier.h>
#include <WebCore/ServiceWorkerJobDataIdentifier.h>
#include <optional>
#include <wtf/ObjectIdentifier.h>
#include <wtf/URLHash.h>
#include <wtf/text/WTFString.h>
#endif
#include "WebCoreArgumentCoders.h"
#include "WebSharedWorkerServerConnectionMessages.h"
#include <WebCore/SharedWorkerKey.h>
#include <WebCore/SharedWorkerObjectIdentifier.h>
#include <WebCore/TransferredMessagePort.h>
#include <WebCore/WorkerOptions.h>
#include "ArgumentCoders.h"
#include "WebCoreArgumentCoders.h"
#include "WebSharedWorkerServerToContextConnectionMessages.h"
#include <WebCore/SharedWorkerIdentifier.h>
#include <wtf/text/WTFString.h>
#include "ArgumentCoders.h"
#include "StorageAreaIdentifier.h"
#include "StorageAreaImplIdentifier.h"
#include "StorageManagerSetMessages.h"
#include "StorageNamespaceIdentifier.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/SecurityOriginData.h>
#include <optional>
#include <pal/SessionID.h>
#include <wtf/HashMap.h>
#include <wtf/text/WTFString.h>
#include "ArgumentCoders.h"
#include "CacheStorageEngineConnectionMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/CacheQueryOptions.h>
#include <WebCore/ClientOrigin.h>
#include <WebCore/DOMCacheEngine.h>
#include <WebCore/ResourceRequest.h>
#include <WebCore/RetrieveRecordsOptions.h>
#include <optional>
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>
#include "ArgumentCoders.h"
#include "FileSystemStorageError.h"
#include "NetworkStorageManagerMessages.h"
#include "SharedFileHandle.h"
#include "StorageAreaIdentifier.h"
#include "StorageAreaImplIdentifier.h"
#include "StorageAreaMapIdentifier.h"
#include "StorageNamespaceIdentifier.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/ClientOrigin.h>
#include <WebCore/FileSystemHandleIdentifier.h>
#include <WebCore/FileSystemSyncAccessHandleIdentifier.h>
#include <WebCore/IDBCursorInfo.h>
#include <WebCore/IDBGetAllRecordsData.h>
#include <WebCore/IDBGetRecordData.h>
#include <WebCore/IDBIndexInfo.h>
#include <WebCore/IDBIterateCursorData.h>
#include <WebCore/IDBKeyData.h>
#include <WebCore/IDBKeyRangeData.h>
#include <WebCore/IDBObjectStoreInfo.h>
#include <WebCore/IDBRequestData.h>
#include <WebCore/IDBResourceIdentifier.h>
#include <WebCore/IDBTransactionInfo.h>
#include <WebCore/IDBValue.h>
#include <WebCore/IndexedDB.h>
#include <WebCore/StorageType.h>
#include <optional>
#include <utility>
#include <wtf/Expected.h>
#include <wtf/HashMap.h>
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>
#if ENABLE(WEB_RTC)
#include "ArgumentCoders.h"
#include "MDNSRegisterIdentifier.h"
#include "NetworkMDNSRegisterMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/ProcessQualified.h>
#include <WebCore/ScriptExecutionContextIdentifier.h>
#include <wtf/ObjectIdentifier.h>
#include <wtf/text/WTFString.h>
#endif
#if USE(LIBWEBRTC)
#include "NetworkRTCMonitorMessages.h"
#endif
#if USE(LIBWEBRTC)
#include "ArgumentCoders.h"
#include "DataReference.h"
#include "LibWebRTCResolverIdentifier.h"
#include "NetworkRTCProviderMessages.h"
#include "RTCNetwork.h"
#include "RTCPacketOptions.h"
#include "WebCoreArgumentCoders.h"
#include "WebPageProxyIdentifier.h"
#include <WebCore/LibWebRTCSocketIdentifier.h>
#include <WebCore/RegistrableDomain.h>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(WEB_RTC)
#include "ArgumentCoders.h"
#include "DataReference.h"
#include "RTCDataChannelRemoteManagerProxyMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/RTCDataChannelIdentifier.h>
#include <WebCore/RTCDataChannelState.h>
#include <WebCore/RTCErrorDetailType.h>
#include <wtf/text/WTFString.h>
#endif
#include "AuxiliaryProcessMessages.h"
#if ENABLE(IPC_TESTING_API)
#include "ArgumentCoders.h"
#include "IPCTesterMessages.h"
#include <wtf/text/WTFString.h>
#endif
#include "ArgumentCoders.h"
#include "UserData.h"
#include "WebConnectionMessages.h"
#include <wtf/text/WTFString.h>
#include "AuthenticationChallengeDisposition.h"
#include "AuthenticationManagerMessages.h"
#include "IdentifierTypes.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/Credential.h>
#include "ArgumentCoders.h"
#include "NotificationManagerMessageHandlerMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/NotificationData.h>
#include <wtf/UUID.h>
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>
#include "ArgumentCoders.h"
#include "CallbackID.h"
#include "DrawingAreaProxyMessages.h"
#include "LayerTreeContext.h"
#if USE(COORDINATED_GRAPHICS) || USE(TEXTURE_MAPPER)
#include "UpdateInfo.h"
#endif
#include <wtf/Vector.h>
#if ENABLE(MEDIA_SESSION_COORDINATOR)
#include "ArgumentCoders.h"
#include "RemoteMediaSessionCoordinatorProxyMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/ExceptionData.h>
#include <WebCore/MediaPositionState.h>
#include <WebCore/MediaSessionPlaybackState.h>
#include <WebCore/MediaSessionReadyState.h>
#include <optional>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(MEDIA_STREAM)
#if PLATFORM(COCOA)
#include "SharedMemory.h"
#endif
#include "SpeechRecognitionRemoteRealtimeMediaSourceManagerMessages.h"
#include "WebCoreArgumentCoders.h"
#if PLATFORM(COCOA)
#include <WebCore/CAAudioStreamDescription.h>
#endif
#include <WebCore/RealtimeMediaSourceIdentifier.h>
#include <wtf/MediaTime.h>
#endif
#include "ArgumentCoders.h"
#include "SpeechRecognitionServerMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/ClientOrigin.h>
#include <WebCore/FrameIdentifier.h>
#include <WebCore/SpeechRecognitionConnectionClientIdentifier.h>
#include <wtf/text/WTFString.h>
#include "VisitedLinkStoreMessages.h"
#include "WebCoreArgumentCoders.h"
#include "WebPageProxyIdentifier.h"
#include <WebCore/SharedStringHash.h>
#include "WebCookieManagerProxyMessages.h"
#include <pal/SessionID.h>
#if ENABLE(FULLSCREEN_API)
#include "WebCoreArgumentCoders.h"
#include "WebFullScreenManagerProxyMessages.h"
#include <WebCore/IntRect.h>
#endif
#include "ArgumentCoders.h"
#include "WebCoreArgumentCoders.h"
#include "WebGeolocationManagerProxyMessages.h"
#include "WebPageProxyIdentifier.h"
#include <WebCore/RegistrableDomain.h>
#include <wtf/text/WTFString.h>
#include "ArgumentCoders.h"
#include "WebCoreArgumentCoders.h"
#include "WebLockRegistryProxyMessages.h"
#include <WebCore/ClientOrigin.h>
#include <WebCore/ProcessQualified.h>
#include <WebCore/ScriptExecutionContextIdentifier.h>
#include <WebCore/WebLockIdentifier.h>
#include <WebCore/WebLockManagerSnapshot.h>
#include <WebCore/WebLockMode.h>
#include <wtf/ObjectIdentifier.h>
#include <wtf/text/WTFString.h>
#include "ArgumentCoders.h"
#include "CallbackID.h"
#if ENABLE(CONTEXT_MENUS)
#include "ContextMenuContextData.h"
#endif
#if ENABLE(DATA_DETECTION)
#include "DataDetectionResult.h"
#endif
#include "DataReference.h"
#include "EditorState.h"
#if PLATFORM(IOS_FAMILY)
#include "FocusedElementInformation.h"
#endif
#include "FormDataReference.h"
#include "FrameInfoData.h"
#include "GeolocationIdentifier.h"
#include "IdentifierTypes.h"
#if PLATFORM(GTK) || PLATFORM(WPE)
#include "InputMethodState.h"
#endif
#if PLATFORM(IOS_FAMILY)
#include "InteractionInformationAtPosition.h"
#endif
#if HAVE(VISIBILITY_PROPAGATION_VIEW)
#include "LayerHostingContext.h"
#endif
#if ENABLE(ARKIT_INLINE_PREVIEW) || ENABLE(ARKIT_INLINE_PREVIEW_IOS)
#include "ModelIdentifier.h"
#endif
#include "NavigationActionData.h"
#if ENABLE(PDFKIT_PLUGIN)
#include "PDFContextMenu.h"
#endif
#if ENABLE(PDFKIT_PLUGIN) || ENABLE(UI_PROCESS_PDF_HUD)
#include "PDFPluginIdentifier.h"
#endif
#include "PlatformPopupMenuData.h"
#include "PolicyDecision.h"
#include "SessionState.h"
#include "ShareableBitmap.h"
#if USE(QUICK_LOOK)
#include "ShareableResource.h"
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
#include "SharedBufferCopy.h"
#endif
#if PLATFORM(COCOA) && ENABLE(DRAG_SUPPORT) || PLATFORM(IOS_FAMILY)
#include "SharedMemory.h"
#endif
#if HAVE(TOUCH_BAR)
#include "TouchBarMenuData.h"
#endif
#if HAVE(TOUCH_BAR)
#include "TouchBarMenuItemData.h"
#endif
#include "URLSchemeTaskParameters.h"
#include "UndoOrRedo.h"
#include "UserData.h"
#if PLATFORM(GTK) || PLATFORM(WPE)
#include "UserMessage.h"
#endif
#if PLATFORM(IOS_FAMILY)
#include "WebAutocorrectionContext.h"
#endif
#include "WebBackForwardListCounts.h"
#include "WebCoreArgumentCoders.h"
#include "WebHitTestResultData.h"
#include "WebNavigationDataStore.h"
#include "WebPageCreationParameters.h"
#include "WebPageProxyIdentifier.h"
#include "WebPageProxyMessages.h"
#include "WebPopupItem.h"
#if ENABLE(SPEECH_SYNTHESIS)
#include "WebSpeechSynthesisVoice.h"
#endif
#include "WebURLSchemeHandlerIdentifier.h"
#include <JavaScriptCore/InspectorTarget.h>
#if PLATFORM(IOS_FAMILY)
#include <WebCore/ActivityState.h>
#endif
#if ENABLE(APP_HIGHLIGHTS)
#include <WebCore/AppHighlight.h>
#endif
#if ENABLE(APPLE_PAY_AMS_UI)
#include <WebCore/ApplePayAMSUIRequest.h>
#endif
#if PLATFORM(IOS_FAMILY)
#include <WebCore/AudioSession.h>
#endif
#include <WebCore/AutoplayEvent.h>
#include <WebCore/BackForwardItemIdentifier.h>
#if ENABLE(MEDIA_STREAM)
#include <WebCore/CaptureDevice.h>
#endif
#include <WebCore/CertificateInfo.h>
#include <WebCore/ClientOrigin.h>
#include <WebCore/Color.h>
#include <WebCore/ContactInfo.h>
#include <WebCore/ContactsRequestData.h>
#if ENABLE(CONTENT_FILTERING)
#include <WebCore/ContentFilterUnblockHandler.h>
#endif
#if ENABLE(CONTENT_EXTENSIONS)
#include <WebCore/ContentRuleListResults.h>
#endif
#include <WebCore/CookieConsentDecisionResult.h>
#include <WebCore/Cursor.h>
#include <WebCore/DOMPasteAccess.h>
#if ENABLE(DATA_DETECTION)
#include <WebCore/DataDetectorElementInfo.h>
#endif
#if ENABLE(DATALIST_ELEMENT)
#include <WebCore/DataListSuggestionInformation.h>
#endif
#if ENABLE(DATE_AND_TIME_INPUT_TYPES)
#include <WebCore/DateTimeChooserParameters.h>
#endif
#if ENABLE(DEVICE_ORIENTATION)
#include <WebCore/DeviceOrientationOrMotionPermissionState.h>
#endif
#include <WebCore/DiagnosticLoggingClient.h>
#include <WebCore/DiagnosticLoggingDomain.h>
#if USE(DICTATION_ALTERNATIVES)
#include <WebCore/DictationContext.h>
#endif
#if PLATFORM(COCOA)
#include <WebCore/DictionaryPopupInfo.h>
#endif
#include <WebCore/DocumentLoader.h>
#if ENABLE(DRAG_SUPPORT) || PLATFORM(GTK) && ENABLE(DRAG_SUPPORT)
#include <WebCore/DragActions.h>
#endif
#if PLATFORM(COCOA) && ENABLE(DRAG_SUPPORT)
#include <WebCore/DragItem.h>
#endif
#include <WebCore/FileChooser.h>
#include <WebCore/FloatPoint.h>
#if PLATFORM(IOS_FAMILY)
#include <WebCore/FloatQuad.h>
#endif
#include <WebCore/FloatRect.h>
#include <WebCore/FloatSize.h>
#include <WebCore/FrameIdentifier.h>
#include <WebCore/FrameLoaderTypes.h>
#include <WebCore/GlobalWindowIdentifier.h>
#if ENABLE(ARKIT_INLINE_PREVIEW)
#include <WebCore/HTMLModelElementCamera.h>
#endif
#if PLATFORM(IOS_FAMILY)
#include <WebCore/InputMode.h>
#endif
#if PLATFORM(IOS_FAMILY)
#include <WebCore/InspectorOverlay.h>
#endif
#include <WebCore/IntPoint.h>
#include <WebCore/IntRect.h>
#include <WebCore/IntSize.h>
#include <WebCore/LayoutMilestone.h>
#if ENABLE(ARKIT_INLINE_PREVIEW_MAC)
#include <WebCore/LayoutPoint.h>
#endif
#include <WebCore/LinkIcon.h>
#if ENABLE(MEDIA_CONTROLS_CONTEXT_MENUS) && USE(UICONTEXTMENU)
#include <WebCore/MediaControlsContextMenuItem.h>
#endif
#if ENABLE(ENCRYPTED_MEDIA)
#include <WebCore/MediaKeySystemRequestIdentifier.h>
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
#include <WebCore/MediaPlaybackTargetContext.h>
#endif
#include <WebCore/MediaProducer.h>
#if ENABLE(MEDIA_USAGE)
#include <WebCore/MediaSessionIdentifier.h>
#endif
#if ENABLE(MEDIA_STREAM)
#include <WebCore/MediaStreamRequest.h>
#endif
#if ENABLE(MEDIA_USAGE)
#include <WebCore/MediaUsageInfo.h>
#endif
#if ENABLE(WEB_AUTHN)
#include <WebCore/MockWebAuthenticationConfiguration.h>
#endif
#include <WebCore/ModalContainerTypes.h>
#include <WebCore/PageIdentifier.h>
#include <WebCore/PermissionDescriptor.h>
#include <WebCore/PermissionState.h>
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
#include <WebCore/PlaybackTargetClientContextIdentifier.h>
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
#include <WebCore/PromisedAttachmentInfo.h>
#endif
#include <WebCore/RectEdges.h>
#include <WebCore/ResourceError.h>
#include <WebCore/ResourceLoaderIdentifier.h>
#include <WebCore/ResourceRequest.h>
#include <WebCore/ResourceResponse.h>
#include <WebCore/SearchPopupMenu.h>
#if ENABLE(ENCRYPTED_MEDIA) || ENABLE(MEDIA_STREAM)
#include <WebCore/SecurityOriginData.h>
#endif
#if PLATFORM(GTK) && ENABLE(DRAG_SUPPORT)
#include <WebCore/SelectionData.h>
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
#include <WebCore/SerializedAttachmentData.h>
#endif
#include <WebCore/ShareData.h>
#include <WebCore/TextCheckerClient.h>
#include <WebCore/TextChecking.h>
#include <WebCore/TextIndicator.h>
#include <WebCore/TextManipulationController.h>
#if ENABLE(IMAGE_ANALYSIS)
#include <WebCore/TextRecognitionResult.h>
#endif
#if HAVE(TRANSLATION_UI_SERVICES) && ENABLE(CONTEXT_MENUS)
#include <WebCore/TranslationContextMenuInfo.h>
#endif
#if ENABLE(MEDIA_STREAM)
#include <WebCore/UserMediaRequestIdentifier.h>
#endif
#include <WebCore/ViewportArguments.h>
#include <WebCore/WindowFeatures.h>
#include <optional>
#include <utility>
#if ENABLE(ARKIT_INLINE_PREVIEW) || ENABLE(ARKIT_INLINE_PREVIEW_MAC)
#include <wtf/Expected.h>
#endif
#if ENABLE(ARKIT_INLINE_PREVIEW_MAC)
#include <wtf/MachSendRight.h>
#endif
#include <wtf/MonotonicTime.h>
#include <wtf/OptionSet.h>
#if ENABLE(ARKIT_INLINE_PREVIEW)
#include <wtf/Seconds.h>
#endif
#include <wtf/URLHash.h>
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>
#include "ArgumentCoders.h"
#if PLATFORM(COCOA)
#include "SandboxExtension.h"
#endif
#if PLATFORM(GTK)
#include "SharedBufferCopy.h"
#endif
#include "SharedMemory.h"
#include "WebCoreArgumentCoders.h"
#include "WebPasteboardProxyMessages.h"
#if PLATFORM(COCOA)
#include <WebCore/Color.h>
#endif
#include <WebCore/PageIdentifier.h>
#include <WebCore/Pasteboard.h>
#include <WebCore/PasteboardItemInfo.h>
#if PLATFORM(GTK)
#include <WebCore/SelectionData.h>
#endif
#include <optional>
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>
#include "ArgumentCoders.h"
#include "UserData.h"
#include "WebProcessPoolMessages.h"
#include <wtf/Seconds.h>
#include <wtf/text/WTFString.h>
#include "ArgumentCoders.h"
#if HAVE(CVDISPLAYLINK)
#include "DisplayLinkObserverID.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "GPUProcessConnectionInfo.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "GPUProcessConnectionParameters.h"
#endif
#include "NetworkProcessConnectionInfo.h"
#include "SessionState.h"
#if PLATFORM(GTK) || PLATFORM(WPE)
#include "UserMessage.h"
#endif
#if ENABLE(WEB_AUTHN)
#include "WebAuthnProcessConnectionInfo.h"
#endif
#include "WebCoreArgumentCoders.h"
#include "WebProcessProxyMessages.h"
#if HAVE(MEDIA_ACCESSIBILITY_FRAMEWORK)
#include <WebCore/CaptionUserPreferences.h>
#endif
#include <WebCore/FrameIdentifier.h>
#include <WebCore/PageIdentifier.h>
#include <WebCore/PrewarmInformation.h>
#include <WebCore/RegistrableDomain.h>
#include <WebCore/SleepDisablerIdentifier.h>
#if PLATFORM(COCOA)
#include <wtf/Vector.h>
#endif
#include <wtf/text/WTFString.h>
#include "ArgumentCoders.h"
#include "ShareableBitmap.h"
#include "WebAutomationSessionMessages.h"
#include <wtf/text/WTFString.h>
#include "ArgumentCoders.h"
#include "DataReference.h"
#include "DownloadID.h"
#include "DownloadProxyMessages.h"
#include "IdentifierTypes.h"
#include "SandboxExtension.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/AuthenticationChallenge.h>
#include <WebCore/ResourceError.h>
#include <WebCore/ResourceRequest.h>
#include <WebCore/ResourceResponse.h>
#include <wtf/text/WTFString.h>
#if ENABLE(GPU_PROCESS)
#include "GPUProcessProxyMessages.h"
#if HAVE(VISIBILITY_PROPAGATION_VIEW)
#include "LayerHostingContext.h"
#endif
#include "WebCoreArgumentCoders.h"
#if HAVE(VISIBILITY_PROPAGATION_VIEW)
#include "WebPageProxyIdentifier.h"
#endif
#if HAVE(VISIBILITY_PROPAGATION_VIEW)
#include <WebCore/PageIdentifier.h>
#endif
#include <WebCore/ProcessIdentifier.h>
#endif
#include "ArgumentCoders.h"
#include "RemoteWebInspectorUIProxyMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/CertificateInfo.h>
#include <WebCore/FloatRect.h>
#include <WebCore/InspectorFrontendClient.h>
#include <wtf/text/WTFString.h>
#include "ArgumentCoders.h"
#include "Attachment.h"
#include "WebCoreArgumentCoders.h"
#include "WebInspectorUIProxyMessages.h"
#include <WebCore/CertificateInfo.h>
#include <WebCore/FloatRect.h>
#include <WebCore/InspectorClient.h>
#include <WebCore/InspectorFrontendClient.h>
#include <optional>
#include <wtf/text/WTFString.h>
#include "ArgumentCoders.h"
#include "FormDataReference.h"
#include "IdentifierTypes.h"
#include "NetworkProcessProxyMessages.h"
#include "NetworkResourceLoadIdentifier.h"
#include "QuotaIncreaseRequestIdentifier.h"
#include "RemoteWorkerType.h"
#include "ResourceLoadInfo.h"
#include "SandboxExtension.h"
#if ENABLE(CONTENT_EXTENSIONS)
#include "UserContentControllerIdentifier.h"
#endif
#include "WebCoreArgumentCoders.h"
#include "WebPageProxyIdentifier.h"
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
#include "WebsiteDataFetchOption.h"
#endif
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
#include "WebsiteDataType.h"
#endif
#include <WebCore/AuthenticationChallenge.h>
#include <WebCore/ClientOrigin.h>
#include <WebCore/DiagnosticLoggingClient.h>
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
#include <WebCore/FrameIdentifier.h>
#endif
#include <WebCore/FrameLoaderTypes.h>
#include <WebCore/ProcessIdentifier.h>
#if ENABLE(SERVICE_WORKER)
#include <WebCore/ProcessQualified.h>
#endif
#include <WebCore/RegistrableDomain.h>
#include <WebCore/ResourceError.h>
#include <WebCore/ResourceRequest.h>
#include <WebCore/ResourceResponse.h>
#if ENABLE(SERVICE_WORKER)
#include <WebCore/ScriptExecutionContextIdentifier.h>
#endif
#include <WebCore/SecurityOriginData.h>
#include <optional>
#include <pal/SessionID.h>
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
#include <wtf/HashMap.h>
#endif
#if ENABLE(APP_BOUND_DOMAINS) || ENABLE(INTELLIGENT_TRACKING_PREVENTION)
#include <wtf/HashSet.h>
#endif
#if ENABLE(SERVICE_WORKER)
#include <wtf/ObjectIdentifier.h>
#endif
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
#include <wtf/OptionSet.h>
#endif
#include <wtf/URLHash.h>
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
#include <wtf/Vector.h>
#endif
#include <wtf/text/WTFString.h>
#include "ArgumentCoders.h"
#include "DataReference.h"
#include "FrameInfoData.h"
#include "WebPageProxyIdentifier.h"
#include "WebUserContentControllerProxyMessages.h"
#include <wtf/text/WTFString.h>
#if ENABLE(WEBXR)
#include "ArgumentCoders.h"
#include "PlatformXRSystemMessages.h"
#include "WebCoreArgumentCoders.h"
#include "XRDeviceInfo.h"
#include <WebCore/PlatformXR.h>
#include <WebCore/SecurityOriginData.h>
#include <optional>
#include <wtf/Vector.h>
#endif
#if PLATFORM(COCOA)
#include "AccessibilityPreferences.h"
#endif
#include "ArgumentCoders.h"
#include "CacheModel.h"
#include "DataReference.h"
#if ENABLE(GAMEPAD)
#include "GamepadData.h"
#endif
#include "IdentifierTypes.h"
#if (ENABLE(MEDIA_STREAM) && ENABLE(SANDBOX_EXTENSIONS))
#include "MediaDeviceSandboxExtensions.h"
#endif
#include "RemoteWorkerInitializationData.h"
#include "SandboxExtension.h"
#if PLATFORM(COCOA)
#include "SharedBufferCopy.h"
#endif
#include "TextCheckerState.h"
#include "UserData.h"
#if PLATFORM(GTK) || PLATFORM(WPE)
#include "UserMessage.h"
#endif
#include "WebCoreArgumentCoders.h"
#include "WebPageCreationParameters.h"
#include "WebPageProxyIdentifier.h"
#include "WebPreferencesStore.h"
#include "WebProcessCreationParameters.h"
#include "WebProcessDataStoreParameters.h"
#include "WebProcessMessages.h"
#include "WebsiteData.h"
#include "WebsiteDataType.h"
#include <WebCore/BackForwardItemIdentifier.h>
#if HAVE(MEDIA_ACCESSIBILITY_FRAMEWORK)
#include <WebCore/CaptionUserPreferences.h>
#endif
#if HAVE(CVDISPLAYLINK)
#include <WebCore/DisplayUpdate.h>
#endif
#if ENABLE(GAMEPAD)
#include <WebCore/GamepadProviderClient.h>
#endif
#if ENABLE(MEDIA_STREAM)
#include <WebCore/MockMediaDevice.h>
#endif
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
#include <WebCore/NetworkStorageSession.h>
#endif
#include <WebCore/PageIdentifier.h>
#include <WebCore/PrewarmInformation.h>
#if ENABLE(SERVICE_WORKER)
#include <WebCore/ProcessQualified.h>
#endif
#include <WebCore/RegistrableDomain.h>
#if PLATFORM(COCOA)
#include <WebCore/ScreenProperties.h>
#endif
#if ENABLE(SERVICE_WORKER)
#include <WebCore/ScriptExecutionContextIdentifier.h>
#endif
#include <WebCore/SecurityOriginData.h>
#if (PLATFORM(COCOA) && ENABLE(CFPREFS_DIRECT_MODE)) || ENABLE(SERVICE_WORKER)
#include <optional>
#endif
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
#include <wtf/HashMap.h>
#endif
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
#include <wtf/HashSet.h>
#endif
#if ENABLE(SERVICE_WORKER)
#include <wtf/ObjectIdentifier.h>
#endif
#include <wtf/OptionSet.h>
#include <wtf/Vector.h>
#include <wtf/WallTime.h>
#include <wtf/text/WTFString.h>
#include "ArgumentCoders.h"
#include "CoordinateSystem.h"
#include "WebAutomationSessionProxyMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/Cookie.h>
#include <WebCore/FrameIdentifier.h>
#include <WebCore/IntPoint.h>
#include <WebCore/IntRect.h>
#include <WebCore/PageIdentifier.h>
#include <optional>
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>
#include "ArgumentCoders.h"
#include "WebCoreArgumentCoders.h"
#include "WebIDBConnectionToServerMessages.h"
#include "WebIDBResult.h"
#include <WebCore/IDBDatabaseNameAndVersion.h>
#include <WebCore/IDBError.h>
#include <WebCore/IDBResourceIdentifier.h>
#include <WebCore/IDBResultData.h>
#include <wtf/Vector.h>
#if ENABLE(FULLSCREEN_API)
#include "ArgumentCoders.h"
#include "WebFullScreenManagerMessages.h"
#include <WebCore/RectEdges.h>
#include <wtf/Seconds.h>
#endif
#if ENABLE(GPU_PROCESS)
#if ENABLE(MEDIA_STREAM) && PLATFORM(COCOA)
#include "AudioMediaStreamTrackRendererInternalUnitIdentifier.h"
#endif
#if ENABLE(ROUTING_ARBITRATION)
#include "AudioSessionRoutingArbitratorProxy.h"
#endif
#include "GPUProcessConnectionMessages.h"
#include "WebCoreArgumentCoders.h"
#if ENABLE(ROUTING_ARBITRATION)
#include <WebCore/AudioSession.h>
#endif
#include <WebCore/PlatformMediaSession.h>
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(WEBGL)
#include "ArgumentCoders.h"
#include "IPCSemaphore.h"
#include "RemoteGraphicsContextGLProxyMessages.h"
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "IPCSemaphore.h"
#include "ImageBufferBackendHandle.h"
#include "RemoteRenderingBackendProxyMessages.h"
#include "RenderingUpdateID.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/GraphicsContextFlushIdentifier.h>
#include <WebCore/RenderingResourceIdentifier.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "IPCSemaphore.h"
#include "RemoteGPUProxyMessages.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "RemoteAudioHardwareListenerMessages.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#if PLATFORM(COCOA)
#include "ArgumentCodersCF.h"
#endif
#include "AudioTrackPrivateRemoteConfiguration.h"
#include "DataReference.h"
#include "MediaPlayerPrivateRemoteMessages.h"
#include "RemoteMediaPlayerState.h"
#include "RemoteMediaResourceIdentifier.h"
#include "TextTrackPrivateRemoteConfiguration.h"
#include "TrackPrivateRemoteIdentifier.h"
#include "VideoTrackPrivateRemoteConfiguration.h"
#include "WebCoreArgumentCoders.h"
#if PLATFORM(COCOA)
#include <WebCore/CVUtilities.h>
#endif
#if PLATFORM(IOS_FAMILY)
#include <WebCore/Cookie.h>
#endif
#include <WebCore/FloatSize.h>
#include <WebCore/ISOVTTCue.h>
#include <WebCore/InbandGenericCue.h>
#include <WebCore/PlatformMediaResourceLoader.h>
#include <WebCore/ResourceError.h>
#include <WebCore/ResourceRequest.h>
#if ENABLE(DATACUE_VALUE)
#include <WebCore/SerializedPlatformDataCueValue.h>
#endif
#if PLATFORM(COCOA)
#include <WebCore/VideoFrameMetadata.h>
#endif
#include <wtf/Expected.h>
#include <wtf/MediaTime.h>
#include <wtf/MonotonicTime.h>
#if PLATFORM(COCOA)
#include <wtf/RetainPtr.h>
#endif
#include <wtf/Seconds.h>
#include <wtf/URLHash.h>
#if PLATFORM(IOS_FAMILY)
#include <wtf/Vector.h>
#endif
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)
#include "MediaSourcePrivateRemoteMessages.h"
#include <wtf/MediaTime.h>
#endif
#if ENABLE(GPU_PROCESS) && USE(AUDIO_SESSION)
#include "RemoteAudioSessionConfiguration.h"
#include "RemoteAudioSessionMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/AudioSession.h>
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS)
#include "RemoteAudioSourceProviderManagerMessages.h"
#include "SharedMemory.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/CAAudioStreamDescription.h>
#include <WebCore/MediaPlayerIdentifier.h>
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
#include "ArgumentCoders.h"
#include "RemoteCDMInstanceMessages.h"
#include "SharedBufferCopy.h"
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
#include "ArgumentCoders.h"
#include "RemoteCDMInstanceSessionMessages.h"
#include "SharedBufferCopy.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/CDMInstanceSession.h>
#include <WebCore/CDMMessageType.h>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(LEGACY_ENCRYPTED_MEDIA)
#include "ArgumentCoders.h"
#include "RemoteLegacyCDMSessionMessages.h"
#include "SharedBufferCopy.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/LegacyCDMSession.h>
#include <optional>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(GPU_PROCESS)
#include "RemoteRemoteCommandListenerMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/PlatformMediaSession.h>
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)
#include "InitializationSegmentInfo.h"
#include "SourceBufferPrivateRemoteMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/PlatformTimeRanges.h>
#include <WebCore/SourceBufferPrivateClient.h>
#include <wtf/MediaTime.h>
#endif
#if USE(LIBWEBRTC) && PLATFORM(COCOA) && ENABLE(GPU_PROCESS)
#include "ArgumentCoders.h"
#include "DataReference.h"
#include "LibWebRTCCodecsMessages.h"
#include "RTCDecoderIdentifier.h"
#include "RTCEncoderIdentifier.h"
#include "RemoteVideoFrameIdentifier.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/LibWebRTCEnumTraits.h>
#include <WebCore/RemoteVideoSample.h>
#include <optional>
#include <webrtc/sdk/WebKit/WebKitEncoder.h>
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(VIDEO)
#include "IPCSemaphore.h"
#include "RemoteVideoFrameIdentifier.h"
#include "RemoteVideoFrameObjectHeapProxyProcessorMessages.h"
#include "SharedMemory.h"
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
#include "SampleBufferDisplayLayerMessages.h"
#endif
#include "ArgumentCoders.h"
#include "WebCoreArgumentCoders.h"
#include "WebGeolocationManagerMessages.h"
#include <WebCore/GeolocationPositionData.h>
#include <WebCore/RegistrableDomain.h>
#include <wtf/text/WTFString.h>
#include "ArgumentCoders.h"
#include "DebuggableInfoData.h"
#include "RemoteWebInspectorUIMessages.h"
#include <wtf/text/WTFString.h>
#include "Attachment.h"
#include "WebCoreArgumentCoders.h"
#include "WebInspectorMessages.h"
#include <WebCore/FrameIdentifier.h>
#include "WebInspectorInterruptDispatcherMessages.h"
#include "ArgumentCoders.h"
#include "DebuggableInfoData.h"
#include "WebInspectorUIMessages.h"
#include "WebPageProxyIdentifier.h"
#include <wtf/text/WTFString.h>
#if ENABLE(MEDIA_SESSION_COORDINATOR)
#include "ArgumentCoders.h"
#include "RemoteMediaSessionCoordinatorMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/MediaSessionCoordinatorState.h>
#include <optional>
#include <wtf/MonotonicTime.h>
#include <wtf/text/WTFString.h>
#endif
#if USE(LIBWEBRTC)
#include "DataReference.h"
#include "LibWebRTCNetworkMessages.h"
#include "RTCNetwork.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/LibWebRTCSocketIdentifier.h>
#endif
#if ENABLE(WEB_RTC)
#include "ArgumentCoders.h"
#include "DataReference.h"
#include "RTCDataChannelRemoteManagerMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/RTCDataChannelIdentifier.h>
#include <WebCore/RTCDataChannelState.h>
#include <WebCore/RTCErrorDetailType.h>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(WEB_RTC)
#include "ArgumentCoders.h"
#include "MDNSRegisterIdentifier.h"
#include "WebCoreArgumentCoders.h"
#include "WebMDNSRegisterMessages.h"
#include <WebCore/MDNSRegisterError.h>
#include <optional>
#include <wtf/text/WTFString.h>
#endif
#if USE(LIBWEBRTC)
#include "ArgumentCoders.h"
#include "RTCNetwork.h"
#include "WebRTCMonitorMessages.h"
#include <wtf/Vector.h>
#endif
#if USE(LIBWEBRTC)
#include "ArgumentCoders.h"
#include "RTCNetwork.h"
#include "WebRTCResolverMessages.h"
#include <wtf/Vector.h>
#endif
#include "ArgumentCoders.h"
#include "NetworkProcessConnectionMessages.h"
#if ENABLE(SHAREABLE_RESOURCE)
#include "ShareableResource.h"
#endif
#include "WebCoreArgumentCoders.h"
#include <JavaScriptCore/ConsoleTypes.h>
#if HAVE(COOKIE_CHANGE_LISTENER_API)
#include <WebCore/Cookie.h>
#endif
#include <WebCore/HTTPCookieAcceptPolicy.h>
#include <WebCore/MessagePortChannelProvider.h>
#include <WebCore/MessagePortIdentifier.h>
#if ENABLE(WEB_RTC)
#include <WebCore/RTCDataChannelIdentifier.h>
#endif
#include <WebCore/ResourceError.h>
#include <WebCore/ResourceLoaderIdentifier.h>
#if ENABLE(SHAREABLE_RESOURCE)
#include <WebCore/ResourceRequest.h>
#endif
#include <WebCore/ResourceResponse.h>
#if ENABLE(WEB_RTC)
#include <optional>
#endif
#if HAVE(COOKIE_CHANGE_LISTENER_API)
#include <wtf/Vector.h>
#endif
#include <wtf/text/WTFString.h>
#if ENABLE(CONTENT_FILTERING_IN_NETWORKING_PROCESS)
#include "ArgumentCoders.h"
#endif
#include "FormDataReference.h"
#include "PrivateRelayed.h"
#if ENABLE(SHAREABLE_RESOURCE)
#include "ShareableResource.h"
#endif
#include "SharedBufferCopy.h"
#include "WebCoreArgumentCoders.h"
#include "WebResourceLoaderMessages.h"
#if ENABLE(CONTENT_FILTERING_IN_NETWORKING_PROCESS)
#include <WebCore/ContentFilterUnblockHandler.h>
#endif
#include <WebCore/NetworkLoadMetrics.h>
#include <WebCore/ResourceError.h>
#include <WebCore/ResourceRequest.h>
#include <WebCore/ResourceResponse.h>
#if ENABLE(CONTENT_FILTERING_IN_NETWORKING_PROCESS)
#include <WebCore/SubstituteData.h>
#endif
#if ENABLE(CONTENT_FILTERING_IN_NETWORKING_PROCESS)
#include <wtf/URLHash.h>
#endif
#if ENABLE(CONTENT_FILTERING_IN_NETWORKING_PROCESS)
#include <wtf/text/WTFString.h>
#endif
#include "ArgumentCoders.h"
#include "DataReference.h"
#include "WebCoreArgumentCoders.h"
#include "WebSocketChannelMessages.h"
#include <WebCore/ResourceRequest.h>
#include <WebCore/ResourceResponse.h>
#include <wtf/text/WTFString.h>
#include "DataReference.h"
#include "WebCoreArgumentCoders.h"
#include "WebSocketStreamMessages.h"
#include <WebCore/SocketStreamError.h>
#include "ArgumentCoders.h"
#include "WebNotificationManagerMessages.h"
#include <wtf/UUID.h>
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>
#if ENABLE(MEDIA_STREAM)
#if ENABLE(SANDBOX_EXTENSIONS)
#include "SandboxExtension.h"
#endif
#include "SpeechRecognitionRealtimeMediaSourceManagerMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/CaptureDevice.h>
#include <WebCore/RealtimeMediaSourceIdentifier.h>
#endif
#include "ArgumentCoders.h"
#include "WebCoreArgumentCoders.h"
#include "WebPreferencesStore.h"
#include "WebSharedWorkerContextManagerConnectionMessages.h"
#include <WebCore/ClientOrigin.h>
#include <WebCore/SharedWorkerIdentifier.h>
#include <WebCore/TransferredMessagePort.h>
#include <WebCore/WorkerFetchResult.h>
#include <WebCore/WorkerOptions.h>
#include <wtf/text/WTFString.h>
#include "ArgumentCoders.h"
#include "WebCoreArgumentCoders.h"
#include "WebSharedWorkerObjectConnectionMessages.h"
#include <WebCore/ResourceError.h>
#include <WebCore/SharedWorkerObjectIdentifier.h>
#include <WebCore/WorkerFetchResult.h>
#include <WebCore/WorkerOptions.h>
#include <wtf/URLHash.h>
#include <wtf/text/WTFString.h>
#if ENABLE(SERVICE_WORKER)
#include "ArgumentCoders.h"
#include "SharedMemory.h"
#include "WebCoreArgumentCoders.h"
#include "WebSWClientConnectionMessages.h"
#include <WebCore/ExceptionData.h>
#include <WebCore/FetchOptions.h>
#include <WebCore/MessageWithMessagePorts.h>
#include <WebCore/ProcessQualified.h>
#include <WebCore/ScriptExecutionContextIdentifier.h>
#include <WebCore/ServiceWorkerData.h>
#include <WebCore/ServiceWorkerIdentifier.h>
#include <WebCore/ServiceWorkerRegistrationData.h>
#include <WebCore/ServiceWorkerRegistrationKey.h>
#include <WebCore/ServiceWorkerTypes.h>
#include <WebCore/ServiceWorkerUpdateViaCache.h>
#include <optional>
#include <wtf/HashSet.h>
#include <wtf/ObjectIdentifier.h>
#include <wtf/WallTime.h>
#include <wtf/text/WTFString.h>
#endif
#if ENABLE(SERVICE_WORKER)
#include "ArgumentCoders.h"
#include "DataReference.h"
#include "FormDataReference.h"
#include "WebCoreArgumentCoders.h"
#include "WebPreferencesStore.h"
#include "WebSWContextManagerConnectionMessages.h"
#include <WebCore/FetchIdentifier.h>
#include <WebCore/FetchOptions.h>
#include <WebCore/MessageWithMessagePorts.h>
#include <WebCore/ResourceRequest.h>
#if ENABLE(SHAREABLE_RESOURCE) && PLATFORM(COCOA)
#include <WebCore/ScriptBuffer.h>
#endif
#include <WebCore/ServiceWorkerClientData.h>
#include <WebCore/ServiceWorkerContextData.h>
#include <WebCore/ServiceWorkerData.h>
#include <WebCore/ServiceWorkerIdentifier.h>
#include <WebCore/ServiceWorkerTypes.h>
#include <WebCore/WorkerThreadMode.h>
#include <optional>
#if ENABLE(SHAREABLE_RESOURCE) && PLATFORM(COCOA)
#include <wtf/HashMap.h>
#endif
#if ENABLE(SHAREABLE_RESOURCE) && PLATFORM(COCOA)
#include <wtf/URLHash.h>
#endif
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>
#endif
#include "ArgumentCoders.h"
#include "ContentWorldShared.h"
#include "InjectUserScriptImmediately.h"
#if ENABLE(CONTENT_EXTENSIONS)
#include "WebCompiledContentRuleListData.h"
#endif
#include "WebUserContentControllerDataTypes.h"
#include "WebUserContentControllerMessages.h"
#include <utility>
#if ENABLE(CONTENT_EXTENSIONS)
#include <wtf/URLHash.h>
#endif
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>
#include "RemoteWebLockRegistryMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/ProcessQualified.h>
#include <WebCore/ScriptExecutionContextIdentifier.h>
#include <WebCore/WebLockIdentifier.h>
#include <wtf/ObjectIdentifier.h>
#include "ArgumentCoders.h"
#include "WebBroadcastChannelRegistryMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/ClientOrigin.h>
#include <WebCore/MessageWithMessagePorts.h>
#include <wtf/text/WTFString.h>
#include "WebCoreArgumentCoders.h"
#include "WebFileSystemStorageConnectionMessages.h"
#include <WebCore/FileSystemSyncAccessHandleIdentifier.h>
#include "WebCoreArgumentCoders.h"
#include "WebSpeechRecognitionConnectionMessages.h"
#include <WebCore/SpeechRecognitionUpdate.h>
#if PLATFORM(COCOA)
#include "ArgumentCoders.h"
#endif
#if PLATFORM(COCOA)
#include "CallbackID.h"
#endif
#include "DrawingAreaMessages.h"
#if PLATFORM(COCOA) || PLATFORM(COCOA) || PLATFORM(GTK) || USE(COORDINATED_GRAPHICS) || USE(TEXTURE_MAPPER) || USE(GRAPHICS_LAYER_WC)
#include "WebCoreArgumentCoders.h"
#endif
#if PLATFORM(COCOA)
#include <WebCore/ColorSpace.h>
#endif
#if PLATFORM(COCOA) || PLATFORM(GTK)
#include <WebCore/FloatPoint.h>
#endif
#if PLATFORM(COCOA)
#include <WebCore/FloatRect.h>
#endif
#if PLATFORM(COCOA) || USE(COORDINATED_GRAPHICS) || USE(TEXTURE_MAPPER) || USE(GRAPHICS_LAYER_WC)
#include <WebCore/IntSize.h>
#endif
#if PLATFORM(COCOA)
#include <optional>
#endif
#if PLATFORM(COCOA)
#include <wtf/MachSendRight.h>
#endif
#if PLATFORM(COCOA)
#include <wtf/MonotonicTime.h>
#endif
#if PLATFORM(COCOA)
#include <wtf/text/WTFString.h>
#endif
#include "ArgumentCoders.h"
#include "EventDispatcherMessages.h"
#if ENABLE(MOMENTUM_EVENT_DISPATCHER)
#include "ScrollingAccelerationCurve.h"
#endif
#include "WebCoreArgumentCoders.h"
#if ENABLE(MAC_GESTURE_EVENTS)
#include "WebGestureEvent.h"
#endif
#if ENABLE(IOS_TOUCH_EVENTS)
#include "WebTouchEvent.h"
#endif
#include "WebWheelEvent.h"
#if HAVE(CVDISPLAYLINK)
#include <WebCore/DisplayUpdate.h>
#endif
#include <WebCore/PageIdentifier.h>
#include <WebCore/RectEdges.h>
#include <optional>
#include "ArgumentCoders.h"
#include "SharedMemory.h"
#include "VisitedLinkTableControllerMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/SharedStringHash.h>
#include <wtf/Vector.h>
#include "ArgumentCoders.h"
#include "CallbackID.h"
#include "ContentAsStringIncludesChildFrames.h"
#include "ContentWorldShared.h"
#if ENABLE(DATA_DETECTION)
#include "DataDetectionResult.h"
#endif
#include "DataReference.h"
#if PLATFORM(IOS_FAMILY)
#include "DocumentEditingContext.h"
#endif
#if !PLATFORM(GTK) && ENABLE(DRAG_SUPPORT) || PLATFORM(GTK) && ENABLE(DRAG_SUPPORT)
#include "DragControllerAction.h"
#endif
#include "DrawingAreaInfo.h"
#if PLATFORM(COCOA) || PLATFORM(MAC)
#include "EditingRange.h"
#endif
#if PLATFORM(IOS_FAMILY)
#include "EditorState.h"
#endif
#if PLATFORM(IOS_FAMILY)
#include "FocusedElementInformation.h"
#endif
#include "FormDataReference.h"
#if ENABLE(UI_PROCESS_PDF_HUD)
#include "FrameInfoData.h"
#endif
#include "FrameTreeNodeData.h"
#if ENABLE(GAMEPAD)
#include "GamepadData.h"
#endif
#if ENABLE(GEOLOCATION)
#include "GeolocationIdentifier.h"
#endif
#if PLATFORM(IOS_FAMILY)
#include "GestureTypes.h"
#endif
#include "IdentifierTypes.h"
#if PLATFORM(COCOA)
#include "InsertTextOptions.h"
#endif
#if PLATFORM(IOS_FAMILY)
#include "InteractionInformationAtPosition.h"
#endif
#if PLATFORM(IOS_FAMILY)
#include "InteractionInformationRequest.h"
#endif
#include "LayerTreeContext.h"
#include "LoadParameters.h"
#include "MediaPlaybackState.h"
#include "NetworkResourceLoadIdentifier.h"
#if ENABLE(UI_PROCESS_PDF_HUD)
#include "PDFPluginIdentifier.h"
#endif
#include "PolicyDecision.h"
#include "PrintInfo.h"
#if (PLATFORM(IOS_FAMILY) && ENABLE(REVEAL))
#include "RevealItem.h"
#endif
#include "SandboxExtension.h"
#include "SessionState.h"
#include "ShareableBitmap.h"
#include "SharedBufferCopy.h"
#if ENABLE(APP_HIGHLIGHTS) || ENABLE(IMAGE_ANALYSIS_ENHANCEMENTS) || PLATFORM(COCOA)
#include "SharedMemory.h"
#endif
#if PLATFORM(IOS_FAMILY)
#include "SyntheticEditingCommandType.h"
#endif
#if ENABLE(IMAGE_ANALYSIS)
#include "TextRecognitionUpdateResult.h"
#endif
#if PLATFORM(IOS_FAMILY)
#include "TransactionID.h"
#endif
#include "UserData.h"
#if PLATFORM(GTK) || PLATFORM(WPE)
#include "UserMessage.h"
#endif
#if PLATFORM(IOS_FAMILY)
#include "WebAutocorrectionData.h"
#endif
#if ENABLE(CONTEXT_MENUS)
#include "WebContextMenuItemData.h"
#endif
#include "WebCoreArgumentCoders.h"
#if PLATFORM(IOS_FAMILY)
#include "WebEvent.h"
#endif
#include "WebFindOptions.h"
#include "WebFoundTextRange.h"
#include "WebKeyboardEvent.h"
#include "WebMouseEvent.h"
#include "WebPageMessages.h"
#include "WebPageProxyIdentifier.h"
#include "WebPreferencesStore.h"
#if !ENABLE(IOS_TOUCH_EVENTS) && ENABLE(TOUCH_EVENTS) || ENABLE(IOS_TOUCH_EVENTS)
#include "WebTouchEvent.h"
#endif
#include "WebURLSchemeHandlerIdentifier.h"
#include "WebWheelEvent.h"
#include "WebsitePoliciesData.h"
#include <JavaScriptCore/ConsoleTypes.h>
#include <JavaScriptCore/InspectorFrontendChannel.h>
#include <WebCore/ActivityState.h>
#if ENABLE(APP_HIGHLIGHTS)
#include <WebCore/AppHighlight.h>
#endif
#if ENABLE(APPLICATION_MANIFEST)
#include <WebCore/ApplicationManifest.h>
#endif
#if PLATFORM(COCOA) || PLATFORM(MAC)
#include <WebCore/AttributedString.h>
#endif
#include <WebCore/BackForwardItemIdentifier.h>
#if ENABLE(MEDIA_STREAM)
#include <WebCore/CaptureDevice.h>
#endif
#include <WebCore/Color.h>
#if PLATFORM(COCOA)
#include <WebCore/CompositionHighlight.h>
#endif
#if PLATFORM(COCOA)
#include <WebCore/CompositionUnderline.h>
#endif
#if ENABLE(DATA_DETECTION)
#include <WebCore/DataDetectorType.h>
#endif
#if PLATFORM(COCOA)
#include <WebCore/DictationAlternative.h>
#endif
#if ENABLE(DRAG_SUPPORT) || PLATFORM(GTK) && ENABLE(DRAG_SUPPORT) || PLATFORM(IOS_FAMILY) && ENABLE(DRAG_SUPPORT)
#include <WebCore/DragActions.h>
#endif
#if !PLATFORM(GTK) && ENABLE(DRAG_SUPPORT) || PLATFORM(GTK) && ENABLE(DRAG_SUPPORT)
#include <WebCore/DragData.h>
#endif
#include <WebCore/ElementContext.h>
#include <WebCore/FloatPoint.h>
#include <WebCore/FloatRect.h>
#include <WebCore/FloatSize.h>
#include <WebCore/FontAttributeChanges.h>
#include <WebCore/FontAttributes.h>
#include <WebCore/FrameIdentifier.h>
#include <WebCore/FrameLoaderTypes.h>
#if ENABLE(GAMEPAD)
#include <WebCore/GamepadProviderClient.h>
#endif
#include <WebCore/GlobalFrameIdentifier.h>
#include <WebCore/GlobalWindowIdentifier.h>
#if ENABLE(APP_HIGHLIGHTS)
#include <WebCore/HighlightVisibility.h>
#endif
#include <WebCore/IntPoint.h>
#include <WebCore/IntRect.h>
#include <WebCore/IntSize.h>
#include <WebCore/JSDOMExceptionHandling.h>
#include <WebCore/LayoutMilestone.h>
#if ENABLE(ENCRYPTED_MEDIA)
#include <WebCore/MediaKeySystemRequestIdentifier.h>
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
#include <WebCore/MediaPlaybackTargetContext.h>
#endif
#include <WebCore/MediaProducer.h>
#if PLATFORM(MAC)
#include <WebCore/PageOverlay.h>
#endif
#include <WebCore/PlatformEvent.h>
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
#include <WebCore/PlaybackTargetClientContextIdentifier.h>
#endif
#include <WebCore/PointerID.h>
#include <WebCore/RectEdges.h>
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
#include <WebCore/RegistrableDomain.h>
#endif
#include <WebCore/ResourceError.h>
#include <WebCore/ResourceLoaderIdentifier.h>
#include <WebCore/ResourceRequest.h>
#include <WebCore/ResourceResponse.h>
#include <WebCore/RunJavaScriptParameters.h>
#include <WebCore/ScrollTypes.h>
#include <WebCore/SecurityPolicyViolationEvent.h>
#if PLATFORM(GTK) && ENABLE(DRAG_SUPPORT)
#include <WebCore/SelectionData.h>
#endif
#include <WebCore/ShouldTreatAsContinuingLoad.h>
#include <WebCore/TextCheckerClient.h>
#if PLATFORM(IOS_FAMILY)
#include <WebCore/TextGranularity.h>
#endif
#if PLATFORM(IOS_FAMILY) && ENABLE(DRAG_SUPPORT)
#include <WebCore/TextIndicator.h>
#endif
#include <WebCore/TextManipulationController.h>
#if ENABLE(IMAGE_ANALYSIS)
#include <WebCore/TextRecognitionResult.h>
#endif
#if ENABLE(MEDIA_STREAM)
#include <WebCore/UserMediaRequestIdentifier.h>
#endif
#if PLATFORM(IOS_FAMILY)
#include <WebCore/ViewportArguments.h>
#endif
#if PLATFORM(IOS_FAMILY)
#include <WebCore/VisibleSelection.h>
#endif
#include <WebCore/WritingDirection.h>
#include <optional>
#include <utility>
#if PLATFORM(COCOA)
#include <wtf/MachSendRight.h>
#endif
#include <wtf/OptionSet.h>
#include <wtf/URLHash.h>
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>
#include "ArgumentCoders.h"
#include "StorageAreaImplIdentifier.h"
#include "StorageAreaMapMessages.h"
#include <optional>
#include <wtf/text/WTFString.h>
#if ENABLE(WEBXR)
#include "PlatformXRSystemProxyMessages.h"
#include "XRDeviceIdentifier.h"
#include <WebCore/PlatformXR.h>
#endif
#include "ViewGestureControllerMessages.h"
#if !PLATFORM(IOS_FAMILY) || PLATFORM(MAC)
#include "WebCoreArgumentCoders.h"
#endif
#if PLATFORM(MAC)
#include <WebCore/FloatPoint.h>
#endif
#if !PLATFORM(IOS_FAMILY) || PLATFORM(MAC)
#include <WebCore/FloatRect.h>
#endif
#include "GtkSettingsManagerProxyMessages.h"
#include "GtkSettingsState.h"
#include "ViewGestureGeometryCollectorMessages.h"
#if PLATFORM(COCOA)
#include "WebCoreArgumentCoders.h"
#endif
#if PLATFORM(COCOA)
#include <WebCore/FloatPoint.h>
#endif

namespace IPC {

#if ENABLE(IPC_TESTING_API)

std::optional<JSC::JSValue> jsValueForArguments(JSC::JSGlobalObject* globalObject, MessageName name, Decoder& decoder)
{
    switch (name) {
#if ENABLE(GPU_PROCESS)
    case MessageName::GPUConnectionToWebProcess_CreateRenderingBackend:
        return jsValueForDecodedArguments<Messages::GPUConnectionToWebProcess::CreateRenderingBackend::Arguments>(globalObject, decoder);
    case MessageName::GPUConnectionToWebProcess_ReleaseRenderingBackend:
        return jsValueForDecodedArguments<Messages::GPUConnectionToWebProcess::ReleaseRenderingBackend::Arguments>(globalObject, decoder);
#if ENABLE(WEBGL)
    case MessageName::GPUConnectionToWebProcess_CreateGraphicsContextGL:
        return jsValueForDecodedArguments<Messages::GPUConnectionToWebProcess::CreateGraphicsContextGL::Arguments>(globalObject, decoder);
    case MessageName::GPUConnectionToWebProcess_ReleaseGraphicsContextGL:
        return jsValueForDecodedArguments<Messages::GPUConnectionToWebProcess::ReleaseGraphicsContextGL::Arguments>(globalObject, decoder);
#endif
    case MessageName::GPUConnectionToWebProcess_CreateRemoteGPU:
        return jsValueForDecodedArguments<Messages::GPUConnectionToWebProcess::CreateRemoteGPU::Arguments>(globalObject, decoder);
    case MessageName::GPUConnectionToWebProcess_ClearNowPlayingInfo:
        return jsValueForDecodedArguments<Messages::GPUConnectionToWebProcess::ClearNowPlayingInfo::Arguments>(globalObject, decoder);
    case MessageName::GPUConnectionToWebProcess_SetNowPlayingInfo:
        return jsValueForDecodedArguments<Messages::GPUConnectionToWebProcess::SetNowPlayingInfo::Arguments>(globalObject, decoder);
#if USE(AUDIO_SESSION)
    case MessageName::GPUConnectionToWebProcess_EnsureAudioSession:
        return jsValueForDecodedArguments<Messages::GPUConnectionToWebProcess::EnsureAudioSession::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(IOS_FAMILY)
    case MessageName::GPUConnectionToWebProcess_EnsureMediaSessionHelper:
        return jsValueForDecodedArguments<Messages::GPUConnectionToWebProcess::EnsureMediaSessionHelper::Arguments>(globalObject, decoder);
#endif
#if ENABLE(VP9)
    case MessageName::GPUConnectionToWebProcess_EnableVP9Decoders:
        return jsValueForDecodedArguments<Messages::GPUConnectionToWebProcess::EnableVP9Decoders::Arguments>(globalObject, decoder);
#endif
#if HAVE(VISIBILITY_PROPAGATION_VIEW)
    case MessageName::GPUConnectionToWebProcess_CreateVisibilityPropagationContextForPage:
        return jsValueForDecodedArguments<Messages::GPUConnectionToWebProcess::CreateVisibilityPropagationContextForPage::Arguments>(globalObject, decoder);
    case MessageName::GPUConnectionToWebProcess_DestroyVisibilityPropagationContextForPage:
        return jsValueForDecodedArguments<Messages::GPUConnectionToWebProcess::DestroyVisibilityPropagationContextForPage::Arguments>(globalObject, decoder);
#endif
    case MessageName::GPUConnectionToWebProcess_SetMediaOverridesForTesting:
        return jsValueForDecodedArguments<Messages::GPUConnectionToWebProcess::SetMediaOverridesForTesting::Arguments>(globalObject, decoder);
    case MessageName::GPUConnectionToWebProcess_CreateAudioHardwareListener:
        return jsValueForDecodedArguments<Messages::GPUConnectionToWebProcess::CreateAudioHardwareListener::Arguments>(globalObject, decoder);
    case MessageName::GPUConnectionToWebProcess_ReleaseAudioHardwareListener:
        return jsValueForDecodedArguments<Messages::GPUConnectionToWebProcess::ReleaseAudioHardwareListener::Arguments>(globalObject, decoder);
    case MessageName::GPUConnectionToWebProcess_CreateRemoteCommandListener:
        return jsValueForDecodedArguments<Messages::GPUConnectionToWebProcess::CreateRemoteCommandListener::Arguments>(globalObject, decoder);
    case MessageName::GPUConnectionToWebProcess_ReleaseRemoteCommandListener:
        return jsValueForDecodedArguments<Messages::GPUConnectionToWebProcess::ReleaseRemoteCommandListener::Arguments>(globalObject, decoder);
    case MessageName::GPUConnectionToWebProcess_SetUserPreferredLanguages:
        return jsValueForDecodedArguments<Messages::GPUConnectionToWebProcess::SetUserPreferredLanguages::Arguments>(globalObject, decoder);
    case MessageName::GPUConnectionToWebProcess_ConfigureLoggingChannel:
        return jsValueForDecodedArguments<Messages::GPUConnectionToWebProcess::ConfigureLoggingChannel::Arguments>(globalObject, decoder);
#if USE(GRAPHICS_LAYER_WC)
    case MessageName::GPUConnectionToWebProcess_CreateWCLayerTreeHost:
        return jsValueForDecodedArguments<Messages::GPUConnectionToWebProcess::CreateWCLayerTreeHost::Arguments>(globalObject, decoder);
    case MessageName::GPUConnectionToWebProcess_ReleaseWCLayerTreeHost:
        return jsValueForDecodedArguments<Messages::GPUConnectionToWebProcess::ReleaseWCLayerTreeHost::Arguments>(globalObject, decoder);
#endif
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::GPUProcess_InitializeGPUProcess:
        return jsValueForDecodedArguments<Messages::GPUProcess::InitializeGPUProcess::Arguments>(globalObject, decoder);
    case MessageName::GPUProcess_CreateGPUConnectionToWebProcess:
        return jsValueForDecodedArguments<Messages::GPUProcess::CreateGPUConnectionToWebProcess::Arguments>(globalObject, decoder);
    case MessageName::GPUProcess_PrepareToSuspend:
        return jsValueForDecodedArguments<Messages::GPUProcess::PrepareToSuspend::Arguments>(globalObject, decoder);
    case MessageName::GPUProcess_ProcessDidResume:
        return jsValueForDecodedArguments<Messages::GPUProcess::ProcessDidResume::Arguments>(globalObject, decoder);
    case MessageName::GPUProcess_AddSession:
        return jsValueForDecodedArguments<Messages::GPUProcess::AddSession::Arguments>(globalObject, decoder);
    case MessageName::GPUProcess_RemoveSession:
        return jsValueForDecodedArguments<Messages::GPUProcess::RemoveSession::Arguments>(globalObject, decoder);
#if ENABLE(MEDIA_STREAM)
    case MessageName::GPUProcess_SetMockCaptureDevicesEnabled:
        return jsValueForDecodedArguments<Messages::GPUProcess::SetMockCaptureDevicesEnabled::Arguments>(globalObject, decoder);
    case MessageName::GPUProcess_SetOrientationForMediaCapture:
        return jsValueForDecodedArguments<Messages::GPUProcess::SetOrientationForMediaCapture::Arguments>(globalObject, decoder);
    case MessageName::GPUProcess_UpdateSandboxAccess:
        return jsValueForDecodedArguments<Messages::GPUProcess::UpdateSandboxAccess::Arguments>(globalObject, decoder);
    case MessageName::GPUProcess_UpdateCaptureAccess:
        return jsValueForDecodedArguments<Messages::GPUProcess::UpdateCaptureAccess::Arguments>(globalObject, decoder);
    case MessageName::GPUProcess_UpdateCaptureOrigin:
        return jsValueForDecodedArguments<Messages::GPUProcess::UpdateCaptureOrigin::Arguments>(globalObject, decoder);
    case MessageName::GPUProcess_AddMockMediaDevice:
        return jsValueForDecodedArguments<Messages::GPUProcess::AddMockMediaDevice::Arguments>(globalObject, decoder);
    case MessageName::GPUProcess_ClearMockMediaDevices:
        return jsValueForDecodedArguments<Messages::GPUProcess::ClearMockMediaDevices::Arguments>(globalObject, decoder);
    case MessageName::GPUProcess_RemoveMockMediaDevice:
        return jsValueForDecodedArguments<Messages::GPUProcess::RemoveMockMediaDevice::Arguments>(globalObject, decoder);
    case MessageName::GPUProcess_ResetMockMediaDevices:
        return jsValueForDecodedArguments<Messages::GPUProcess::ResetMockMediaDevices::Arguments>(globalObject, decoder);
    case MessageName::GPUProcess_SetMockCaptureDevicesInterrupted:
        return jsValueForDecodedArguments<Messages::GPUProcess::SetMockCaptureDevicesInterrupted::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(MAC)
    case MessageName::GPUProcess_DisplayConfigurationChanged:
        return jsValueForDecodedArguments<Messages::GPUProcess::DisplayConfigurationChanged::Arguments>(globalObject, decoder);
    case MessageName::GPUProcess_SetScreenProperties:
        return jsValueForDecodedArguments<Messages::GPUProcess::SetScreenProperties::Arguments>(globalObject, decoder);
#endif
#if HAVE(SC_CONTENT_SHARING_SESSION)
    case MessageName::GPUProcess_ShowWindowPicker:
        return jsValueForDecodedArguments<Messages::GPUProcess::ShowWindowPicker::Arguments>(globalObject, decoder);
    case MessageName::GPUProcess_ShowScreenPicker:
        return jsValueForDecodedArguments<Messages::GPUProcess::ShowScreenPicker::Arguments>(globalObject, decoder);
#endif
#if ENABLE(MEDIA_SOURCE)
    case MessageName::GPUProcess_SetWebMParserEnabled:
        return jsValueForDecodedArguments<Messages::GPUProcess::SetWebMParserEnabled::Arguments>(globalObject, decoder);
#endif
#if ENABLE(WEBM_FORMAT_READER)
    case MessageName::GPUProcess_SetWebMFormatReaderEnabled:
        return jsValueForDecodedArguments<Messages::GPUProcess::SetWebMFormatReaderEnabled::Arguments>(globalObject, decoder);
#endif
#if ENABLE(OPUS)
    case MessageName::GPUProcess_SetOpusDecoderEnabled:
        return jsValueForDecodedArguments<Messages::GPUProcess::SetOpusDecoderEnabled::Arguments>(globalObject, decoder);
#endif
#if ENABLE(VORBIS)
    case MessageName::GPUProcess_SetVorbisDecoderEnabled:
        return jsValueForDecodedArguments<Messages::GPUProcess::SetVorbisDecoderEnabled::Arguments>(globalObject, decoder);
#endif
#if ENABLE(MEDIA_SOURCE) && HAVE(AVSAMPLEBUFFERVIDEOOUTPUT)
    case MessageName::GPUProcess_SetMediaSourceInlinePaintingEnabled:
        return jsValueForDecodedArguments<Messages::GPUProcess::SetMediaSourceInlinePaintingEnabled::Arguments>(globalObject, decoder);
#endif
#if HAVE(SCREEN_CAPTURE_KIT)
    case MessageName::GPUProcess_SetUseScreenCaptureKit:
        return jsValueForDecodedArguments<Messages::GPUProcess::SetUseScreenCaptureKit::Arguments>(globalObject, decoder);
#endif
    case MessageName::GPUProcess_RequestBitmapImageForCurrentTime:
        return jsValueForDecodedArguments<Messages::GPUProcess::RequestBitmapImageForCurrentTime::Arguments>(globalObject, decoder);
#if ENABLE(CFPREFS_DIRECT_MODE)
    case MessageName::GPUProcess_NotifyPreferencesChanged:
        return jsValueForDecodedArguments<Messages::GPUProcess::NotifyPreferencesChanged::Arguments>(globalObject, decoder);
#endif
    case MessageName::GPUProcess_WebProcessConnectionCountForTesting:
        return jsValueForDecodedArguments<Messages::GPUProcess::WebProcessConnectionCountForTesting::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteDisplayListRecorder_Save:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::Save::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_Restore:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::Restore::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_Translate:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::Translate::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_Rotate:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::Rotate::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_Scale:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::Scale::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_SetCTM:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::SetCTM::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_ConcatenateCTM:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::ConcatenateCTM::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_SetInlineFillColor:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::SetInlineFillColor::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_SetInlineStrokeColor:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::SetInlineStrokeColor::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_SetStrokeThickness:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::SetStrokeThickness::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_SetState:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::SetState::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_SetLineCap:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::SetLineCap::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_SetLineDash:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::SetLineDash::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_SetLineJoin:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::SetLineJoin::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_SetMiterLimit:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::SetMiterLimit::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_ClearShadow:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::ClearShadow::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_Clip:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::Clip::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_ClipOut:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::ClipOut::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_ClipToImageBuffer:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::ClipToImageBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_ClipOutToPath:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::ClipOutToPath::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_ClipPath:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::ClipPath::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_DrawGlyphs:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::DrawGlyphs::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_DrawFilteredImageBuffer:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::DrawFilteredImageBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_DrawImageBuffer:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::DrawImageBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_DrawNativeImage:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::DrawNativeImage::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_DrawPattern:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::DrawPattern::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_BeginTransparencyLayer:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::BeginTransparencyLayer::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_EndTransparencyLayer:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::EndTransparencyLayer::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_DrawRect:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::DrawRect::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_DrawLine:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::DrawLine::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_DrawLinesForText:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::DrawLinesForText::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_DrawDotsForDocumentMarker:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::DrawDotsForDocumentMarker::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_DrawEllipse:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::DrawEllipse::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_DrawPath:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::DrawPath::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_DrawFocusRingPath:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::DrawFocusRingPath::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_DrawFocusRingRects:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::DrawFocusRingRects::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_FillRect:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::FillRect::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_FillRectWithColor:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::FillRectWithColor::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_FillRectWithGradient:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::FillRectWithGradient::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_FillCompositedRect:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::FillCompositedRect::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_FillRoundedRect:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::FillRoundedRect::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_FillRectWithRoundedHole:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::FillRectWithRoundedHole::Arguments>(globalObject, decoder);
#if ENABLE(INLINE_PATH_DATA)
    case MessageName::RemoteDisplayListRecorder_FillLine:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::FillLine::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_FillArc:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::FillArc::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_FillQuadCurve:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::FillQuadCurve::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_FillBezierCurve:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::FillBezierCurve::Arguments>(globalObject, decoder);
#endif
    case MessageName::RemoteDisplayListRecorder_FillPath:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::FillPath::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_FillEllipse:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::FillEllipse::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_ConvertToLuminanceMask:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::ConvertToLuminanceMask::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_TransformToColorSpace:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::TransformToColorSpace::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_PaintFrameForMedia:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::PaintFrameForMedia::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_StrokeRect:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::StrokeRect::Arguments>(globalObject, decoder);
#if ENABLE(INLINE_PATH_DATA)
    case MessageName::RemoteDisplayListRecorder_StrokeLine:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::StrokeLine::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_StrokeArc:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::StrokeArc::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_StrokeQuadCurve:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::StrokeQuadCurve::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_StrokeBezierCurve:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::StrokeBezierCurve::Arguments>(globalObject, decoder);
#endif
    case MessageName::RemoteDisplayListRecorder_StrokePath:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::StrokePath::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_StrokeEllipse:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::StrokeEllipse::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_ClearRect:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::ClearRect::Arguments>(globalObject, decoder);
#if USE(CG)
    case MessageName::RemoteDisplayListRecorder_ApplyStrokePattern:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::ApplyStrokePattern::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_ApplyFillPattern:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::ApplyFillPattern::Arguments>(globalObject, decoder);
#endif
    case MessageName::RemoteDisplayListRecorder_ApplyDeviceScaleFactor:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::ApplyDeviceScaleFactor::Arguments>(globalObject, decoder);
    case MessageName::RemoteDisplayListRecorder_FlushContext:
        return jsValueForDecodedArguments<Messages::RemoteDisplayListRecorder::FlushContext::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(WEBGL)
    case MessageName::RemoteGraphicsContextGL_Reshape:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Reshape::Arguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::RemoteGraphicsContextGL_PrepareForDisplay:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::PrepareForDisplay::Arguments>(globalObject, decoder);
#endif
#if USE(GRAPHICS_LAYER_WC)
    case MessageName::RemoteGraphicsContextGL_PrepareForDisplay:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::PrepareForDisplay::Arguments>(globalObject, decoder);
#endif
#if !PLATFORM(COCOA) && !USE(GRAPHICS_LAYER_WC)
    case MessageName::RemoteGraphicsContextGL_PrepareForDisplay:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::PrepareForDisplay::Arguments>(globalObject, decoder);
#endif
    case MessageName::RemoteGraphicsContextGL_EnsureExtensionEnabled:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::EnsureExtensionEnabled::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_MarkContextChanged:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::MarkContextChanged::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_SynthesizeGLError:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::SynthesizeGLError::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetError:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetError::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_PaintRenderingResultsToCanvas:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::PaintRenderingResultsToCanvas::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_PaintCompositedResultsToCanvas:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::PaintCompositedResultsToCanvas::Arguments>(globalObject, decoder);
#if ENABLE(VIDEO)
    case MessageName::RemoteGraphicsContextGL_CopyTextureFromVideoFrame:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CopyTextureFromVideoFrame::Arguments>(globalObject, decoder);
#endif
#if ENABLE(MEDIA_STREAM)
    case MessageName::RemoteGraphicsContextGL_PaintCompositedResultsToMediaSample:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::PaintCompositedResultsToMediaSample::Arguments>(globalObject, decoder);
#endif
    case MessageName::RemoteGraphicsContextGL_SimulateEventForTesting:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::SimulateEventForTesting::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_MoveErrorsToSyntheticErrorList:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::MoveErrorsToSyntheticErrorList::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_ActiveTexture:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::ActiveTexture::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_AttachShader:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::AttachShader::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_BindAttribLocation:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::BindAttribLocation::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_BindBuffer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::BindBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_BindFramebuffer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::BindFramebuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_BindRenderbuffer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::BindRenderbuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_BindTexture:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::BindTexture::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_BlendColor:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::BlendColor::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_BlendEquation:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::BlendEquation::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_BlendEquationSeparate:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::BlendEquationSeparate::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_BlendFunc:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::BlendFunc::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_BlendFuncSeparate:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::BlendFuncSeparate::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CheckFramebufferStatus:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CheckFramebufferStatus::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Clear:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Clear::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_ClearColor:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::ClearColor::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_ClearDepth:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::ClearDepth::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_ClearStencil:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::ClearStencil::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_ColorMask:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::ColorMask::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CompileShader:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CompileShader::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CopyTexImage2D:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CopyTexImage2D::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CopyTexSubImage2D:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CopyTexSubImage2D::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CreateBuffer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CreateBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CreateFramebuffer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CreateFramebuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CreateProgram:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CreateProgram::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CreateRenderbuffer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CreateRenderbuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CreateShader:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CreateShader::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CreateTexture:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CreateTexture::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CullFace:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CullFace::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_DeleteBuffer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::DeleteBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_DeleteFramebuffer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::DeleteFramebuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_DeleteProgram:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::DeleteProgram::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_DeleteRenderbuffer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::DeleteRenderbuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_DeleteShader:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::DeleteShader::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_DeleteTexture:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::DeleteTexture::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_DepthFunc:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::DepthFunc::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_DepthMask:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::DepthMask::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_DepthRange:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::DepthRange::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_DetachShader:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::DetachShader::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Disable:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Disable::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_DisableVertexAttribArray:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::DisableVertexAttribArray::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_DrawArrays:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::DrawArrays::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_DrawElements:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::DrawElements::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Enable:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Enable::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_EnableVertexAttribArray:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::EnableVertexAttribArray::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Finish:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Finish::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Flush:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Flush::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_FramebufferRenderbuffer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::FramebufferRenderbuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_FramebufferTexture2D:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::FramebufferTexture2D::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_FrontFace:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::FrontFace::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GenerateMipmap:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GenerateMipmap::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetActiveAttrib:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetActiveAttrib::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetActiveUniform:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetActiveUniform::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetAttribLocation:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetAttribLocation::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetBufferParameteri:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetBufferParameteri::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetString:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetString::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetFloatv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetFloatv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetIntegerv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetIntegerv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetInteger64:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetInteger64::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetInteger64i:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetInteger64i::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetProgrami:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetProgrami::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetBooleanv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetBooleanv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetFramebufferAttachmentParameteri:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetFramebufferAttachmentParameteri::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetProgramInfoLog:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetProgramInfoLog::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetRenderbufferParameteri:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetRenderbufferParameteri::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetShaderi:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetShaderi::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetShaderInfoLog:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetShaderInfoLog::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetShaderPrecisionFormat:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetShaderPrecisionFormat::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetShaderSource:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetShaderSource::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetTexParameterf:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetTexParameterf::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetTexParameteri:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetTexParameteri::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetUniformfv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetUniformfv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetUniformiv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetUniformiv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetUniformuiv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetUniformuiv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetUniformLocation:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetUniformLocation::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetVertexAttribOffset:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetVertexAttribOffset::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Hint:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Hint::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_IsBuffer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::IsBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_IsEnabled:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::IsEnabled::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_IsFramebuffer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::IsFramebuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_IsProgram:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::IsProgram::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_IsRenderbuffer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::IsRenderbuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_IsShader:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::IsShader::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_IsTexture:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::IsTexture::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_LineWidth:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::LineWidth::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_LinkProgram:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::LinkProgram::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_PixelStorei:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::PixelStorei::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_PolygonOffset:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::PolygonOffset::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_RenderbufferStorage:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::RenderbufferStorage::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_SampleCoverage:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::SampleCoverage::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Scissor:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Scissor::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_ShaderSource:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::ShaderSource::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_StencilFunc:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::StencilFunc::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_StencilFuncSeparate:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::StencilFuncSeparate::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_StencilMask:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::StencilMask::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_StencilMaskSeparate:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::StencilMaskSeparate::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_StencilOp:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::StencilOp::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_StencilOpSeparate:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::StencilOpSeparate::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_TexParameterf:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::TexParameterf::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_TexParameteri:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::TexParameteri::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Uniform1f:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Uniform1f::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Uniform1fv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Uniform1fv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Uniform1i:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Uniform1i::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Uniform1iv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Uniform1iv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Uniform2f:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Uniform2f::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Uniform2fv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Uniform2fv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Uniform2i:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Uniform2i::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Uniform2iv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Uniform2iv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Uniform3f:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Uniform3f::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Uniform3fv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Uniform3fv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Uniform3i:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Uniform3i::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Uniform3iv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Uniform3iv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Uniform4f:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Uniform4f::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Uniform4fv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Uniform4fv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Uniform4i:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Uniform4i::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Uniform4iv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Uniform4iv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_UniformMatrix2fv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::UniformMatrix2fv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_UniformMatrix3fv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::UniformMatrix3fv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_UniformMatrix4fv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::UniformMatrix4fv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_UseProgram:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::UseProgram::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_ValidateProgram:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::ValidateProgram::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_VertexAttrib1f:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::VertexAttrib1f::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_VertexAttrib1fv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::VertexAttrib1fv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_VertexAttrib2f:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::VertexAttrib2f::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_VertexAttrib2fv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::VertexAttrib2fv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_VertexAttrib3f:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::VertexAttrib3f::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_VertexAttrib3fv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::VertexAttrib3fv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_VertexAttrib4f:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::VertexAttrib4f::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_VertexAttrib4fv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::VertexAttrib4fv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_VertexAttribPointer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::VertexAttribPointer::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Viewport:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Viewport::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_BufferData0:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::BufferData0::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_BufferData1:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::BufferData1::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_BufferSubData:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::BufferSubData::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_ReadnPixels0:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::ReadnPixels0::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_ReadnPixels1:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::ReadnPixels1::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_TexImage2D0:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::TexImage2D0::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_TexImage2D1:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::TexImage2D1::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_TexSubImage2D0:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::TexSubImage2D0::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_TexSubImage2D1:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::TexSubImage2D1::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CompressedTexImage2D0:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CompressedTexImage2D0::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CompressedTexImage2D1:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CompressedTexImage2D1::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CompressedTexSubImage2D0:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CompressedTexSubImage2D0::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CompressedTexSubImage2D1:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CompressedTexSubImage2D1::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_DrawArraysInstanced:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::DrawArraysInstanced::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_DrawElementsInstanced:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::DrawElementsInstanced::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_VertexAttribDivisor:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::VertexAttribDivisor::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CreateVertexArray:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CreateVertexArray::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_DeleteVertexArray:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::DeleteVertexArray::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_IsVertexArray:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::IsVertexArray::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_BindVertexArray:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::BindVertexArray::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CopyBufferSubData:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CopyBufferSubData::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetBufferSubData:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetBufferSubData::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_BlitFramebuffer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::BlitFramebuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_FramebufferTextureLayer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::FramebufferTextureLayer::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_InvalidateFramebuffer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::InvalidateFramebuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_InvalidateSubFramebuffer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::InvalidateSubFramebuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_ReadBuffer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::ReadBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_RenderbufferStorageMultisample:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::RenderbufferStorageMultisample::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_TexStorage2D:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::TexStorage2D::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_TexStorage3D:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::TexStorage3D::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_TexImage3D0:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::TexImage3D0::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_TexImage3D1:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::TexImage3D1::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_TexSubImage3D0:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::TexSubImage3D0::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_TexSubImage3D1:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::TexSubImage3D1::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CopyTexSubImage3D:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CopyTexSubImage3D::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CompressedTexImage3D0:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CompressedTexImage3D0::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CompressedTexImage3D1:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CompressedTexImage3D1::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CompressedTexSubImage3D0:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CompressedTexSubImage3D0::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CompressedTexSubImage3D1:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CompressedTexSubImage3D1::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetFragDataLocation:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetFragDataLocation::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Uniform1ui:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Uniform1ui::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Uniform2ui:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Uniform2ui::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Uniform3ui:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Uniform3ui::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Uniform4ui:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Uniform4ui::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Uniform1uiv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Uniform1uiv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Uniform2uiv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Uniform2uiv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Uniform3uiv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Uniform3uiv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_Uniform4uiv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::Uniform4uiv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_UniformMatrix2x3fv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::UniformMatrix2x3fv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_UniformMatrix3x2fv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::UniformMatrix3x2fv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_UniformMatrix2x4fv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::UniformMatrix2x4fv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_UniformMatrix4x2fv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::UniformMatrix4x2fv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_UniformMatrix3x4fv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::UniformMatrix3x4fv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_UniformMatrix4x3fv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::UniformMatrix4x3fv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_VertexAttribI4i:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::VertexAttribI4i::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_VertexAttribI4iv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::VertexAttribI4iv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_VertexAttribI4ui:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::VertexAttribI4ui::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_VertexAttribI4uiv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::VertexAttribI4uiv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_VertexAttribIPointer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::VertexAttribIPointer::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_DrawRangeElements:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::DrawRangeElements::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_DrawBuffers:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::DrawBuffers::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_ClearBufferiv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::ClearBufferiv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_ClearBufferuiv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::ClearBufferuiv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_ClearBufferfv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::ClearBufferfv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_ClearBufferfi:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::ClearBufferfi::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CreateQuery:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CreateQuery::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_DeleteQuery:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::DeleteQuery::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_IsQuery:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::IsQuery::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_BeginQuery:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::BeginQuery::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_EndQuery:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::EndQuery::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetQuery:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetQuery::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetQueryObjectui:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetQueryObjectui::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CreateSampler:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CreateSampler::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_DeleteSampler:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::DeleteSampler::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_IsSampler:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::IsSampler::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_BindSampler:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::BindSampler::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_SamplerParameteri:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::SamplerParameteri::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_SamplerParameterf:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::SamplerParameterf::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetSamplerParameterf:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetSamplerParameterf::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetSamplerParameteri:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetSamplerParameteri::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_FenceSync:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::FenceSync::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_IsSync:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::IsSync::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_DeleteSync:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::DeleteSync::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_ClientWaitSync:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::ClientWaitSync::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_WaitSync:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::WaitSync::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetSynci:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetSynci::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CreateTransformFeedback:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CreateTransformFeedback::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_DeleteTransformFeedback:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::DeleteTransformFeedback::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_IsTransformFeedback:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::IsTransformFeedback::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_BindTransformFeedback:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::BindTransformFeedback::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_BeginTransformFeedback:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::BeginTransformFeedback::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_EndTransformFeedback:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::EndTransformFeedback::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_TransformFeedbackVaryings:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::TransformFeedbackVaryings::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetTransformFeedbackVarying:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetTransformFeedbackVarying::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_PauseTransformFeedback:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::PauseTransformFeedback::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_ResumeTransformFeedback:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::ResumeTransformFeedback::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_BindBufferBase:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::BindBufferBase::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_BindBufferRange:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::BindBufferRange::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetUniformIndices:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetUniformIndices::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetActiveUniforms:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetActiveUniforms::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetUniformBlockIndex:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetUniformBlockIndex::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetActiveUniformBlockName:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetActiveUniformBlockName::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_UniformBlockBinding:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::UniformBlockBinding::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetActiveUniformBlockiv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetActiveUniformBlockiv::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetGraphicsResetStatusARB:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetGraphicsResetStatusARB::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetTranslatedShaderSourceANGLE:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetTranslatedShaderSourceANGLE::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_DrawBuffersEXT:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::DrawBuffersEXT::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetInternalformativ:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetInternalformativ::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_MultiDrawArraysANGLE:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::MultiDrawArraysANGLE::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_MultiDrawArraysInstancedANGLE:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::MultiDrawArraysInstancedANGLE::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_MultiDrawElementsANGLE:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::MultiDrawElementsANGLE::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_MultiDrawElementsInstancedANGLE:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::MultiDrawElementsInstancedANGLE::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_PaintRenderingResultsToPixelBuffer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::PaintRenderingResultsToPixelBuffer::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteRenderingBackend_CreateImageBuffer:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::CreateImageBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackend_GetPixelBufferForImageBuffer:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::GetPixelBufferForImageBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackend_GetPixelBufferForImageBufferWithNewMemory:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::GetPixelBufferForImageBufferWithNewMemory::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackend_DestroyGetPixelBufferSharedMemory:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::DestroyGetPixelBufferSharedMemory::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackend_PutPixelBufferForImageBuffer:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::PutPixelBufferForImageBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackend_GetDataURLForImageBuffer:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::GetDataURLForImageBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackend_GetDataForImageBuffer:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::GetDataForImageBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackend_GetShareableBitmapForImageBuffer:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::GetShareableBitmapForImageBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackend_GetFilteredImageForImageBuffer:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::GetFilteredImageForImageBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackend_CacheNativeImage:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::CacheNativeImage::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackend_CacheFont:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::CacheFont::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackend_DeleteAllFonts:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::DeleteAllFonts::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackend_ReleaseRemoteResource:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::ReleaseRemoteResource::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackend_MarkSurfaceNonVolatile:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::MarkSurfaceNonVolatile::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackend_SwapToValidFrontBuffer:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::SwapToValidFrontBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackend_MarkSurfacesVolatile:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::MarkSurfacesVolatile::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackend_FinalizeRenderingUpdate:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::FinalizeRenderingUpdate::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteAdapter_RequestDevice:
        return jsValueForDecodedArguments<Messages::RemoteAdapter::RequestDevice::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteBindGroup_SetLabel:
        return jsValueForDecodedArguments<Messages::RemoteBindGroup::SetLabel::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteBindGroupLayout_SetLabel:
        return jsValueForDecodedArguments<Messages::RemoteBindGroupLayout::SetLabel::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteBuffer_MapAsync:
        return jsValueForDecodedArguments<Messages::RemoteBuffer::MapAsync::Arguments>(globalObject, decoder);
    case MessageName::RemoteBuffer_Unmap:
        return jsValueForDecodedArguments<Messages::RemoteBuffer::Unmap::Arguments>(globalObject, decoder);
    case MessageName::RemoteBuffer_Destroy:
        return jsValueForDecodedArguments<Messages::RemoteBuffer::Destroy::Arguments>(globalObject, decoder);
    case MessageName::RemoteBuffer_SetLabel:
        return jsValueForDecodedArguments<Messages::RemoteBuffer::SetLabel::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteCommandBuffer_SetLabel:
        return jsValueForDecodedArguments<Messages::RemoteCommandBuffer::SetLabel::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteCommandEncoder_BeginRenderPass:
        return jsValueForDecodedArguments<Messages::RemoteCommandEncoder::BeginRenderPass::Arguments>(globalObject, decoder);
    case MessageName::RemoteCommandEncoder_BeginComputePass:
        return jsValueForDecodedArguments<Messages::RemoteCommandEncoder::BeginComputePass::Arguments>(globalObject, decoder);
    case MessageName::RemoteCommandEncoder_CopyBufferToBuffer:
        return jsValueForDecodedArguments<Messages::RemoteCommandEncoder::CopyBufferToBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteCommandEncoder_CopyBufferToTexture:
        return jsValueForDecodedArguments<Messages::RemoteCommandEncoder::CopyBufferToTexture::Arguments>(globalObject, decoder);
    case MessageName::RemoteCommandEncoder_CopyTextureToBuffer:
        return jsValueForDecodedArguments<Messages::RemoteCommandEncoder::CopyTextureToBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteCommandEncoder_CopyTextureToTexture:
        return jsValueForDecodedArguments<Messages::RemoteCommandEncoder::CopyTextureToTexture::Arguments>(globalObject, decoder);
    case MessageName::RemoteCommandEncoder_ClearBuffer:
        return jsValueForDecodedArguments<Messages::RemoteCommandEncoder::ClearBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteCommandEncoder_PushDebugGroup:
        return jsValueForDecodedArguments<Messages::RemoteCommandEncoder::PushDebugGroup::Arguments>(globalObject, decoder);
    case MessageName::RemoteCommandEncoder_PopDebugGroup:
        return jsValueForDecodedArguments<Messages::RemoteCommandEncoder::PopDebugGroup::Arguments>(globalObject, decoder);
    case MessageName::RemoteCommandEncoder_InsertDebugMarker:
        return jsValueForDecodedArguments<Messages::RemoteCommandEncoder::InsertDebugMarker::Arguments>(globalObject, decoder);
    case MessageName::RemoteCommandEncoder_WriteTimestamp:
        return jsValueForDecodedArguments<Messages::RemoteCommandEncoder::WriteTimestamp::Arguments>(globalObject, decoder);
    case MessageName::RemoteCommandEncoder_ResolveQuerySet:
        return jsValueForDecodedArguments<Messages::RemoteCommandEncoder::ResolveQuerySet::Arguments>(globalObject, decoder);
    case MessageName::RemoteCommandEncoder_Finish:
        return jsValueForDecodedArguments<Messages::RemoteCommandEncoder::Finish::Arguments>(globalObject, decoder);
    case MessageName::RemoteCommandEncoder_SetLabel:
        return jsValueForDecodedArguments<Messages::RemoteCommandEncoder::SetLabel::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteComputePassEncoder_SetPipeline:
        return jsValueForDecodedArguments<Messages::RemoteComputePassEncoder::SetPipeline::Arguments>(globalObject, decoder);
    case MessageName::RemoteComputePassEncoder_Dispatch:
        return jsValueForDecodedArguments<Messages::RemoteComputePassEncoder::Dispatch::Arguments>(globalObject, decoder);
    case MessageName::RemoteComputePassEncoder_DispatchIndirect:
        return jsValueForDecodedArguments<Messages::RemoteComputePassEncoder::DispatchIndirect::Arguments>(globalObject, decoder);
    case MessageName::RemoteComputePassEncoder_End:
        return jsValueForDecodedArguments<Messages::RemoteComputePassEncoder::End::Arguments>(globalObject, decoder);
    case MessageName::RemoteComputePassEncoder_SetBindGroup:
        return jsValueForDecodedArguments<Messages::RemoteComputePassEncoder::SetBindGroup::Arguments>(globalObject, decoder);
    case MessageName::RemoteComputePassEncoder_PushDebugGroup:
        return jsValueForDecodedArguments<Messages::RemoteComputePassEncoder::PushDebugGroup::Arguments>(globalObject, decoder);
    case MessageName::RemoteComputePassEncoder_PopDebugGroup:
        return jsValueForDecodedArguments<Messages::RemoteComputePassEncoder::PopDebugGroup::Arguments>(globalObject, decoder);
    case MessageName::RemoteComputePassEncoder_InsertDebugMarker:
        return jsValueForDecodedArguments<Messages::RemoteComputePassEncoder::InsertDebugMarker::Arguments>(globalObject, decoder);
    case MessageName::RemoteComputePassEncoder_SetLabel:
        return jsValueForDecodedArguments<Messages::RemoteComputePassEncoder::SetLabel::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteComputePipeline_GetBindGroupLayout:
        return jsValueForDecodedArguments<Messages::RemoteComputePipeline::GetBindGroupLayout::Arguments>(globalObject, decoder);
    case MessageName::RemoteComputePipeline_SetLabel:
        return jsValueForDecodedArguments<Messages::RemoteComputePipeline::SetLabel::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteDevice_Destroy:
        return jsValueForDecodedArguments<Messages::RemoteDevice::Destroy::Arguments>(globalObject, decoder);
    case MessageName::RemoteDevice_CreateBuffer:
        return jsValueForDecodedArguments<Messages::RemoteDevice::CreateBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteDevice_CreateTexture:
        return jsValueForDecodedArguments<Messages::RemoteDevice::CreateTexture::Arguments>(globalObject, decoder);
    case MessageName::RemoteDevice_CreateSampler:
        return jsValueForDecodedArguments<Messages::RemoteDevice::CreateSampler::Arguments>(globalObject, decoder);
    case MessageName::RemoteDevice_ImportExternalTexture:
        return jsValueForDecodedArguments<Messages::RemoteDevice::ImportExternalTexture::Arguments>(globalObject, decoder);
    case MessageName::RemoteDevice_CreateBindGroupLayout:
        return jsValueForDecodedArguments<Messages::RemoteDevice::CreateBindGroupLayout::Arguments>(globalObject, decoder);
    case MessageName::RemoteDevice_CreatePipelineLayout:
        return jsValueForDecodedArguments<Messages::RemoteDevice::CreatePipelineLayout::Arguments>(globalObject, decoder);
    case MessageName::RemoteDevice_CreateBindGroup:
        return jsValueForDecodedArguments<Messages::RemoteDevice::CreateBindGroup::Arguments>(globalObject, decoder);
    case MessageName::RemoteDevice_CreateShaderModule:
        return jsValueForDecodedArguments<Messages::RemoteDevice::CreateShaderModule::Arguments>(globalObject, decoder);
    case MessageName::RemoteDevice_CreateComputePipeline:
        return jsValueForDecodedArguments<Messages::RemoteDevice::CreateComputePipeline::Arguments>(globalObject, decoder);
    case MessageName::RemoteDevice_CreateRenderPipeline:
        return jsValueForDecodedArguments<Messages::RemoteDevice::CreateRenderPipeline::Arguments>(globalObject, decoder);
    case MessageName::RemoteDevice_CreateComputePipelineAsync:
        return jsValueForDecodedArguments<Messages::RemoteDevice::CreateComputePipelineAsync::Arguments>(globalObject, decoder);
    case MessageName::RemoteDevice_CreateRenderPipelineAsync:
        return jsValueForDecodedArguments<Messages::RemoteDevice::CreateRenderPipelineAsync::Arguments>(globalObject, decoder);
    case MessageName::RemoteDevice_CreateCommandEncoder:
        return jsValueForDecodedArguments<Messages::RemoteDevice::CreateCommandEncoder::Arguments>(globalObject, decoder);
    case MessageName::RemoteDevice_CreateRenderBundleEncoder:
        return jsValueForDecodedArguments<Messages::RemoteDevice::CreateRenderBundleEncoder::Arguments>(globalObject, decoder);
    case MessageName::RemoteDevice_CreateQuerySet:
        return jsValueForDecodedArguments<Messages::RemoteDevice::CreateQuerySet::Arguments>(globalObject, decoder);
    case MessageName::RemoteDevice_PushErrorScope:
        return jsValueForDecodedArguments<Messages::RemoteDevice::PushErrorScope::Arguments>(globalObject, decoder);
    case MessageName::RemoteDevice_PopErrorScope:
        return jsValueForDecodedArguments<Messages::RemoteDevice::PopErrorScope::Arguments>(globalObject, decoder);
    case MessageName::RemoteDevice_SetLabel:
        return jsValueForDecodedArguments<Messages::RemoteDevice::SetLabel::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteExternalTexture_SetLabel:
        return jsValueForDecodedArguments<Messages::RemoteExternalTexture::SetLabel::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteGPU_RequestAdapter:
        return jsValueForDecodedArguments<Messages::RemoteGPU::RequestAdapter::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemotePipelineLayout_SetLabel:
        return jsValueForDecodedArguments<Messages::RemotePipelineLayout::SetLabel::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteQuerySet_Destroy:
        return jsValueForDecodedArguments<Messages::RemoteQuerySet::Destroy::Arguments>(globalObject, decoder);
    case MessageName::RemoteQuerySet_SetLabel:
        return jsValueForDecodedArguments<Messages::RemoteQuerySet::SetLabel::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteQueue_Submit:
        return jsValueForDecodedArguments<Messages::RemoteQueue::Submit::Arguments>(globalObject, decoder);
    case MessageName::RemoteQueue_OnSubmittedWorkDone:
        return jsValueForDecodedArguments<Messages::RemoteQueue::OnSubmittedWorkDone::Arguments>(globalObject, decoder);
    case MessageName::RemoteQueue_WriteBuffer:
        return jsValueForDecodedArguments<Messages::RemoteQueue::WriteBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteQueue_WriteTexture:
        return jsValueForDecodedArguments<Messages::RemoteQueue::WriteTexture::Arguments>(globalObject, decoder);
    case MessageName::RemoteQueue_CopyExternalImageToTexture:
        return jsValueForDecodedArguments<Messages::RemoteQueue::CopyExternalImageToTexture::Arguments>(globalObject, decoder);
    case MessageName::RemoteQueue_SetLabel:
        return jsValueForDecodedArguments<Messages::RemoteQueue::SetLabel::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteRenderBundle_SetLabel:
        return jsValueForDecodedArguments<Messages::RemoteRenderBundle::SetLabel::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteRenderBundleEncoder_SetPipeline:
        return jsValueForDecodedArguments<Messages::RemoteRenderBundleEncoder::SetPipeline::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderBundleEncoder_SetIndexBuffer:
        return jsValueForDecodedArguments<Messages::RemoteRenderBundleEncoder::SetIndexBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderBundleEncoder_SetVertexBuffer:
        return jsValueForDecodedArguments<Messages::RemoteRenderBundleEncoder::SetVertexBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderBundleEncoder_Draw:
        return jsValueForDecodedArguments<Messages::RemoteRenderBundleEncoder::Draw::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderBundleEncoder_DrawIndexed:
        return jsValueForDecodedArguments<Messages::RemoteRenderBundleEncoder::DrawIndexed::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderBundleEncoder_DrawIndirect:
        return jsValueForDecodedArguments<Messages::RemoteRenderBundleEncoder::DrawIndirect::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderBundleEncoder_DrawIndexedIndirect:
        return jsValueForDecodedArguments<Messages::RemoteRenderBundleEncoder::DrawIndexedIndirect::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderBundleEncoder_SetBindGroup:
        return jsValueForDecodedArguments<Messages::RemoteRenderBundleEncoder::SetBindGroup::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderBundleEncoder_PushDebugGroup:
        return jsValueForDecodedArguments<Messages::RemoteRenderBundleEncoder::PushDebugGroup::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderBundleEncoder_PopDebugGroup:
        return jsValueForDecodedArguments<Messages::RemoteRenderBundleEncoder::PopDebugGroup::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderBundleEncoder_InsertDebugMarker:
        return jsValueForDecodedArguments<Messages::RemoteRenderBundleEncoder::InsertDebugMarker::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderBundleEncoder_Finish:
        return jsValueForDecodedArguments<Messages::RemoteRenderBundleEncoder::Finish::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderBundleEncoder_SetLabel:
        return jsValueForDecodedArguments<Messages::RemoteRenderBundleEncoder::SetLabel::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteRenderPassEncoder_SetPipeline:
        return jsValueForDecodedArguments<Messages::RemoteRenderPassEncoder::SetPipeline::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderPassEncoder_SetIndexBuffer:
        return jsValueForDecodedArguments<Messages::RemoteRenderPassEncoder::SetIndexBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderPassEncoder_SetVertexBuffer:
        return jsValueForDecodedArguments<Messages::RemoteRenderPassEncoder::SetVertexBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderPassEncoder_Draw:
        return jsValueForDecodedArguments<Messages::RemoteRenderPassEncoder::Draw::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderPassEncoder_DrawIndexed:
        return jsValueForDecodedArguments<Messages::RemoteRenderPassEncoder::DrawIndexed::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderPassEncoder_DrawIndirect:
        return jsValueForDecodedArguments<Messages::RemoteRenderPassEncoder::DrawIndirect::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderPassEncoder_DrawIndexedIndirect:
        return jsValueForDecodedArguments<Messages::RemoteRenderPassEncoder::DrawIndexedIndirect::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderPassEncoder_SetBindGroup:
        return jsValueForDecodedArguments<Messages::RemoteRenderPassEncoder::SetBindGroup::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderPassEncoder_PushDebugGroup:
        return jsValueForDecodedArguments<Messages::RemoteRenderPassEncoder::PushDebugGroup::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderPassEncoder_PopDebugGroup:
        return jsValueForDecodedArguments<Messages::RemoteRenderPassEncoder::PopDebugGroup::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderPassEncoder_InsertDebugMarker:
        return jsValueForDecodedArguments<Messages::RemoteRenderPassEncoder::InsertDebugMarker::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderPassEncoder_SetViewport:
        return jsValueForDecodedArguments<Messages::RemoteRenderPassEncoder::SetViewport::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderPassEncoder_SetScissorRect:
        return jsValueForDecodedArguments<Messages::RemoteRenderPassEncoder::SetScissorRect::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderPassEncoder_SetBlendConstant:
        return jsValueForDecodedArguments<Messages::RemoteRenderPassEncoder::SetBlendConstant::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderPassEncoder_SetStencilReference:
        return jsValueForDecodedArguments<Messages::RemoteRenderPassEncoder::SetStencilReference::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderPassEncoder_BeginOcclusionQuery:
        return jsValueForDecodedArguments<Messages::RemoteRenderPassEncoder::BeginOcclusionQuery::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderPassEncoder_EndOcclusionQuery:
        return jsValueForDecodedArguments<Messages::RemoteRenderPassEncoder::EndOcclusionQuery::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderPassEncoder_ExecuteBundles:
        return jsValueForDecodedArguments<Messages::RemoteRenderPassEncoder::ExecuteBundles::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderPassEncoder_End:
        return jsValueForDecodedArguments<Messages::RemoteRenderPassEncoder::End::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderPassEncoder_SetLabel:
        return jsValueForDecodedArguments<Messages::RemoteRenderPassEncoder::SetLabel::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteRenderPipeline_GetBindGroupLayout:
        return jsValueForDecodedArguments<Messages::RemoteRenderPipeline::GetBindGroupLayout::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderPipeline_SetLabel:
        return jsValueForDecodedArguments<Messages::RemoteRenderPipeline::SetLabel::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteSampler_SetLabel:
        return jsValueForDecodedArguments<Messages::RemoteSampler::SetLabel::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteShaderModule_CompilationInfo:
        return jsValueForDecodedArguments<Messages::RemoteShaderModule::CompilationInfo::Arguments>(globalObject, decoder);
    case MessageName::RemoteShaderModule_SetLabel:
        return jsValueForDecodedArguments<Messages::RemoteShaderModule::SetLabel::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteTexture_CreateView:
        return jsValueForDecodedArguments<Messages::RemoteTexture::CreateView::Arguments>(globalObject, decoder);
    case MessageName::RemoteTexture_Destroy:
        return jsValueForDecodedArguments<Messages::RemoteTexture::Destroy::Arguments>(globalObject, decoder);
    case MessageName::RemoteTexture_SetLabel:
        return jsValueForDecodedArguments<Messages::RemoteTexture::SetLabel::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteTextureView_SetLabel:
        return jsValueForDecodedArguments<Messages::RemoteTextureView::SetLabel::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(WEB_AUDIO)
    case MessageName::RemoteAudioDestinationManager_CreateAudioDestination:
        return jsValueForDecodedArguments<Messages::RemoteAudioDestinationManager::CreateAudioDestination::Arguments>(globalObject, decoder);
    case MessageName::RemoteAudioDestinationManager_DeleteAudioDestination:
        return jsValueForDecodedArguments<Messages::RemoteAudioDestinationManager::DeleteAudioDestination::Arguments>(globalObject, decoder);
    case MessageName::RemoteAudioDestinationManager_StartAudioDestination:
        return jsValueForDecodedArguments<Messages::RemoteAudioDestinationManager::StartAudioDestination::Arguments>(globalObject, decoder);
    case MessageName::RemoteAudioDestinationManager_StopAudioDestination:
        return jsValueForDecodedArguments<Messages::RemoteAudioDestinationManager::StopAudioDestination::Arguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::RemoteAudioDestinationManager_AudioSamplesStorageChanged:
        return jsValueForDecodedArguments<Messages::RemoteAudioDestinationManager::AudioSamplesStorageChanged::Arguments>(globalObject, decoder);
#endif
#endif
#if ENABLE(GPU_PROCESS) && USE(AUDIO_SESSION)
    case MessageName::RemoteAudioSessionProxy_SetCategory:
        return jsValueForDecodedArguments<Messages::RemoteAudioSessionProxy::SetCategory::Arguments>(globalObject, decoder);
    case MessageName::RemoteAudioSessionProxy_SetPreferredBufferSize:
        return jsValueForDecodedArguments<Messages::RemoteAudioSessionProxy::SetPreferredBufferSize::Arguments>(globalObject, decoder);
    case MessageName::RemoteAudioSessionProxy_TryToSetActive:
        return jsValueForDecodedArguments<Messages::RemoteAudioSessionProxy::TryToSetActive::Arguments>(globalObject, decoder);
    case MessageName::RemoteAudioSessionProxy_SetIsPlayingToBluetoothOverride:
        return jsValueForDecodedArguments<Messages::RemoteAudioSessionProxy::SetIsPlayingToBluetoothOverride::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
    case MessageName::RemoteCDMFactoryProxy_CreateCDM:
        return jsValueForDecodedArguments<Messages::RemoteCDMFactoryProxy::CreateCDM::Arguments>(globalObject, decoder);
    case MessageName::RemoteCDMFactoryProxy_SupportsKeySystem:
        return jsValueForDecodedArguments<Messages::RemoteCDMFactoryProxy::SupportsKeySystem::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
    case MessageName::RemoteCDMInstanceProxy_CreateSession:
        return jsValueForDecodedArguments<Messages::RemoteCDMInstanceProxy::CreateSession::Arguments>(globalObject, decoder);
    case MessageName::RemoteCDMInstanceProxy_InitializeWithConfiguration:
        return jsValueForDecodedArguments<Messages::RemoteCDMInstanceProxy::InitializeWithConfiguration::Arguments>(globalObject, decoder);
    case MessageName::RemoteCDMInstanceProxy_SetServerCertificate:
        return jsValueForDecodedArguments<Messages::RemoteCDMInstanceProxy::SetServerCertificate::Arguments>(globalObject, decoder);
    case MessageName::RemoteCDMInstanceProxy_SetStorageDirectory:
        return jsValueForDecodedArguments<Messages::RemoteCDMInstanceProxy::SetStorageDirectory::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
    case MessageName::RemoteCDMInstanceSessionProxy_RequestLicense:
        return jsValueForDecodedArguments<Messages::RemoteCDMInstanceSessionProxy::RequestLicense::Arguments>(globalObject, decoder);
    case MessageName::RemoteCDMInstanceSessionProxy_UpdateLicense:
        return jsValueForDecodedArguments<Messages::RemoteCDMInstanceSessionProxy::UpdateLicense::Arguments>(globalObject, decoder);
    case MessageName::RemoteCDMInstanceSessionProxy_LoadSession:
        return jsValueForDecodedArguments<Messages::RemoteCDMInstanceSessionProxy::LoadSession::Arguments>(globalObject, decoder);
    case MessageName::RemoteCDMInstanceSessionProxy_CloseSession:
        return jsValueForDecodedArguments<Messages::RemoteCDMInstanceSessionProxy::CloseSession::Arguments>(globalObject, decoder);
    case MessageName::RemoteCDMInstanceSessionProxy_RemoveSessionData:
        return jsValueForDecodedArguments<Messages::RemoteCDMInstanceSessionProxy::RemoveSessionData::Arguments>(globalObject, decoder);
    case MessageName::RemoteCDMInstanceSessionProxy_StoreRecordOfKeyUsage:
        return jsValueForDecodedArguments<Messages::RemoteCDMInstanceSessionProxy::StoreRecordOfKeyUsage::Arguments>(globalObject, decoder);
    case MessageName::RemoteCDMInstanceSessionProxy_DisplayIDChanged:
        return jsValueForDecodedArguments<Messages::RemoteCDMInstanceSessionProxy::DisplayIDChanged::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
    case MessageName::RemoteCDMProxy_GetSupportedConfiguration:
        return jsValueForDecodedArguments<Messages::RemoteCDMProxy::GetSupportedConfiguration::Arguments>(globalObject, decoder);
    case MessageName::RemoteCDMProxy_CreateInstance:
        return jsValueForDecodedArguments<Messages::RemoteCDMProxy::CreateInstance::Arguments>(globalObject, decoder);
    case MessageName::RemoteCDMProxy_LoadAndInitialize:
        return jsValueForDecodedArguments<Messages::RemoteCDMProxy::LoadAndInitialize::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(LEGACY_ENCRYPTED_MEDIA)
    case MessageName::RemoteLegacyCDMFactoryProxy_CreateCDM:
        return jsValueForDecodedArguments<Messages::RemoteLegacyCDMFactoryProxy::CreateCDM::Arguments>(globalObject, decoder);
    case MessageName::RemoteLegacyCDMFactoryProxy_SupportsKeySystem:
        return jsValueForDecodedArguments<Messages::RemoteLegacyCDMFactoryProxy::SupportsKeySystem::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(LEGACY_ENCRYPTED_MEDIA)
    case MessageName::RemoteLegacyCDMProxy_SupportsMIMEType:
        return jsValueForDecodedArguments<Messages::RemoteLegacyCDMProxy::SupportsMIMEType::Arguments>(globalObject, decoder);
    case MessageName::RemoteLegacyCDMProxy_CreateSession:
        return jsValueForDecodedArguments<Messages::RemoteLegacyCDMProxy::CreateSession::Arguments>(globalObject, decoder);
    case MessageName::RemoteLegacyCDMProxy_SetPlayerId:
        return jsValueForDecodedArguments<Messages::RemoteLegacyCDMProxy::SetPlayerId::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(LEGACY_ENCRYPTED_MEDIA)
    case MessageName::RemoteLegacyCDMSessionProxy_GenerateKeyRequest:
        return jsValueForDecodedArguments<Messages::RemoteLegacyCDMSessionProxy::GenerateKeyRequest::Arguments>(globalObject, decoder);
    case MessageName::RemoteLegacyCDMSessionProxy_ReleaseKeys:
        return jsValueForDecodedArguments<Messages::RemoteLegacyCDMSessionProxy::ReleaseKeys::Arguments>(globalObject, decoder);
    case MessageName::RemoteLegacyCDMSessionProxy_Update:
        return jsValueForDecodedArguments<Messages::RemoteLegacyCDMSessionProxy::Update::Arguments>(globalObject, decoder);
    case MessageName::RemoteLegacyCDMSessionProxy_CachedKeyForKeyID:
        return jsValueForDecodedArguments<Messages::RemoteLegacyCDMSessionProxy::CachedKeyForKeyID::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteMediaEngineConfigurationFactoryProxy_CreateDecodingConfiguration:
        return jsValueForDecodedArguments<Messages::RemoteMediaEngineConfigurationFactoryProxy::CreateDecodingConfiguration::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaEngineConfigurationFactoryProxy_CreateEncodingConfiguration:
        return jsValueForDecodedArguments<Messages::RemoteMediaEngineConfigurationFactoryProxy::CreateEncodingConfiguration::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteMediaPlayerManagerProxy_CreateMediaPlayer:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerManagerProxy::CreateMediaPlayer::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerManagerProxy_DeleteMediaPlayer:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerManagerProxy::DeleteMediaPlayer::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerManagerProxy_GetSupportedTypes:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerManagerProxy::GetSupportedTypes::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerManagerProxy_SupportsTypeAndCodecs:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerManagerProxy::SupportsTypeAndCodecs::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerManagerProxy_OriginsInMediaCache:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerManagerProxy::OriginsInMediaCache::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerManagerProxy_ClearMediaCache:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerManagerProxy::ClearMediaCache::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerManagerProxy_ClearMediaCacheForOrigins:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerManagerProxy::ClearMediaCacheForOrigins::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerManagerProxy_SupportsKeySystem:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerManagerProxy::SupportsKeySystem::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteMediaPlayerProxy_PrepareForPlayback:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::PrepareForPlayback::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_Load:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::Load::Arguments>(globalObject, decoder);
#if ENABLE(MEDIA_SOURCE)
    case MessageName::RemoteMediaPlayerProxy_LoadMediaSource:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::LoadMediaSource::Arguments>(globalObject, decoder);
#endif
    case MessageName::RemoteMediaPlayerProxy_CancelLoad:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::CancelLoad::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_PrepareToPlay:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::PrepareToPlay::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_Play:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::Play::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_Pause:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::Pause::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_SetVolume:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::SetVolume::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_SetMuted:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::SetMuted::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_Seek:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::Seek::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_SeekWithTolerance:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::SeekWithTolerance::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_SetPreload:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::SetPreload::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_SetPrivateBrowsingMode:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::SetPrivateBrowsingMode::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_SetPreservesPitch:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::SetPreservesPitch::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_SetPitchCorrectionAlgorithm:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::SetPitchCorrectionAlgorithm::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_PrepareForRendering:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::PrepareForRendering::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_SetPageIsVisible:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::SetPageIsVisible::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_SetShouldMaintainAspectRatio:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::SetShouldMaintainAspectRatio::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_AcceleratedRenderingStateChanged:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::AcceleratedRenderingStateChanged::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_SetShouldDisableSleep:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::SetShouldDisableSleep::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_SetRate:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::SetRate::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_DidLoadingProgress:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::DidLoadingProgress::Arguments>(globalObject, decoder);
#if ENABLE(VIDEO_PRESENTATION_MODE)
    case MessageName::RemoteMediaPlayerProxy_UpdateVideoFullscreenInlineImage:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::UpdateVideoFullscreenInlineImage::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_SetVideoFullscreenMode:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::SetVideoFullscreenMode::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_SetVideoFullscreenGravity:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::SetVideoFullscreenGravity::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_VideoFullscreenStandbyChanged:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::VideoFullscreenStandbyChanged::Arguments>(globalObject, decoder);
#endif
    case MessageName::RemoteMediaPlayerProxy_SetBufferingPolicy:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::SetBufferingPolicy::Arguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::RemoteMediaPlayerProxy_SetVideoInlineSizeFenced:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::SetVideoInlineSizeFenced::Arguments>(globalObject, decoder);
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET)
    case MessageName::RemoteMediaPlayerProxy_SetWirelessVideoPlaybackDisabled:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::SetWirelessVideoPlaybackDisabled::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_SetWirelessPlaybackTarget:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::SetWirelessPlaybackTarget::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_SetShouldPlayToPlaybackTarget:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::SetShouldPlayToPlaybackTarget::Arguments>(globalObject, decoder);
#endif
#if ENABLE(LEGACY_ENCRYPTED_MEDIA)
    case MessageName::RemoteMediaPlayerProxy_SetLegacyCDMSession:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::SetLegacyCDMSession::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_KeyAdded:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::KeyAdded::Arguments>(globalObject, decoder);
#endif
#if ENABLE(ENCRYPTED_MEDIA)
    case MessageName::RemoteMediaPlayerProxy_CdmInstanceAttached:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::CdmInstanceAttached::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_CdmInstanceDetached:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::CdmInstanceDetached::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_AttemptToDecryptWithInstance:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::AttemptToDecryptWithInstance::Arguments>(globalObject, decoder);
#endif
#if ENABLE(LEGACY_ENCRYPTED_MEDIA) && ENABLE(ENCRYPTED_MEDIA)
    case MessageName::RemoteMediaPlayerProxy_SetShouldContinueAfterKeyNeeded:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::SetShouldContinueAfterKeyNeeded::Arguments>(globalObject, decoder);
#endif
    case MessageName::RemoteMediaPlayerProxy_BeginSimulatedHDCPError:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::BeginSimulatedHDCPError::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_EndSimulatedHDCPError:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::EndSimulatedHDCPError::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_NotifyActiveSourceBuffersChanged:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::NotifyActiveSourceBuffersChanged::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_ApplicationWillResignActive:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::ApplicationWillResignActive::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_ApplicationDidBecomeActive:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::ApplicationDidBecomeActive::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_NotifyTrackModeChanged:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::NotifyTrackModeChanged::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_TracksChanged:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::TracksChanged::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_AudioTrackSetEnabled:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::AudioTrackSetEnabled::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_VideoTrackSetSelected:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::VideoTrackSetSelected::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_TextTrackSetMode:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::TextTrackSetMode::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_PerformTaskAtMediaTime:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::PerformTaskAtMediaTime::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_WouldTaintOrigin:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::WouldTaintOrigin::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_SetVideoPlaybackMetricsUpdateInterval:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::SetVideoPlaybackMetricsUpdateInterval::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_SetPreferredDynamicRangeMode:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::SetPreferredDynamicRangeMode::Arguments>(globalObject, decoder);
#if PLATFORM(IOS_FAMILY)
    case MessageName::RemoteMediaPlayerProxy_ErrorLog:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::ErrorLog::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_AccessLog:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::AccessLog::Arguments>(globalObject, decoder);
#endif
#if ENABLE(WEB_AUDIO)
    case MessageName::RemoteMediaPlayerProxy_CreateAudioSourceProvider:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::CreateAudioSourceProvider::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_SetShouldEnableAudioSourceProvider:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::SetShouldEnableAudioSourceProvider::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(COCOA)
    case MessageName::RemoteMediaPlayerProxy_NativeImageForCurrentTime:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::NativeImageForCurrentTime::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_ColorSpace:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::ColorSpace::Arguments>(globalObject, decoder);
#endif
    case MessageName::RemoteMediaPlayerProxy_VideoFrameForCurrentTimeIfChanged:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::VideoFrameForCurrentTimeIfChanged::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_PlayAtHostTime:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::PlayAtHostTime::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_PauseAtHostTime:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::PauseAtHostTime::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_StartVideoFrameMetadataGathering:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::StartVideoFrameMetadataGathering::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_StopVideoFrameMetadataGathering:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::StopVideoFrameMetadataGathering::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteMediaResourceManager_ResponseReceived:
        return jsValueForDecodedArguments<Messages::RemoteMediaResourceManager::ResponseReceived::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaResourceManager_RedirectReceived:
        return jsValueForDecodedArguments<Messages::RemoteMediaResourceManager::RedirectReceived::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaResourceManager_DataSent:
        return jsValueForDecodedArguments<Messages::RemoteMediaResourceManager::DataSent::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaResourceManager_DataReceived:
        return jsValueForDecodedArguments<Messages::RemoteMediaResourceManager::DataReceived::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaResourceManager_AccessControlCheckFailed:
        return jsValueForDecodedArguments<Messages::RemoteMediaResourceManager::AccessControlCheckFailed::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaResourceManager_LoadFailed:
        return jsValueForDecodedArguments<Messages::RemoteMediaResourceManager::LoadFailed::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaResourceManager_LoadFinished:
        return jsValueForDecodedArguments<Messages::RemoteMediaResourceManager::LoadFinished::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)
    case MessageName::RemoteMediaSourceProxy_AddSourceBuffer:
        return jsValueForDecodedArguments<Messages::RemoteMediaSourceProxy::AddSourceBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaSourceProxy_DurationChanged:
        return jsValueForDecodedArguments<Messages::RemoteMediaSourceProxy::DurationChanged::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaSourceProxy_BufferedChanged:
        return jsValueForDecodedArguments<Messages::RemoteMediaSourceProxy::BufferedChanged::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaSourceProxy_SetReadyState:
        return jsValueForDecodedArguments<Messages::RemoteMediaSourceProxy::SetReadyState::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaSourceProxy_SetIsSeeking:
        return jsValueForDecodedArguments<Messages::RemoteMediaSourceProxy::SetIsSeeking::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaSourceProxy_WaitForSeekCompleted:
        return jsValueForDecodedArguments<Messages::RemoteMediaSourceProxy::WaitForSeekCompleted::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaSourceProxy_SeekCompleted:
        return jsValueForDecodedArguments<Messages::RemoteMediaSourceProxy::SeekCompleted::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaSourceProxy_SetTimeFudgeFactor:
        return jsValueForDecodedArguments<Messages::RemoteMediaSourceProxy::SetTimeFudgeFactor::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteRemoteCommandListenerProxy_UpdateSupportedCommands:
        return jsValueForDecodedArguments<Messages::RemoteRemoteCommandListenerProxy::UpdateSupportedCommands::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)
    case MessageName::RemoteSourceBufferProxy_SetActive:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::SetActive::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_CanSwitchToType:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::CanSwitchToType::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_SetMode:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::SetMode::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_Append:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::Append::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_Abort:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::Abort::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_ResetParserState:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::ResetParserState::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_RemovedFromMediaSource:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::RemovedFromMediaSource::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_SetMediaSourceEnded:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::SetMediaSourceEnded::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_SetReadyState:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::SetReadyState::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_StartChangingType:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::StartChangingType::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_UpdateBufferedFromTrackBuffers:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::UpdateBufferedFromTrackBuffers::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_AddTrackBuffer:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::AddTrackBuffer::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_ResetTrackBuffers:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::ResetTrackBuffers::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_ClearTrackBuffers:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::ClearTrackBuffers::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_SetAllTrackBuffersNeedRandomAccess:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::SetAllTrackBuffersNeedRandomAccess::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_RemoveCodedFrames:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::RemoveCodedFrames::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_EvictCodedFrames:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::EvictCodedFrames::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_ReenqueueMediaIfNeeded:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::ReenqueueMediaIfNeeded::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_SetGroupStartTimestamp:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::SetGroupStartTimestamp::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_SetGroupStartTimestampToEndTimestamp:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::SetGroupStartTimestampToEndTimestamp::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_SetShouldGenerateTimestamps:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::SetShouldGenerateTimestamps::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_ResetTimestampOffsetInTrackBuffers:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::ResetTimestampOffsetInTrackBuffers::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_SetTimestampOffset:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::SetTimestampOffset::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_SetAppendWindowStart:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::SetAppendWindowStart::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_SetAppendWindowEnd:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::SetAppendWindowEnd::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_SeekToTime:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::SeekToTime::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_UpdateTrackIds:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::UpdateTrackIds::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_BufferedSamplesForTrackId:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::BufferedSamplesForTrackId::Arguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_EnqueuedSamplesForTrackID:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::EnqueuedSamplesForTrackID::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(VIDEO)
#if PLATFORM(COCOA)
    case MessageName::RemoteVideoFrameObjectHeap_GetVideoFrameBuffer:
        return jsValueForDecodedArguments<Messages::RemoteVideoFrameObjectHeap::GetVideoFrameBuffer::Arguments>(globalObject, decoder);
#endif
    case MessageName::RemoteVideoFrameObjectHeap_ReleaseVideoFrame:
        return jsValueForDecodedArguments<Messages::RemoteVideoFrameObjectHeap::ReleaseVideoFrame::Arguments>(globalObject, decoder);
#endif
#if USE(LIBWEBRTC) && PLATFORM(COCOA) && ENABLE(GPU_PROCESS)
    case MessageName::LibWebRTCCodecsProxy_CreateH264Decoder:
        return jsValueForDecodedArguments<Messages::LibWebRTCCodecsProxy::CreateH264Decoder::Arguments>(globalObject, decoder);
    case MessageName::LibWebRTCCodecsProxy_CreateH265Decoder:
        return jsValueForDecodedArguments<Messages::LibWebRTCCodecsProxy::CreateH265Decoder::Arguments>(globalObject, decoder);
    case MessageName::LibWebRTCCodecsProxy_CreateVP9Decoder:
        return jsValueForDecodedArguments<Messages::LibWebRTCCodecsProxy::CreateVP9Decoder::Arguments>(globalObject, decoder);
    case MessageName::LibWebRTCCodecsProxy_ReleaseDecoder:
        return jsValueForDecodedArguments<Messages::LibWebRTCCodecsProxy::ReleaseDecoder::Arguments>(globalObject, decoder);
    case MessageName::LibWebRTCCodecsProxy_DecodeFrame:
        return jsValueForDecodedArguments<Messages::LibWebRTCCodecsProxy::DecodeFrame::Arguments>(globalObject, decoder);
    case MessageName::LibWebRTCCodecsProxy_SetFrameSize:
        return jsValueForDecodedArguments<Messages::LibWebRTCCodecsProxy::SetFrameSize::Arguments>(globalObject, decoder);
    case MessageName::LibWebRTCCodecsProxy_CreateEncoder:
        return jsValueForDecodedArguments<Messages::LibWebRTCCodecsProxy::CreateEncoder::Arguments>(globalObject, decoder);
    case MessageName::LibWebRTCCodecsProxy_ReleaseEncoder:
        return jsValueForDecodedArguments<Messages::LibWebRTCCodecsProxy::ReleaseEncoder::Arguments>(globalObject, decoder);
    case MessageName::LibWebRTCCodecsProxy_InitializeEncoder:
        return jsValueForDecodedArguments<Messages::LibWebRTCCodecsProxy::InitializeEncoder::Arguments>(globalObject, decoder);
    case MessageName::LibWebRTCCodecsProxy_EncodeFrame:
        return jsValueForDecodedArguments<Messages::LibWebRTCCodecsProxy::EncodeFrame::Arguments>(globalObject, decoder);
    case MessageName::LibWebRTCCodecsProxy_SetEncodeRates:
        return jsValueForDecodedArguments<Messages::LibWebRTCCodecsProxy::SetEncodeRates::Arguments>(globalObject, decoder);
    case MessageName::LibWebRTCCodecsProxy_SetSharedVideoFrameSemaphore:
        return jsValueForDecodedArguments<Messages::LibWebRTCCodecsProxy::SetSharedVideoFrameSemaphore::Arguments>(globalObject, decoder);
    case MessageName::LibWebRTCCodecsProxy_SetSharedVideoFrameMemory:
        return jsValueForDecodedArguments<Messages::LibWebRTCCodecsProxy::SetSharedVideoFrameMemory::Arguments>(globalObject, decoder);
    case MessageName::LibWebRTCCodecsProxy_SetRTCLoggingLevel:
        return jsValueForDecodedArguments<Messages::LibWebRTCCodecsProxy::SetRTCLoggingLevel::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
    case MessageName::RemoteAudioMediaStreamTrackRendererInternalUnitManager_CreateUnit:
        return jsValueForDecodedArguments<Messages::RemoteAudioMediaStreamTrackRendererInternalUnitManager::CreateUnit::Arguments>(globalObject, decoder);
    case MessageName::RemoteAudioMediaStreamTrackRendererInternalUnitManager_DeleteUnit:
        return jsValueForDecodedArguments<Messages::RemoteAudioMediaStreamTrackRendererInternalUnitManager::DeleteUnit::Arguments>(globalObject, decoder);
    case MessageName::RemoteAudioMediaStreamTrackRendererInternalUnitManager_StartUnit:
        return jsValueForDecodedArguments<Messages::RemoteAudioMediaStreamTrackRendererInternalUnitManager::StartUnit::Arguments>(globalObject, decoder);
    case MessageName::RemoteAudioMediaStreamTrackRendererInternalUnitManager_StopUnit:
        return jsValueForDecodedArguments<Messages::RemoteAudioMediaStreamTrackRendererInternalUnitManager::StopUnit::Arguments>(globalObject, decoder);
    case MessageName::RemoteAudioMediaStreamTrackRendererInternalUnitManager_SetAudioOutputDevice:
        return jsValueForDecodedArguments<Messages::RemoteAudioMediaStreamTrackRendererInternalUnitManager::SetAudioOutputDevice::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
    case MessageName::RemoteMediaRecorder_AudioSamplesStorageChanged:
        return jsValueForDecodedArguments<Messages::RemoteMediaRecorder::AudioSamplesStorageChanged::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaRecorder_AudioSamplesAvailable:
        return jsValueForDecodedArguments<Messages::RemoteMediaRecorder::AudioSamplesAvailable::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaRecorder_VideoSampleAvailable:
        return jsValueForDecodedArguments<Messages::RemoteMediaRecorder::VideoSampleAvailable::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaRecorder_FetchData:
        return jsValueForDecodedArguments<Messages::RemoteMediaRecorder::FetchData::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaRecorder_StopRecording:
        return jsValueForDecodedArguments<Messages::RemoteMediaRecorder::StopRecording::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaRecorder_Pause:
        return jsValueForDecodedArguments<Messages::RemoteMediaRecorder::Pause::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaRecorder_Resume:
        return jsValueForDecodedArguments<Messages::RemoteMediaRecorder::Resume::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaRecorder_SetSharedVideoFrameSemaphore:
        return jsValueForDecodedArguments<Messages::RemoteMediaRecorder::SetSharedVideoFrameSemaphore::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaRecorder_SetSharedVideoFrameMemory:
        return jsValueForDecodedArguments<Messages::RemoteMediaRecorder::SetSharedVideoFrameMemory::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
    case MessageName::RemoteMediaRecorderManager_CreateRecorder:
        return jsValueForDecodedArguments<Messages::RemoteMediaRecorderManager::CreateRecorder::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaRecorderManager_ReleaseRecorder:
        return jsValueForDecodedArguments<Messages::RemoteMediaRecorderManager::ReleaseRecorder::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
#if !RELEASE_LOG_DISABLED
    case MessageName::RemoteSampleBufferDisplayLayer_SetLogIdentifier:
        return jsValueForDecodedArguments<Messages::RemoteSampleBufferDisplayLayer::SetLogIdentifier::Arguments>(globalObject, decoder);
#endif
    case MessageName::RemoteSampleBufferDisplayLayer_UpdateDisplayMode:
        return jsValueForDecodedArguments<Messages::RemoteSampleBufferDisplayLayer::UpdateDisplayMode::Arguments>(globalObject, decoder);
    case MessageName::RemoteSampleBufferDisplayLayer_UpdateAffineTransform:
        return jsValueForDecodedArguments<Messages::RemoteSampleBufferDisplayLayer::UpdateAffineTransform::Arguments>(globalObject, decoder);
    case MessageName::RemoteSampleBufferDisplayLayer_UpdateBoundsAndPosition:
        return jsValueForDecodedArguments<Messages::RemoteSampleBufferDisplayLayer::UpdateBoundsAndPosition::Arguments>(globalObject, decoder);
    case MessageName::RemoteSampleBufferDisplayLayer_Flush:
        return jsValueForDecodedArguments<Messages::RemoteSampleBufferDisplayLayer::Flush::Arguments>(globalObject, decoder);
    case MessageName::RemoteSampleBufferDisplayLayer_FlushAndRemoveImage:
        return jsValueForDecodedArguments<Messages::RemoteSampleBufferDisplayLayer::FlushAndRemoveImage::Arguments>(globalObject, decoder);
    case MessageName::RemoteSampleBufferDisplayLayer_EnqueueSample:
        return jsValueForDecodedArguments<Messages::RemoteSampleBufferDisplayLayer::EnqueueSample::Arguments>(globalObject, decoder);
    case MessageName::RemoteSampleBufferDisplayLayer_EnqueueSampleCV:
        return jsValueForDecodedArguments<Messages::RemoteSampleBufferDisplayLayer::EnqueueSampleCV::Arguments>(globalObject, decoder);
    case MessageName::RemoteSampleBufferDisplayLayer_ClearEnqueuedSamples:
        return jsValueForDecodedArguments<Messages::RemoteSampleBufferDisplayLayer::ClearEnqueuedSamples::Arguments>(globalObject, decoder);
    case MessageName::RemoteSampleBufferDisplayLayer_Play:
        return jsValueForDecodedArguments<Messages::RemoteSampleBufferDisplayLayer::Play::Arguments>(globalObject, decoder);
    case MessageName::RemoteSampleBufferDisplayLayer_Pause:
        return jsValueForDecodedArguments<Messages::RemoteSampleBufferDisplayLayer::Pause::Arguments>(globalObject, decoder);
    case MessageName::RemoteSampleBufferDisplayLayer_SetSharedVideoFrameSemaphore:
        return jsValueForDecodedArguments<Messages::RemoteSampleBufferDisplayLayer::SetSharedVideoFrameSemaphore::Arguments>(globalObject, decoder);
    case MessageName::RemoteSampleBufferDisplayLayer_SetSharedVideoFrameMemory:
        return jsValueForDecodedArguments<Messages::RemoteSampleBufferDisplayLayer::SetSharedVideoFrameMemory::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
    case MessageName::RemoteSampleBufferDisplayLayerManager_CreateLayer:
        return jsValueForDecodedArguments<Messages::RemoteSampleBufferDisplayLayerManager::CreateLayer::Arguments>(globalObject, decoder);
    case MessageName::RemoteSampleBufferDisplayLayerManager_ReleaseLayer:
        return jsValueForDecodedArguments<Messages::RemoteSampleBufferDisplayLayerManager::ReleaseLayer::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebCookieManager_GetHostnamesWithCookies:
        return jsValueForDecodedArguments<Messages::WebCookieManager::GetHostnamesWithCookies::Arguments>(globalObject, decoder);
    case MessageName::WebCookieManager_DeleteCookiesForHostnames:
        return jsValueForDecodedArguments<Messages::WebCookieManager::DeleteCookiesForHostnames::Arguments>(globalObject, decoder);
    case MessageName::WebCookieManager_DeleteAllCookies:
        return jsValueForDecodedArguments<Messages::WebCookieManager::DeleteAllCookies::Arguments>(globalObject, decoder);
    case MessageName::WebCookieManager_SetCookie:
        return jsValueForDecodedArguments<Messages::WebCookieManager::SetCookie::Arguments>(globalObject, decoder);
    case MessageName::WebCookieManager_SetCookies:
        return jsValueForDecodedArguments<Messages::WebCookieManager::SetCookies::Arguments>(globalObject, decoder);
    case MessageName::WebCookieManager_GetAllCookies:
        return jsValueForDecodedArguments<Messages::WebCookieManager::GetAllCookies::Arguments>(globalObject, decoder);
    case MessageName::WebCookieManager_GetCookies:
        return jsValueForDecodedArguments<Messages::WebCookieManager::GetCookies::Arguments>(globalObject, decoder);
    case MessageName::WebCookieManager_DeleteCookie:
        return jsValueForDecodedArguments<Messages::WebCookieManager::DeleteCookie::Arguments>(globalObject, decoder);
    case MessageName::WebCookieManager_DeleteAllCookiesModifiedSince:
        return jsValueForDecodedArguments<Messages::WebCookieManager::DeleteAllCookiesModifiedSince::Arguments>(globalObject, decoder);
    case MessageName::WebCookieManager_SetHTTPCookieAcceptPolicy:
        return jsValueForDecodedArguments<Messages::WebCookieManager::SetHTTPCookieAcceptPolicy::Arguments>(globalObject, decoder);
    case MessageName::WebCookieManager_GetHTTPCookieAcceptPolicy:
        return jsValueForDecodedArguments<Messages::WebCookieManager::GetHTTPCookieAcceptPolicy::Arguments>(globalObject, decoder);
    case MessageName::WebCookieManager_StartObservingCookieChanges:
        return jsValueForDecodedArguments<Messages::WebCookieManager::StartObservingCookieChanges::Arguments>(globalObject, decoder);
    case MessageName::WebCookieManager_StopObservingCookieChanges:
        return jsValueForDecodedArguments<Messages::WebCookieManager::StopObservingCookieChanges::Arguments>(globalObject, decoder);
#if USE(SOUP)
    case MessageName::WebCookieManager_SetCookiePersistentStorage:
        return jsValueForDecodedArguments<Messages::WebCookieManager::SetCookiePersistentStorage::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebIDBServer_DeleteDatabase:
        return jsValueForDecodedArguments<Messages::WebIDBServer::DeleteDatabase::Arguments>(globalObject, decoder);
    case MessageName::WebIDBServer_OpenDatabase:
        return jsValueForDecodedArguments<Messages::WebIDBServer::OpenDatabase::Arguments>(globalObject, decoder);
    case MessageName::WebIDBServer_AbortTransaction:
        return jsValueForDecodedArguments<Messages::WebIDBServer::AbortTransaction::Arguments>(globalObject, decoder);
    case MessageName::WebIDBServer_CommitTransaction:
        return jsValueForDecodedArguments<Messages::WebIDBServer::CommitTransaction::Arguments>(globalObject, decoder);
    case MessageName::WebIDBServer_DidFinishHandlingVersionChangeTransaction:
        return jsValueForDecodedArguments<Messages::WebIDBServer::DidFinishHandlingVersionChangeTransaction::Arguments>(globalObject, decoder);
    case MessageName::WebIDBServer_CreateObjectStore:
        return jsValueForDecodedArguments<Messages::WebIDBServer::CreateObjectStore::Arguments>(globalObject, decoder);
    case MessageName::WebIDBServer_DeleteObjectStore:
        return jsValueForDecodedArguments<Messages::WebIDBServer::DeleteObjectStore::Arguments>(globalObject, decoder);
    case MessageName::WebIDBServer_RenameObjectStore:
        return jsValueForDecodedArguments<Messages::WebIDBServer::RenameObjectStore::Arguments>(globalObject, decoder);
    case MessageName::WebIDBServer_ClearObjectStore:
        return jsValueForDecodedArguments<Messages::WebIDBServer::ClearObjectStore::Arguments>(globalObject, decoder);
    case MessageName::WebIDBServer_CreateIndex:
        return jsValueForDecodedArguments<Messages::WebIDBServer::CreateIndex::Arguments>(globalObject, decoder);
    case MessageName::WebIDBServer_DeleteIndex:
        return jsValueForDecodedArguments<Messages::WebIDBServer::DeleteIndex::Arguments>(globalObject, decoder);
    case MessageName::WebIDBServer_RenameIndex:
        return jsValueForDecodedArguments<Messages::WebIDBServer::RenameIndex::Arguments>(globalObject, decoder);
    case MessageName::WebIDBServer_PutOrAdd:
        return jsValueForDecodedArguments<Messages::WebIDBServer::PutOrAdd::Arguments>(globalObject, decoder);
    case MessageName::WebIDBServer_GetRecord:
        return jsValueForDecodedArguments<Messages::WebIDBServer::GetRecord::Arguments>(globalObject, decoder);
    case MessageName::WebIDBServer_GetAllRecords:
        return jsValueForDecodedArguments<Messages::WebIDBServer::GetAllRecords::Arguments>(globalObject, decoder);
    case MessageName::WebIDBServer_GetCount:
        return jsValueForDecodedArguments<Messages::WebIDBServer::GetCount::Arguments>(globalObject, decoder);
    case MessageName::WebIDBServer_DeleteRecord:
        return jsValueForDecodedArguments<Messages::WebIDBServer::DeleteRecord::Arguments>(globalObject, decoder);
    case MessageName::WebIDBServer_OpenCursor:
        return jsValueForDecodedArguments<Messages::WebIDBServer::OpenCursor::Arguments>(globalObject, decoder);
    case MessageName::WebIDBServer_IterateCursor:
        return jsValueForDecodedArguments<Messages::WebIDBServer::IterateCursor::Arguments>(globalObject, decoder);
    case MessageName::WebIDBServer_EstablishTransaction:
        return jsValueForDecodedArguments<Messages::WebIDBServer::EstablishTransaction::Arguments>(globalObject, decoder);
    case MessageName::WebIDBServer_DatabaseConnectionPendingClose:
        return jsValueForDecodedArguments<Messages::WebIDBServer::DatabaseConnectionPendingClose::Arguments>(globalObject, decoder);
    case MessageName::WebIDBServer_DatabaseConnectionClosed:
        return jsValueForDecodedArguments<Messages::WebIDBServer::DatabaseConnectionClosed::Arguments>(globalObject, decoder);
    case MessageName::WebIDBServer_AbortOpenAndUpgradeNeeded:
        return jsValueForDecodedArguments<Messages::WebIDBServer::AbortOpenAndUpgradeNeeded::Arguments>(globalObject, decoder);
    case MessageName::WebIDBServer_DidFireVersionChangeEvent:
        return jsValueForDecodedArguments<Messages::WebIDBServer::DidFireVersionChangeEvent::Arguments>(globalObject, decoder);
    case MessageName::WebIDBServer_OpenDBRequestCancelled:
        return jsValueForDecodedArguments<Messages::WebIDBServer::OpenDBRequestCancelled::Arguments>(globalObject, decoder);
    case MessageName::WebIDBServer_GetAllDatabaseNamesAndVersions:
        return jsValueForDecodedArguments<Messages::WebIDBServer::GetAllDatabaseNamesAndVersions::Arguments>(globalObject, decoder);
    case MessageName::NetworkBroadcastChannelRegistry_RegisterChannel:
        return jsValueForDecodedArguments<Messages::NetworkBroadcastChannelRegistry::RegisterChannel::Arguments>(globalObject, decoder);
    case MessageName::NetworkBroadcastChannelRegistry_UnregisterChannel:
        return jsValueForDecodedArguments<Messages::NetworkBroadcastChannelRegistry::UnregisterChannel::Arguments>(globalObject, decoder);
    case MessageName::NetworkBroadcastChannelRegistry_PostMessage:
        return jsValueForDecodedArguments<Messages::NetworkBroadcastChannelRegistry::PostMessage::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_ScheduleResourceLoad:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::ScheduleResourceLoad::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_PerformSynchronousLoad:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::PerformSynchronousLoad::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_TestProcessIncomingSyncMessagesWhenWaitingForSyncReply:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::TestProcessIncomingSyncMessagesWhenWaitingForSyncReply::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_LoadPing:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::LoadPing::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_RemoveLoadIdentifier:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::RemoveLoadIdentifier::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_PageLoadCompleted:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::PageLoadCompleted::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_BrowsingContextRemoved:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::BrowsingContextRemoved::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_PrefetchDNS:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::PrefetchDNS::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_SendH2Ping:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::SendH2Ping::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_PreconnectTo:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::PreconnectTo::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_IsResourceLoadFinished:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::IsResourceLoadFinished::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_StartDownload:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::StartDownload::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_ConvertMainResourceLoadToDownload:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::ConvertMainResourceLoadToDownload::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_CookiesForDOM:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::CookiesForDOM::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_SetCookiesFromDOM:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::SetCookiesFromDOM::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_CookieRequestHeaderFieldValue:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::CookieRequestHeaderFieldValue::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_GetRawCookies:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::GetRawCookies::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_SetRawCookie:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::SetRawCookie::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_DeleteCookie:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::DeleteCookie::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_DomCookiesForHost:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::DomCookiesForHost::Arguments>(globalObject, decoder);
#if HAVE(COOKIE_CHANGE_LISTENER_API)
    case MessageName::NetworkConnectionToWebProcess_UnsubscribeFromCookieChangeNotifications:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::UnsubscribeFromCookieChangeNotifications::Arguments>(globalObject, decoder);
#endif
    case MessageName::NetworkConnectionToWebProcess_RegisterFileBlobURL:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::RegisterFileBlobURL::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_RegisterBlobURL:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::RegisterBlobURL::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_RegisterBlobURLFromURL:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::RegisterBlobURLFromURL::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_RegisterBlobURLOptionallyFileBacked:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::RegisterBlobURLOptionallyFileBacked::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_RegisterBlobURLForSlice:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::RegisterBlobURLForSlice::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_UnregisterBlobURL:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::UnregisterBlobURL::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_BlobSize:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::BlobSize::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_WriteBlobsToTemporaryFilesForIndexedDB:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::WriteBlobsToTemporaryFilesForIndexedDB::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_RegisterBlobURLHandle:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::RegisterBlobURLHandle::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_UnregisterBlobURLHandle:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::UnregisterBlobURLHandle::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_SetCaptureExtraNetworkLoadMetricsEnabled:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::SetCaptureExtraNetworkLoadMetricsEnabled::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_CreateSocketStream:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::CreateSocketStream::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_CreateSocketChannel:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::CreateSocketChannel::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_ClearPageSpecificData:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::ClearPageSpecificData::Arguments>(globalObject, decoder);
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
    case MessageName::NetworkConnectionToWebProcess_RemoveStorageAccessForFrame:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::RemoveStorageAccessForFrame::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_LogUserInteraction:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::LogUserInteraction::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_ResourceLoadStatisticsUpdated:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::ResourceLoadStatisticsUpdated::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_HasStorageAccess:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::HasStorageAccess::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_RequestStorageAccess:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::RequestStorageAccess::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_RequestStorageAccessUnderOpener:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::RequestStorageAccessUnderOpener::Arguments>(globalObject, decoder);
#endif
    case MessageName::NetworkConnectionToWebProcess_AddOriginAccessAllowListEntry:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::AddOriginAccessAllowListEntry::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_RemoveOriginAccessAllowListEntry:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::RemoveOriginAccessAllowListEntry::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_ResetOriginAccessAllowLists:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::ResetOriginAccessAllowLists::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_GetNetworkLoadInformationResponse:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::GetNetworkLoadInformationResponse::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_GetNetworkLoadIntermediateInformation:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::GetNetworkLoadIntermediateInformation::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_TakeNetworkLoadInformationMetrics:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::TakeNetworkLoadInformationMetrics::Arguments>(globalObject, decoder);
#if ENABLE(SERVICE_WORKER)
    case MessageName::NetworkConnectionToWebProcess_EstablishSWContextConnection:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::EstablishSWContextConnection::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_CloseSWContextConnection:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::CloseSWContextConnection::Arguments>(globalObject, decoder);
#endif
    case MessageName::NetworkConnectionToWebProcess_EstablishSharedWorkerContextConnection:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::EstablishSharedWorkerContextConnection::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_CloseSharedWorkerContextConnection:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::CloseSharedWorkerContextConnection::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_CreateRTCProvider:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::CreateRTCProvider::Arguments>(globalObject, decoder);
#if ENABLE(WEB_RTC)
    case MessageName::NetworkConnectionToWebProcess_ConnectToRTCDataChannelRemoteSource:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::ConnectToRTCDataChannelRemoteSource::Arguments>(globalObject, decoder);
#endif
    case MessageName::NetworkConnectionToWebProcess_UpdateQuotaBasedOnSpaceUsageForTesting:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::UpdateQuotaBasedOnSpaceUsageForTesting::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_CreateNewMessagePortChannel:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::CreateNewMessagePortChannel::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_EntangleLocalPortInThisProcessToRemote:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::EntangleLocalPortInThisProcessToRemote::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_MessagePortDisentangled:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::MessagePortDisentangled::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_MessagePortClosed:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::MessagePortClosed::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_TakeAllMessagesForPort:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::TakeAllMessagesForPort::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_PostMessageToRemote:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::PostMessageToRemote::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_CheckRemotePortForActivity:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::CheckRemotePortForActivity::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_DidDeliverMessagePortMessages:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::DidDeliverMessagePortMessages::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_RegisterURLSchemesAsCORSEnabled:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::RegisterURLSchemesAsCORSEnabled::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_SetCORSDisablingPatterns:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::SetCORSDisablingPatterns::Arguments>(globalObject, decoder);
#if PLATFORM(MAC)
    case MessageName::NetworkConnectionToWebProcess_GetProcessDisplayName:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::GetProcessDisplayName::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_UpdateActivePages:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::UpdateActivePages::Arguments>(globalObject, decoder);
#endif
    case MessageName::NetworkConnectionToWebProcess_SetResourceLoadSchedulingMode:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::SetResourceLoadSchedulingMode::Arguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_PrioritizeResourceLoads:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::PrioritizeResourceLoads::Arguments>(globalObject, decoder);
#if ENABLE(CONTENT_EXTENSIONS)
    case MessageName::NetworkContentRuleListManager_Remove:
        return jsValueForDecodedArguments<Messages::NetworkContentRuleListManager::Remove::Arguments>(globalObject, decoder);
    case MessageName::NetworkContentRuleListManager_AddContentRuleLists:
        return jsValueForDecodedArguments<Messages::NetworkContentRuleListManager::AddContentRuleLists::Arguments>(globalObject, decoder);
    case MessageName::NetworkContentRuleListManager_RemoveContentRuleList:
        return jsValueForDecodedArguments<Messages::NetworkContentRuleListManager::RemoveContentRuleList::Arguments>(globalObject, decoder);
    case MessageName::NetworkContentRuleListManager_RemoveAllContentRuleLists:
        return jsValueForDecodedArguments<Messages::NetworkContentRuleListManager::RemoveAllContentRuleLists::Arguments>(globalObject, decoder);
#endif
    case MessageName::NetworkProcess_InitializeNetworkProcess:
        return jsValueForDecodedArguments<Messages::NetworkProcess::InitializeNetworkProcess::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_CreateNetworkConnectionToWebProcess:
        return jsValueForDecodedArguments<Messages::NetworkProcess::CreateNetworkConnectionToWebProcess::Arguments>(globalObject, decoder);
#if USE(SOUP)
    case MessageName::NetworkProcess_SetIgnoreTLSErrors:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetIgnoreTLSErrors::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_UserPreferredLanguagesChanged:
        return jsValueForDecodedArguments<Messages::NetworkProcess::UserPreferredLanguagesChanged::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetNetworkProxySettings:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetNetworkProxySettings::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_PrefetchDNS:
        return jsValueForDecodedArguments<Messages::NetworkProcess::PrefetchDNS::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetPersistentCredentialStorageEnabled:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetPersistentCredentialStorageEnabled::Arguments>(globalObject, decoder);
#endif
#if USE(CURL)
    case MessageName::NetworkProcess_SetNetworkProxySettings:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetNetworkProxySettings::Arguments>(globalObject, decoder);
#endif
    case MessageName::NetworkProcess_ClearCachedCredentials:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ClearCachedCredentials::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_AddWebsiteDataStore:
        return jsValueForDecodedArguments<Messages::NetworkProcess::AddWebsiteDataStore::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_DestroySession:
        return jsValueForDecodedArguments<Messages::NetworkProcess::DestroySession::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_FetchWebsiteData:
        return jsValueForDecodedArguments<Messages::NetworkProcess::FetchWebsiteData::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_DeleteWebsiteData:
        return jsValueForDecodedArguments<Messages::NetworkProcess::DeleteWebsiteData::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_DeleteWebsiteDataForOrigins:
        return jsValueForDecodedArguments<Messages::NetworkProcess::DeleteWebsiteDataForOrigins::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_RenameOriginInWebsiteData:
        return jsValueForDecodedArguments<Messages::NetworkProcess::RenameOriginInWebsiteData::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_DownloadRequest:
        return jsValueForDecodedArguments<Messages::NetworkProcess::DownloadRequest::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ResumeDownload:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ResumeDownload::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_CancelDownload:
        return jsValueForDecodedArguments<Messages::NetworkProcess::CancelDownload::Arguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::NetworkProcess_PublishDownloadProgress:
        return jsValueForDecodedArguments<Messages::NetworkProcess::PublishDownloadProgress::Arguments>(globalObject, decoder);
#endif
    case MessageName::NetworkProcess_RequestResource:
        return jsValueForDecodedArguments<Messages::NetworkProcess::RequestResource::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ApplicationDidEnterBackground:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ApplicationDidEnterBackground::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ApplicationWillEnterForeground:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ApplicationWillEnterForeground::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ContinueWillSendRequest:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ContinueWillSendRequest::Arguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::NetworkProcess_SetQOS:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetQOS::Arguments>(globalObject, decoder);
#endif
    case MessageName::NetworkProcess_SetAllowsAnySSLCertificateForWebSocket:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetAllowsAnySSLCertificateForWebSocket::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_FlushCookies:
        return jsValueForDecodedArguments<Messages::NetworkProcess::FlushCookies::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_AllowSpecificHTTPSCertificateForHost:
        return jsValueForDecodedArguments<Messages::NetworkProcess::AllowSpecificHTTPSCertificateForHost::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_AllowTLSCertificateChainForLocalPCMTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::AllowTLSCertificateChainForLocalPCMTesting::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetCacheModel:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetCacheModel::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetCacheModelSynchronouslyForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetCacheModelSynchronouslyForTesting::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ProcessWillSuspendImminentlyForTestingSync:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ProcessWillSuspendImminentlyForTestingSync::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_PrepareToSuspend:
        return jsValueForDecodedArguments<Messages::NetworkProcess::PrepareToSuspend::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ProcessDidResume:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ProcessDidResume::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_PreconnectTo:
        return jsValueForDecodedArguments<Messages::NetworkProcess::PreconnectTo::Arguments>(globalObject, decoder);
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
    case MessageName::NetworkProcess_ClearPrevalentResource:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ClearPrevalentResource::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ClearUserInteraction:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ClearUserInteraction::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_DumpResourceLoadStatistics:
        return jsValueForDecodedArguments<Messages::NetworkProcess::DumpResourceLoadStatistics::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetResourceLoadStatisticsEnabled:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetResourceLoadStatisticsEnabled::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetResourceLoadStatisticsLogTestingEvent:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetResourceLoadStatisticsLogTestingEvent::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_UpdatePrevalentDomainsToBlockCookiesFor:
        return jsValueForDecodedArguments<Messages::NetworkProcess::UpdatePrevalentDomainsToBlockCookiesFor::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_IsGrandfathered:
        return jsValueForDecodedArguments<Messages::NetworkProcess::IsGrandfathered::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_IsPrevalentResource:
        return jsValueForDecodedArguments<Messages::NetworkProcess::IsPrevalentResource::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_IsVeryPrevalentResource:
        return jsValueForDecodedArguments<Messages::NetworkProcess::IsVeryPrevalentResource::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetAgeCapForClientSideCookies:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetAgeCapForClientSideCookies::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetLastSeen:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetLastSeen::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_MergeStatisticForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::MergeStatisticForTesting::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_InsertExpiredStatisticForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::InsertExpiredStatisticForTesting::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetPrevalentResource:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetPrevalentResource::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetPrevalentResourceForDebugMode:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetPrevalentResourceForDebugMode::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_IsResourceLoadStatisticsEphemeral:
        return jsValueForDecodedArguments<Messages::NetworkProcess::IsResourceLoadStatisticsEphemeral::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_HadUserInteraction:
        return jsValueForDecodedArguments<Messages::NetworkProcess::HadUserInteraction::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_IsRelationshipOnlyInDatabaseOnce:
        return jsValueForDecodedArguments<Messages::NetworkProcess::IsRelationshipOnlyInDatabaseOnce::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_HasLocalStorage:
        return jsValueForDecodedArguments<Messages::NetworkProcess::HasLocalStorage::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_GetAllStorageAccessEntries:
        return jsValueForDecodedArguments<Messages::NetworkProcess::GetAllStorageAccessEntries::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_IsRegisteredAsRedirectingTo:
        return jsValueForDecodedArguments<Messages::NetworkProcess::IsRegisteredAsRedirectingTo::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_IsRegisteredAsSubFrameUnder:
        return jsValueForDecodedArguments<Messages::NetworkProcess::IsRegisteredAsSubFrameUnder::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_IsRegisteredAsSubresourceUnder:
        return jsValueForDecodedArguments<Messages::NetworkProcess::IsRegisteredAsSubresourceUnder::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_DomainIDExistsInDatabase:
        return jsValueForDecodedArguments<Messages::NetworkProcess::DomainIDExistsInDatabase::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_LogFrameNavigation:
        return jsValueForDecodedArguments<Messages::NetworkProcess::LogFrameNavigation::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_LogUserInteraction:
        return jsValueForDecodedArguments<Messages::NetworkProcess::LogUserInteraction::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ResetParametersToDefaultValues:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ResetParametersToDefaultValues::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ScheduleClearInMemoryAndPersistent:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ScheduleClearInMemoryAndPersistent::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ScheduleCookieBlockingUpdate:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ScheduleCookieBlockingUpdate::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ScheduleStatisticsAndDataRecordsProcessing:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ScheduleStatisticsAndDataRecordsProcessing::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_StatisticsDatabaseHasAllTables:
        return jsValueForDecodedArguments<Messages::NetworkProcess::StatisticsDatabaseHasAllTables::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetCacheMaxAgeCapForPrevalentResources:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetCacheMaxAgeCapForPrevalentResources::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetGrandfathered:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetGrandfathered::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_GetResourceLoadStatisticsDataSummary:
        return jsValueForDecodedArguments<Messages::NetworkProcess::GetResourceLoadStatisticsDataSummary::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetGrandfatheringTime:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetGrandfatheringTime::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetMaxStatisticsEntries:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetMaxStatisticsEntries::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetMinimumTimeBetweenDataRecordsRemoval:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetMinimumTimeBetweenDataRecordsRemoval::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetPruneEntriesDownTo:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetPruneEntriesDownTo::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetShouldClassifyResourcesBeforeDataRecordsRemoval:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetShouldClassifyResourcesBeforeDataRecordsRemoval::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetNotifyPagesWhenDataRecordsWereScanned:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetNotifyPagesWhenDataRecordsWereScanned::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetIsRunningResourceLoadStatisticsTest:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetIsRunningResourceLoadStatisticsTest::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetResourceLoadStatisticsDebugMode:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetResourceLoadStatisticsDebugMode::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetVeryPrevalentResource:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetVeryPrevalentResource::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetSubframeUnderTopFrameDomain:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetSubframeUnderTopFrameDomain::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetSubresourceUnderTopFrameDomain:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetSubresourceUnderTopFrameDomain::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetSubresourceUniqueRedirectTo:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetSubresourceUniqueRedirectTo::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetSubresourceUniqueRedirectFrom:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetSubresourceUniqueRedirectFrom::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetTimeToLiveUserInteraction:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetTimeToLiveUserInteraction::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetTopFrameUniqueRedirectTo:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetTopFrameUniqueRedirectTo::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetTopFrameUniqueRedirectFrom:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetTopFrameUniqueRedirectFrom::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ResetCacheMaxAgeCapForPrevalentResources:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ResetCacheMaxAgeCapForPrevalentResources::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_DidCommitCrossSiteLoadWithDataTransfer:
        return jsValueForDecodedArguments<Messages::NetworkProcess::DidCommitCrossSiteLoadWithDataTransfer::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetCrossSiteLoadWithLinkDecorationForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetCrossSiteLoadWithLinkDecorationForTesting::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ResetCrossSiteLoadsWithLinkDecorationForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ResetCrossSiteLoadsWithLinkDecorationForTesting::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_DeleteCookiesForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::DeleteCookiesForTesting::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_HasIsolatedSession:
        return jsValueForDecodedArguments<Messages::NetworkProcess::HasIsolatedSession::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_CloseITPDatabase:
        return jsValueForDecodedArguments<Messages::NetworkProcess::CloseITPDatabase::Arguments>(globalObject, decoder);
#endif
#if (ENABLE(INTELLIGENT_TRACKING_PREVENTION) && ENABLE(APP_BOUND_DOMAINS))
    case MessageName::NetworkProcess_SetAppBoundDomainsForResourceLoadStatistics:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetAppBoundDomainsForResourceLoadStatistics::Arguments>(globalObject, decoder);
#endif
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
    case MessageName::NetworkProcess_SetShouldDowngradeReferrerForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetShouldDowngradeReferrerForTesting::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetThirdPartyCookieBlockingMode:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetThirdPartyCookieBlockingMode::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetShouldEnbleSameSiteStrictEnforcementForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetShouldEnbleSameSiteStrictEnforcementForTesting::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetFirstPartyWebsiteDataRemovalModeForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetFirstPartyWebsiteDataRemovalModeForTesting::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetToSameSiteStrictCookiesForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetToSameSiteStrictCookiesForTesting::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetFirstPartyHostCNAMEDomainForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetFirstPartyHostCNAMEDomainForTesting::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetThirdPartyCNAMEDomainForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetThirdPartyCNAMEDomainForTesting::Arguments>(globalObject, decoder);
#endif
    case MessageName::NetworkProcess_SetPrivateClickMeasurementDebugMode:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetPrivateClickMeasurementDebugMode::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetSessionIsControlledByAutomation:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetSessionIsControlledByAutomation::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_RegisterURLSchemeAsSecure:
        return jsValueForDecodedArguments<Messages::NetworkProcess::RegisterURLSchemeAsSecure::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_RegisterURLSchemeAsBypassingContentSecurityPolicy:
        return jsValueForDecodedArguments<Messages::NetworkProcess::RegisterURLSchemeAsBypassingContentSecurityPolicy::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_RegisterURLSchemeAsLocal:
        return jsValueForDecodedArguments<Messages::NetworkProcess::RegisterURLSchemeAsLocal::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_RegisterURLSchemeAsNoAccess:
        return jsValueForDecodedArguments<Messages::NetworkProcess::RegisterURLSchemeAsNoAccess::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SyncLocalStorage:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SyncLocalStorage::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_StorePrivateClickMeasurement:
        return jsValueForDecodedArguments<Messages::NetworkProcess::StorePrivateClickMeasurement::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_DumpPrivateClickMeasurement:
        return jsValueForDecodedArguments<Messages::NetworkProcess::DumpPrivateClickMeasurement::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ClearPrivateClickMeasurement:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ClearPrivateClickMeasurement::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetPrivateClickMeasurementOverrideTimerForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetPrivateClickMeasurementOverrideTimerForTesting::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_MarkAttributedPrivateClickMeasurementsAsExpiredForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::MarkAttributedPrivateClickMeasurementsAsExpiredForTesting::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetPrivateClickMeasurementEphemeralMeasurementForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetPrivateClickMeasurementEphemeralMeasurementForTesting::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SimulatePrivateClickMeasurementSessionRestart:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SimulatePrivateClickMeasurementSessionRestart::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetPrivateClickMeasurementTokenPublicKeyURLForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetPrivateClickMeasurementTokenPublicKeyURLForTesting::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetPrivateClickMeasurementTokenSignatureURLForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetPrivateClickMeasurementTokenSignatureURLForTesting::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetPrivateClickMeasurementAttributionReportURLsForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetPrivateClickMeasurementAttributionReportURLsForTesting::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_MarkPrivateClickMeasurementsAsExpiredForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::MarkPrivateClickMeasurementsAsExpiredForTesting::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetPCMFraudPreventionValuesForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetPCMFraudPreventionValuesForTesting::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetPrivateClickMeasurementAppBundleIDForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetPrivateClickMeasurementAppBundleIDForTesting::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ClosePCMDatabase:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ClosePCMDatabase::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetServiceWorkerFetchTimeoutForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetServiceWorkerFetchTimeoutForTesting::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ResetServiceWorkerFetchTimeoutForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ResetServiceWorkerFetchTimeoutForTesting::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ResetQuota:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ResetQuota::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ClearStorage:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ClearStorage::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_DidIncreaseQuota:
        return jsValueForDecodedArguments<Messages::NetworkProcess::DidIncreaseQuota::Arguments>(globalObject, decoder);
#if ENABLE(APP_BOUND_DOMAINS)
    case MessageName::NetworkProcess_HasAppBoundSession:
        return jsValueForDecodedArguments<Messages::NetworkProcess::HasAppBoundSession::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ClearAppBoundSession:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ClearAppBoundSession::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(IOS_FAMILY) && !PLATFORM(MACCATALYST)
    case MessageName::NetworkProcess_DisableServiceWorkerEntitlement:
        return jsValueForDecodedArguments<Messages::NetworkProcess::DisableServiceWorkerEntitlement::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ClearServiceWorkerEntitlementOverride:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ClearServiceWorkerEntitlementOverride::Arguments>(globalObject, decoder);
#endif
    case MessageName::NetworkProcess_UpdateBundleIdentifier:
        return jsValueForDecodedArguments<Messages::NetworkProcess::UpdateBundleIdentifier::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ClearBundleIdentifier:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ClearBundleIdentifier::Arguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::NetworkProcess_AppPrivacyReportTestingData:
        return jsValueForDecodedArguments<Messages::NetworkProcess::AppPrivacyReportTestingData::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ClearAppPrivacyReportTestingData:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ClearAppPrivacyReportTestingData::Arguments>(globalObject, decoder);
#endif
    case MessageName::NetworkProcess_AddWebPageNetworkParameters:
        return jsValueForDecodedArguments<Messages::NetworkProcess::AddWebPageNetworkParameters::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_RemoveWebPageNetworkParameters:
        return jsValueForDecodedArguments<Messages::NetworkProcess::RemoveWebPageNetworkParameters::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_CountNonDefaultSessionSets:
        return jsValueForDecodedArguments<Messages::NetworkProcess::CountNonDefaultSessionSets::Arguments>(globalObject, decoder);
#if ENABLE(CFPREFS_DIRECT_MODE)
    case MessageName::NetworkProcess_NotifyPreferencesChanged:
        return jsValueForDecodedArguments<Messages::NetworkProcess::NotifyPreferencesChanged::Arguments>(globalObject, decoder);
#endif
#if ENABLE(SERVICE_WORKER)
    case MessageName::NetworkProcess_GetPendingPushMessages:
        return jsValueForDecodedArguments<Messages::NetworkProcess::GetPendingPushMessages::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ProcessPushMessage:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ProcessPushMessage::Arguments>(globalObject, decoder);
#endif
    case MessageName::NetworkProcess_DeletePushAndNotificationRegistration:
        return jsValueForDecodedArguments<Messages::NetworkProcess::DeletePushAndNotificationRegistration::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcess_GetOriginsWithPushAndNotificationPermissions:
        return jsValueForDecodedArguments<Messages::NetworkProcess::GetOriginsWithPushAndNotificationPermissions::Arguments>(globalObject, decoder);
    case MessageName::NetworkResourceLoader_ContinueWillSendRequest:
        return jsValueForDecodedArguments<Messages::NetworkResourceLoader::ContinueWillSendRequest::Arguments>(globalObject, decoder);
    case MessageName::NetworkResourceLoader_ContinueDidReceiveResponse:
        return jsValueForDecodedArguments<Messages::NetworkResourceLoader::ContinueDidReceiveResponse::Arguments>(globalObject, decoder);
    case MessageName::NetworkSocketChannel_SendString:
        return jsValueForDecodedArguments<Messages::NetworkSocketChannel::SendString::Arguments>(globalObject, decoder);
    case MessageName::NetworkSocketChannel_SendData:
        return jsValueForDecodedArguments<Messages::NetworkSocketChannel::SendData::Arguments>(globalObject, decoder);
    case MessageName::NetworkSocketChannel_Close:
        return jsValueForDecodedArguments<Messages::NetworkSocketChannel::Close::Arguments>(globalObject, decoder);
    case MessageName::NetworkSocketStream_SendData:
        return jsValueForDecodedArguments<Messages::NetworkSocketStream::SendData::Arguments>(globalObject, decoder);
    case MessageName::NetworkSocketStream_SendHandshake:
        return jsValueForDecodedArguments<Messages::NetworkSocketStream::SendHandshake::Arguments>(globalObject, decoder);
    case MessageName::NetworkSocketStream_Close:
        return jsValueForDecodedArguments<Messages::NetworkSocketStream::Close::Arguments>(globalObject, decoder);
#if ENABLE(SERVICE_WORKER)
    case MessageName::ServiceWorkerDownloadTask_DidFail:
        return jsValueForDecodedArguments<Messages::ServiceWorkerDownloadTask::DidFail::Arguments>(globalObject, decoder);
    case MessageName::ServiceWorkerDownloadTask_DidReceiveData:
        return jsValueForDecodedArguments<Messages::ServiceWorkerDownloadTask::DidReceiveData::Arguments>(globalObject, decoder);
    case MessageName::ServiceWorkerDownloadTask_DidReceiveFormData:
        return jsValueForDecodedArguments<Messages::ServiceWorkerDownloadTask::DidReceiveFormData::Arguments>(globalObject, decoder);
    case MessageName::ServiceWorkerDownloadTask_DidFinish:
        return jsValueForDecodedArguments<Messages::ServiceWorkerDownloadTask::DidFinish::Arguments>(globalObject, decoder);
#endif
#if ENABLE(SERVICE_WORKER)
    case MessageName::ServiceWorkerFetchTask_DidNotHandle:
        return jsValueForDecodedArguments<Messages::ServiceWorkerFetchTask::DidNotHandle::Arguments>(globalObject, decoder);
    case MessageName::ServiceWorkerFetchTask_DidFail:
        return jsValueForDecodedArguments<Messages::ServiceWorkerFetchTask::DidFail::Arguments>(globalObject, decoder);
    case MessageName::ServiceWorkerFetchTask_DidReceiveRedirectResponse:
        return jsValueForDecodedArguments<Messages::ServiceWorkerFetchTask::DidReceiveRedirectResponse::Arguments>(globalObject, decoder);
    case MessageName::ServiceWorkerFetchTask_DidReceiveResponse:
        return jsValueForDecodedArguments<Messages::ServiceWorkerFetchTask::DidReceiveResponse::Arguments>(globalObject, decoder);
    case MessageName::ServiceWorkerFetchTask_DidReceiveData:
        return jsValueForDecodedArguments<Messages::ServiceWorkerFetchTask::DidReceiveData::Arguments>(globalObject, decoder);
    case MessageName::ServiceWorkerFetchTask_DidReceiveFormData:
        return jsValueForDecodedArguments<Messages::ServiceWorkerFetchTask::DidReceiveFormData::Arguments>(globalObject, decoder);
    case MessageName::ServiceWorkerFetchTask_DidFinish:
        return jsValueForDecodedArguments<Messages::ServiceWorkerFetchTask::DidFinish::Arguments>(globalObject, decoder);
#endif
#if ENABLE(SERVICE_WORKER)
    case MessageName::WebSWServerConnection_ScheduleJobInServer:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::ScheduleJobInServer::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_ScheduleUnregisterJobInServer:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::ScheduleUnregisterJobInServer::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_FinishFetchingScriptInServer:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::FinishFetchingScriptInServer::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_AddServiceWorkerRegistrationInServer:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::AddServiceWorkerRegistrationInServer::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_RemoveServiceWorkerRegistrationInServer:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::RemoveServiceWorkerRegistrationInServer::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_PostMessageToServiceWorker:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::PostMessageToServiceWorker::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_DidResolveRegistrationPromise:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::DidResolveRegistrationPromise::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_MatchRegistration:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::MatchRegistration::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_WhenRegistrationReady:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::WhenRegistrationReady::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_GetRegistrations:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::GetRegistrations::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_RegisterServiceWorkerClient:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::RegisterServiceWorkerClient::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_UnregisterServiceWorkerClient:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::UnregisterServiceWorkerClient::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_TerminateWorkerFromClient:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::TerminateWorkerFromClient::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_WhenServiceWorkerIsTerminatedForTesting:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::WhenServiceWorkerIsTerminatedForTesting::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_SetThrottleState:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::SetThrottleState::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_StoreRegistrationsOnDisk:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::StoreRegistrationsOnDisk::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_SubscribeToPushService:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::SubscribeToPushService::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_UnsubscribeFromPushService:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::UnsubscribeFromPushService::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_GetPushSubscription:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::GetPushSubscription::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_GetPushPermissionState:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::GetPushPermissionState::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_EnableNavigationPreload:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::EnableNavigationPreload::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_DisableNavigationPreload:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::DisableNavigationPreload::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_SetNavigationPreloadHeaderValue:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::SetNavigationPreloadHeaderValue::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_GetNavigationPreloadState:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::GetNavigationPreloadState::Arguments>(globalObject, decoder);
#endif
#if ENABLE(SERVICE_WORKER)
    case MessageName::WebSWServerToContextConnection_ScriptContextFailedToStart:
        return jsValueForDecodedArguments<Messages::WebSWServerToContextConnection::ScriptContextFailedToStart::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerToContextConnection_ScriptContextStarted:
        return jsValueForDecodedArguments<Messages::WebSWServerToContextConnection::ScriptContextStarted::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerToContextConnection_DidFinishInstall:
        return jsValueForDecodedArguments<Messages::WebSWServerToContextConnection::DidFinishInstall::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerToContextConnection_DidFinishActivation:
        return jsValueForDecodedArguments<Messages::WebSWServerToContextConnection::DidFinishActivation::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerToContextConnection_SetServiceWorkerHasPendingEvents:
        return jsValueForDecodedArguments<Messages::WebSWServerToContextConnection::SetServiceWorkerHasPendingEvents::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerToContextConnection_SkipWaiting:
        return jsValueForDecodedArguments<Messages::WebSWServerToContextConnection::SkipWaiting::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerToContextConnection_WorkerTerminated:
        return jsValueForDecodedArguments<Messages::WebSWServerToContextConnection::WorkerTerminated::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerToContextConnection_FindClientByVisibleIdentifier:
        return jsValueForDecodedArguments<Messages::WebSWServerToContextConnection::FindClientByVisibleIdentifier::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerToContextConnection_MatchAll:
        return jsValueForDecodedArguments<Messages::WebSWServerToContextConnection::MatchAll::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerToContextConnection_Claim:
        return jsValueForDecodedArguments<Messages::WebSWServerToContextConnection::Claim::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerToContextConnection_SetScriptResource:
        return jsValueForDecodedArguments<Messages::WebSWServerToContextConnection::SetScriptResource::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerToContextConnection_PostMessageToServiceWorkerClient:
        return jsValueForDecodedArguments<Messages::WebSWServerToContextConnection::PostMessageToServiceWorkerClient::Arguments>(globalObject, decoder);
    case MessageName::WebSWServerToContextConnection_DidFailHeartBeatCheck:
        return jsValueForDecodedArguments<Messages::WebSWServerToContextConnection::DidFailHeartBeatCheck::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebSharedWorkerServerConnection_RequestSharedWorker:
        return jsValueForDecodedArguments<Messages::WebSharedWorkerServerConnection::RequestSharedWorker::Arguments>(globalObject, decoder);
    case MessageName::WebSharedWorkerServerConnection_SharedWorkerObjectIsGoingAway:
        return jsValueForDecodedArguments<Messages::WebSharedWorkerServerConnection::SharedWorkerObjectIsGoingAway::Arguments>(globalObject, decoder);
    case MessageName::WebSharedWorkerServerToContextConnection_PostExceptionToWorkerObject:
        return jsValueForDecodedArguments<Messages::WebSharedWorkerServerToContextConnection::PostExceptionToWorkerObject::Arguments>(globalObject, decoder);
    case MessageName::StorageManagerSet_ConnectToLocalStorageArea:
        return jsValueForDecodedArguments<Messages::StorageManagerSet::ConnectToLocalStorageArea::Arguments>(globalObject, decoder);
    case MessageName::StorageManagerSet_ConnectToTransientLocalStorageArea:
        return jsValueForDecodedArguments<Messages::StorageManagerSet::ConnectToTransientLocalStorageArea::Arguments>(globalObject, decoder);
    case MessageName::StorageManagerSet_ConnectToSessionStorageArea:
        return jsValueForDecodedArguments<Messages::StorageManagerSet::ConnectToSessionStorageArea::Arguments>(globalObject, decoder);
    case MessageName::StorageManagerSet_DisconnectFromStorageArea:
        return jsValueForDecodedArguments<Messages::StorageManagerSet::DisconnectFromStorageArea::Arguments>(globalObject, decoder);
    case MessageName::StorageManagerSet_GetValues:
        return jsValueForDecodedArguments<Messages::StorageManagerSet::GetValues::Arguments>(globalObject, decoder);
    case MessageName::StorageManagerSet_CloneSessionStorageNamespace:
        return jsValueForDecodedArguments<Messages::StorageManagerSet::CloneSessionStorageNamespace::Arguments>(globalObject, decoder);
    case MessageName::StorageManagerSet_SetItem:
        return jsValueForDecodedArguments<Messages::StorageManagerSet::SetItem::Arguments>(globalObject, decoder);
    case MessageName::StorageManagerSet_RemoveItem:
        return jsValueForDecodedArguments<Messages::StorageManagerSet::RemoveItem::Arguments>(globalObject, decoder);
    case MessageName::StorageManagerSet_Clear:
        return jsValueForDecodedArguments<Messages::StorageManagerSet::Clear::Arguments>(globalObject, decoder);
    case MessageName::CacheStorageEngineConnection_Reference:
        return jsValueForDecodedArguments<Messages::CacheStorageEngineConnection::Reference::Arguments>(globalObject, decoder);
    case MessageName::CacheStorageEngineConnection_Dereference:
        return jsValueForDecodedArguments<Messages::CacheStorageEngineConnection::Dereference::Arguments>(globalObject, decoder);
    case MessageName::CacheStorageEngineConnection_Open:
        return jsValueForDecodedArguments<Messages::CacheStorageEngineConnection::Open::Arguments>(globalObject, decoder);
    case MessageName::CacheStorageEngineConnection_Remove:
        return jsValueForDecodedArguments<Messages::CacheStorageEngineConnection::Remove::Arguments>(globalObject, decoder);
    case MessageName::CacheStorageEngineConnection_Caches:
        return jsValueForDecodedArguments<Messages::CacheStorageEngineConnection::Caches::Arguments>(globalObject, decoder);
    case MessageName::CacheStorageEngineConnection_RetrieveRecords:
        return jsValueForDecodedArguments<Messages::CacheStorageEngineConnection::RetrieveRecords::Arguments>(globalObject, decoder);
    case MessageName::CacheStorageEngineConnection_DeleteMatchingRecords:
        return jsValueForDecodedArguments<Messages::CacheStorageEngineConnection::DeleteMatchingRecords::Arguments>(globalObject, decoder);
    case MessageName::CacheStorageEngineConnection_PutRecords:
        return jsValueForDecodedArguments<Messages::CacheStorageEngineConnection::PutRecords::Arguments>(globalObject, decoder);
    case MessageName::CacheStorageEngineConnection_ClearMemoryRepresentation:
        return jsValueForDecodedArguments<Messages::CacheStorageEngineConnection::ClearMemoryRepresentation::Arguments>(globalObject, decoder);
    case MessageName::CacheStorageEngineConnection_EngineRepresentation:
        return jsValueForDecodedArguments<Messages::CacheStorageEngineConnection::EngineRepresentation::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_Persisted:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::Persisted::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_Persist:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::Persist::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_FileSystemGetDirectory:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::FileSystemGetDirectory::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_CloseHandle:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::CloseHandle::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_IsSameEntry:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::IsSameEntry::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_GetFileHandle:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::GetFileHandle::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_GetDirectoryHandle:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::GetDirectoryHandle::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_RemoveEntry:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::RemoveEntry::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_Resolve:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::Resolve::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_Move:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::Move::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_GetFile:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::GetFile::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_CreateSyncAccessHandle:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::CreateSyncAccessHandle::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_CloseSyncAccessHandle:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::CloseSyncAccessHandle::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_GetHandleNames:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::GetHandleNames::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_GetHandle:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::GetHandle::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_ConnectToStorageArea:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::ConnectToStorageArea::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_ConnectToStorageAreaSync:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::ConnectToStorageAreaSync::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_DisconnectFromStorageArea:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::DisconnectFromStorageArea::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_CloneSessionStorageNamespace:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::CloneSessionStorageNamespace::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_SetItem:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::SetItem::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_RemoveItem:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::RemoveItem::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_Clear:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::Clear::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_OpenDatabase:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::OpenDatabase::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_OpenDBRequestCancelled:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::OpenDBRequestCancelled::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_DeleteDatabase:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::DeleteDatabase::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_EstablishTransaction:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::EstablishTransaction::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_DatabaseConnectionPendingClose:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::DatabaseConnectionPendingClose::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_DatabaseConnectionClosed:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::DatabaseConnectionClosed::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_AbortOpenAndUpgradeNeeded:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::AbortOpenAndUpgradeNeeded::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_DidFireVersionChangeEvent:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::DidFireVersionChangeEvent::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_DidFinishHandlingVersionChangeTransaction:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::DidFinishHandlingVersionChangeTransaction::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_AbortTransaction:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::AbortTransaction::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_CommitTransaction:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::CommitTransaction::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_CreateObjectStore:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::CreateObjectStore::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_DeleteObjectStore:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::DeleteObjectStore::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_RenameObjectStore:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::RenameObjectStore::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_ClearObjectStore:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::ClearObjectStore::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_CreateIndex:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::CreateIndex::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_DeleteIndex:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::DeleteIndex::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_RenameIndex:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::RenameIndex::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_PutOrAdd:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::PutOrAdd::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_GetRecord:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::GetRecord::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_GetAllRecords:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::GetAllRecords::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_GetCount:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::GetCount::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_DeleteRecord:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::DeleteRecord::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_OpenCursor:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::OpenCursor::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_IterateCursor:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::IterateCursor::Arguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_GetAllDatabaseNamesAndVersions:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::GetAllDatabaseNamesAndVersions::Arguments>(globalObject, decoder);
#if ENABLE(WEB_RTC)
    case MessageName::NetworkMDNSRegister_UnregisterMDNSNames:
        return jsValueForDecodedArguments<Messages::NetworkMDNSRegister::UnregisterMDNSNames::Arguments>(globalObject, decoder);
    case MessageName::NetworkMDNSRegister_RegisterMDNSName:
        return jsValueForDecodedArguments<Messages::NetworkMDNSRegister::RegisterMDNSName::Arguments>(globalObject, decoder);
#endif
#if USE(LIBWEBRTC)
    case MessageName::NetworkRTCMonitor_StartUpdatingIfNeeded:
        return jsValueForDecodedArguments<Messages::NetworkRTCMonitor::StartUpdatingIfNeeded::Arguments>(globalObject, decoder);
    case MessageName::NetworkRTCMonitor_StopUpdating:
        return jsValueForDecodedArguments<Messages::NetworkRTCMonitor::StopUpdating::Arguments>(globalObject, decoder);
#endif
#if USE(LIBWEBRTC)
    case MessageName::NetworkRTCProvider_CreateUDPSocket:
        return jsValueForDecodedArguments<Messages::NetworkRTCProvider::CreateUDPSocket::Arguments>(globalObject, decoder);
    case MessageName::NetworkRTCProvider_CreateServerTCPSocket:
        return jsValueForDecodedArguments<Messages::NetworkRTCProvider::CreateServerTCPSocket::Arguments>(globalObject, decoder);
    case MessageName::NetworkRTCProvider_CreateClientTCPSocket:
        return jsValueForDecodedArguments<Messages::NetworkRTCProvider::CreateClientTCPSocket::Arguments>(globalObject, decoder);
    case MessageName::NetworkRTCProvider_WrapNewTCPConnection:
        return jsValueForDecodedArguments<Messages::NetworkRTCProvider::WrapNewTCPConnection::Arguments>(globalObject, decoder);
    case MessageName::NetworkRTCProvider_SetPlatformTCPSocketsEnabled:
        return jsValueForDecodedArguments<Messages::NetworkRTCProvider::SetPlatformTCPSocketsEnabled::Arguments>(globalObject, decoder);
    case MessageName::NetworkRTCProvider_SetPlatformUDPSocketsEnabled:
        return jsValueForDecodedArguments<Messages::NetworkRTCProvider::SetPlatformUDPSocketsEnabled::Arguments>(globalObject, decoder);
    case MessageName::NetworkRTCProvider_CreateResolver:
        return jsValueForDecodedArguments<Messages::NetworkRTCProvider::CreateResolver::Arguments>(globalObject, decoder);
    case MessageName::NetworkRTCProvider_StopResolver:
        return jsValueForDecodedArguments<Messages::NetworkRTCProvider::StopResolver::Arguments>(globalObject, decoder);
    case MessageName::NetworkRTCProvider_SendToSocket:
        return jsValueForDecodedArguments<Messages::NetworkRTCProvider::SendToSocket::Arguments>(globalObject, decoder);
    case MessageName::NetworkRTCProvider_CloseSocket:
        return jsValueForDecodedArguments<Messages::NetworkRTCProvider::CloseSocket::Arguments>(globalObject, decoder);
    case MessageName::NetworkRTCProvider_SetSocketOption:
        return jsValueForDecodedArguments<Messages::NetworkRTCProvider::SetSocketOption::Arguments>(globalObject, decoder);
#endif
#if ENABLE(WEB_RTC)
    case MessageName::RTCDataChannelRemoteManagerProxy_SendData:
        return jsValueForDecodedArguments<Messages::RTCDataChannelRemoteManagerProxy::SendData::Arguments>(globalObject, decoder);
    case MessageName::RTCDataChannelRemoteManagerProxy_Close:
        return jsValueForDecodedArguments<Messages::RTCDataChannelRemoteManagerProxy::Close::Arguments>(globalObject, decoder);
    case MessageName::RTCDataChannelRemoteManagerProxy_ChangeReadyState:
        return jsValueForDecodedArguments<Messages::RTCDataChannelRemoteManagerProxy::ChangeReadyState::Arguments>(globalObject, decoder);
    case MessageName::RTCDataChannelRemoteManagerProxy_ReceiveData:
        return jsValueForDecodedArguments<Messages::RTCDataChannelRemoteManagerProxy::ReceiveData::Arguments>(globalObject, decoder);
    case MessageName::RTCDataChannelRemoteManagerProxy_DetectError:
        return jsValueForDecodedArguments<Messages::RTCDataChannelRemoteManagerProxy::DetectError::Arguments>(globalObject, decoder);
    case MessageName::RTCDataChannelRemoteManagerProxy_BufferedAmountIsDecreasing:
        return jsValueForDecodedArguments<Messages::RTCDataChannelRemoteManagerProxy::BufferedAmountIsDecreasing::Arguments>(globalObject, decoder);
#endif
    case MessageName::AuxiliaryProcess_ShutDown:
        return jsValueForDecodedArguments<Messages::AuxiliaryProcess::ShutDown::Arguments>(globalObject, decoder);
    case MessageName::AuxiliaryProcess_SetProcessSuppressionEnabled:
        return jsValueForDecodedArguments<Messages::AuxiliaryProcess::SetProcessSuppressionEnabled::Arguments>(globalObject, decoder);
    case MessageName::AuxiliaryProcess_MainThreadPing:
        return jsValueForDecodedArguments<Messages::AuxiliaryProcess::MainThreadPing::Arguments>(globalObject, decoder);
#if OS(LINUX)
    case MessageName::AuxiliaryProcess_DidReceiveMemoryPressureEvent:
        return jsValueForDecodedArguments<Messages::AuxiliaryProcess::DidReceiveMemoryPressureEvent::Arguments>(globalObject, decoder);
#endif
#if ENABLE(IPC_TESTING_API)
    case MessageName::IPCTester_StartMessageTesting:
        return jsValueForDecodedArguments<Messages::IPCTester::StartMessageTesting::Arguments>(globalObject, decoder);
    case MessageName::IPCTester_StopMessageTesting:
        return jsValueForDecodedArguments<Messages::IPCTester::StopMessageTesting::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebConnection_HandleMessage:
        return jsValueForDecodedArguments<Messages::WebConnection::HandleMessage::Arguments>(globalObject, decoder);
    case MessageName::AuthenticationManager_CompleteAuthenticationChallenge:
        return jsValueForDecodedArguments<Messages::AuthenticationManager::CompleteAuthenticationChallenge::Arguments>(globalObject, decoder);
    case MessageName::NotificationManagerMessageHandler_RequestSystemNotificationPermission:
        return jsValueForDecodedArguments<Messages::NotificationManagerMessageHandler::RequestSystemNotificationPermission::Arguments>(globalObject, decoder);
    case MessageName::NotificationManagerMessageHandler_ShowNotification:
        return jsValueForDecodedArguments<Messages::NotificationManagerMessageHandler::ShowNotification::Arguments>(globalObject, decoder);
    case MessageName::NotificationManagerMessageHandler_CancelNotification:
        return jsValueForDecodedArguments<Messages::NotificationManagerMessageHandler::CancelNotification::Arguments>(globalObject, decoder);
    case MessageName::NotificationManagerMessageHandler_ClearNotifications:
        return jsValueForDecodedArguments<Messages::NotificationManagerMessageHandler::ClearNotifications::Arguments>(globalObject, decoder);
    case MessageName::NotificationManagerMessageHandler_DidDestroyNotification:
        return jsValueForDecodedArguments<Messages::NotificationManagerMessageHandler::DidDestroyNotification::Arguments>(globalObject, decoder);
    case MessageName::DrawingAreaProxy_EnterAcceleratedCompositingMode:
        return jsValueForDecodedArguments<Messages::DrawingAreaProxy::EnterAcceleratedCompositingMode::Arguments>(globalObject, decoder);
    case MessageName::DrawingAreaProxy_UpdateAcceleratedCompositingMode:
        return jsValueForDecodedArguments<Messages::DrawingAreaProxy::UpdateAcceleratedCompositingMode::Arguments>(globalObject, decoder);
    case MessageName::DrawingAreaProxy_DidFirstLayerFlush:
        return jsValueForDecodedArguments<Messages::DrawingAreaProxy::DidFirstLayerFlush::Arguments>(globalObject, decoder);
    case MessageName::DrawingAreaProxy_DispatchPresentationCallbacksAfterFlushingLayers:
        return jsValueForDecodedArguments<Messages::DrawingAreaProxy::DispatchPresentationCallbacksAfterFlushingLayers::Arguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::DrawingAreaProxy_DidUpdateGeometry:
        return jsValueForDecodedArguments<Messages::DrawingAreaProxy::DidUpdateGeometry::Arguments>(globalObject, decoder);
#endif
#if USE(COORDINATED_GRAPHICS) || USE(TEXTURE_MAPPER)
    case MessageName::DrawingAreaProxy_Update:
        return jsValueForDecodedArguments<Messages::DrawingAreaProxy::Update::Arguments>(globalObject, decoder);
    case MessageName::DrawingAreaProxy_DidUpdateBackingStoreState:
        return jsValueForDecodedArguments<Messages::DrawingAreaProxy::DidUpdateBackingStoreState::Arguments>(globalObject, decoder);
    case MessageName::DrawingAreaProxy_ExitAcceleratedCompositingMode:
        return jsValueForDecodedArguments<Messages::DrawingAreaProxy::ExitAcceleratedCompositingMode::Arguments>(globalObject, decoder);
#endif
#if ENABLE(MEDIA_SESSION_COORDINATOR)
    case MessageName::RemoteMediaSessionCoordinatorProxy_Join:
        return jsValueForDecodedArguments<Messages::RemoteMediaSessionCoordinatorProxy::Join::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaSessionCoordinatorProxy_Leave:
        return jsValueForDecodedArguments<Messages::RemoteMediaSessionCoordinatorProxy::Leave::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaSessionCoordinatorProxy_CoordinateSeekTo:
        return jsValueForDecodedArguments<Messages::RemoteMediaSessionCoordinatorProxy::CoordinateSeekTo::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaSessionCoordinatorProxy_CoordinatePlay:
        return jsValueForDecodedArguments<Messages::RemoteMediaSessionCoordinatorProxy::CoordinatePlay::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaSessionCoordinatorProxy_CoordinatePause:
        return jsValueForDecodedArguments<Messages::RemoteMediaSessionCoordinatorProxy::CoordinatePause::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaSessionCoordinatorProxy_CoordinateSetTrack:
        return jsValueForDecodedArguments<Messages::RemoteMediaSessionCoordinatorProxy::CoordinateSetTrack::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaSessionCoordinatorProxy_PositionStateChanged:
        return jsValueForDecodedArguments<Messages::RemoteMediaSessionCoordinatorProxy::PositionStateChanged::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaSessionCoordinatorProxy_ReadyStateChanged:
        return jsValueForDecodedArguments<Messages::RemoteMediaSessionCoordinatorProxy::ReadyStateChanged::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaSessionCoordinatorProxy_PlaybackStateChanged:
        return jsValueForDecodedArguments<Messages::RemoteMediaSessionCoordinatorProxy::PlaybackStateChanged::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaSessionCoordinatorProxy_TrackIdentifierChanged:
        return jsValueForDecodedArguments<Messages::RemoteMediaSessionCoordinatorProxy::TrackIdentifierChanged::Arguments>(globalObject, decoder);
#endif
#if ENABLE(MEDIA_STREAM)
    case MessageName::SpeechRecognitionRemoteRealtimeMediaSourceManager_RemoteAudioSamplesAvailable:
        return jsValueForDecodedArguments<Messages::SpeechRecognitionRemoteRealtimeMediaSourceManager::RemoteAudioSamplesAvailable::Arguments>(globalObject, decoder);
    case MessageName::SpeechRecognitionRemoteRealtimeMediaSourceManager_RemoteCaptureFailed:
        return jsValueForDecodedArguments<Messages::SpeechRecognitionRemoteRealtimeMediaSourceManager::RemoteCaptureFailed::Arguments>(globalObject, decoder);
    case MessageName::SpeechRecognitionRemoteRealtimeMediaSourceManager_RemoteSourceStopped:
        return jsValueForDecodedArguments<Messages::SpeechRecognitionRemoteRealtimeMediaSourceManager::RemoteSourceStopped::Arguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::SpeechRecognitionRemoteRealtimeMediaSourceManager_SetStorage:
        return jsValueForDecodedArguments<Messages::SpeechRecognitionRemoteRealtimeMediaSourceManager::SetStorage::Arguments>(globalObject, decoder);
#endif
#endif
    case MessageName::SpeechRecognitionServer_Start:
        return jsValueForDecodedArguments<Messages::SpeechRecognitionServer::Start::Arguments>(globalObject, decoder);
    case MessageName::SpeechRecognitionServer_Stop:
        return jsValueForDecodedArguments<Messages::SpeechRecognitionServer::Stop::Arguments>(globalObject, decoder);
    case MessageName::SpeechRecognitionServer_Abort:
        return jsValueForDecodedArguments<Messages::SpeechRecognitionServer::Abort::Arguments>(globalObject, decoder);
    case MessageName::SpeechRecognitionServer_Invalidate:
        return jsValueForDecodedArguments<Messages::SpeechRecognitionServer::Invalidate::Arguments>(globalObject, decoder);
    case MessageName::VisitedLinkStore_AddVisitedLinkHashFromPage:
        return jsValueForDecodedArguments<Messages::VisitedLinkStore::AddVisitedLinkHashFromPage::Arguments>(globalObject, decoder);
    case MessageName::WebCookieManagerProxy_CookiesDidChange:
        return jsValueForDecodedArguments<Messages::WebCookieManagerProxy::CookiesDidChange::Arguments>(globalObject, decoder);
#if ENABLE(FULLSCREEN_API)
    case MessageName::WebFullScreenManagerProxy_SupportsFullScreen:
        return jsValueForDecodedArguments<Messages::WebFullScreenManagerProxy::SupportsFullScreen::Arguments>(globalObject, decoder);
    case MessageName::WebFullScreenManagerProxy_EnterFullScreen:
        return jsValueForDecodedArguments<Messages::WebFullScreenManagerProxy::EnterFullScreen::Arguments>(globalObject, decoder);
    case MessageName::WebFullScreenManagerProxy_ExitFullScreen:
        return jsValueForDecodedArguments<Messages::WebFullScreenManagerProxy::ExitFullScreen::Arguments>(globalObject, decoder);
    case MessageName::WebFullScreenManagerProxy_BeganEnterFullScreen:
        return jsValueForDecodedArguments<Messages::WebFullScreenManagerProxy::BeganEnterFullScreen::Arguments>(globalObject, decoder);
    case MessageName::WebFullScreenManagerProxy_BeganExitFullScreen:
        return jsValueForDecodedArguments<Messages::WebFullScreenManagerProxy::BeganExitFullScreen::Arguments>(globalObject, decoder);
    case MessageName::WebFullScreenManagerProxy_Close:
        return jsValueForDecodedArguments<Messages::WebFullScreenManagerProxy::Close::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebGeolocationManagerProxy_StartUpdating:
        return jsValueForDecodedArguments<Messages::WebGeolocationManagerProxy::StartUpdating::Arguments>(globalObject, decoder);
    case MessageName::WebGeolocationManagerProxy_StopUpdating:
        return jsValueForDecodedArguments<Messages::WebGeolocationManagerProxy::StopUpdating::Arguments>(globalObject, decoder);
    case MessageName::WebGeolocationManagerProxy_SetEnableHighAccuracy:
        return jsValueForDecodedArguments<Messages::WebGeolocationManagerProxy::SetEnableHighAccuracy::Arguments>(globalObject, decoder);
    case MessageName::WebLockRegistryProxy_RequestLock:
        return jsValueForDecodedArguments<Messages::WebLockRegistryProxy::RequestLock::Arguments>(globalObject, decoder);
    case MessageName::WebLockRegistryProxy_ReleaseLock:
        return jsValueForDecodedArguments<Messages::WebLockRegistryProxy::ReleaseLock::Arguments>(globalObject, decoder);
    case MessageName::WebLockRegistryProxy_AbortLockRequest:
        return jsValueForDecodedArguments<Messages::WebLockRegistryProxy::AbortLockRequest::Arguments>(globalObject, decoder);
    case MessageName::WebLockRegistryProxy_Snapshot:
        return jsValueForDecodedArguments<Messages::WebLockRegistryProxy::Snapshot::Arguments>(globalObject, decoder);
    case MessageName::WebLockRegistryProxy_ClientIsGoingAway:
        return jsValueForDecodedArguments<Messages::WebLockRegistryProxy::ClientIsGoingAway::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_CreateNewPage:
        return jsValueForDecodedArguments<Messages::WebPageProxy::CreateNewPage::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ShowPage:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShowPage::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ClosePage:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ClosePage::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RunJavaScriptAlert:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RunJavaScriptAlert::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RunJavaScriptConfirm:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RunJavaScriptConfirm::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RunJavaScriptPrompt:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RunJavaScriptPrompt::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_MouseDidMoveOverElement:
        return jsValueForDecodedArguments<Messages::WebPageProxy::MouseDidMoveOverElement::Arguments>(globalObject, decoder);
#if ENABLE(WEBGL)
    case MessageName::WebPageProxy_WebGLPolicyForURL:
        return jsValueForDecodedArguments<Messages::WebPageProxy::WebGLPolicyForURL::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ResolveWebGLPolicyForURL:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ResolveWebGLPolicyForURL::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_DidChangeViewportProperties:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidChangeViewportProperties::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidReceiveEvent:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidReceiveEvent::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SetCursor:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetCursor::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SetCursorHiddenUntilMouseMoves:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetCursorHiddenUntilMouseMoves::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SetStatusText:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetStatusText::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SetFocus:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetFocus::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_TakeFocus:
        return jsValueForDecodedArguments<Messages::WebPageProxy::TakeFocus::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_FocusedFrameChanged:
        return jsValueForDecodedArguments<Messages::WebPageProxy::FocusedFrameChanged::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SetRenderTreeSize:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetRenderTreeSize::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SetToolbarsAreVisible:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetToolbarsAreVisible::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_GetToolbarsAreVisible:
        return jsValueForDecodedArguments<Messages::WebPageProxy::GetToolbarsAreVisible::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SetMenuBarIsVisible:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetMenuBarIsVisible::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_GetMenuBarIsVisible:
        return jsValueForDecodedArguments<Messages::WebPageProxy::GetMenuBarIsVisible::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SetStatusBarIsVisible:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetStatusBarIsVisible::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_GetStatusBarIsVisible:
        return jsValueForDecodedArguments<Messages::WebPageProxy::GetStatusBarIsVisible::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SetIsResizable:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetIsResizable::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SetWindowFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetWindowFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_GetWindowFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::GetWindowFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ScreenToRootView:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ScreenToRootView::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RootViewToScreen:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RootViewToScreen::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_AccessibilityScreenToRootView:
        return jsValueForDecodedArguments<Messages::WebPageProxy::AccessibilityScreenToRootView::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RootViewToAccessibilityScreen:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RootViewToAccessibilityScreen::Arguments>(globalObject, decoder);
#if PLATFORM(COCOA) || PLATFORM(GTK)
    case MessageName::WebPageProxy_ShowValidationMessage:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShowValidationMessage::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_HideValidationMessage:
        return jsValueForDecodedArguments<Messages::WebPageProxy::HideValidationMessage::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_RunBeforeUnloadConfirmPanel:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RunBeforeUnloadConfirmPanel::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_PageDidScroll:
        return jsValueForDecodedArguments<Messages::WebPageProxy::PageDidScroll::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SetHasActiveAnimatedScrolls:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetHasActiveAnimatedScrolls::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RunOpenPanel:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RunOpenPanel::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ShowShareSheet:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShowShareSheet::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ShowContactPicker:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShowContactPicker::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_PrintFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::PrintFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RunModal:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RunModal::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_NotifyScrollerThumbIsVisibleInRect:
        return jsValueForDecodedArguments<Messages::WebPageProxy::NotifyScrollerThumbIsVisibleInRect::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RecommendedScrollbarStyleDidChange:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RecommendedScrollbarStyleDidChange::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidChangeScrollbarsForMainFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidChangeScrollbarsForMainFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidChangeScrollOffsetPinningForMainFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidChangeScrollOffsetPinningForMainFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidChangePageCount:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidChangePageCount::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ThemeColorChanged:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ThemeColorChanged::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_PageExtendedBackgroundColorDidChange:
        return jsValueForDecodedArguments<Messages::WebPageProxy::PageExtendedBackgroundColorDidChange::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SampledPageTopColorChanged:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SampledPageTopColorChanged::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SetCanShortCircuitHorizontalWheelEvents:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetCanShortCircuitHorizontalWheelEvents::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidChangeContentSize:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidChangeContentSize::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidChangeIntrinsicContentSize:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidChangeIntrinsicContentSize::Arguments>(globalObject, decoder);
#if ENABLE(INPUT_TYPE_COLOR)
    case MessageName::WebPageProxy_ShowColorPicker:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShowColorPicker::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SetColorPickerColor:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetColorPickerColor::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_EndColorPicker:
        return jsValueForDecodedArguments<Messages::WebPageProxy::EndColorPicker::Arguments>(globalObject, decoder);
#endif
#if ENABLE(DATALIST_ELEMENT)
    case MessageName::WebPageProxy_ShowDataListSuggestions:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShowDataListSuggestions::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_HandleKeydownInDataList:
        return jsValueForDecodedArguments<Messages::WebPageProxy::HandleKeydownInDataList::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_EndDataListSuggestions:
        return jsValueForDecodedArguments<Messages::WebPageProxy::EndDataListSuggestions::Arguments>(globalObject, decoder);
#endif
#if ENABLE(DATE_AND_TIME_INPUT_TYPES)
    case MessageName::WebPageProxy_ShowDateTimePicker:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShowDateTimePicker::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_EndDateTimePicker:
        return jsValueForDecodedArguments<Messages::WebPageProxy::EndDateTimePicker::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_DecidePolicyForResponse:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DecidePolicyForResponse::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DecidePolicyForNavigationActionAsync:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DecidePolicyForNavigationActionAsync::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DecidePolicyForNavigationActionSync:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DecidePolicyForNavigationActionSync::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DecidePolicyForNewWindowAction:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DecidePolicyForNewWindowAction::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_UnableToImplementPolicy:
        return jsValueForDecodedArguments<Messages::WebPageProxy::UnableToImplementPolicy::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidChangeProgress:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidChangeProgress::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidFinishProgress:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidFinishProgress::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidStartProgress:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidStartProgress::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SetNetworkRequestsInProgress:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetNetworkRequestsInProgress::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidCreateMainFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidCreateMainFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidCreateSubframe:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidCreateSubframe::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidCreateWindow:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidCreateWindow::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidStartProvisionalLoadForFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidStartProvisionalLoadForFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidReceiveServerRedirectForProvisionalLoadForFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidReceiveServerRedirectForProvisionalLoadForFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_WillPerformClientRedirectForFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::WillPerformClientRedirectForFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidCancelClientRedirectForFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidCancelClientRedirectForFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidChangeProvisionalURLForFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidChangeProvisionalURLForFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidFailProvisionalLoadForFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidFailProvisionalLoadForFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidCommitLoadForFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidCommitLoadForFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidFailLoadForFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidFailLoadForFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidFinishDocumentLoadForFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidFinishDocumentLoadForFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidFinishLoadForFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidFinishLoadForFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidFirstLayoutForFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidFirstLayoutForFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidFirstVisuallyNonEmptyLayoutForFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidFirstVisuallyNonEmptyLayoutForFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidReachLayoutMilestone:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidReachLayoutMilestone::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidReceiveTitleForFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidReceiveTitleForFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidDisplayInsecureContentForFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidDisplayInsecureContentForFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidRunInsecureContentForFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidRunInsecureContentForFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidDetectXSSForFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidDetectXSSForFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidSameDocumentNavigationForFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidSameDocumentNavigationForFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidChangeMainDocument:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidChangeMainDocument::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidExplicitOpenForFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidExplicitOpenForFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidDestroyNavigation:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidDestroyNavigation::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_MainFramePluginHandlesPageScaleGestureDidChange:
        return jsValueForDecodedArguments<Messages::WebPageProxy::MainFramePluginHandlesPageScaleGestureDidChange::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidNavigateWithNavigationData:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidNavigateWithNavigationData::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidPerformClientRedirect:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidPerformClientRedirect::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidPerformServerRedirect:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidPerformServerRedirect::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidUpdateHistoryTitle:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidUpdateHistoryTitle::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidFinishLoadingDataForCustomContentProvider:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidFinishLoadingDataForCustomContentProvider::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_WillSubmitForm:
        return jsValueForDecodedArguments<Messages::WebPageProxy::WillSubmitForm::Arguments>(globalObject, decoder);
#if PLATFORM(IOS_FAMILY)
    case MessageName::WebPageProxy_InterpretKeyEvent:
        return jsValueForDecodedArguments<Messages::WebPageProxy::InterpretKeyEvent::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidReceivePositionInformation:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidReceivePositionInformation::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SaveImageToLibrary:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SaveImageToLibrary::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ShowPlaybackTargetPicker:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShowPlaybackTargetPicker::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_CommitPotentialTapFailed:
        return jsValueForDecodedArguments<Messages::WebPageProxy::CommitPotentialTapFailed::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidNotHandleTapAsClick:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidNotHandleTapAsClick::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidCompleteSyntheticClick:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidCompleteSyntheticClick::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DisableDoubleTapGesturesDuringTapIfNecessary:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DisableDoubleTapGesturesDuringTapIfNecessary::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_HandleSmartMagnificationInformationForPotentialTap:
        return jsValueForDecodedArguments<Messages::WebPageProxy::HandleSmartMagnificationInformationForPotentialTap::Arguments>(globalObject, decoder);
#endif
#if ENABLE(DATA_DETECTION)
    case MessageName::WebPageProxy_SetDataDetectionResult:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetDataDetectionResult::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_HandleClickForDataDetectionResult:
        return jsValueForDecodedArguments<Messages::WebPageProxy::HandleClickForDataDetectionResult::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_PageScaleFactorDidChange:
        return jsValueForDecodedArguments<Messages::WebPageProxy::PageScaleFactorDidChange::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_PluginScaleFactorDidChange:
        return jsValueForDecodedArguments<Messages::WebPageProxy::PluginScaleFactorDidChange::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_PluginZoomFactorDidChange:
        return jsValueForDecodedArguments<Messages::WebPageProxy::PluginZoomFactorDidChange::Arguments>(globalObject, decoder);
#if PLATFORM(GTK) || PLATFORM(WPE)
    case MessageName::WebPageProxy_BindAccessibilityTree:
        return jsValueForDecodedArguments<Messages::WebPageProxy::BindAccessibilityTree::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SetInputMethodState:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetInputMethodState::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_BackForwardAddItem:
        return jsValueForDecodedArguments<Messages::WebPageProxy::BackForwardAddItem::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_BackForwardGoToItem:
        return jsValueForDecodedArguments<Messages::WebPageProxy::BackForwardGoToItem::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_BackForwardItemAtIndex:
        return jsValueForDecodedArguments<Messages::WebPageProxy::BackForwardItemAtIndex::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_BackForwardListCounts:
        return jsValueForDecodedArguments<Messages::WebPageProxy::BackForwardListCounts::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_BackForwardClear:
        return jsValueForDecodedArguments<Messages::WebPageProxy::BackForwardClear::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_WillGoToBackForwardListItem:
        return jsValueForDecodedArguments<Messages::WebPageProxy::WillGoToBackForwardListItem::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RegisterEditCommandForUndo:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RegisterEditCommandForUndo::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ClearAllEditCommands:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ClearAllEditCommands::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RegisterInsertionUndoGrouping:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RegisterInsertionUndoGrouping::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_CanUndoRedo:
        return jsValueForDecodedArguments<Messages::WebPageProxy::CanUndoRedo::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ExecuteUndoRedo:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ExecuteUndoRedo::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_LogDiagnosticMessageFromWebProcess:
        return jsValueForDecodedArguments<Messages::WebPageProxy::LogDiagnosticMessageFromWebProcess::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_LogDiagnosticMessageWithResultFromWebProcess:
        return jsValueForDecodedArguments<Messages::WebPageProxy::LogDiagnosticMessageWithResultFromWebProcess::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_LogDiagnosticMessageWithValueFromWebProcess:
        return jsValueForDecodedArguments<Messages::WebPageProxy::LogDiagnosticMessageWithValueFromWebProcess::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_LogDiagnosticMessageWithEnhancedPrivacyFromWebProcess:
        return jsValueForDecodedArguments<Messages::WebPageProxy::LogDiagnosticMessageWithEnhancedPrivacyFromWebProcess::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_LogDiagnosticMessageWithValueDictionaryFromWebProcess:
        return jsValueForDecodedArguments<Messages::WebPageProxy::LogDiagnosticMessageWithValueDictionaryFromWebProcess::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_LogDiagnosticMessageWithDomainFromWebProcess:
        return jsValueForDecodedArguments<Messages::WebPageProxy::LogDiagnosticMessageWithDomainFromWebProcess::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_LogScrollingEvent:
        return jsValueForDecodedArguments<Messages::WebPageProxy::LogScrollingEvent::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_EditorStateChanged:
        return jsValueForDecodedArguments<Messages::WebPageProxy::EditorStateChanged::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_CompositionWasCanceled:
        return jsValueForDecodedArguments<Messages::WebPageProxy::CompositionWasCanceled::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SetHasHadSelectionChangesFromUserInteraction:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetHasHadSelectionChangesFromUserInteraction::Arguments>(globalObject, decoder);
#if ENABLE(IMAGE_ANALYSIS)
    case MessageName::WebPageProxy_RequestTextRecognition:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RequestTextRecognition::Arguments>(globalObject, decoder);
#endif
#if HAVE(TRANSLATION_UI_SERVICES) && ENABLE(CONTEXT_MENUS)
    case MessageName::WebPageProxy_HandleContextMenuTranslation:
        return jsValueForDecodedArguments<Messages::WebPageProxy::HandleContextMenuTranslation::Arguments>(globalObject, decoder);
#endif
#if ENABLE(MEDIA_CONTROLS_CONTEXT_MENUS) && USE(UICONTEXTMENU)
    case MessageName::WebPageProxy_ShowMediaControlsContextMenu:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShowMediaControlsContextMenu::Arguments>(globalObject, decoder);
#endif
#if HAVE(TOUCH_BAR)
    case MessageName::WebPageProxy_SetIsTouchBarUpdateSupressedForHiddenContentEditable:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetIsTouchBarUpdateSupressedForHiddenContentEditable::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SetIsNeverRichlyEditableForTouchBar:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetIsNeverRichlyEditableForTouchBar::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_RequestDOMPasteAccess:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RequestDOMPasteAccess::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidCountStringMatches:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidCountStringMatches::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SetTextIndicator:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetTextIndicator::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ClearTextIndicator:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ClearTextIndicator::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidFindString:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidFindString::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidFailToFindString:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidFailToFindString::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidFindStringMatches:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidFindStringMatches::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidGetImageForFindMatch:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidGetImageForFindMatch::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ShowPopupMenu:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShowPopupMenu::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_HidePopupMenu:
        return jsValueForDecodedArguments<Messages::WebPageProxy::HidePopupMenu::Arguments>(globalObject, decoder);
#if ENABLE(CONTEXT_MENUS)
    case MessageName::WebPageProxy_ShowContextMenu:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShowContextMenu::Arguments>(globalObject, decoder);
#endif
#if ENABLE(SERVICE_WORKER)
    case MessageName::WebPageProxy_DidFinishServiceWorkerPageRegistration:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidFinishServiceWorkerPageRegistration::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_ExceededDatabaseQuota:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ExceededDatabaseQuota::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ReachedApplicationCacheOriginQuota:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ReachedApplicationCacheOriginQuota::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RequestGeolocationPermissionForFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RequestGeolocationPermissionForFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RevokeGeolocationAuthorizationToken:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RevokeGeolocationAuthorizationToken::Arguments>(globalObject, decoder);
#if ENABLE(MEDIA_STREAM)
    case MessageName::WebPageProxy_RequestUserMediaPermissionForFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RequestUserMediaPermissionForFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_EnumerateMediaDevicesForFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::EnumerateMediaDevicesForFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_BeginMonitoringCaptureDevices:
        return jsValueForDecodedArguments<Messages::WebPageProxy::BeginMonitoringCaptureDevices::Arguments>(globalObject, decoder);
#endif
#if ENABLE(ENCRYPTED_MEDIA)
    case MessageName::WebPageProxy_RequestMediaKeySystemPermissionForFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RequestMediaKeySystemPermissionForFrame::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_RequestNotificationPermission:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RequestNotificationPermission::Arguments>(globalObject, decoder);
#if USE(UNIFIED_TEXT_CHECKING)
    case MessageName::WebPageProxy_CheckTextOfParagraph:
        return jsValueForDecodedArguments<Messages::WebPageProxy::CheckTextOfParagraph::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_CheckSpellingOfString:
        return jsValueForDecodedArguments<Messages::WebPageProxy::CheckSpellingOfString::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_CheckGrammarOfString:
        return jsValueForDecodedArguments<Messages::WebPageProxy::CheckGrammarOfString::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SpellingUIIsShowing:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SpellingUIIsShowing::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_UpdateSpellingUIWithMisspelledWord:
        return jsValueForDecodedArguments<Messages::WebPageProxy::UpdateSpellingUIWithMisspelledWord::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_UpdateSpellingUIWithGrammarString:
        return jsValueForDecodedArguments<Messages::WebPageProxy::UpdateSpellingUIWithGrammarString::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_GetGuessesForWord:
        return jsValueForDecodedArguments<Messages::WebPageProxy::GetGuessesForWord::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_LearnWord:
        return jsValueForDecodedArguments<Messages::WebPageProxy::LearnWord::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_IgnoreWord:
        return jsValueForDecodedArguments<Messages::WebPageProxy::IgnoreWord::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RequestCheckingOfString:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RequestCheckingOfString::Arguments>(globalObject, decoder);
#if ENABLE(DRAG_SUPPORT)
    case MessageName::WebPageProxy_DidPerformDragControllerAction:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidPerformDragControllerAction::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidEndDragging:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidEndDragging::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(COCOA) && ENABLE(DRAG_SUPPORT)
    case MessageName::WebPageProxy_StartDrag:
        return jsValueForDecodedArguments<Messages::WebPageProxy::StartDrag::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SetPromisedDataForImage:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetPromisedDataForImage::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(GTK) && ENABLE(DRAG_SUPPORT)
    case MessageName::WebPageProxy_StartDrag:
        return jsValueForDecodedArguments<Messages::WebPageProxy::StartDrag::Arguments>(globalObject, decoder);
#endif
#if ENABLE(DRAG_SUPPORT)
    case MessageName::WebPageProxy_DidPerformDragOperation:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidPerformDragOperation::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(IOS_FAMILY) && ENABLE(DRAG_SUPPORT)
    case MessageName::WebPageProxy_DidHandleDragStartRequest:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidHandleDragStartRequest::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidHandleAdditionalDragItemsRequest:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidHandleAdditionalDragItemsRequest::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_WillReceiveEditDragSnapshot:
        return jsValueForDecodedArguments<Messages::WebPageProxy::WillReceiveEditDragSnapshot::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidReceiveEditDragSnapshot:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidReceiveEditDragSnapshot::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(COCOA)
    case MessageName::WebPageProxy_DidPerformDictionaryLookup:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidPerformDictionaryLookup::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ExecuteSavedCommandBySelector:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ExecuteSavedCommandBySelector::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RegisterWebProcessAccessibilityToken:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RegisterWebProcessAccessibilityToken::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_GetIsSpeaking:
        return jsValueForDecodedArguments<Messages::WebPageProxy::GetIsSpeaking::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_Speak:
        return jsValueForDecodedArguments<Messages::WebPageProxy::Speak::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_StopSpeaking:
        return jsValueForDecodedArguments<Messages::WebPageProxy::StopSpeaking::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_MakeFirstResponder:
        return jsValueForDecodedArguments<Messages::WebPageProxy::MakeFirstResponder::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_AssistiveTechnologyMakeFirstResponder:
        return jsValueForDecodedArguments<Messages::WebPageProxy::AssistiveTechnologyMakeFirstResponder::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SearchWithSpotlight:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SearchWithSpotlight::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SearchTheWeb:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SearchTheWeb::Arguments>(globalObject, decoder);
#endif
#if HAVE(TOUCH_BAR)
    case MessageName::WebPageProxy_TouchBarMenuDataChanged:
        return jsValueForDecodedArguments<Messages::WebPageProxy::TouchBarMenuDataChanged::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_TouchBarMenuItemDataAdded:
        return jsValueForDecodedArguments<Messages::WebPageProxy::TouchBarMenuItemDataAdded::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_TouchBarMenuItemDataRemoved:
        return jsValueForDecodedArguments<Messages::WebPageProxy::TouchBarMenuItemDataRemoved::Arguments>(globalObject, decoder);
#endif
#if USE(APPKIT)
    case MessageName::WebPageProxy_SubstitutionsPanelIsShowing:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SubstitutionsPanelIsShowing::Arguments>(globalObject, decoder);
#endif
#if USE(AUTOMATIC_TEXT_REPLACEMENT)
    case MessageName::WebPageProxy_toggleSmartInsertDelete:
        return jsValueForDecodedArguments<Messages::WebPageProxy::toggleSmartInsertDelete::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_toggleAutomaticQuoteSubstitution:
        return jsValueForDecodedArguments<Messages::WebPageProxy::toggleAutomaticQuoteSubstitution::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_toggleAutomaticLinkDetection:
        return jsValueForDecodedArguments<Messages::WebPageProxy::toggleAutomaticLinkDetection::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_toggleAutomaticDashSubstitution:
        return jsValueForDecodedArguments<Messages::WebPageProxy::toggleAutomaticDashSubstitution::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_toggleAutomaticTextReplacement:
        return jsValueForDecodedArguments<Messages::WebPageProxy::toggleAutomaticTextReplacement::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(MAC)
    case MessageName::WebPageProxy_ShowCorrectionPanel:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShowCorrectionPanel::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DismissCorrectionPanel:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DismissCorrectionPanel::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DismissCorrectionPanelSoon:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DismissCorrectionPanelSoon::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RecordAutocorrectionResponse:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RecordAutocorrectionResponse::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SetEditableElementIsFocused:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetEditableElementIsFocused::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_HandleAcceptsFirstMouse:
        return jsValueForDecodedArguments<Messages::WebPageProxy::HandleAcceptsFirstMouse::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_DidUpdateRenderingAfterCommittingLoad:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidUpdateRenderingAfterCommittingLoad::Arguments>(globalObject, decoder);
#if USE(DICTATION_ALTERNATIVES)
    case MessageName::WebPageProxy_ShowDictationAlternativeUI:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShowDictationAlternativeUI::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RemoveDictationAlternatives:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RemoveDictationAlternatives::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DictationAlternatives:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DictationAlternatives::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(IOS_FAMILY)
    case MessageName::WebPageProxy_CouldNotRestorePageState:
        return jsValueForDecodedArguments<Messages::WebPageProxy::CouldNotRestorePageState::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RestorePageState:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RestorePageState::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RestorePageCenterAndScale:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RestorePageCenterAndScale::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidGetTapHighlightGeometries:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidGetTapHighlightGeometries::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ElementDidFocus:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ElementDidFocus::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ElementDidBlur:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ElementDidBlur::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_UpdateInputContextAfterBlurringAndRefocusingElement:
        return jsValueForDecodedArguments<Messages::WebPageProxy::UpdateInputContextAfterBlurringAndRefocusingElement::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_FocusedElementDidChangeInputMode:
        return jsValueForDecodedArguments<Messages::WebPageProxy::FocusedElementDidChangeInputMode::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ScrollingNodeScrollWillStartScroll:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ScrollingNodeScrollWillStartScroll::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ScrollingNodeScrollDidEndScroll:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ScrollingNodeScrollDidEndScroll::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ShowInspectorHighlight:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShowInspectorHighlight::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_HideInspectorHighlight:
        return jsValueForDecodedArguments<Messages::WebPageProxy::HideInspectorHighlight::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ShowInspectorIndication:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShowInspectorIndication::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_HideInspectorIndication:
        return jsValueForDecodedArguments<Messages::WebPageProxy::HideInspectorIndication::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_EnableInspectorNodeSearch:
        return jsValueForDecodedArguments<Messages::WebPageProxy::EnableInspectorNodeSearch::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DisableInspectorNodeSearch:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DisableInspectorNodeSearch::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_UpdateStringForFind:
        return jsValueForDecodedArguments<Messages::WebPageProxy::UpdateStringForFind::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_HandleAutocorrectionContext:
        return jsValueForDecodedArguments<Messages::WebPageProxy::HandleAutocorrectionContext::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ShowDataDetectorsUIForPositionInformation:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShowDataDetectorsUIForPositionInformation::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_DidChangeInspectorFrontendCount:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidChangeInspectorFrontendCount::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_CreateInspectorTarget:
        return jsValueForDecodedArguments<Messages::WebPageProxy::CreateInspectorTarget::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DestroyInspectorTarget:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DestroyInspectorTarget::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SendMessageToInspectorFrontend:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SendMessageToInspectorFrontend::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SaveRecentSearches:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SaveRecentSearches::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_LoadRecentSearches:
        return jsValueForDecodedArguments<Messages::WebPageProxy::LoadRecentSearches::Arguments>(globalObject, decoder);
#if ENABLE(PDFKIT_PLUGIN) && !ENABLE(UI_PROCESS_PDF_HUD)
    case MessageName::WebPageProxy_SavePDFToFileInDownloadsFolder:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SavePDFToFileInDownloadsFolder::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SavePDFToTemporaryFolderAndOpenWithNativeApplication:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SavePDFToTemporaryFolderAndOpenWithNativeApplication::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_OpenPDFFromTemporaryFolderWithNativeApplication:
        return jsValueForDecodedArguments<Messages::WebPageProxy::OpenPDFFromTemporaryFolderWithNativeApplication::Arguments>(globalObject, decoder);
#endif
#if ENABLE(PDFKIT_PLUGIN)
    case MessageName::WebPageProxy_ShowPDFContextMenu:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShowPDFContextMenu::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_DidUpdateActivityState:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidUpdateActivityState::Arguments>(globalObject, decoder);
#if ENABLE(WEB_CRYPTO)
    case MessageName::WebPageProxy_WrapCryptoKey:
        return jsValueForDecodedArguments<Messages::WebPageProxy::WrapCryptoKey::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_UnwrapCryptoKey:
        return jsValueForDecodedArguments<Messages::WebPageProxy::UnwrapCryptoKey::Arguments>(globalObject, decoder);
#endif
#if (ENABLE(TELEPHONE_NUMBER_DETECTION) && PLATFORM(MAC))
    case MessageName::WebPageProxy_ShowTelephoneNumberMenu:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShowTelephoneNumberMenu::Arguments>(globalObject, decoder);
#endif
#if USE(QUICK_LOOK)
    case MessageName::WebPageProxy_DidStartLoadForQuickLookDocumentInMainFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidStartLoadForQuickLookDocumentInMainFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidFinishLoadForQuickLookDocumentInMainFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidFinishLoadForQuickLookDocumentInMainFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RequestPasswordForQuickLookDocumentInMainFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RequestPasswordForQuickLookDocumentInMainFrame::Arguments>(globalObject, decoder);
#endif
#if ENABLE(CONTENT_FILTERING)
    case MessageName::WebPageProxy_ContentFilterDidBlockLoadForFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ContentFilterDidBlockLoadForFrame::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_IsPlayingMediaDidChange:
        return jsValueForDecodedArguments<Messages::WebPageProxy::IsPlayingMediaDidChange::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_HandleAutoplayEvent:
        return jsValueForDecodedArguments<Messages::WebPageProxy::HandleAutoplayEvent::Arguments>(globalObject, decoder);
#if PLATFORM(MAC)
    case MessageName::WebPageProxy_DidPerformImmediateActionHitTest:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidPerformImmediateActionHitTest::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_HandleMessage:
        return jsValueForDecodedArguments<Messages::WebPageProxy::HandleMessage::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_HandleSynchronousMessage:
        return jsValueForDecodedArguments<Messages::WebPageProxy::HandleSynchronousMessage::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_HandleAutoFillButtonClick:
        return jsValueForDecodedArguments<Messages::WebPageProxy::HandleAutoFillButtonClick::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidResignInputElementStrongPasswordAppearance:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidResignInputElementStrongPasswordAppearance::Arguments>(globalObject, decoder);
#if ENABLE(CONTENT_EXTENSIONS)
    case MessageName::WebPageProxy_ContentRuleListNotification:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ContentRuleListNotification::Arguments>(globalObject, decoder);
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    case MessageName::WebPageProxy_AddPlaybackTargetPickerClient:
        return jsValueForDecodedArguments<Messages::WebPageProxy::AddPlaybackTargetPickerClient::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RemovePlaybackTargetPickerClient:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RemovePlaybackTargetPickerClient::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ShowPlaybackTargetPicker:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShowPlaybackTargetPicker::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_PlaybackTargetPickerClientStateDidChange:
        return jsValueForDecodedArguments<Messages::WebPageProxy::PlaybackTargetPickerClientStateDidChange::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SetMockMediaPlaybackTargetPickerEnabled:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetMockMediaPlaybackTargetPickerEnabled::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SetMockMediaPlaybackTargetPickerState:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetMockMediaPlaybackTargetPickerState::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_MockMediaPlaybackTargetPickerDismissPopup:
        return jsValueForDecodedArguments<Messages::WebPageProxy::MockMediaPlaybackTargetPickerDismissPopup::Arguments>(globalObject, decoder);
#endif
#if ENABLE(VIDEO_PRESENTATION_MODE)
    case MessageName::WebPageProxy_SetMockVideoPresentationModeEnabled:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetMockVideoPresentationModeEnabled::Arguments>(globalObject, decoder);
#endif
#if ENABLE(POINTER_LOCK)
    case MessageName::WebPageProxy_RequestPointerLock:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RequestPointerLock::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RequestPointerUnlock:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RequestPointerUnlock::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_DidFailToSuspendAfterProcessSwap:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidFailToSuspendAfterProcessSwap::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidSuspendAfterProcessSwap:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidSuspendAfterProcessSwap::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ImageOrMediaDocumentSizeChanged:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ImageOrMediaDocumentSizeChanged::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_UseFixedLayoutDidChange:
        return jsValueForDecodedArguments<Messages::WebPageProxy::UseFixedLayoutDidChange::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_FixedLayoutSizeDidChange:
        return jsValueForDecodedArguments<Messages::WebPageProxy::FixedLayoutSizeDidChange::Arguments>(globalObject, decoder);
#if ENABLE(VIDEO) && USE(GSTREAMER)
    case MessageName::WebPageProxy_RequestInstallMissingMediaPlugins:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RequestInstallMissingMediaPlugins::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_DidRestoreScrollPosition:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidRestoreScrollPosition::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RequestScrollToRect:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RequestScrollToRect::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_GetLoadDecisionForIcon:
        return jsValueForDecodedArguments<Messages::WebPageProxy::GetLoadDecisionForIcon::Arguments>(globalObject, decoder);
#if PLATFORM(MAC)
    case MessageName::WebPageProxy_DidHandleAcceptedCandidate:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidHandleAcceptedCandidate::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_SetIsUsingHighPerformanceWebGL:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetIsUsingHighPerformanceWebGL::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_StartURLSchemeTask:
        return jsValueForDecodedArguments<Messages::WebPageProxy::StartURLSchemeTask::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_StopURLSchemeTask:
        return jsValueForDecodedArguments<Messages::WebPageProxy::StopURLSchemeTask::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_LoadSynchronousURLSchemeTask:
        return jsValueForDecodedArguments<Messages::WebPageProxy::LoadSynchronousURLSchemeTask::Arguments>(globalObject, decoder);
#if ENABLE(DEVICE_ORIENTATION)
    case MessageName::WebPageProxy_ShouldAllowDeviceOrientationAndMotionAccess:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShouldAllowDeviceOrientationAndMotionAccess::Arguments>(globalObject, decoder);
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    case MessageName::WebPageProxy_RegisterAttachmentIdentifierFromData:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RegisterAttachmentIdentifierFromData::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RegisterAttachmentIdentifierFromFilePath:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RegisterAttachmentIdentifierFromFilePath::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RegisterAttachmentIdentifier:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RegisterAttachmentIdentifier::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RegisterAttachmentsFromSerializedData:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RegisterAttachmentsFromSerializedData::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_CloneAttachmentData:
        return jsValueForDecodedArguments<Messages::WebPageProxy::CloneAttachmentData::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidInsertAttachmentWithIdentifier:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidInsertAttachmentWithIdentifier::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DidRemoveAttachmentWithIdentifier:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidRemoveAttachmentWithIdentifier::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SerializedAttachmentDataForIdentifiers:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SerializedAttachmentDataForIdentifiers::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_WritePromisedAttachmentToPasteboard:
        return jsValueForDecodedArguments<Messages::WebPageProxy::WritePromisedAttachmentToPasteboard::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RequestAttachmentIcon:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RequestAttachmentIcon::Arguments>(globalObject, decoder);
#endif
#if ENABLE(APP_HIGHLIGHTS)
    case MessageName::WebPageProxy_StoreAppHighlight:
        return jsValueForDecodedArguments<Messages::WebPageProxy::StoreAppHighlight::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_SignedPublicKeyAndChallengeString:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SignedPublicKeyAndChallengeString::Arguments>(globalObject, decoder);
#if ENABLE(SPEECH_SYNTHESIS)
    case MessageName::WebPageProxy_SpeechSynthesisVoiceList:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SpeechSynthesisVoiceList::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SpeechSynthesisSpeak:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SpeechSynthesisSpeak::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SpeechSynthesisSetFinishedCallback:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SpeechSynthesisSetFinishedCallback::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SpeechSynthesisCancel:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SpeechSynthesisCancel::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SpeechSynthesisPause:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SpeechSynthesisPause::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SpeechSynthesisResume:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SpeechSynthesisResume::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SpeechSynthesisResetState:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SpeechSynthesisResetState::Arguments>(globalObject, decoder);
#endif
#if ENABLE(UI_PROCESS_PDF_HUD)
    case MessageName::WebPageProxy_CreatePDFHUD:
        return jsValueForDecodedArguments<Messages::WebPageProxy::CreatePDFHUD::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_UpdatePDFHUDLocation:
        return jsValueForDecodedArguments<Messages::WebPageProxy::UpdatePDFHUDLocation::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RemovePDFHUD:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RemovePDFHUD::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_ConfigureLoggingChannel:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ConfigureLoggingChannel::Arguments>(globalObject, decoder);
#if PLATFORM(GTK)
    case MessageName::WebPageProxy_ShowEmojiPicker:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShowEmojiPicker::Arguments>(globalObject, decoder);
#endif
#if HAVE(VISIBILITY_PROPAGATION_VIEW)
    case MessageName::WebPageProxy_DidCreateContextInWebProcessForVisibilityPropagation:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidCreateContextInWebProcessForVisibilityPropagation::Arguments>(globalObject, decoder);
#endif
#if ENABLE(WEB_AUTHN)
    case MessageName::WebPageProxy_SetMockWebAuthenticationConfiguration:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetMockWebAuthenticationConfiguration::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    case MessageName::WebPageProxy_SendMessageToWebView:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SendMessageToWebView::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SendMessageToWebViewWithReply:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SendMessageToWebViewWithReply::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_DidFindTextManipulationItems:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DidFindTextManipulationItems::Arguments>(globalObject, decoder);
#if ENABLE(MEDIA_USAGE)
    case MessageName::WebPageProxy_AddMediaUsageManagerSession:
        return jsValueForDecodedArguments<Messages::WebPageProxy::AddMediaUsageManagerSession::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_UpdateMediaUsageManagerSessionState:
        return jsValueForDecodedArguments<Messages::WebPageProxy::UpdateMediaUsageManagerSessionState::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RemoveMediaUsageManagerSession:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RemoveMediaUsageManagerSession::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_SetHasExecutedAppBoundBehaviorBeforeNavigation:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SetHasExecutedAppBoundBehaviorBeforeNavigation::Arguments>(globalObject, decoder);
#if PLATFORM(MAC)
    case MessageName::WebPageProxy_ChangeUniversalAccessZoomFocus:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ChangeUniversalAccessZoomFocus::Arguments>(globalObject, decoder);
#endif
#if ENABLE(ARKIT_INLINE_PREVIEW_IOS)
    case MessageName::WebPageProxy_TakeModelElementFullscreen:
        return jsValueForDecodedArguments<Messages::WebPageProxy::TakeModelElementFullscreen::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ModelElementSetInteractionEnabled:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementSetInteractionEnabled::Arguments>(globalObject, decoder);
#endif
#if ENABLE(ARKIT_INLINE_PREVIEW_MAC)
    case MessageName::WebPageProxy_ModelElementDidCreatePreview:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementDidCreatePreview::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ModelElementSizeDidChange:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementSizeDidChange::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_HandleMouseDownForModelElement:
        return jsValueForDecodedArguments<Messages::WebPageProxy::HandleMouseDownForModelElement::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_HandleMouseMoveForModelElement:
        return jsValueForDecodedArguments<Messages::WebPageProxy::HandleMouseMoveForModelElement::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_HandleMouseUpForModelElement:
        return jsValueForDecodedArguments<Messages::WebPageProxy::HandleMouseUpForModelElement::Arguments>(globalObject, decoder);
#endif
#if ENABLE(ARKIT_INLINE_PREVIEW)
    case MessageName::WebPageProxy_ModelElementGetCamera:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementGetCamera::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ModelElementSetCamera:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementSetCamera::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ModelElementIsPlayingAnimation:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementIsPlayingAnimation::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ModelElementSetAnimationIsPlaying:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementSetAnimationIsPlaying::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ModelElementIsLoopingAnimation:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementIsLoopingAnimation::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ModelElementSetIsLoopingAnimation:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementSetIsLoopingAnimation::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ModelElementAnimationDuration:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementAnimationDuration::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ModelElementAnimationCurrentTime:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementAnimationCurrentTime::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ModelElementSetAnimationCurrentTime:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementSetAnimationCurrentTime::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ModelElementHasAudio:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementHasAudio::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ModelElementIsMuted:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementIsMuted::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ModelElementSetIsMuted:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementSetIsMuted::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_QueryPermission:
        return jsValueForDecodedArguments<Messages::WebPageProxy::QueryPermission::Arguments>(globalObject, decoder);
#if ENABLE(APPLE_PAY_AMS_UI)
    case MessageName::WebPageProxy_StartApplePayAMSUISession:
        return jsValueForDecodedArguments<Messages::WebPageProxy::StartApplePayAMSUISession::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_AbortApplePayAMSUISession:
        return jsValueForDecodedArguments<Messages::WebPageProxy::AbortApplePayAMSUISession::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_RequestCookieConsent:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RequestCookieConsent::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ClassifyModalContainerControls:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ClassifyModalContainerControls::Arguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DecidePolicyForModalContainer:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DecidePolicyForModalContainer::Arguments>(globalObject, decoder);
#if PLATFORM(IOS_FAMILY)
    case MessageName::WebPasteboardProxy_WriteURLToPasteboard:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::WriteURLToPasteboard::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_WriteWebContentToPasteboard:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::WriteWebContentToPasteboard::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_WriteImageToPasteboard:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::WriteImageToPasteboard::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_WriteStringToPasteboard:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::WriteStringToPasteboard::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_UpdateSupportedTypeIdentifiers:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::UpdateSupportedTypeIdentifiers::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPasteboardProxy_WriteCustomData:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::WriteCustomData::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_TypesSafeForDOMToReadAndWrite:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::TypesSafeForDOMToReadAndWrite::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_AllPasteboardItemInfo:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::AllPasteboardItemInfo::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_InformationForItemAtIndex:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::InformationForItemAtIndex::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_GetPasteboardItemsCount:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::GetPasteboardItemsCount::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_ReadStringFromPasteboard:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::ReadStringFromPasteboard::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_ReadURLFromPasteboard:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::ReadURLFromPasteboard::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_ReadBufferFromPasteboard:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::ReadBufferFromPasteboard::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_ContainsStringSafeForDOMToReadForType:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::ContainsStringSafeForDOMToReadForType::Arguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::WebPasteboardProxy_GetNumberOfFiles:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::GetNumberOfFiles::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_GetPasteboardTypes:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::GetPasteboardTypes::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_GetPasteboardPathnamesForType:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::GetPasteboardPathnamesForType::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_GetPasteboardStringForType:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::GetPasteboardStringForType::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_GetPasteboardStringsForType:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::GetPasteboardStringsForType::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_GetPasteboardBufferForType:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::GetPasteboardBufferForType::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_GetPasteboardChangeCount:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::GetPasteboardChangeCount::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_GetPasteboardColor:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::GetPasteboardColor::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_GetPasteboardURL:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::GetPasteboardURL::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_AddPasteboardTypes:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::AddPasteboardTypes::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_SetPasteboardTypes:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::SetPasteboardTypes::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_SetPasteboardURL:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::SetPasteboardURL::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_SetPasteboardColor:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::SetPasteboardColor::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_SetPasteboardStringForType:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::SetPasteboardStringForType::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_SetPasteboardBufferForType:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::SetPasteboardBufferForType::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_ContainsURLStringSuitableForLoading:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::ContainsURLStringSuitableForLoading::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_URLStringSuitableForLoading:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::URLStringSuitableForLoading::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(GTK)
    case MessageName::WebPasteboardProxy_GetTypes:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::GetTypes::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_ReadText:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::ReadText::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_ReadFilePaths:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::ReadFilePaths::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_ReadBuffer:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::ReadBuffer::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_WriteToClipboard:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::WriteToClipboard::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_ClearClipboard:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::ClearClipboard::Arguments>(globalObject, decoder);
#endif
#if USE(LIBWPE)
    case MessageName::WebPasteboardProxy_GetPasteboardTypes:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::GetPasteboardTypes::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_WriteWebContentToPasteboard:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::WriteWebContentToPasteboard::Arguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_WriteStringToPasteboard:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::WriteStringToPasteboard::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebProcessPool_HandleMessage:
        return jsValueForDecodedArguments<Messages::WebProcessPool::HandleMessage::Arguments>(globalObject, decoder);
    case MessageName::WebProcessPool_HandleSynchronousMessage:
        return jsValueForDecodedArguments<Messages::WebProcessPool::HandleSynchronousMessage::Arguments>(globalObject, decoder);
#if ENABLE(GAMEPAD)
    case MessageName::WebProcessPool_StartedUsingGamepads:
        return jsValueForDecodedArguments<Messages::WebProcessPool::StartedUsingGamepads::Arguments>(globalObject, decoder);
    case MessageName::WebProcessPool_StoppedUsingGamepads:
        return jsValueForDecodedArguments<Messages::WebProcessPool::StoppedUsingGamepads::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebProcessPool_ReportWebContentCPUTime:
        return jsValueForDecodedArguments<Messages::WebProcessPool::ReportWebContentCPUTime::Arguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_UpdateBackForwardItem:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::UpdateBackForwardItem::Arguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_DidDestroyFrame:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::DidDestroyFrame::Arguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_DidDestroyUserGestureToken:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::DidDestroyUserGestureToken::Arguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_ShouldTerminate:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::ShouldTerminate::Arguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_EnableSuddenTermination:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::EnableSuddenTermination::Arguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_DisableSuddenTermination:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::DisableSuddenTermination::Arguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_GetNetworkProcessConnection:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::GetNetworkProcessConnection::Arguments>(globalObject, decoder);
#if ENABLE(GPU_PROCESS)
    case MessageName::WebProcessProxy_GetGPUProcessConnection:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::GetGPUProcessConnection::Arguments>(globalObject, decoder);
#endif
#if ENABLE(WEB_AUTHN)
    case MessageName::WebProcessProxy_GetWebAuthnProcessConnection:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::GetWebAuthnProcessConnection::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebProcessProxy_SetIsHoldingLockedFiles:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::SetIsHoldingLockedFiles::Arguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_DidExceedActiveMemoryLimit:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::DidExceedActiveMemoryLimit::Arguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_DidExceedInactiveMemoryLimit:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::DidExceedInactiveMemoryLimit::Arguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_DidExceedCPULimit:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::DidExceedCPULimit::Arguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_StopResponsivenessTimer:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::StopResponsivenessTimer::Arguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_DidReceiveBackgroundResponsivenessPing:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::DidReceiveBackgroundResponsivenessPing::Arguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_MemoryPressureStatusChanged:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::MemoryPressureStatusChanged::Arguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_DidExceedInactiveMemoryLimitWhileActive:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::DidExceedInactiveMemoryLimitWhileActive::Arguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_DidCollectPrewarmInformation:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::DidCollectPrewarmInformation::Arguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::WebProcessProxy_CacheMediaMIMETypes:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::CacheMediaMIMETypes::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(MAC)
    case MessageName::WebProcessProxy_RequestHighPerformanceGPU:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::RequestHighPerformanceGPU::Arguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_ReleaseHighPerformanceGPU:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::ReleaseHighPerformanceGPU::Arguments>(globalObject, decoder);
#endif
#if HAVE(CVDISPLAYLINK)
    case MessageName::WebProcessProxy_StartDisplayLink:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::StartDisplayLink::Arguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_StopDisplayLink:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::StopDisplayLink::Arguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_SetDisplayLinkPreferredFramesPerSecond:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::SetDisplayLinkPreferredFramesPerSecond::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    case MessageName::WebProcessProxy_SendMessageToWebContext:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::SendMessageToWebContext::Arguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_SendMessageToWebContextWithReply:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::SendMessageToWebContextWithReply::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebProcessProxy_DidCreateSleepDisabler:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::DidCreateSleepDisabler::Arguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_DidDestroySleepDisabler:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::DidDestroySleepDisabler::Arguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_CreateSpeechRecognitionServer:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::CreateSpeechRecognitionServer::Arguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_DestroySpeechRecognitionServer:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::DestroySpeechRecognitionServer::Arguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_SystemBeep:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::SystemBeep::Arguments>(globalObject, decoder);
#if PLATFORM(MAC)
    case MessageName::WebProcessProxy_IsAXAuthenticated:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::IsAXAuthenticated::Arguments>(globalObject, decoder);
#endif
#if HAVE(MEDIA_ACCESSIBILITY_FRAMEWORK)
    case MessageName::WebProcessProxy_SetCaptionDisplayMode:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::SetCaptionDisplayMode::Arguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_SetCaptionLanguage:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::SetCaptionLanguage::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebAutomationSession_DidEvaluateJavaScriptFunction:
        return jsValueForDecodedArguments<Messages::WebAutomationSession::DidEvaluateJavaScriptFunction::Arguments>(globalObject, decoder);
    case MessageName::WebAutomationSession_DidTakeScreenshot:
        return jsValueForDecodedArguments<Messages::WebAutomationSession::DidTakeScreenshot::Arguments>(globalObject, decoder);
    case MessageName::DownloadProxy_DidStart:
        return jsValueForDecodedArguments<Messages::DownloadProxy::DidStart::Arguments>(globalObject, decoder);
    case MessageName::DownloadProxy_DidReceiveAuthenticationChallenge:
        return jsValueForDecodedArguments<Messages::DownloadProxy::DidReceiveAuthenticationChallenge::Arguments>(globalObject, decoder);
    case MessageName::DownloadProxy_WillSendRequest:
        return jsValueForDecodedArguments<Messages::DownloadProxy::WillSendRequest::Arguments>(globalObject, decoder);
    case MessageName::DownloadProxy_DecideDestinationWithSuggestedFilename:
        return jsValueForDecodedArguments<Messages::DownloadProxy::DecideDestinationWithSuggestedFilename::Arguments>(globalObject, decoder);
    case MessageName::DownloadProxy_DidReceiveData:
        return jsValueForDecodedArguments<Messages::DownloadProxy::DidReceiveData::Arguments>(globalObject, decoder);
    case MessageName::DownloadProxy_DidCreateDestination:
        return jsValueForDecodedArguments<Messages::DownloadProxy::DidCreateDestination::Arguments>(globalObject, decoder);
    case MessageName::DownloadProxy_DidFinish:
        return jsValueForDecodedArguments<Messages::DownloadProxy::DidFinish::Arguments>(globalObject, decoder);
    case MessageName::DownloadProxy_DidFail:
        return jsValueForDecodedArguments<Messages::DownloadProxy::DidFail::Arguments>(globalObject, decoder);
#if ENABLE(GPU_PROCESS)
#if HAVE(VISIBILITY_PROPAGATION_VIEW)
    case MessageName::GPUProcessProxy_DidCreateContextForVisibilityPropagation:
        return jsValueForDecodedArguments<Messages::GPUProcessProxy::DidCreateContextForVisibilityPropagation::Arguments>(globalObject, decoder);
#endif
    case MessageName::GPUProcessProxy_ProcessIsReadyToExit:
        return jsValueForDecodedArguments<Messages::GPUProcessProxy::ProcessIsReadyToExit::Arguments>(globalObject, decoder);
    case MessageName::GPUProcessProxy_TerminateWebProcess:
        return jsValueForDecodedArguments<Messages::GPUProcessProxy::TerminateWebProcess::Arguments>(globalObject, decoder);
#endif
    case MessageName::RemoteWebInspectorUIProxy_FrontendLoaded:
        return jsValueForDecodedArguments<Messages::RemoteWebInspectorUIProxy::FrontendLoaded::Arguments>(globalObject, decoder);
    case MessageName::RemoteWebInspectorUIProxy_FrontendDidClose:
        return jsValueForDecodedArguments<Messages::RemoteWebInspectorUIProxy::FrontendDidClose::Arguments>(globalObject, decoder);
    case MessageName::RemoteWebInspectorUIProxy_Reopen:
        return jsValueForDecodedArguments<Messages::RemoteWebInspectorUIProxy::Reopen::Arguments>(globalObject, decoder);
    case MessageName::RemoteWebInspectorUIProxy_ResetState:
        return jsValueForDecodedArguments<Messages::RemoteWebInspectorUIProxy::ResetState::Arguments>(globalObject, decoder);
    case MessageName::RemoteWebInspectorUIProxy_BringToFront:
        return jsValueForDecodedArguments<Messages::RemoteWebInspectorUIProxy::BringToFront::Arguments>(globalObject, decoder);
    case MessageName::RemoteWebInspectorUIProxy_Save:
        return jsValueForDecodedArguments<Messages::RemoteWebInspectorUIProxy::Save::Arguments>(globalObject, decoder);
    case MessageName::RemoteWebInspectorUIProxy_Append:
        return jsValueForDecodedArguments<Messages::RemoteWebInspectorUIProxy::Append::Arguments>(globalObject, decoder);
    case MessageName::RemoteWebInspectorUIProxy_SetForcedAppearance:
        return jsValueForDecodedArguments<Messages::RemoteWebInspectorUIProxy::SetForcedAppearance::Arguments>(globalObject, decoder);
    case MessageName::RemoteWebInspectorUIProxy_SetSheetRect:
        return jsValueForDecodedArguments<Messages::RemoteWebInspectorUIProxy::SetSheetRect::Arguments>(globalObject, decoder);
    case MessageName::RemoteWebInspectorUIProxy_StartWindowDrag:
        return jsValueForDecodedArguments<Messages::RemoteWebInspectorUIProxy::StartWindowDrag::Arguments>(globalObject, decoder);
    case MessageName::RemoteWebInspectorUIProxy_OpenURLExternally:
        return jsValueForDecodedArguments<Messages::RemoteWebInspectorUIProxy::OpenURLExternally::Arguments>(globalObject, decoder);
    case MessageName::RemoteWebInspectorUIProxy_ShowCertificate:
        return jsValueForDecodedArguments<Messages::RemoteWebInspectorUIProxy::ShowCertificate::Arguments>(globalObject, decoder);
    case MessageName::RemoteWebInspectorUIProxy_SendMessageToBackend:
        return jsValueForDecodedArguments<Messages::RemoteWebInspectorUIProxy::SendMessageToBackend::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_OpenLocalInspectorFrontend:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::OpenLocalInspectorFrontend::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_SetFrontendConnection:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::SetFrontendConnection::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_SendMessageToBackend:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::SendMessageToBackend::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_FrontendLoaded:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::FrontendLoaded::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_DidClose:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::DidClose::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_BringToFront:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::BringToFront::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_BringInspectedPageToFront:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::BringInspectedPageToFront::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_Reopen:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::Reopen::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_ResetState:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::ResetState::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_SetForcedAppearance:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::SetForcedAppearance::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_OpenURLExternally:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::OpenURLExternally::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_InspectedURLChanged:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::InspectedURLChanged::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_ShowCertificate:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::ShowCertificate::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_ElementSelectionChanged:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::ElementSelectionChanged::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_TimelineRecordingChanged:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::TimelineRecordingChanged::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_SetDeveloperPreferenceOverride:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::SetDeveloperPreferenceOverride::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_Save:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::Save::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_Append:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::Append::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_AttachBottom:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::AttachBottom::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_AttachRight:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::AttachRight::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_AttachLeft:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::AttachLeft::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_Detach:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::Detach::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_AttachAvailabilityChanged:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::AttachAvailabilityChanged::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_SetAttachedWindowHeight:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::SetAttachedWindowHeight::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_SetAttachedWindowWidth:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::SetAttachedWindowWidth::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_SetSheetRect:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::SetSheetRect::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUIProxy_StartWindowDrag:
        return jsValueForDecodedArguments<Messages::WebInspectorUIProxy::StartWindowDrag::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_DidReceiveAuthenticationChallenge:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::DidReceiveAuthenticationChallenge::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_NegotiatedLegacyTLS:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::NegotiatedLegacyTLS::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_DidNegotiateModernTLS:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::DidNegotiateModernTLS::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_TestProcessIncomingSyncMessagesWhenWaitingForSyncReply:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::TestProcessIncomingSyncMessagesWhenWaitingForSyncReply::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_TerminateUnresponsiveServiceWorkerProcesses:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::TerminateUnresponsiveServiceWorkerProcesses::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_LogDiagnosticMessage:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::LogDiagnosticMessage::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_LogDiagnosticMessageWithResult:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::LogDiagnosticMessageWithResult::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_LogDiagnosticMessageWithValue:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::LogDiagnosticMessageWithValue::Arguments>(globalObject, decoder);
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
    case MessageName::NetworkProcessProxy_LogTestingEvent:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::LogTestingEvent::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_NotifyResourceLoadStatisticsProcessed:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::NotifyResourceLoadStatisticsProcessed::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_NotifyWebsiteDataDeletionForRegistrableDomainsFinished:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::NotifyWebsiteDataDeletionForRegistrableDomainsFinished::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_NotifyWebsiteDataScanForRegistrableDomainsFinished:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::NotifyWebsiteDataScanForRegistrableDomainsFinished::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_RequestStorageAccessConfirm:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::RequestStorageAccessConfirm::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_DeleteWebsiteDataInUIProcessForRegistrableDomains:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::DeleteWebsiteDataInUIProcessForRegistrableDomains::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_DidCommitCrossSiteLoadWithDataTransferFromPrevalentResource:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::DidCommitCrossSiteLoadWithDataTransferFromPrevalentResource::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_SetDomainsWithUserInteraction:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::SetDomainsWithUserInteraction::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_SetDomainsWithCrossPageStorageAccess:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::SetDomainsWithCrossPageStorageAccess::Arguments>(globalObject, decoder);
#endif
#if ENABLE(CONTENT_EXTENSIONS)
    case MessageName::NetworkProcessProxy_ContentExtensionRules:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::ContentExtensionRules::Arguments>(globalObject, decoder);
#endif
    case MessageName::NetworkProcessProxy_RetrieveCacheStorageParameters:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::RetrieveCacheStorageParameters::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_TerminateWebProcess:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::TerminateWebProcess::Arguments>(globalObject, decoder);
#if ENABLE(SERVICE_WORKER)
    case MessageName::NetworkProcessProxy_EstablishServiceWorkerContextConnectionToNetworkProcess:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::EstablishServiceWorkerContextConnectionToNetworkProcess::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_StartServiceWorkerBackgroundProcessing:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::StartServiceWorkerBackgroundProcessing::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_EndServiceWorkerBackgroundProcessing:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::EndServiceWorkerBackgroundProcessing::Arguments>(globalObject, decoder);
#endif
    case MessageName::NetworkProcessProxy_EstablishSharedWorkerContextConnectionToNetworkProcess:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::EstablishSharedWorkerContextConnectionToNetworkProcess::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_RemoteWorkerContextConnectionNoLongerNeeded:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::RemoteWorkerContextConnectionNoLongerNeeded::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_RegisterRemoteWorkerClientProcess:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::RegisterRemoteWorkerClientProcess::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_UnregisterRemoteWorkerClientProcess:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::UnregisterRemoteWorkerClientProcess::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_SetWebProcessHasUploads:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::SetWebProcessHasUploads::Arguments>(globalObject, decoder);
#if ENABLE(APP_BOUND_DOMAINS)
    case MessageName::NetworkProcessProxy_GetAppBoundDomains:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::GetAppBoundDomains::Arguments>(globalObject, decoder);
#endif
    case MessageName::NetworkProcessProxy_RequestStorageSpace:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::RequestStorageSpace::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_IncreaseQuota:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::IncreaseQuota::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_ResourceLoadDidSendRequest:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::ResourceLoadDidSendRequest::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_ResourceLoadDidPerformHTTPRedirection:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::ResourceLoadDidPerformHTTPRedirection::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_ResourceLoadDidReceiveChallenge:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::ResourceLoadDidReceiveChallenge::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_ResourceLoadDidReceiveResponse:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::ResourceLoadDidReceiveResponse::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_ResourceLoadDidCompleteWithError:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::ResourceLoadDidCompleteWithError::Arguments>(globalObject, decoder);
#if ENABLE(CONTENT_FILTERING_IN_NETWORKING_PROCESS)
    case MessageName::NetworkProcessProxy_ReloadAfterUnblockedContentFilter:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::ReloadAfterUnblockedContentFilter::Arguments>(globalObject, decoder);
#endif
    case MessageName::NetworkProcessProxy_TriggerBrowsingContextGroupSwitchForNavigation:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::TriggerBrowsingContextGroupSwitchForNavigation::Arguments>(globalObject, decoder);
#if USE(SOUP)
    case MessageName::NetworkProcessProxy_DidExceedMemoryLimit:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::DidExceedMemoryLimit::Arguments>(globalObject, decoder);
#endif
#if ENABLE(APPLE_PAY_REMOTE_UI_USES_SCENE)
    case MessageName::NetworkProcessProxy_GetWindowSceneIdentifierForPaymentPresentation:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::GetWindowSceneIdentifierForPaymentPresentation::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebUserContentControllerProxy_DidPostMessage:
        return jsValueForDecodedArguments<Messages::WebUserContentControllerProxy::DidPostMessage::Arguments>(globalObject, decoder);
#if ENABLE(WEBXR)
    case MessageName::PlatformXRSystem_EnumerateImmersiveXRDevices:
        return jsValueForDecodedArguments<Messages::PlatformXRSystem::EnumerateImmersiveXRDevices::Arguments>(globalObject, decoder);
    case MessageName::PlatformXRSystem_RequestPermissionOnSessionFeatures:
        return jsValueForDecodedArguments<Messages::PlatformXRSystem::RequestPermissionOnSessionFeatures::Arguments>(globalObject, decoder);
    case MessageName::PlatformXRSystem_InitializeTrackingAndRendering:
        return jsValueForDecodedArguments<Messages::PlatformXRSystem::InitializeTrackingAndRendering::Arguments>(globalObject, decoder);
    case MessageName::PlatformXRSystem_ShutDownTrackingAndRendering:
        return jsValueForDecodedArguments<Messages::PlatformXRSystem::ShutDownTrackingAndRendering::Arguments>(globalObject, decoder);
    case MessageName::PlatformXRSystem_RequestFrame:
        return jsValueForDecodedArguments<Messages::PlatformXRSystem::RequestFrame::Arguments>(globalObject, decoder);
    case MessageName::PlatformXRSystem_SubmitFrame:
        return jsValueForDecodedArguments<Messages::PlatformXRSystem::SubmitFrame::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebProcess_InitializeWebProcess:
        return jsValueForDecodedArguments<Messages::WebProcess::InitializeWebProcess::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_SetWebsiteDataStoreParameters:
        return jsValueForDecodedArguments<Messages::WebProcess::SetWebsiteDataStoreParameters::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_CreateWebPage:
        return jsValueForDecodedArguments<Messages::WebProcess::CreateWebPage::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_PrewarmWithDomainInformation:
        return jsValueForDecodedArguments<Messages::WebProcess::PrewarmWithDomainInformation::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_SetCacheModel:
        return jsValueForDecodedArguments<Messages::WebProcess::SetCacheModel::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_RegisterURLSchemeAsEmptyDocument:
        return jsValueForDecodedArguments<Messages::WebProcess::RegisterURLSchemeAsEmptyDocument::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_RegisterURLSchemeAsSecure:
        return jsValueForDecodedArguments<Messages::WebProcess::RegisterURLSchemeAsSecure::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_RegisterURLSchemeAsBypassingContentSecurityPolicy:
        return jsValueForDecodedArguments<Messages::WebProcess::RegisterURLSchemeAsBypassingContentSecurityPolicy::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_SetDomainRelaxationForbiddenForURLScheme:
        return jsValueForDecodedArguments<Messages::WebProcess::SetDomainRelaxationForbiddenForURLScheme::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_RegisterURLSchemeAsLocal:
        return jsValueForDecodedArguments<Messages::WebProcess::RegisterURLSchemeAsLocal::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_RegisterURLSchemeAsNoAccess:
        return jsValueForDecodedArguments<Messages::WebProcess::RegisterURLSchemeAsNoAccess::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_RegisterURLSchemeAsDisplayIsolated:
        return jsValueForDecodedArguments<Messages::WebProcess::RegisterURLSchemeAsDisplayIsolated::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_RegisterURLSchemeAsCORSEnabled:
        return jsValueForDecodedArguments<Messages::WebProcess::RegisterURLSchemeAsCORSEnabled::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_RegisterURLSchemeAsCachePartitioned:
        return jsValueForDecodedArguments<Messages::WebProcess::RegisterURLSchemeAsCachePartitioned::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_RegisterURLSchemeAsCanDisplayOnlyIfCanRequest:
        return jsValueForDecodedArguments<Messages::WebProcess::RegisterURLSchemeAsCanDisplayOnlyIfCanRequest::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_SetDefaultRequestTimeoutInterval:
        return jsValueForDecodedArguments<Messages::WebProcess::SetDefaultRequestTimeoutInterval::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_SetAlwaysUsesComplexTextCodePath:
        return jsValueForDecodedArguments<Messages::WebProcess::SetAlwaysUsesComplexTextCodePath::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_SetShouldUseFontSmoothing:
        return jsValueForDecodedArguments<Messages::WebProcess::SetShouldUseFontSmoothing::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_SetResourceLoadStatisticsEnabled:
        return jsValueForDecodedArguments<Messages::WebProcess::SetResourceLoadStatisticsEnabled::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_ClearResourceLoadStatistics:
        return jsValueForDecodedArguments<Messages::WebProcess::ClearResourceLoadStatistics::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_UserPreferredLanguagesChanged:
        return jsValueForDecodedArguments<Messages::WebProcess::UserPreferredLanguagesChanged::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_FullKeyboardAccessModeChanged:
        return jsValueForDecodedArguments<Messages::WebProcess::FullKeyboardAccessModeChanged::Arguments>(globalObject, decoder);
#if HAVE(MOUSE_DEVICE_OBSERVATION)
    case MessageName::WebProcess_SetHasMouseDevice:
        return jsValueForDecodedArguments<Messages::WebProcess::SetHasMouseDevice::Arguments>(globalObject, decoder);
#endif
#if HAVE(STYLUS_DEVICE_OBSERVATION)
    case MessageName::WebProcess_SetHasStylusDevice:
        return jsValueForDecodedArguments<Messages::WebProcess::SetHasStylusDevice::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebProcess_RefreshPlugins:
        return jsValueForDecodedArguments<Messages::WebProcess::RefreshPlugins::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_StartMemorySampler:
        return jsValueForDecodedArguments<Messages::WebProcess::StartMemorySampler::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_StopMemorySampler:
        return jsValueForDecodedArguments<Messages::WebProcess::StopMemorySampler::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_SetTextCheckerState:
        return jsValueForDecodedArguments<Messages::WebProcess::SetTextCheckerState::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_SetEnhancedAccessibility:
        return jsValueForDecodedArguments<Messages::WebProcess::SetEnhancedAccessibility::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_GarbageCollectJavaScriptObjects:
        return jsValueForDecodedArguments<Messages::WebProcess::GarbageCollectJavaScriptObjects::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_SetJavaScriptGarbageCollectorTimerEnabled:
        return jsValueForDecodedArguments<Messages::WebProcess::SetJavaScriptGarbageCollectorTimerEnabled::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_SetInjectedBundleParameter:
        return jsValueForDecodedArguments<Messages::WebProcess::SetInjectedBundleParameter::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_SetInjectedBundleParameters:
        return jsValueForDecodedArguments<Messages::WebProcess::SetInjectedBundleParameters::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_HandleInjectedBundleMessage:
        return jsValueForDecodedArguments<Messages::WebProcess::HandleInjectedBundleMessage::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_FetchWebsiteData:
        return jsValueForDecodedArguments<Messages::WebProcess::FetchWebsiteData::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_DeleteWebsiteData:
        return jsValueForDecodedArguments<Messages::WebProcess::DeleteWebsiteData::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_DeleteWebsiteDataForOrigins:
        return jsValueForDecodedArguments<Messages::WebProcess::DeleteWebsiteDataForOrigins::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_SetHiddenPageDOMTimerThrottlingIncreaseLimit:
        return jsValueForDecodedArguments<Messages::WebProcess::SetHiddenPageDOMTimerThrottlingIncreaseLimit::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_SetMemoryCacheDisabled:
        return jsValueForDecodedArguments<Messages::WebProcess::SetMemoryCacheDisabled::Arguments>(globalObject, decoder);
#if ENABLE(SERVICE_CONTROLS)
    case MessageName::WebProcess_SetEnabledServices:
        return jsValueForDecodedArguments<Messages::WebProcess::SetEnabledServices::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebProcess_EnsureAutomationSessionProxy:
        return jsValueForDecodedArguments<Messages::WebProcess::EnsureAutomationSessionProxy::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_DestroyAutomationSessionProxy:
        return jsValueForDecodedArguments<Messages::WebProcess::DestroyAutomationSessionProxy::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_PrepareToSuspend:
        return jsValueForDecodedArguments<Messages::WebProcess::PrepareToSuspend::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_ProcessDidResume:
        return jsValueForDecodedArguments<Messages::WebProcess::ProcessDidResume::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_BackgroundResponsivenessPing:
        return jsValueForDecodedArguments<Messages::WebProcess::BackgroundResponsivenessPing::Arguments>(globalObject, decoder);
#if ENABLE(GAMEPAD)
    case MessageName::WebProcess_SetInitialGamepads:
        return jsValueForDecodedArguments<Messages::WebProcess::SetInitialGamepads::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_GamepadConnected:
        return jsValueForDecodedArguments<Messages::WebProcess::GamepadConnected::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_GamepadDisconnected:
        return jsValueForDecodedArguments<Messages::WebProcess::GamepadDisconnected::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebProcess_EstablishSharedWorkerContextConnectionToNetworkProcess:
        return jsValueForDecodedArguments<Messages::WebProcess::EstablishSharedWorkerContextConnectionToNetworkProcess::Arguments>(globalObject, decoder);
#if ENABLE(SERVICE_WORKER)
    case MessageName::WebProcess_EstablishServiceWorkerContextConnectionToNetworkProcess:
        return jsValueForDecodedArguments<Messages::WebProcess::EstablishServiceWorkerContextConnectionToNetworkProcess::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebProcess_SetHasSuspendedPageProxy:
        return jsValueForDecodedArguments<Messages::WebProcess::SetHasSuspendedPageProxy::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_SetIsInProcessCache:
        return jsValueForDecodedArguments<Messages::WebProcess::SetIsInProcessCache::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_MarkIsNoLongerPrewarmed:
        return jsValueForDecodedArguments<Messages::WebProcess::MarkIsNoLongerPrewarmed::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_GetActivePagesOriginsForTesting:
        return jsValueForDecodedArguments<Messages::WebProcess::GetActivePagesOriginsForTesting::Arguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::WebProcess_SetScreenProperties:
        return jsValueForDecodedArguments<Messages::WebProcess::SetScreenProperties::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(MAC)
    case MessageName::WebProcess_ScrollerStylePreferenceChanged:
        return jsValueForDecodedArguments<Messages::WebProcess::ScrollerStylePreferenceChanged::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_DisplayConfigurationChanged:
        return jsValueForDecodedArguments<Messages::WebProcess::DisplayConfigurationChanged::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(IOS_FAMILY)
    case MessageName::WebProcess_UserInterfaceIdiomDidChange:
        return jsValueForDecodedArguments<Messages::WebProcess::UserInterfaceIdiomDidChange::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(IOS_FAMILY) && !PLATFORM(MACCATALYST)
    case MessageName::WebProcess_BacklightLevelDidChange:
        return jsValueForDecodedArguments<Messages::WebProcess::BacklightLevelDidChange::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(MAC) || PLATFORM(MACCATALYST)
    case MessageName::WebProcess_ColorPreferencesDidChange:
        return jsValueForDecodedArguments<Messages::WebProcess::ColorPreferencesDidChange::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebProcess_IsJITEnabled:
        return jsValueForDecodedArguments<Messages::WebProcess::IsJITEnabled::Arguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::WebProcess_SetMediaMIMETypes:
        return jsValueForDecodedArguments<Messages::WebProcess::SetMediaMIMETypes::Arguments>(globalObject, decoder);
#endif
#if (PLATFORM(COCOA) && ENABLE(REMOTE_INSPECTOR))
    case MessageName::WebProcess_EnableRemoteWebInspector:
        return jsValueForDecodedArguments<Messages::WebProcess::EnableRemoteWebInspector::Arguments>(globalObject, decoder);
#endif
#if ENABLE(MEDIA_STREAM)
    case MessageName::WebProcess_AddMockMediaDevice:
        return jsValueForDecodedArguments<Messages::WebProcess::AddMockMediaDevice::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_ClearMockMediaDevices:
        return jsValueForDecodedArguments<Messages::WebProcess::ClearMockMediaDevices::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_RemoveMockMediaDevice:
        return jsValueForDecodedArguments<Messages::WebProcess::RemoveMockMediaDevice::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_ResetMockMediaDevices:
        return jsValueForDecodedArguments<Messages::WebProcess::ResetMockMediaDevices::Arguments>(globalObject, decoder);
#endif
#if (ENABLE(MEDIA_STREAM) && ENABLE(SANDBOX_EXTENSIONS))
    case MessageName::WebProcess_GrantUserMediaDeviceSandboxExtensions:
        return jsValueForDecodedArguments<Messages::WebProcess::GrantUserMediaDeviceSandboxExtensions::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_RevokeUserMediaDeviceSandboxExtensions:
        return jsValueForDecodedArguments<Messages::WebProcess::RevokeUserMediaDeviceSandboxExtensions::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebProcess_ClearCurrentModifierStateForTesting:
        return jsValueForDecodedArguments<Messages::WebProcess::ClearCurrentModifierStateForTesting::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_SetBackForwardCacheCapacity:
        return jsValueForDecodedArguments<Messages::WebProcess::SetBackForwardCacheCapacity::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_ClearCachedPage:
        return jsValueForDecodedArguments<Messages::WebProcess::ClearCachedPage::Arguments>(globalObject, decoder);
#if PLATFORM(GTK) || PLATFORM(WPE)
    case MessageName::WebProcess_SendMessageToWebExtension:
        return jsValueForDecodedArguments<Messages::WebProcess::SendMessageToWebExtension::Arguments>(globalObject, decoder);
#endif
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
    case MessageName::WebProcess_SeedResourceLoadStatisticsForTesting:
        return jsValueForDecodedArguments<Messages::WebProcess::SeedResourceLoadStatisticsForTesting::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_SetThirdPartyCookieBlockingMode:
        return jsValueForDecodedArguments<Messages::WebProcess::SetThirdPartyCookieBlockingMode::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_SetDomainsWithUserInteraction:
        return jsValueForDecodedArguments<Messages::WebProcess::SetDomainsWithUserInteraction::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_SetDomainsWithCrossPageStorageAccess:
        return jsValueForDecodedArguments<Messages::WebProcess::SetDomainsWithCrossPageStorageAccess::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_SendResourceLoadStatisticsDataImmediately:
        return jsValueForDecodedArguments<Messages::WebProcess::SendResourceLoadStatisticsDataImmediately::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebProcess_GrantAccessToAssetServices:
        return jsValueForDecodedArguments<Messages::WebProcess::GrantAccessToAssetServices::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_RevokeAccessToAssetServices:
        return jsValueForDecodedArguments<Messages::WebProcess::RevokeAccessToAssetServices::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_SwitchFromStaticFontRegistryToUserFontRegistry:
        return jsValueForDecodedArguments<Messages::WebProcess::SwitchFromStaticFontRegistryToUserFontRegistry::Arguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::WebProcess_UnblockServicesRequiredByAccessibility:
        return jsValueForDecodedArguments<Messages::WebProcess::UnblockServicesRequiredByAccessibility::Arguments>(globalObject, decoder);
#endif
#if (PLATFORM(COCOA) && ENABLE(CFPREFS_DIRECT_MODE))
    case MessageName::WebProcess_NotifyPreferencesChanged:
        return jsValueForDecodedArguments<Messages::WebProcess::NotifyPreferencesChanged::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_UnblockPreferenceService:
        return jsValueForDecodedArguments<Messages::WebProcess::UnblockPreferenceService::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(COCOA)
    case MessageName::WebProcess_PowerSourceDidChange:
        return jsValueForDecodedArguments<Messages::WebProcess::PowerSourceDidChange::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(GTK) && !USE(GTK4)
    case MessageName::WebProcess_SetUseSystemAppearanceForScrollbars:
        return jsValueForDecodedArguments<Messages::WebProcess::SetUseSystemAppearanceForScrollbars::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(COCOA)
    case MessageName::WebProcess_DidWriteToPasteboardAsynchronously:
        return jsValueForDecodedArguments<Messages::WebProcess::DidWriteToPasteboardAsynchronously::Arguments>(globalObject, decoder);
#endif
#if HAVE(CVDISPLAYLINK)
    case MessageName::WebProcess_DisplayWasRefreshed:
        return jsValueForDecodedArguments<Messages::WebProcess::DisplayWasRefreshed::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(MAC)
    case MessageName::WebProcess_SystemWillPowerOn:
        return jsValueForDecodedArguments<Messages::WebProcess::SystemWillPowerOn::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_SystemWillSleep:
        return jsValueForDecodedArguments<Messages::WebProcess::SystemWillSleep::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_SystemDidWake:
        return jsValueForDecodedArguments<Messages::WebProcess::SystemDidWake::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(COCOA)
    case MessageName::WebProcess_ConsumeAudioComponentRegistrations:
        return jsValueForDecodedArguments<Messages::WebProcess::ConsumeAudioComponentRegistrations::Arguments>(globalObject, decoder);
    case MessageName::WebProcess_AccessibilityPreferencesDidChange:
        return jsValueForDecodedArguments<Messages::WebProcess::AccessibilityPreferencesDidChange::Arguments>(globalObject, decoder);
#endif
#if HAVE(MEDIA_ACCESSIBILITY_FRAMEWORK)
    case MessageName::WebProcess_SetMediaAccessibilityPreferences:
        return jsValueForDecodedArguments<Messages::WebProcess::SetMediaAccessibilityPreferences::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebAutomationSessionProxy_EvaluateJavaScriptFunction:
        return jsValueForDecodedArguments<Messages::WebAutomationSessionProxy::EvaluateJavaScriptFunction::Arguments>(globalObject, decoder);
    case MessageName::WebAutomationSessionProxy_ResolveChildFrameWithOrdinal:
        return jsValueForDecodedArguments<Messages::WebAutomationSessionProxy::ResolveChildFrameWithOrdinal::Arguments>(globalObject, decoder);
    case MessageName::WebAutomationSessionProxy_ResolveChildFrameWithNodeHandle:
        return jsValueForDecodedArguments<Messages::WebAutomationSessionProxy::ResolveChildFrameWithNodeHandle::Arguments>(globalObject, decoder);
    case MessageName::WebAutomationSessionProxy_ResolveChildFrameWithName:
        return jsValueForDecodedArguments<Messages::WebAutomationSessionProxy::ResolveChildFrameWithName::Arguments>(globalObject, decoder);
    case MessageName::WebAutomationSessionProxy_ResolveParentFrame:
        return jsValueForDecodedArguments<Messages::WebAutomationSessionProxy::ResolveParentFrame::Arguments>(globalObject, decoder);
    case MessageName::WebAutomationSessionProxy_ComputeElementLayout:
        return jsValueForDecodedArguments<Messages::WebAutomationSessionProxy::ComputeElementLayout::Arguments>(globalObject, decoder);
    case MessageName::WebAutomationSessionProxy_SelectOptionElement:
        return jsValueForDecodedArguments<Messages::WebAutomationSessionProxy::SelectOptionElement::Arguments>(globalObject, decoder);
    case MessageName::WebAutomationSessionProxy_SetFilesForInputFileUpload:
        return jsValueForDecodedArguments<Messages::WebAutomationSessionProxy::SetFilesForInputFileUpload::Arguments>(globalObject, decoder);
    case MessageName::WebAutomationSessionProxy_TakeScreenshot:
        return jsValueForDecodedArguments<Messages::WebAutomationSessionProxy::TakeScreenshot::Arguments>(globalObject, decoder);
    case MessageName::WebAutomationSessionProxy_SnapshotRectForScreenshot:
        return jsValueForDecodedArguments<Messages::WebAutomationSessionProxy::SnapshotRectForScreenshot::Arguments>(globalObject, decoder);
    case MessageName::WebAutomationSessionProxy_GetCookiesForFrame:
        return jsValueForDecodedArguments<Messages::WebAutomationSessionProxy::GetCookiesForFrame::Arguments>(globalObject, decoder);
    case MessageName::WebAutomationSessionProxy_DeleteCookie:
        return jsValueForDecodedArguments<Messages::WebAutomationSessionProxy::DeleteCookie::Arguments>(globalObject, decoder);
    case MessageName::WebIDBConnectionToServer_DidDeleteDatabase:
        return jsValueForDecodedArguments<Messages::WebIDBConnectionToServer::DidDeleteDatabase::Arguments>(globalObject, decoder);
    case MessageName::WebIDBConnectionToServer_DidOpenDatabase:
        return jsValueForDecodedArguments<Messages::WebIDBConnectionToServer::DidOpenDatabase::Arguments>(globalObject, decoder);
    case MessageName::WebIDBConnectionToServer_DidAbortTransaction:
        return jsValueForDecodedArguments<Messages::WebIDBConnectionToServer::DidAbortTransaction::Arguments>(globalObject, decoder);
    case MessageName::WebIDBConnectionToServer_DidCommitTransaction:
        return jsValueForDecodedArguments<Messages::WebIDBConnectionToServer::DidCommitTransaction::Arguments>(globalObject, decoder);
    case MessageName::WebIDBConnectionToServer_DidCreateObjectStore:
        return jsValueForDecodedArguments<Messages::WebIDBConnectionToServer::DidCreateObjectStore::Arguments>(globalObject, decoder);
    case MessageName::WebIDBConnectionToServer_DidDeleteObjectStore:
        return jsValueForDecodedArguments<Messages::WebIDBConnectionToServer::DidDeleteObjectStore::Arguments>(globalObject, decoder);
    case MessageName::WebIDBConnectionToServer_DidRenameObjectStore:
        return jsValueForDecodedArguments<Messages::WebIDBConnectionToServer::DidRenameObjectStore::Arguments>(globalObject, decoder);
    case MessageName::WebIDBConnectionToServer_DidClearObjectStore:
        return jsValueForDecodedArguments<Messages::WebIDBConnectionToServer::DidClearObjectStore::Arguments>(globalObject, decoder);
    case MessageName::WebIDBConnectionToServer_DidCreateIndex:
        return jsValueForDecodedArguments<Messages::WebIDBConnectionToServer::DidCreateIndex::Arguments>(globalObject, decoder);
    case MessageName::WebIDBConnectionToServer_DidDeleteIndex:
        return jsValueForDecodedArguments<Messages::WebIDBConnectionToServer::DidDeleteIndex::Arguments>(globalObject, decoder);
    case MessageName::WebIDBConnectionToServer_DidRenameIndex:
        return jsValueForDecodedArguments<Messages::WebIDBConnectionToServer::DidRenameIndex::Arguments>(globalObject, decoder);
    case MessageName::WebIDBConnectionToServer_DidPutOrAdd:
        return jsValueForDecodedArguments<Messages::WebIDBConnectionToServer::DidPutOrAdd::Arguments>(globalObject, decoder);
    case MessageName::WebIDBConnectionToServer_DidGetRecord:
        return jsValueForDecodedArguments<Messages::WebIDBConnectionToServer::DidGetRecord::Arguments>(globalObject, decoder);
    case MessageName::WebIDBConnectionToServer_DidGetAllRecords:
        return jsValueForDecodedArguments<Messages::WebIDBConnectionToServer::DidGetAllRecords::Arguments>(globalObject, decoder);
    case MessageName::WebIDBConnectionToServer_DidGetCount:
        return jsValueForDecodedArguments<Messages::WebIDBConnectionToServer::DidGetCount::Arguments>(globalObject, decoder);
    case MessageName::WebIDBConnectionToServer_DidDeleteRecord:
        return jsValueForDecodedArguments<Messages::WebIDBConnectionToServer::DidDeleteRecord::Arguments>(globalObject, decoder);
    case MessageName::WebIDBConnectionToServer_DidOpenCursor:
        return jsValueForDecodedArguments<Messages::WebIDBConnectionToServer::DidOpenCursor::Arguments>(globalObject, decoder);
    case MessageName::WebIDBConnectionToServer_DidIterateCursor:
        return jsValueForDecodedArguments<Messages::WebIDBConnectionToServer::DidIterateCursor::Arguments>(globalObject, decoder);
    case MessageName::WebIDBConnectionToServer_FireVersionChangeEvent:
        return jsValueForDecodedArguments<Messages::WebIDBConnectionToServer::FireVersionChangeEvent::Arguments>(globalObject, decoder);
    case MessageName::WebIDBConnectionToServer_DidStartTransaction:
        return jsValueForDecodedArguments<Messages::WebIDBConnectionToServer::DidStartTransaction::Arguments>(globalObject, decoder);
    case MessageName::WebIDBConnectionToServer_DidCloseFromServer:
        return jsValueForDecodedArguments<Messages::WebIDBConnectionToServer::DidCloseFromServer::Arguments>(globalObject, decoder);
    case MessageName::WebIDBConnectionToServer_NotifyOpenDBRequestBlocked:
        return jsValueForDecodedArguments<Messages::WebIDBConnectionToServer::NotifyOpenDBRequestBlocked::Arguments>(globalObject, decoder);
    case MessageName::WebIDBConnectionToServer_DidGetAllDatabaseNamesAndVersions:
        return jsValueForDecodedArguments<Messages::WebIDBConnectionToServer::DidGetAllDatabaseNamesAndVersions::Arguments>(globalObject, decoder);
#if ENABLE(FULLSCREEN_API)
    case MessageName::WebFullScreenManager_RequestEnterFullScreen:
        return jsValueForDecodedArguments<Messages::WebFullScreenManager::RequestEnterFullScreen::Arguments>(globalObject, decoder);
    case MessageName::WebFullScreenManager_RequestExitFullScreen:
        return jsValueForDecodedArguments<Messages::WebFullScreenManager::RequestExitFullScreen::Arguments>(globalObject, decoder);
    case MessageName::WebFullScreenManager_WillEnterFullScreen:
        return jsValueForDecodedArguments<Messages::WebFullScreenManager::WillEnterFullScreen::Arguments>(globalObject, decoder);
    case MessageName::WebFullScreenManager_DidEnterFullScreen:
        return jsValueForDecodedArguments<Messages::WebFullScreenManager::DidEnterFullScreen::Arguments>(globalObject, decoder);
    case MessageName::WebFullScreenManager_WillExitFullScreen:
        return jsValueForDecodedArguments<Messages::WebFullScreenManager::WillExitFullScreen::Arguments>(globalObject, decoder);
    case MessageName::WebFullScreenManager_DidExitFullScreen:
        return jsValueForDecodedArguments<Messages::WebFullScreenManager::DidExitFullScreen::Arguments>(globalObject, decoder);
    case MessageName::WebFullScreenManager_SetAnimatingFullScreen:
        return jsValueForDecodedArguments<Messages::WebFullScreenManager::SetAnimatingFullScreen::Arguments>(globalObject, decoder);
    case MessageName::WebFullScreenManager_SaveScrollPosition:
        return jsValueForDecodedArguments<Messages::WebFullScreenManager::SaveScrollPosition::Arguments>(globalObject, decoder);
    case MessageName::WebFullScreenManager_RestoreScrollPosition:
        return jsValueForDecodedArguments<Messages::WebFullScreenManager::RestoreScrollPosition::Arguments>(globalObject, decoder);
    case MessageName::WebFullScreenManager_SetFullscreenInsets:
        return jsValueForDecodedArguments<Messages::WebFullScreenManager::SetFullscreenInsets::Arguments>(globalObject, decoder);
    case MessageName::WebFullScreenManager_SetFullscreenAutoHideDuration:
        return jsValueForDecodedArguments<Messages::WebFullScreenManager::SetFullscreenAutoHideDuration::Arguments>(globalObject, decoder);
    case MessageName::WebFullScreenManager_SetFullscreenControlsHidden:
        return jsValueForDecodedArguments<Messages::WebFullScreenManager::SetFullscreenControlsHidden::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::GPUProcessConnection_DidReceiveRemoteCommand:
        return jsValueForDecodedArguments<Messages::GPUProcessConnection::DidReceiveRemoteCommand::Arguments>(globalObject, decoder);
#if ENABLE(ROUTING_ARBITRATION)
    case MessageName::GPUProcessConnection_BeginRoutingArbitrationWithCategory:
        return jsValueForDecodedArguments<Messages::GPUProcessConnection::BeginRoutingArbitrationWithCategory::Arguments>(globalObject, decoder);
    case MessageName::GPUProcessConnection_EndRoutingArbitration:
        return jsValueForDecodedArguments<Messages::GPUProcessConnection::EndRoutingArbitration::Arguments>(globalObject, decoder);
#endif
#if ENABLE(MEDIA_STREAM) && PLATFORM(COCOA)
    case MessageName::GPUProcessConnection_ResetAudioMediaStreamTrackRendererInternalUnit:
        return jsValueForDecodedArguments<Messages::GPUProcessConnection::ResetAudioMediaStreamTrackRendererInternalUnit::Arguments>(globalObject, decoder);
#endif
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(WEBGL)
    case MessageName::RemoteGraphicsContextGLProxy_WasCreated:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGLProxy::WasCreated::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGLProxy_WasLost:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGLProxy::WasLost::Arguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGLProxy_WasChanged:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGLProxy::WasChanged::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteRenderingBackendProxy_DidCreateImageBufferBackend:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackendProxy::DidCreateImageBufferBackend::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackendProxy_DidFlush:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackendProxy::DidFlush::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackendProxy_DidFinalizeRenderingUpdate:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackendProxy::DidFinalizeRenderingUpdate::Arguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackendProxy_DidCreateWakeUpSemaphoreForDisplayListStream:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackendProxy::DidCreateWakeUpSemaphoreForDisplayListStream::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteGPUProxy_WasCreated:
        return jsValueForDecodedArguments<Messages::RemoteGPUProxy::WasCreated::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteAudioHardwareListener_AudioHardwareDidBecomeActive:
        return jsValueForDecodedArguments<Messages::RemoteAudioHardwareListener::AudioHardwareDidBecomeActive::Arguments>(globalObject, decoder);
    case MessageName::RemoteAudioHardwareListener_AudioHardwareDidBecomeInactive:
        return jsValueForDecodedArguments<Messages::RemoteAudioHardwareListener::AudioHardwareDidBecomeInactive::Arguments>(globalObject, decoder);
    case MessageName::RemoteAudioHardwareListener_AudioOutputDeviceChanged:
        return jsValueForDecodedArguments<Messages::RemoteAudioHardwareListener::AudioOutputDeviceChanged::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::MediaPlayerPrivateRemote_NetworkStateChanged:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::NetworkStateChanged::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_ReadyStateChanged:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::ReadyStateChanged::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_FirstVideoFrameAvailable:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::FirstVideoFrameAvailable::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_VolumeChanged:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::VolumeChanged::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_MuteChanged:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::MuteChanged::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_TimeChanged:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::TimeChanged::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_DurationChanged:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::DurationChanged::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_RateChanged:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::RateChanged::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_PlaybackStateChanged:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::PlaybackStateChanged::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_EngineFailedToLoad:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::EngineFailedToLoad::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_UpdateCachedState:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::UpdateCachedState::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_CharacteristicChanged:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::CharacteristicChanged::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_SizeChanged:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::SizeChanged::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_RenderingModeChanged:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::RenderingModeChanged::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_CurrentTimeChanged:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::CurrentTimeChanged::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_AddRemoteAudioTrack:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::AddRemoteAudioTrack::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_RemoveRemoteAudioTrack:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::RemoveRemoteAudioTrack::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_RemoteAudioTrackConfigurationChanged:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::RemoteAudioTrackConfigurationChanged::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_AddRemoteVideoTrack:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::AddRemoteVideoTrack::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_RemoveRemoteVideoTrack:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::RemoveRemoteVideoTrack::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_RemoteVideoTrackConfigurationChanged:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::RemoteVideoTrackConfigurationChanged::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_AddRemoteTextTrack:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::AddRemoteTextTrack::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_RemoveRemoteTextTrack:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::RemoveRemoteTextTrack::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_RemoteTextTrackConfigurationChanged:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::RemoteTextTrackConfigurationChanged::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_ParseWebVTTFileHeader:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::ParseWebVTTFileHeader::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_ParseWebVTTCueData:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::ParseWebVTTCueData::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_ParseWebVTTCueDataStruct:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::ParseWebVTTCueDataStruct::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_AddDataCue:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::AddDataCue::Arguments>(globalObject, decoder);
#if ENABLE(DATACUE_VALUE)
    case MessageName::MediaPlayerPrivateRemote_AddDataCueWithType:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::AddDataCueWithType::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_UpdateDataCue:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::UpdateDataCue::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_RemoveDataCue:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::RemoveDataCue::Arguments>(globalObject, decoder);
#endif
    case MessageName::MediaPlayerPrivateRemote_AddGenericCue:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::AddGenericCue::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_UpdateGenericCue:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::UpdateGenericCue::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_RemoveGenericCue:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::RemoveGenericCue::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_RequestResource:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::RequestResource::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_RemoveResource:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::RemoveResource::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_SendH2Ping:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::SendH2Ping::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_ResourceNotSupported:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::ResourceNotSupported::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_ActiveSourceBuffersChanged:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::ActiveSourceBuffersChanged::Arguments>(globalObject, decoder);
#if ENABLE(ENCRYPTED_MEDIA)
    case MessageName::MediaPlayerPrivateRemote_WaitingForKeyChanged:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::WaitingForKeyChanged::Arguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_InitializationDataEncountered:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::InitializationDataEncountered::Arguments>(globalObject, decoder);
#endif
#if ENABLE(LEGACY_ENCRYPTED_MEDIA)
    case MessageName::MediaPlayerPrivateRemote_MediaPlayerKeyNeeded:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::MediaPlayerKeyNeeded::Arguments>(globalObject, decoder);
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET)
    case MessageName::MediaPlayerPrivateRemote_CurrentPlaybackTargetIsWirelessChanged:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::CurrentPlaybackTargetIsWirelessChanged::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(IOS_FAMILY)
    case MessageName::MediaPlayerPrivateRemote_GetRawCookies:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::GetRawCookies::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(COCOA)
    case MessageName::MediaPlayerPrivateRemote_PushVideoFrameMetadata:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::PushVideoFrameMetadata::Arguments>(globalObject, decoder);
#endif
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)
    case MessageName::MediaSourcePrivateRemote_SeekToTime:
        return jsValueForDecodedArguments<Messages::MediaSourcePrivateRemote::SeekToTime::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && USE(AUDIO_SESSION)
    case MessageName::RemoteAudioSession_ConfigurationChanged:
        return jsValueForDecodedArguments<Messages::RemoteAudioSession::ConfigurationChanged::Arguments>(globalObject, decoder);
    case MessageName::RemoteAudioSession_BeginInterruption:
        return jsValueForDecodedArguments<Messages::RemoteAudioSession::BeginInterruption::Arguments>(globalObject, decoder);
    case MessageName::RemoteAudioSession_EndInterruption:
        return jsValueForDecodedArguments<Messages::RemoteAudioSession::EndInterruption::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS)
    case MessageName::RemoteAudioSourceProviderManager_AudioStorageChanged:
        return jsValueForDecodedArguments<Messages::RemoteAudioSourceProviderManager::AudioStorageChanged::Arguments>(globalObject, decoder);
    case MessageName::RemoteAudioSourceProviderManager_AudioSamplesAvailable:
        return jsValueForDecodedArguments<Messages::RemoteAudioSourceProviderManager::AudioSamplesAvailable::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
    case MessageName::RemoteCDMInstance_UnrequestedInitializationDataReceived:
        return jsValueForDecodedArguments<Messages::RemoteCDMInstance::UnrequestedInitializationDataReceived::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
    case MessageName::RemoteCDMInstanceSession_UpdateKeyStatuses:
        return jsValueForDecodedArguments<Messages::RemoteCDMInstanceSession::UpdateKeyStatuses::Arguments>(globalObject, decoder);
    case MessageName::RemoteCDMInstanceSession_SendMessage:
        return jsValueForDecodedArguments<Messages::RemoteCDMInstanceSession::SendMessage::Arguments>(globalObject, decoder);
    case MessageName::RemoteCDMInstanceSession_SessionIdChanged:
        return jsValueForDecodedArguments<Messages::RemoteCDMInstanceSession::SessionIdChanged::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(LEGACY_ENCRYPTED_MEDIA)
    case MessageName::RemoteLegacyCDMSession_SendMessage:
        return jsValueForDecodedArguments<Messages::RemoteLegacyCDMSession::SendMessage::Arguments>(globalObject, decoder);
    case MessageName::RemoteLegacyCDMSession_SendError:
        return jsValueForDecodedArguments<Messages::RemoteLegacyCDMSession::SendError::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteRemoteCommandListener_DidReceiveRemoteControlCommand:
        return jsValueForDecodedArguments<Messages::RemoteRemoteCommandListener::DidReceiveRemoteControlCommand::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)
    case MessageName::SourceBufferPrivateRemote_SourceBufferPrivateDidReceiveInitializationSegment:
        return jsValueForDecodedArguments<Messages::SourceBufferPrivateRemote::SourceBufferPrivateDidReceiveInitializationSegment::Arguments>(globalObject, decoder);
    case MessageName::SourceBufferPrivateRemote_SourceBufferPrivateStreamEndedWithDecodeError:
        return jsValueForDecodedArguments<Messages::SourceBufferPrivateRemote::SourceBufferPrivateStreamEndedWithDecodeError::Arguments>(globalObject, decoder);
    case MessageName::SourceBufferPrivateRemote_SourceBufferPrivateAppendError:
        return jsValueForDecodedArguments<Messages::SourceBufferPrivateRemote::SourceBufferPrivateAppendError::Arguments>(globalObject, decoder);
    case MessageName::SourceBufferPrivateRemote_SourceBufferPrivateAppendComplete:
        return jsValueForDecodedArguments<Messages::SourceBufferPrivateRemote::SourceBufferPrivateAppendComplete::Arguments>(globalObject, decoder);
    case MessageName::SourceBufferPrivateRemote_SourceBufferPrivateHighestPresentationTimestampChanged:
        return jsValueForDecodedArguments<Messages::SourceBufferPrivateRemote::SourceBufferPrivateHighestPresentationTimestampChanged::Arguments>(globalObject, decoder);
    case MessageName::SourceBufferPrivateRemote_SourceBufferPrivateDurationChanged:
        return jsValueForDecodedArguments<Messages::SourceBufferPrivateRemote::SourceBufferPrivateDurationChanged::Arguments>(globalObject, decoder);
    case MessageName::SourceBufferPrivateRemote_SourceBufferPrivateDidParseSample:
        return jsValueForDecodedArguments<Messages::SourceBufferPrivateRemote::SourceBufferPrivateDidParseSample::Arguments>(globalObject, decoder);
    case MessageName::SourceBufferPrivateRemote_SourceBufferPrivateDidDropSample:
        return jsValueForDecodedArguments<Messages::SourceBufferPrivateRemote::SourceBufferPrivateDidDropSample::Arguments>(globalObject, decoder);
    case MessageName::SourceBufferPrivateRemote_SourceBufferPrivateBufferedDirtyChanged:
        return jsValueForDecodedArguments<Messages::SourceBufferPrivateRemote::SourceBufferPrivateBufferedDirtyChanged::Arguments>(globalObject, decoder);
    case MessageName::SourceBufferPrivateRemote_SourceBufferPrivateDidReceiveRenderingError:
        return jsValueForDecodedArguments<Messages::SourceBufferPrivateRemote::SourceBufferPrivateDidReceiveRenderingError::Arguments>(globalObject, decoder);
    case MessageName::SourceBufferPrivateRemote_SourceBufferPrivateReportExtraMemoryCost:
        return jsValueForDecodedArguments<Messages::SourceBufferPrivateRemote::SourceBufferPrivateReportExtraMemoryCost::Arguments>(globalObject, decoder);
#endif
#if USE(LIBWEBRTC) && PLATFORM(COCOA) && ENABLE(GPU_PROCESS)
    case MessageName::LibWebRTCCodecs_FailedDecoding:
        return jsValueForDecodedArguments<Messages::LibWebRTCCodecs::FailedDecoding::Arguments>(globalObject, decoder);
    case MessageName::LibWebRTCCodecs_CompletedDecoding:
        return jsValueForDecodedArguments<Messages::LibWebRTCCodecs::CompletedDecoding::Arguments>(globalObject, decoder);
    case MessageName::LibWebRTCCodecs_CompletedEncoding:
        return jsValueForDecodedArguments<Messages::LibWebRTCCodecs::CompletedEncoding::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(VIDEO)
    case MessageName::RemoteVideoFrameObjectHeapProxyProcessor_SetSharedVideoFrameSemaphore:
        return jsValueForDecodedArguments<Messages::RemoteVideoFrameObjectHeapProxyProcessor::SetSharedVideoFrameSemaphore::Arguments>(globalObject, decoder);
    case MessageName::RemoteVideoFrameObjectHeapProxyProcessor_SetSharedVideoFrameMemory:
        return jsValueForDecodedArguments<Messages::RemoteVideoFrameObjectHeapProxyProcessor::SetSharedVideoFrameMemory::Arguments>(globalObject, decoder);
    case MessageName::RemoteVideoFrameObjectHeapProxyProcessor_VideoFrameBufferNotFound:
        return jsValueForDecodedArguments<Messages::RemoteVideoFrameObjectHeapProxyProcessor::VideoFrameBufferNotFound::Arguments>(globalObject, decoder);
    case MessageName::RemoteVideoFrameObjectHeapProxyProcessor_NewVideoFrameBuffer:
        return jsValueForDecodedArguments<Messages::RemoteVideoFrameObjectHeapProxyProcessor::NewVideoFrameBuffer::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
    case MessageName::SampleBufferDisplayLayer_SetDidFail:
        return jsValueForDecodedArguments<Messages::SampleBufferDisplayLayer::SetDidFail::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebGeolocationManager_DidChangePosition:
        return jsValueForDecodedArguments<Messages::WebGeolocationManager::DidChangePosition::Arguments>(globalObject, decoder);
    case MessageName::WebGeolocationManager_DidFailToDeterminePosition:
        return jsValueForDecodedArguments<Messages::WebGeolocationManager::DidFailToDeterminePosition::Arguments>(globalObject, decoder);
#if PLATFORM(IOS_FAMILY)
    case MessageName::WebGeolocationManager_ResetPermissions:
        return jsValueForDecodedArguments<Messages::WebGeolocationManager::ResetPermissions::Arguments>(globalObject, decoder);
#endif
    case MessageName::RemoteWebInspectorUI_Initialize:
        return jsValueForDecodedArguments<Messages::RemoteWebInspectorUI::Initialize::Arguments>(globalObject, decoder);
    case MessageName::RemoteWebInspectorUI_UpdateFindString:
        return jsValueForDecodedArguments<Messages::RemoteWebInspectorUI::UpdateFindString::Arguments>(globalObject, decoder);
#if ENABLE(INSPECTOR_TELEMETRY)
    case MessageName::RemoteWebInspectorUI_SetDiagnosticLoggingAvailable:
        return jsValueForDecodedArguments<Messages::RemoteWebInspectorUI::SetDiagnosticLoggingAvailable::Arguments>(globalObject, decoder);
#endif
    case MessageName::RemoteWebInspectorUI_ShowConsole:
        return jsValueForDecodedArguments<Messages::RemoteWebInspectorUI::ShowConsole::Arguments>(globalObject, decoder);
    case MessageName::RemoteWebInspectorUI_ShowResources:
        return jsValueForDecodedArguments<Messages::RemoteWebInspectorUI::ShowResources::Arguments>(globalObject, decoder);
    case MessageName::RemoteWebInspectorUI_DidSave:
        return jsValueForDecodedArguments<Messages::RemoteWebInspectorUI::DidSave::Arguments>(globalObject, decoder);
    case MessageName::RemoteWebInspectorUI_DidAppend:
        return jsValueForDecodedArguments<Messages::RemoteWebInspectorUI::DidAppend::Arguments>(globalObject, decoder);
    case MessageName::RemoteWebInspectorUI_SendMessageToFrontend:
        return jsValueForDecodedArguments<Messages::RemoteWebInspectorUI::SendMessageToFrontend::Arguments>(globalObject, decoder);
    case MessageName::WebInspector_Show:
        return jsValueForDecodedArguments<Messages::WebInspector::Show::Arguments>(globalObject, decoder);
    case MessageName::WebInspector_Close:
        return jsValueForDecodedArguments<Messages::WebInspector::Close::Arguments>(globalObject, decoder);
    case MessageName::WebInspector_SetAttached:
        return jsValueForDecodedArguments<Messages::WebInspector::SetAttached::Arguments>(globalObject, decoder);
    case MessageName::WebInspector_ShowConsole:
        return jsValueForDecodedArguments<Messages::WebInspector::ShowConsole::Arguments>(globalObject, decoder);
    case MessageName::WebInspector_ShowResources:
        return jsValueForDecodedArguments<Messages::WebInspector::ShowResources::Arguments>(globalObject, decoder);
    case MessageName::WebInspector_ShowMainResourceForFrame:
        return jsValueForDecodedArguments<Messages::WebInspector::ShowMainResourceForFrame::Arguments>(globalObject, decoder);
    case MessageName::WebInspector_StartPageProfiling:
        return jsValueForDecodedArguments<Messages::WebInspector::StartPageProfiling::Arguments>(globalObject, decoder);
    case MessageName::WebInspector_StopPageProfiling:
        return jsValueForDecodedArguments<Messages::WebInspector::StopPageProfiling::Arguments>(globalObject, decoder);
    case MessageName::WebInspector_StartElementSelection:
        return jsValueForDecodedArguments<Messages::WebInspector::StartElementSelection::Arguments>(globalObject, decoder);
    case MessageName::WebInspector_StopElementSelection:
        return jsValueForDecodedArguments<Messages::WebInspector::StopElementSelection::Arguments>(globalObject, decoder);
    case MessageName::WebInspector_SetFrontendConnection:
        return jsValueForDecodedArguments<Messages::WebInspector::SetFrontendConnection::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorInterruptDispatcher_NotifyNeedDebuggerBreak:
        return jsValueForDecodedArguments<Messages::WebInspectorInterruptDispatcher::NotifyNeedDebuggerBreak::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUI_EstablishConnection:
        return jsValueForDecodedArguments<Messages::WebInspectorUI::EstablishConnection::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUI_UpdateConnection:
        return jsValueForDecodedArguments<Messages::WebInspectorUI::UpdateConnection::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUI_AttachedBottom:
        return jsValueForDecodedArguments<Messages::WebInspectorUI::AttachedBottom::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUI_AttachedRight:
        return jsValueForDecodedArguments<Messages::WebInspectorUI::AttachedRight::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUI_AttachedLeft:
        return jsValueForDecodedArguments<Messages::WebInspectorUI::AttachedLeft::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUI_Detached:
        return jsValueForDecodedArguments<Messages::WebInspectorUI::Detached::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUI_SetDockingUnavailable:
        return jsValueForDecodedArguments<Messages::WebInspectorUI::SetDockingUnavailable::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUI_SetIsVisible:
        return jsValueForDecodedArguments<Messages::WebInspectorUI::SetIsVisible::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUI_UpdateFindString:
        return jsValueForDecodedArguments<Messages::WebInspectorUI::UpdateFindString::Arguments>(globalObject, decoder);
#if ENABLE(INSPECTOR_TELEMETRY)
    case MessageName::WebInspectorUI_SetDiagnosticLoggingAvailable:
        return jsValueForDecodedArguments<Messages::WebInspectorUI::SetDiagnosticLoggingAvailable::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebInspectorUI_ShowConsole:
        return jsValueForDecodedArguments<Messages::WebInspectorUI::ShowConsole::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUI_ShowResources:
        return jsValueForDecodedArguments<Messages::WebInspectorUI::ShowResources::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUI_ShowMainResourceForFrame:
        return jsValueForDecodedArguments<Messages::WebInspectorUI::ShowMainResourceForFrame::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUI_StartPageProfiling:
        return jsValueForDecodedArguments<Messages::WebInspectorUI::StartPageProfiling::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUI_StopPageProfiling:
        return jsValueForDecodedArguments<Messages::WebInspectorUI::StopPageProfiling::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUI_StartElementSelection:
        return jsValueForDecodedArguments<Messages::WebInspectorUI::StartElementSelection::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUI_StopElementSelection:
        return jsValueForDecodedArguments<Messages::WebInspectorUI::StopElementSelection::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUI_DidSave:
        return jsValueForDecodedArguments<Messages::WebInspectorUI::DidSave::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUI_DidAppend:
        return jsValueForDecodedArguments<Messages::WebInspectorUI::DidAppend::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUI_SendMessageToFrontend:
        return jsValueForDecodedArguments<Messages::WebInspectorUI::SendMessageToFrontend::Arguments>(globalObject, decoder);
    case MessageName::WebInspectorUI_EvaluateInFrontendForTesting:
        return jsValueForDecodedArguments<Messages::WebInspectorUI::EvaluateInFrontendForTesting::Arguments>(globalObject, decoder);
#if ENABLE(MEDIA_SESSION_COORDINATOR)
    case MessageName::RemoteMediaSessionCoordinator_SeekSessionToTime:
        return jsValueForDecodedArguments<Messages::RemoteMediaSessionCoordinator::SeekSessionToTime::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaSessionCoordinator_PlaySession:
        return jsValueForDecodedArguments<Messages::RemoteMediaSessionCoordinator::PlaySession::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaSessionCoordinator_PauseSession:
        return jsValueForDecodedArguments<Messages::RemoteMediaSessionCoordinator::PauseSession::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaSessionCoordinator_SetSessionTrack:
        return jsValueForDecodedArguments<Messages::RemoteMediaSessionCoordinator::SetSessionTrack::Arguments>(globalObject, decoder);
    case MessageName::RemoteMediaSessionCoordinator_CoordinatorStateChanged:
        return jsValueForDecodedArguments<Messages::RemoteMediaSessionCoordinator::CoordinatorStateChanged::Arguments>(globalObject, decoder);
#endif
#if USE(LIBWEBRTC)
    case MessageName::LibWebRTCNetwork_SignalReadPacket:
        return jsValueForDecodedArguments<Messages::LibWebRTCNetwork::SignalReadPacket::Arguments>(globalObject, decoder);
    case MessageName::LibWebRTCNetwork_SignalSentPacket:
        return jsValueForDecodedArguments<Messages::LibWebRTCNetwork::SignalSentPacket::Arguments>(globalObject, decoder);
    case MessageName::LibWebRTCNetwork_SignalAddressReady:
        return jsValueForDecodedArguments<Messages::LibWebRTCNetwork::SignalAddressReady::Arguments>(globalObject, decoder);
    case MessageName::LibWebRTCNetwork_SignalConnect:
        return jsValueForDecodedArguments<Messages::LibWebRTCNetwork::SignalConnect::Arguments>(globalObject, decoder);
    case MessageName::LibWebRTCNetwork_SignalClose:
        return jsValueForDecodedArguments<Messages::LibWebRTCNetwork::SignalClose::Arguments>(globalObject, decoder);
    case MessageName::LibWebRTCNetwork_SignalNewConnection:
        return jsValueForDecodedArguments<Messages::LibWebRTCNetwork::SignalNewConnection::Arguments>(globalObject, decoder);
#endif
#if ENABLE(WEB_RTC)
    case MessageName::RTCDataChannelRemoteManager_SendData:
        return jsValueForDecodedArguments<Messages::RTCDataChannelRemoteManager::SendData::Arguments>(globalObject, decoder);
    case MessageName::RTCDataChannelRemoteManager_Close:
        return jsValueForDecodedArguments<Messages::RTCDataChannelRemoteManager::Close::Arguments>(globalObject, decoder);
    case MessageName::RTCDataChannelRemoteManager_ChangeReadyState:
        return jsValueForDecodedArguments<Messages::RTCDataChannelRemoteManager::ChangeReadyState::Arguments>(globalObject, decoder);
    case MessageName::RTCDataChannelRemoteManager_ReceiveData:
        return jsValueForDecodedArguments<Messages::RTCDataChannelRemoteManager::ReceiveData::Arguments>(globalObject, decoder);
    case MessageName::RTCDataChannelRemoteManager_DetectError:
        return jsValueForDecodedArguments<Messages::RTCDataChannelRemoteManager::DetectError::Arguments>(globalObject, decoder);
    case MessageName::RTCDataChannelRemoteManager_BufferedAmountIsDecreasing:
        return jsValueForDecodedArguments<Messages::RTCDataChannelRemoteManager::BufferedAmountIsDecreasing::Arguments>(globalObject, decoder);
#endif
#if ENABLE(WEB_RTC)
    case MessageName::WebMDNSRegister_FinishedRegisteringMDNSName:
        return jsValueForDecodedArguments<Messages::WebMDNSRegister::FinishedRegisteringMDNSName::Arguments>(globalObject, decoder);
#endif
#if USE(LIBWEBRTC)
    case MessageName::WebRTCMonitor_NetworksChanged:
        return jsValueForDecodedArguments<Messages::WebRTCMonitor::NetworksChanged::Arguments>(globalObject, decoder);
#endif
#if USE(LIBWEBRTC)
    case MessageName::WebRTCResolver_SetResolvedAddress:
        return jsValueForDecodedArguments<Messages::WebRTCResolver::SetResolvedAddress::Arguments>(globalObject, decoder);
    case MessageName::WebRTCResolver_ResolvedAddressError:
        return jsValueForDecodedArguments<Messages::WebRTCResolver::ResolvedAddressError::Arguments>(globalObject, decoder);
#endif
#if ENABLE(SHAREABLE_RESOURCE)
    case MessageName::NetworkProcessConnection_DidCacheResource:
        return jsValueForDecodedArguments<Messages::NetworkProcessConnection::DidCacheResource::Arguments>(globalObject, decoder);
#endif
    case MessageName::NetworkProcessConnection_DidFinishPingLoad:
        return jsValueForDecodedArguments<Messages::NetworkProcessConnection::DidFinishPingLoad::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessConnection_DidFinishPreconnection:
        return jsValueForDecodedArguments<Messages::NetworkProcessConnection::DidFinishPreconnection::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessConnection_SetOnLineState:
        return jsValueForDecodedArguments<Messages::NetworkProcessConnection::SetOnLineState::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessConnection_CookieAcceptPolicyChanged:
        return jsValueForDecodedArguments<Messages::NetworkProcessConnection::CookieAcceptPolicyChanged::Arguments>(globalObject, decoder);
#if HAVE(COOKIE_CHANGE_LISTENER_API)
    case MessageName::NetworkProcessConnection_CookiesAdded:
        return jsValueForDecodedArguments<Messages::NetworkProcessConnection::CookiesAdded::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessConnection_CookiesDeleted:
        return jsValueForDecodedArguments<Messages::NetworkProcessConnection::CookiesDeleted::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessConnection_AllCookiesDeleted:
        return jsValueForDecodedArguments<Messages::NetworkProcessConnection::AllCookiesDeleted::Arguments>(globalObject, decoder);
#endif
#if ENABLE(WEB_RTC)
    case MessageName::NetworkProcessConnection_ConnectToRTCDataChannelRemoteSource:
        return jsValueForDecodedArguments<Messages::NetworkProcessConnection::ConnectToRTCDataChannelRemoteSource::Arguments>(globalObject, decoder);
#endif
    case MessageName::NetworkProcessConnection_CheckProcessLocalPortForActivity:
        return jsValueForDecodedArguments<Messages::NetworkProcessConnection::CheckProcessLocalPortForActivity::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessConnection_MessagesAvailableForPort:
        return jsValueForDecodedArguments<Messages::NetworkProcessConnection::MessagesAvailableForPort::Arguments>(globalObject, decoder);
    case MessageName::NetworkProcessConnection_BroadcastConsoleMessage:
        return jsValueForDecodedArguments<Messages::NetworkProcessConnection::BroadcastConsoleMessage::Arguments>(globalObject, decoder);
    case MessageName::WebResourceLoader_WillSendRequest:
        return jsValueForDecodedArguments<Messages::WebResourceLoader::WillSendRequest::Arguments>(globalObject, decoder);
    case MessageName::WebResourceLoader_DidSendData:
        return jsValueForDecodedArguments<Messages::WebResourceLoader::DidSendData::Arguments>(globalObject, decoder);
    case MessageName::WebResourceLoader_DidReceiveResponse:
        return jsValueForDecodedArguments<Messages::WebResourceLoader::DidReceiveResponse::Arguments>(globalObject, decoder);
    case MessageName::WebResourceLoader_DidReceiveData:
        return jsValueForDecodedArguments<Messages::WebResourceLoader::DidReceiveData::Arguments>(globalObject, decoder);
    case MessageName::WebResourceLoader_DidFinishResourceLoad:
        return jsValueForDecodedArguments<Messages::WebResourceLoader::DidFinishResourceLoad::Arguments>(globalObject, decoder);
    case MessageName::WebResourceLoader_DidFailResourceLoad:
        return jsValueForDecodedArguments<Messages::WebResourceLoader::DidFailResourceLoad::Arguments>(globalObject, decoder);
    case MessageName::WebResourceLoader_DidFailServiceWorkerLoad:
        return jsValueForDecodedArguments<Messages::WebResourceLoader::DidFailServiceWorkerLoad::Arguments>(globalObject, decoder);
    case MessageName::WebResourceLoader_ServiceWorkerDidNotHandle:
        return jsValueForDecodedArguments<Messages::WebResourceLoader::ServiceWorkerDidNotHandle::Arguments>(globalObject, decoder);
    case MessageName::WebResourceLoader_DidBlockAuthenticationChallenge:
        return jsValueForDecodedArguments<Messages::WebResourceLoader::DidBlockAuthenticationChallenge::Arguments>(globalObject, decoder);
    case MessageName::WebResourceLoader_StopLoadingAfterXFrameOptionsOrContentSecurityPolicyDenied:
        return jsValueForDecodedArguments<Messages::WebResourceLoader::StopLoadingAfterXFrameOptionsOrContentSecurityPolicyDenied::Arguments>(globalObject, decoder);
#if ENABLE(SHAREABLE_RESOURCE)
    case MessageName::WebResourceLoader_DidReceiveResource:
        return jsValueForDecodedArguments<Messages::WebResourceLoader::DidReceiveResource::Arguments>(globalObject, decoder);
#endif
#if ENABLE(CONTENT_FILTERING_IN_NETWORKING_PROCESS)
    case MessageName::WebResourceLoader_ContentFilterDidBlockLoad:
        return jsValueForDecodedArguments<Messages::WebResourceLoader::ContentFilterDidBlockLoad::Arguments>(globalObject, decoder);
    case MessageName::WebResourceLoader_CancelMainResourceLoadForContentFilter:
        return jsValueForDecodedArguments<Messages::WebResourceLoader::CancelMainResourceLoadForContentFilter::Arguments>(globalObject, decoder);
    case MessageName::WebResourceLoader_HandleProvisionalLoadFailureFromContentFilter:
        return jsValueForDecodedArguments<Messages::WebResourceLoader::HandleProvisionalLoadFailureFromContentFilter::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebSocketChannel_DidConnect:
        return jsValueForDecodedArguments<Messages::WebSocketChannel::DidConnect::Arguments>(globalObject, decoder);
    case MessageName::WebSocketChannel_DidClose:
        return jsValueForDecodedArguments<Messages::WebSocketChannel::DidClose::Arguments>(globalObject, decoder);
    case MessageName::WebSocketChannel_DidReceiveText:
        return jsValueForDecodedArguments<Messages::WebSocketChannel::DidReceiveText::Arguments>(globalObject, decoder);
    case MessageName::WebSocketChannel_DidReceiveBinaryData:
        return jsValueForDecodedArguments<Messages::WebSocketChannel::DidReceiveBinaryData::Arguments>(globalObject, decoder);
    case MessageName::WebSocketChannel_DidReceiveMessageError:
        return jsValueForDecodedArguments<Messages::WebSocketChannel::DidReceiveMessageError::Arguments>(globalObject, decoder);
    case MessageName::WebSocketChannel_DidSendHandshakeRequest:
        return jsValueForDecodedArguments<Messages::WebSocketChannel::DidSendHandshakeRequest::Arguments>(globalObject, decoder);
    case MessageName::WebSocketChannel_DidReceiveHandshakeResponse:
        return jsValueForDecodedArguments<Messages::WebSocketChannel::DidReceiveHandshakeResponse::Arguments>(globalObject, decoder);
    case MessageName::WebSocketStream_DidOpenSocketStream:
        return jsValueForDecodedArguments<Messages::WebSocketStream::DidOpenSocketStream::Arguments>(globalObject, decoder);
    case MessageName::WebSocketStream_DidCloseSocketStream:
        return jsValueForDecodedArguments<Messages::WebSocketStream::DidCloseSocketStream::Arguments>(globalObject, decoder);
    case MessageName::WebSocketStream_DidReceiveSocketStreamData:
        return jsValueForDecodedArguments<Messages::WebSocketStream::DidReceiveSocketStreamData::Arguments>(globalObject, decoder);
    case MessageName::WebSocketStream_DidFailToReceiveSocketStreamData:
        return jsValueForDecodedArguments<Messages::WebSocketStream::DidFailToReceiveSocketStreamData::Arguments>(globalObject, decoder);
    case MessageName::WebSocketStream_DidUpdateBufferedAmount:
        return jsValueForDecodedArguments<Messages::WebSocketStream::DidUpdateBufferedAmount::Arguments>(globalObject, decoder);
    case MessageName::WebSocketStream_DidFailSocketStream:
        return jsValueForDecodedArguments<Messages::WebSocketStream::DidFailSocketStream::Arguments>(globalObject, decoder);
    case MessageName::WebSocketStream_DidSendData:
        return jsValueForDecodedArguments<Messages::WebSocketStream::DidSendData::Arguments>(globalObject, decoder);
    case MessageName::WebSocketStream_DidSendHandshake:
        return jsValueForDecodedArguments<Messages::WebSocketStream::DidSendHandshake::Arguments>(globalObject, decoder);
    case MessageName::WebNotificationManager_DidShowNotification:
        return jsValueForDecodedArguments<Messages::WebNotificationManager::DidShowNotification::Arguments>(globalObject, decoder);
    case MessageName::WebNotificationManager_DidClickNotification:
        return jsValueForDecodedArguments<Messages::WebNotificationManager::DidClickNotification::Arguments>(globalObject, decoder);
    case MessageName::WebNotificationManager_DidCloseNotifications:
        return jsValueForDecodedArguments<Messages::WebNotificationManager::DidCloseNotifications::Arguments>(globalObject, decoder);
    case MessageName::WebNotificationManager_DidUpdateNotificationDecision:
        return jsValueForDecodedArguments<Messages::WebNotificationManager::DidUpdateNotificationDecision::Arguments>(globalObject, decoder);
    case MessageName::WebNotificationManager_DidRemoveNotificationDecisions:
        return jsValueForDecodedArguments<Messages::WebNotificationManager::DidRemoveNotificationDecisions::Arguments>(globalObject, decoder);
#if ENABLE(MEDIA_STREAM)
    case MessageName::SpeechRecognitionRealtimeMediaSourceManager_CreateSource:
        return jsValueForDecodedArguments<Messages::SpeechRecognitionRealtimeMediaSourceManager::CreateSource::Arguments>(globalObject, decoder);
    case MessageName::SpeechRecognitionRealtimeMediaSourceManager_DeleteSource:
        return jsValueForDecodedArguments<Messages::SpeechRecognitionRealtimeMediaSourceManager::DeleteSource::Arguments>(globalObject, decoder);
    case MessageName::SpeechRecognitionRealtimeMediaSourceManager_Start:
        return jsValueForDecodedArguments<Messages::SpeechRecognitionRealtimeMediaSourceManager::Start::Arguments>(globalObject, decoder);
    case MessageName::SpeechRecognitionRealtimeMediaSourceManager_Stop:
        return jsValueForDecodedArguments<Messages::SpeechRecognitionRealtimeMediaSourceManager::Stop::Arguments>(globalObject, decoder);
#if ENABLE(SANDBOX_EXTENSIONS)
    case MessageName::SpeechRecognitionRealtimeMediaSourceManager_GrantSandboxExtensions:
        return jsValueForDecodedArguments<Messages::SpeechRecognitionRealtimeMediaSourceManager::GrantSandboxExtensions::Arguments>(globalObject, decoder);
    case MessageName::SpeechRecognitionRealtimeMediaSourceManager_RevokeSandboxExtensions:
        return jsValueForDecodedArguments<Messages::SpeechRecognitionRealtimeMediaSourceManager::RevokeSandboxExtensions::Arguments>(globalObject, decoder);
#endif
#endif
    case MessageName::WebSharedWorkerContextManagerConnection_LaunchSharedWorker:
        return jsValueForDecodedArguments<Messages::WebSharedWorkerContextManagerConnection::LaunchSharedWorker::Arguments>(globalObject, decoder);
    case MessageName::WebSharedWorkerContextManagerConnection_PostConnectEvent:
        return jsValueForDecodedArguments<Messages::WebSharedWorkerContextManagerConnection::PostConnectEvent::Arguments>(globalObject, decoder);
    case MessageName::WebSharedWorkerContextManagerConnection_TerminateSharedWorker:
        return jsValueForDecodedArguments<Messages::WebSharedWorkerContextManagerConnection::TerminateSharedWorker::Arguments>(globalObject, decoder);
    case MessageName::WebSharedWorkerContextManagerConnection_UpdatePreferencesStore:
        return jsValueForDecodedArguments<Messages::WebSharedWorkerContextManagerConnection::UpdatePreferencesStore::Arguments>(globalObject, decoder);
    case MessageName::WebSharedWorkerContextManagerConnection_SetUserAgent:
        return jsValueForDecodedArguments<Messages::WebSharedWorkerContextManagerConnection::SetUserAgent::Arguments>(globalObject, decoder);
    case MessageName::WebSharedWorkerContextManagerConnection_Close:
        return jsValueForDecodedArguments<Messages::WebSharedWorkerContextManagerConnection::Close::Arguments>(globalObject, decoder);
    case MessageName::WebSharedWorkerObjectConnection_FetchScriptInClient:
        return jsValueForDecodedArguments<Messages::WebSharedWorkerObjectConnection::FetchScriptInClient::Arguments>(globalObject, decoder);
    case MessageName::WebSharedWorkerObjectConnection_NotifyWorkerObjectOfLoadCompletion:
        return jsValueForDecodedArguments<Messages::WebSharedWorkerObjectConnection::NotifyWorkerObjectOfLoadCompletion::Arguments>(globalObject, decoder);
    case MessageName::WebSharedWorkerObjectConnection_PostExceptionToWorkerObject:
        return jsValueForDecodedArguments<Messages::WebSharedWorkerObjectConnection::PostExceptionToWorkerObject::Arguments>(globalObject, decoder);
#if ENABLE(SERVICE_WORKER)
    case MessageName::WebSWClientConnection_JobRejectedInServer:
        return jsValueForDecodedArguments<Messages::WebSWClientConnection::JobRejectedInServer::Arguments>(globalObject, decoder);
    case MessageName::WebSWClientConnection_RegistrationJobResolvedInServer:
        return jsValueForDecodedArguments<Messages::WebSWClientConnection::RegistrationJobResolvedInServer::Arguments>(globalObject, decoder);
    case MessageName::WebSWClientConnection_StartScriptFetchForServer:
        return jsValueForDecodedArguments<Messages::WebSWClientConnection::StartScriptFetchForServer::Arguments>(globalObject, decoder);
    case MessageName::WebSWClientConnection_UpdateRegistrationState:
        return jsValueForDecodedArguments<Messages::WebSWClientConnection::UpdateRegistrationState::Arguments>(globalObject, decoder);
    case MessageName::WebSWClientConnection_UpdateWorkerState:
        return jsValueForDecodedArguments<Messages::WebSWClientConnection::UpdateWorkerState::Arguments>(globalObject, decoder);
    case MessageName::WebSWClientConnection_FireUpdateFoundEvent:
        return jsValueForDecodedArguments<Messages::WebSWClientConnection::FireUpdateFoundEvent::Arguments>(globalObject, decoder);
    case MessageName::WebSWClientConnection_SetRegistrationLastUpdateTime:
        return jsValueForDecodedArguments<Messages::WebSWClientConnection::SetRegistrationLastUpdateTime::Arguments>(globalObject, decoder);
    case MessageName::WebSWClientConnection_SetRegistrationUpdateViaCache:
        return jsValueForDecodedArguments<Messages::WebSWClientConnection::SetRegistrationUpdateViaCache::Arguments>(globalObject, decoder);
    case MessageName::WebSWClientConnection_NotifyClientsOfControllerChange:
        return jsValueForDecodedArguments<Messages::WebSWClientConnection::NotifyClientsOfControllerChange::Arguments>(globalObject, decoder);
    case MessageName::WebSWClientConnection_SetSWOriginTableIsImported:
        return jsValueForDecodedArguments<Messages::WebSWClientConnection::SetSWOriginTableIsImported::Arguments>(globalObject, decoder);
    case MessageName::WebSWClientConnection_SetSWOriginTableSharedMemory:
        return jsValueForDecodedArguments<Messages::WebSWClientConnection::SetSWOriginTableSharedMemory::Arguments>(globalObject, decoder);
    case MessageName::WebSWClientConnection_PostMessageToServiceWorkerClient:
        return jsValueForDecodedArguments<Messages::WebSWClientConnection::PostMessageToServiceWorkerClient::Arguments>(globalObject, decoder);
    case MessageName::WebSWClientConnection_SetDocumentIsControlled:
        return jsValueForDecodedArguments<Messages::WebSWClientConnection::SetDocumentIsControlled::Arguments>(globalObject, decoder);
#endif
#if ENABLE(SERVICE_WORKER)
    case MessageName::WebSWContextManagerConnection_InstallServiceWorker:
        return jsValueForDecodedArguments<Messages::WebSWContextManagerConnection::InstallServiceWorker::Arguments>(globalObject, decoder);
    case MessageName::WebSWContextManagerConnection_UpdateAppInitiatedValue:
        return jsValueForDecodedArguments<Messages::WebSWContextManagerConnection::UpdateAppInitiatedValue::Arguments>(globalObject, decoder);
    case MessageName::WebSWContextManagerConnection_StartFetch:
        return jsValueForDecodedArguments<Messages::WebSWContextManagerConnection::StartFetch::Arguments>(globalObject, decoder);
    case MessageName::WebSWContextManagerConnection_CancelFetch:
        return jsValueForDecodedArguments<Messages::WebSWContextManagerConnection::CancelFetch::Arguments>(globalObject, decoder);
    case MessageName::WebSWContextManagerConnection_ContinueDidReceiveFetchResponse:
        return jsValueForDecodedArguments<Messages::WebSWContextManagerConnection::ContinueDidReceiveFetchResponse::Arguments>(globalObject, decoder);
    case MessageName::WebSWContextManagerConnection_PostMessageToServiceWorker:
        return jsValueForDecodedArguments<Messages::WebSWContextManagerConnection::PostMessageToServiceWorker::Arguments>(globalObject, decoder);
    case MessageName::WebSWContextManagerConnection_FireInstallEvent:
        return jsValueForDecodedArguments<Messages::WebSWContextManagerConnection::FireInstallEvent::Arguments>(globalObject, decoder);
    case MessageName::WebSWContextManagerConnection_FireActivateEvent:
        return jsValueForDecodedArguments<Messages::WebSWContextManagerConnection::FireActivateEvent::Arguments>(globalObject, decoder);
    case MessageName::WebSWContextManagerConnection_FirePushEvent:
        return jsValueForDecodedArguments<Messages::WebSWContextManagerConnection::FirePushEvent::Arguments>(globalObject, decoder);
    case MessageName::WebSWContextManagerConnection_TerminateWorker:
        return jsValueForDecodedArguments<Messages::WebSWContextManagerConnection::TerminateWorker::Arguments>(globalObject, decoder);
#if ENABLE(SHAREABLE_RESOURCE) && PLATFORM(COCOA)
    case MessageName::WebSWContextManagerConnection_DidSaveScriptsToDisk:
        return jsValueForDecodedArguments<Messages::WebSWContextManagerConnection::DidSaveScriptsToDisk::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebSWContextManagerConnection_MatchAllCompleted:
        return jsValueForDecodedArguments<Messages::WebSWContextManagerConnection::MatchAllCompleted::Arguments>(globalObject, decoder);
    case MessageName::WebSWContextManagerConnection_SetUserAgent:
        return jsValueForDecodedArguments<Messages::WebSWContextManagerConnection::SetUserAgent::Arguments>(globalObject, decoder);
    case MessageName::WebSWContextManagerConnection_UpdatePreferencesStore:
        return jsValueForDecodedArguments<Messages::WebSWContextManagerConnection::UpdatePreferencesStore::Arguments>(globalObject, decoder);
    case MessageName::WebSWContextManagerConnection_Close:
        return jsValueForDecodedArguments<Messages::WebSWContextManagerConnection::Close::Arguments>(globalObject, decoder);
    case MessageName::WebSWContextManagerConnection_SetThrottleState:
        return jsValueForDecodedArguments<Messages::WebSWContextManagerConnection::SetThrottleState::Arguments>(globalObject, decoder);
    case MessageName::WebSWContextManagerConnection_ConvertFetchToDownload:
        return jsValueForDecodedArguments<Messages::WebSWContextManagerConnection::ConvertFetchToDownload::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebUserContentController_AddContentWorlds:
        return jsValueForDecodedArguments<Messages::WebUserContentController::AddContentWorlds::Arguments>(globalObject, decoder);
    case MessageName::WebUserContentController_RemoveContentWorlds:
        return jsValueForDecodedArguments<Messages::WebUserContentController::RemoveContentWorlds::Arguments>(globalObject, decoder);
    case MessageName::WebUserContentController_AddUserScripts:
        return jsValueForDecodedArguments<Messages::WebUserContentController::AddUserScripts::Arguments>(globalObject, decoder);
    case MessageName::WebUserContentController_RemoveUserScript:
        return jsValueForDecodedArguments<Messages::WebUserContentController::RemoveUserScript::Arguments>(globalObject, decoder);
    case MessageName::WebUserContentController_RemoveAllUserScripts:
        return jsValueForDecodedArguments<Messages::WebUserContentController::RemoveAllUserScripts::Arguments>(globalObject, decoder);
    case MessageName::WebUserContentController_AddUserStyleSheets:
        return jsValueForDecodedArguments<Messages::WebUserContentController::AddUserStyleSheets::Arguments>(globalObject, decoder);
    case MessageName::WebUserContentController_RemoveUserStyleSheet:
        return jsValueForDecodedArguments<Messages::WebUserContentController::RemoveUserStyleSheet::Arguments>(globalObject, decoder);
    case MessageName::WebUserContentController_RemoveAllUserStyleSheets:
        return jsValueForDecodedArguments<Messages::WebUserContentController::RemoveAllUserStyleSheets::Arguments>(globalObject, decoder);
    case MessageName::WebUserContentController_AddUserScriptMessageHandlers:
        return jsValueForDecodedArguments<Messages::WebUserContentController::AddUserScriptMessageHandlers::Arguments>(globalObject, decoder);
    case MessageName::WebUserContentController_RemoveUserScriptMessageHandler:
        return jsValueForDecodedArguments<Messages::WebUserContentController::RemoveUserScriptMessageHandler::Arguments>(globalObject, decoder);
    case MessageName::WebUserContentController_RemoveAllUserScriptMessageHandlersForWorlds:
        return jsValueForDecodedArguments<Messages::WebUserContentController::RemoveAllUserScriptMessageHandlersForWorlds::Arguments>(globalObject, decoder);
    case MessageName::WebUserContentController_RemoveAllUserScriptMessageHandlers:
        return jsValueForDecodedArguments<Messages::WebUserContentController::RemoveAllUserScriptMessageHandlers::Arguments>(globalObject, decoder);
#if ENABLE(CONTENT_EXTENSIONS)
    case MessageName::WebUserContentController_AddContentRuleLists:
        return jsValueForDecodedArguments<Messages::WebUserContentController::AddContentRuleLists::Arguments>(globalObject, decoder);
    case MessageName::WebUserContentController_RemoveContentRuleList:
        return jsValueForDecodedArguments<Messages::WebUserContentController::RemoveContentRuleList::Arguments>(globalObject, decoder);
    case MessageName::WebUserContentController_RemoveAllContentRuleLists:
        return jsValueForDecodedArguments<Messages::WebUserContentController::RemoveAllContentRuleLists::Arguments>(globalObject, decoder);
#endif
    case MessageName::RemoteWebLockRegistry_DidCompleteLockRequest:
        return jsValueForDecodedArguments<Messages::RemoteWebLockRegistry::DidCompleteLockRequest::Arguments>(globalObject, decoder);
    case MessageName::RemoteWebLockRegistry_DidStealLock:
        return jsValueForDecodedArguments<Messages::RemoteWebLockRegistry::DidStealLock::Arguments>(globalObject, decoder);
    case MessageName::WebBroadcastChannelRegistry_PostMessageToRemote:
        return jsValueForDecodedArguments<Messages::WebBroadcastChannelRegistry::PostMessageToRemote::Arguments>(globalObject, decoder);
    case MessageName::WebFileSystemStorageConnection_InvalidateAccessHandle:
        return jsValueForDecodedArguments<Messages::WebFileSystemStorageConnection::InvalidateAccessHandle::Arguments>(globalObject, decoder);
    case MessageName::WebSpeechRecognitionConnection_DidReceiveUpdate:
        return jsValueForDecodedArguments<Messages::WebSpeechRecognitionConnection::DidReceiveUpdate::Arguments>(globalObject, decoder);
#if USE(COORDINATED_GRAPHICS) || USE(TEXTURE_MAPPER)
    case MessageName::DrawingArea_UpdateBackingStoreState:
        return jsValueForDecodedArguments<Messages::DrawingArea::UpdateBackingStoreState::Arguments>(globalObject, decoder);
#endif
    case MessageName::DrawingArea_DidUpdate:
        return jsValueForDecodedArguments<Messages::DrawingArea::DidUpdate::Arguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::DrawingArea_UpdateGeometry:
        return jsValueForDecodedArguments<Messages::DrawingArea::UpdateGeometry::Arguments>(globalObject, decoder);
    case MessageName::DrawingArea_SetDeviceScaleFactor:
        return jsValueForDecodedArguments<Messages::DrawingArea::SetDeviceScaleFactor::Arguments>(globalObject, decoder);
    case MessageName::DrawingArea_SetColorSpace:
        return jsValueForDecodedArguments<Messages::DrawingArea::SetColorSpace::Arguments>(globalObject, decoder);
    case MessageName::DrawingArea_SetViewExposedRect:
        return jsValueForDecodedArguments<Messages::DrawingArea::SetViewExposedRect::Arguments>(globalObject, decoder);
    case MessageName::DrawingArea_AcceleratedAnimationDidStart:
        return jsValueForDecodedArguments<Messages::DrawingArea::AcceleratedAnimationDidStart::Arguments>(globalObject, decoder);
    case MessageName::DrawingArea_AcceleratedAnimationDidEnd:
        return jsValueForDecodedArguments<Messages::DrawingArea::AcceleratedAnimationDidEnd::Arguments>(globalObject, decoder);
    case MessageName::DrawingArea_AddTransactionCallbackID:
        return jsValueForDecodedArguments<Messages::DrawingArea::AddTransactionCallbackID::Arguments>(globalObject, decoder);
#endif
#if USE(GRAPHICS_LAYER_WC)
    case MessageName::DrawingArea_UpdateGeometry:
        return jsValueForDecodedArguments<Messages::DrawingArea::UpdateGeometry::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(COCOA) || PLATFORM(GTK)
    case MessageName::DrawingArea_AdjustTransientZoom:
        return jsValueForDecodedArguments<Messages::DrawingArea::AdjustTransientZoom::Arguments>(globalObject, decoder);
    case MessageName::DrawingArea_CommitTransientZoom:
        return jsValueForDecodedArguments<Messages::DrawingArea::CommitTransientZoom::Arguments>(globalObject, decoder);
#endif
    case MessageName::EventDispatcher_WheelEvent:
        return jsValueForDecodedArguments<Messages::EventDispatcher::WheelEvent::Arguments>(globalObject, decoder);
#if ENABLE(IOS_TOUCH_EVENTS)
    case MessageName::EventDispatcher_TouchEvent:
        return jsValueForDecodedArguments<Messages::EventDispatcher::TouchEvent::Arguments>(globalObject, decoder);
    case MessageName::EventDispatcher_TouchEventWithoutCallback:
        return jsValueForDecodedArguments<Messages::EventDispatcher::TouchEventWithoutCallback::Arguments>(globalObject, decoder);
#endif
#if ENABLE(MAC_GESTURE_EVENTS)
    case MessageName::EventDispatcher_GestureEvent:
        return jsValueForDecodedArguments<Messages::EventDispatcher::GestureEvent::Arguments>(globalObject, decoder);
#endif
#if HAVE(CVDISPLAYLINK)
    case MessageName::EventDispatcher_DisplayWasRefreshed:
        return jsValueForDecodedArguments<Messages::EventDispatcher::DisplayWasRefreshed::Arguments>(globalObject, decoder);
#endif
#if ENABLE(MOMENTUM_EVENT_DISPATCHER)
    case MessageName::EventDispatcher_SetScrollingAccelerationCurve:
        return jsValueForDecodedArguments<Messages::EventDispatcher::SetScrollingAccelerationCurve::Arguments>(globalObject, decoder);
#endif
    case MessageName::EventDispatcher_PageScreenDidChange:
        return jsValueForDecodedArguments<Messages::EventDispatcher::PageScreenDidChange::Arguments>(globalObject, decoder);
    case MessageName::VisitedLinkTableController_SetVisitedLinkTable:
        return jsValueForDecodedArguments<Messages::VisitedLinkTableController::SetVisitedLinkTable::Arguments>(globalObject, decoder);
    case MessageName::VisitedLinkTableController_VisitedLinkStateChanged:
        return jsValueForDecodedArguments<Messages::VisitedLinkTableController::VisitedLinkStateChanged::Arguments>(globalObject, decoder);
    case MessageName::VisitedLinkTableController_AllVisitedLinkStateChanged:
        return jsValueForDecodedArguments<Messages::VisitedLinkTableController::AllVisitedLinkStateChanged::Arguments>(globalObject, decoder);
    case MessageName::VisitedLinkTableController_RemoveAllVisitedLinks:
        return jsValueForDecodedArguments<Messages::VisitedLinkTableController::RemoveAllVisitedLinks::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetInitialFocus:
        return jsValueForDecodedArguments<Messages::WebPage::SetInitialFocus::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetActivityState:
        return jsValueForDecodedArguments<Messages::WebPage::SetActivityState::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetLayerHostingMode:
        return jsValueForDecodedArguments<Messages::WebPage::SetLayerHostingMode::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetBackgroundColor:
        return jsValueForDecodedArguments<Messages::WebPage::SetBackgroundColor::Arguments>(globalObject, decoder);
    case MessageName::WebPage_AddConsoleMessage:
        return jsValueForDecodedArguments<Messages::WebPage::AddConsoleMessage::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SendCSPViolationReport:
        return jsValueForDecodedArguments<Messages::WebPage::SendCSPViolationReport::Arguments>(globalObject, decoder);
    case MessageName::WebPage_EnqueueSecurityPolicyViolationEvent:
        return jsValueForDecodedArguments<Messages::WebPage::EnqueueSecurityPolicyViolationEvent::Arguments>(globalObject, decoder);
    case MessageName::WebPage_TestProcessIncomingSyncMessagesWhenWaitingForSyncReply:
        return jsValueForDecodedArguments<Messages::WebPage::TestProcessIncomingSyncMessagesWhenWaitingForSyncReply::Arguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::WebPage_SetTopContentInsetFenced:
        return jsValueForDecodedArguments<Messages::WebPage::SetTopContentInsetFenced::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_SetTopContentInset:
        return jsValueForDecodedArguments<Messages::WebPage::SetTopContentInset::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetUnderlayColor:
        return jsValueForDecodedArguments<Messages::WebPage::SetUnderlayColor::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetUnderPageBackgroundColorOverride:
        return jsValueForDecodedArguments<Messages::WebPage::SetUnderPageBackgroundColorOverride::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ViewWillStartLiveResize:
        return jsValueForDecodedArguments<Messages::WebPage::ViewWillStartLiveResize::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ViewWillEndLiveResize:
        return jsValueForDecodedArguments<Messages::WebPage::ViewWillEndLiveResize::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ExecuteEditCommandWithCallback:
        return jsValueForDecodedArguments<Messages::WebPage::ExecuteEditCommandWithCallback::Arguments>(globalObject, decoder);
    case MessageName::WebPage_KeyEvent:
        return jsValueForDecodedArguments<Messages::WebPage::KeyEvent::Arguments>(globalObject, decoder);
    case MessageName::WebPage_MouseEvent:
        return jsValueForDecodedArguments<Messages::WebPage::MouseEvent::Arguments>(globalObject, decoder);
#if PLATFORM(IOS_FAMILY)
    case MessageName::WebPage_SetViewportConfigurationViewLayoutSize:
        return jsValueForDecodedArguments<Messages::WebPage::SetViewportConfigurationViewLayoutSize::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetMinimumUnobscuredSize:
        return jsValueForDecodedArguments<Messages::WebPage::SetMinimumUnobscuredSize::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetMaximumUnobscuredSize:
        return jsValueForDecodedArguments<Messages::WebPage::SetMaximumUnobscuredSize::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetDeviceOrientation:
        return jsValueForDecodedArguments<Messages::WebPage::SetDeviceOrientation::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetOverrideViewportArguments:
        return jsValueForDecodedArguments<Messages::WebPage::SetOverrideViewportArguments::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DynamicViewportSizeUpdate:
        return jsValueForDecodedArguments<Messages::WebPage::DynamicViewportSizeUpdate::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetScreenIsBeingCaptured:
        return jsValueForDecodedArguments<Messages::WebPage::SetScreenIsBeingCaptured::Arguments>(globalObject, decoder);
    case MessageName::WebPage_AttemptSyntheticClick:
        return jsValueForDecodedArguments<Messages::WebPage::AttemptSyntheticClick::Arguments>(globalObject, decoder);
    case MessageName::WebPage_PotentialTapAtPosition:
        return jsValueForDecodedArguments<Messages::WebPage::PotentialTapAtPosition::Arguments>(globalObject, decoder);
    case MessageName::WebPage_CommitPotentialTap:
        return jsValueForDecodedArguments<Messages::WebPage::CommitPotentialTap::Arguments>(globalObject, decoder);
    case MessageName::WebPage_CancelPotentialTap:
        return jsValueForDecodedArguments<Messages::WebPage::CancelPotentialTap::Arguments>(globalObject, decoder);
    case MessageName::WebPage_TapHighlightAtPosition:
        return jsValueForDecodedArguments<Messages::WebPage::TapHighlightAtPosition::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DidRecognizeLongPress:
        return jsValueForDecodedArguments<Messages::WebPage::DidRecognizeLongPress::Arguments>(globalObject, decoder);
    case MessageName::WebPage_HandleDoubleTapForDoubleClickAtPoint:
        return jsValueForDecodedArguments<Messages::WebPage::HandleDoubleTapForDoubleClickAtPoint::Arguments>(globalObject, decoder);
    case MessageName::WebPage_InspectorNodeSearchMovedToPosition:
        return jsValueForDecodedArguments<Messages::WebPage::InspectorNodeSearchMovedToPosition::Arguments>(globalObject, decoder);
    case MessageName::WebPage_InspectorNodeSearchEndedAtPosition:
        return jsValueForDecodedArguments<Messages::WebPage::InspectorNodeSearchEndedAtPosition::Arguments>(globalObject, decoder);
    case MessageName::WebPage_BlurFocusedElement:
        return jsValueForDecodedArguments<Messages::WebPage::BlurFocusedElement::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SelectWithGesture:
        return jsValueForDecodedArguments<Messages::WebPage::SelectWithGesture::Arguments>(globalObject, decoder);
    case MessageName::WebPage_UpdateSelectionWithTouches:
        return jsValueForDecodedArguments<Messages::WebPage::UpdateSelectionWithTouches::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SelectWithTwoTouches:
        return jsValueForDecodedArguments<Messages::WebPage::SelectWithTwoTouches::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ExtendSelection:
        return jsValueForDecodedArguments<Messages::WebPage::ExtendSelection::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SelectWordBackward:
        return jsValueForDecodedArguments<Messages::WebPage::SelectWordBackward::Arguments>(globalObject, decoder);
    case MessageName::WebPage_MoveSelectionByOffset:
        return jsValueForDecodedArguments<Messages::WebPage::MoveSelectionByOffset::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SelectTextWithGranularityAtPoint:
        return jsValueForDecodedArguments<Messages::WebPage::SelectTextWithGranularityAtPoint::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SelectPositionAtBoundaryWithDirection:
        return jsValueForDecodedArguments<Messages::WebPage::SelectPositionAtBoundaryWithDirection::Arguments>(globalObject, decoder);
    case MessageName::WebPage_MoveSelectionAtBoundaryWithDirection:
        return jsValueForDecodedArguments<Messages::WebPage::MoveSelectionAtBoundaryWithDirection::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SelectPositionAtPoint:
        return jsValueForDecodedArguments<Messages::WebPage::SelectPositionAtPoint::Arguments>(globalObject, decoder);
    case MessageName::WebPage_BeginSelectionInDirection:
        return jsValueForDecodedArguments<Messages::WebPage::BeginSelectionInDirection::Arguments>(globalObject, decoder);
    case MessageName::WebPage_UpdateSelectionWithExtentPoint:
        return jsValueForDecodedArguments<Messages::WebPage::UpdateSelectionWithExtentPoint::Arguments>(globalObject, decoder);
    case MessageName::WebPage_UpdateSelectionWithExtentPointAndBoundary:
        return jsValueForDecodedArguments<Messages::WebPage::UpdateSelectionWithExtentPointAndBoundary::Arguments>(globalObject, decoder);
    case MessageName::WebPage_RequestDictationContext:
        return jsValueForDecodedArguments<Messages::WebPage::RequestDictationContext::Arguments>(globalObject, decoder);
#endif
#if (PLATFORM(IOS_FAMILY) && ENABLE(REVEAL))
    case MessageName::WebPage_RequestRVItemInCurrentSelectedRange:
        return jsValueForDecodedArguments<Messages::WebPage::RequestRVItemInCurrentSelectedRange::Arguments>(globalObject, decoder);
    case MessageName::WebPage_PrepareSelectionForContextMenuWithLocationInView:
        return jsValueForDecodedArguments<Messages::WebPage::PrepareSelectionForContextMenuWithLocationInView::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(IOS_FAMILY)
    case MessageName::WebPage_ReplaceDictatedText:
        return jsValueForDecodedArguments<Messages::WebPage::ReplaceDictatedText::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ReplaceSelectedText:
        return jsValueForDecodedArguments<Messages::WebPage::ReplaceSelectedText::Arguments>(globalObject, decoder);
    case MessageName::WebPage_RequestAutocorrectionData:
        return jsValueForDecodedArguments<Messages::WebPage::RequestAutocorrectionData::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ApplyAutocorrection:
        return jsValueForDecodedArguments<Messages::WebPage::ApplyAutocorrection::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SyncApplyAutocorrection:
        return jsValueForDecodedArguments<Messages::WebPage::SyncApplyAutocorrection::Arguments>(globalObject, decoder);
    case MessageName::WebPage_HandleAutocorrectionContextRequest:
        return jsValueForDecodedArguments<Messages::WebPage::HandleAutocorrectionContextRequest::Arguments>(globalObject, decoder);
    case MessageName::WebPage_RequestEvasionRectsAboveSelection:
        return jsValueForDecodedArguments<Messages::WebPage::RequestEvasionRectsAboveSelection::Arguments>(globalObject, decoder);
    case MessageName::WebPage_GetPositionInformation:
        return jsValueForDecodedArguments<Messages::WebPage::GetPositionInformation::Arguments>(globalObject, decoder);
    case MessageName::WebPage_RequestPositionInformation:
        return jsValueForDecodedArguments<Messages::WebPage::RequestPositionInformation::Arguments>(globalObject, decoder);
    case MessageName::WebPage_StartInteractionWithElementContextOrPosition:
        return jsValueForDecodedArguments<Messages::WebPage::StartInteractionWithElementContextOrPosition::Arguments>(globalObject, decoder);
    case MessageName::WebPage_StopInteraction:
        return jsValueForDecodedArguments<Messages::WebPage::StopInteraction::Arguments>(globalObject, decoder);
    case MessageName::WebPage_PerformActionOnElement:
        return jsValueForDecodedArguments<Messages::WebPage::PerformActionOnElement::Arguments>(globalObject, decoder);
    case MessageName::WebPage_FocusNextFocusedElement:
        return jsValueForDecodedArguments<Messages::WebPage::FocusNextFocusedElement::Arguments>(globalObject, decoder);
    case MessageName::WebPage_AutofillLoginCredentials:
        return jsValueForDecodedArguments<Messages::WebPage::AutofillLoginCredentials::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetFocusedElementValue:
        return jsValueForDecodedArguments<Messages::WebPage::SetFocusedElementValue::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetFocusedElementSelectedIndex:
        return jsValueForDecodedArguments<Messages::WebPage::SetFocusedElementSelectedIndex::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ApplicationWillResignActive:
        return jsValueForDecodedArguments<Messages::WebPage::ApplicationWillResignActive::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ApplicationDidEnterBackground:
        return jsValueForDecodedArguments<Messages::WebPage::ApplicationDidEnterBackground::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ApplicationDidFinishSnapshottingAfterEnteringBackground:
        return jsValueForDecodedArguments<Messages::WebPage::ApplicationDidFinishSnapshottingAfterEnteringBackground::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ApplicationWillEnterForeground:
        return jsValueForDecodedArguments<Messages::WebPage::ApplicationWillEnterForeground::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ApplicationDidBecomeActive:
        return jsValueForDecodedArguments<Messages::WebPage::ApplicationDidBecomeActive::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ApplicationDidEnterBackgroundForMedia:
        return jsValueForDecodedArguments<Messages::WebPage::ApplicationDidEnterBackgroundForMedia::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ApplicationWillEnterForegroundForMedia:
        return jsValueForDecodedArguments<Messages::WebPage::ApplicationWillEnterForegroundForMedia::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ContentSizeCategoryDidChange:
        return jsValueForDecodedArguments<Messages::WebPage::ContentSizeCategoryDidChange::Arguments>(globalObject, decoder);
    case MessageName::WebPage_GetSelectionContext:
        return jsValueForDecodedArguments<Messages::WebPage::GetSelectionContext::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetAllowsMediaDocumentInlinePlayback:
        return jsValueForDecodedArguments<Messages::WebPage::SetAllowsMediaDocumentInlinePlayback::Arguments>(globalObject, decoder);
    case MessageName::WebPage_HandleTwoFingerTapAtPoint:
        return jsValueForDecodedArguments<Messages::WebPage::HandleTwoFingerTapAtPoint::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetForceAlwaysUserScalable:
        return jsValueForDecodedArguments<Messages::WebPage::SetForceAlwaysUserScalable::Arguments>(globalObject, decoder);
    case MessageName::WebPage_GetRectsForGranularityWithSelectionOffset:
        return jsValueForDecodedArguments<Messages::WebPage::GetRectsForGranularityWithSelectionOffset::Arguments>(globalObject, decoder);
    case MessageName::WebPage_GetRectsAtSelectionOffsetWithText:
        return jsValueForDecodedArguments<Messages::WebPage::GetRectsAtSelectionOffsetWithText::Arguments>(globalObject, decoder);
    case MessageName::WebPage_StoreSelectionForAccessibility:
        return jsValueForDecodedArguments<Messages::WebPage::StoreSelectionForAccessibility::Arguments>(globalObject, decoder);
    case MessageName::WebPage_StartAutoscrollAtPosition:
        return jsValueForDecodedArguments<Messages::WebPage::StartAutoscrollAtPosition::Arguments>(globalObject, decoder);
    case MessageName::WebPage_CancelAutoscroll:
        return jsValueForDecodedArguments<Messages::WebPage::CancelAutoscroll::Arguments>(globalObject, decoder);
    case MessageName::WebPage_RequestFocusedElementInformation:
        return jsValueForDecodedArguments<Messages::WebPage::RequestFocusedElementInformation::Arguments>(globalObject, decoder);
    case MessageName::WebPage_HardwareKeyboardAvailabilityChanged:
        return jsValueForDecodedArguments<Messages::WebPage::HardwareKeyboardAvailabilityChanged::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetIsShowingInputViewForFocusedElement:
        return jsValueForDecodedArguments<Messages::WebPage::SetIsShowingInputViewForFocusedElement::Arguments>(globalObject, decoder);
    case MessageName::WebPage_UpdateSelectionWithDelta:
        return jsValueForDecodedArguments<Messages::WebPage::UpdateSelectionWithDelta::Arguments>(globalObject, decoder);
    case MessageName::WebPage_RequestDocumentEditingContext:
        return jsValueForDecodedArguments<Messages::WebPage::RequestDocumentEditingContext::Arguments>(globalObject, decoder);
    case MessageName::WebPage_GenerateSyntheticEditingCommand:
        return jsValueForDecodedArguments<Messages::WebPage::GenerateSyntheticEditingCommand::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetShouldRevealCurrentSelectionAfterInsertion:
        return jsValueForDecodedArguments<Messages::WebPage::SetShouldRevealCurrentSelectionAfterInsertion::Arguments>(globalObject, decoder);
    case MessageName::WebPage_InsertTextPlaceholder:
        return jsValueForDecodedArguments<Messages::WebPage::InsertTextPlaceholder::Arguments>(globalObject, decoder);
    case MessageName::WebPage_RemoveTextPlaceholder:
        return jsValueForDecodedArguments<Messages::WebPage::RemoveTextPlaceholder::Arguments>(globalObject, decoder);
    case MessageName::WebPage_TextInputContextsInRect:
        return jsValueForDecodedArguments<Messages::WebPage::TextInputContextsInRect::Arguments>(globalObject, decoder);
    case MessageName::WebPage_FocusTextInputContextAndPlaceCaret:
        return jsValueForDecodedArguments<Messages::WebPage::FocusTextInputContextAndPlaceCaret::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ClearServiceWorkerEntitlementOverride:
        return jsValueForDecodedArguments<Messages::WebPage::ClearServiceWorkerEntitlementOverride::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_RequestImageBitmap:
        return jsValueForDecodedArguments<Messages::WebPage::RequestImageBitmap::Arguments>(globalObject, decoder);
#if ENABLE(IMAGE_ANALYSIS_ENHANCEMENTS)
    case MessageName::WebPage_InstallCroppedImageOverlay:
        return jsValueForDecodedArguments<Messages::WebPage::InstallCroppedImageOverlay::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetCroppedImageOverlayVisibility:
        return jsValueForDecodedArguments<Messages::WebPage::SetCroppedImageOverlayVisibility::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_SetControlledByAutomation:
        return jsValueForDecodedArguments<Messages::WebPage::SetControlledByAutomation::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ConnectInspector:
        return jsValueForDecodedArguments<Messages::WebPage::ConnectInspector::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DisconnectInspector:
        return jsValueForDecodedArguments<Messages::WebPage::DisconnectInspector::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SendMessageToTargetBackend:
        return jsValueForDecodedArguments<Messages::WebPage::SendMessageToTargetBackend::Arguments>(globalObject, decoder);
#if ENABLE(REMOTE_INSPECTOR)
    case MessageName::WebPage_SetIndicating:
        return jsValueForDecodedArguments<Messages::WebPage::SetIndicating::Arguments>(globalObject, decoder);
#endif
#if ENABLE(IOS_TOUCH_EVENTS)
    case MessageName::WebPage_ResetPotentialTapSecurityOrigin:
        return jsValueForDecodedArguments<Messages::WebPage::ResetPotentialTapSecurityOrigin::Arguments>(globalObject, decoder);
    case MessageName::WebPage_TouchEventSync:
        return jsValueForDecodedArguments<Messages::WebPage::TouchEventSync::Arguments>(globalObject, decoder);
#endif
#if !ENABLE(IOS_TOUCH_EVENTS) && ENABLE(TOUCH_EVENTS)
    case MessageName::WebPage_TouchEvent:
        return jsValueForDecodedArguments<Messages::WebPage::TouchEvent::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_CancelPointer:
        return jsValueForDecodedArguments<Messages::WebPage::CancelPointer::Arguments>(globalObject, decoder);
    case MessageName::WebPage_TouchWithIdentifierWasRemoved:
        return jsValueForDecodedArguments<Messages::WebPage::TouchWithIdentifierWasRemoved::Arguments>(globalObject, decoder);
#if ENABLE(INPUT_TYPE_COLOR)
    case MessageName::WebPage_DidEndColorPicker:
        return jsValueForDecodedArguments<Messages::WebPage::DidEndColorPicker::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DidChooseColor:
        return jsValueForDecodedArguments<Messages::WebPage::DidChooseColor::Arguments>(globalObject, decoder);
#endif
#if ENABLE(DATALIST_ELEMENT)
    case MessageName::WebPage_DidSelectDataListOption:
        return jsValueForDecodedArguments<Messages::WebPage::DidSelectDataListOption::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DidCloseSuggestions:
        return jsValueForDecodedArguments<Messages::WebPage::DidCloseSuggestions::Arguments>(globalObject, decoder);
#endif
#if ENABLE(DATE_AND_TIME_INPUT_TYPES)
    case MessageName::WebPage_DidChooseDate:
        return jsValueForDecodedArguments<Messages::WebPage::DidChooseDate::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DidEndDateTimePicker:
        return jsValueForDecodedArguments<Messages::WebPage::DidEndDateTimePicker::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_ScrollBy:
        return jsValueForDecodedArguments<Messages::WebPage::ScrollBy::Arguments>(globalObject, decoder);
    case MessageName::WebPage_CenterSelectionInVisibleArea:
        return jsValueForDecodedArguments<Messages::WebPage::CenterSelectionInVisibleArea::Arguments>(globalObject, decoder);
    case MessageName::WebPage_GoToBackForwardItem:
        return jsValueForDecodedArguments<Messages::WebPage::GoToBackForwardItem::Arguments>(globalObject, decoder);
    case MessageName::WebPage_TryRestoreScrollPosition:
        return jsValueForDecodedArguments<Messages::WebPage::TryRestoreScrollPosition::Arguments>(globalObject, decoder);
    case MessageName::WebPage_LoadURLInFrame:
        return jsValueForDecodedArguments<Messages::WebPage::LoadURLInFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPage_LoadDataInFrame:
        return jsValueForDecodedArguments<Messages::WebPage::LoadDataInFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPage_LoadRequest:
        return jsValueForDecodedArguments<Messages::WebPage::LoadRequest::Arguments>(globalObject, decoder);
    case MessageName::WebPage_LoadRequestWaitingForProcessLaunch:
        return jsValueForDecodedArguments<Messages::WebPage::LoadRequestWaitingForProcessLaunch::Arguments>(globalObject, decoder);
    case MessageName::WebPage_LoadData:
        return jsValueForDecodedArguments<Messages::WebPage::LoadData::Arguments>(globalObject, decoder);
    case MessageName::WebPage_LoadSimulatedRequestAndResponse:
        return jsValueForDecodedArguments<Messages::WebPage::LoadSimulatedRequestAndResponse::Arguments>(globalObject, decoder);
    case MessageName::WebPage_LoadAlternateHTML:
        return jsValueForDecodedArguments<Messages::WebPage::LoadAlternateHTML::Arguments>(globalObject, decoder);
    case MessageName::WebPage_NavigateToPDFLinkWithSimulatedClick:
        return jsValueForDecodedArguments<Messages::WebPage::NavigateToPDFLinkWithSimulatedClick::Arguments>(globalObject, decoder);
    case MessageName::WebPage_GetPDFFirstPageSize:
        return jsValueForDecodedArguments<Messages::WebPage::GetPDFFirstPageSize::Arguments>(globalObject, decoder);
    case MessageName::WebPage_Reload:
        return jsValueForDecodedArguments<Messages::WebPage::Reload::Arguments>(globalObject, decoder);
    case MessageName::WebPage_StopLoading:
        return jsValueForDecodedArguments<Messages::WebPage::StopLoading::Arguments>(globalObject, decoder);
    case MessageName::WebPage_StopLoadingFrame:
        return jsValueForDecodedArguments<Messages::WebPage::StopLoadingFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPage_RestoreSession:
        return jsValueForDecodedArguments<Messages::WebPage::RestoreSession::Arguments>(globalObject, decoder);
    case MessageName::WebPage_UpdateBackForwardListForReattach:
        return jsValueForDecodedArguments<Messages::WebPage::UpdateBackForwardListForReattach::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetCurrentHistoryItemForReattach:
        return jsValueForDecodedArguments<Messages::WebPage::SetCurrentHistoryItemForReattach::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DidRemoveBackForwardItem:
        return jsValueForDecodedArguments<Messages::WebPage::DidRemoveBackForwardItem::Arguments>(globalObject, decoder);
    case MessageName::WebPage_UpdateWebsitePolicies:
        return jsValueForDecodedArguments<Messages::WebPage::UpdateWebsitePolicies::Arguments>(globalObject, decoder);
    case MessageName::WebPage_NotifyUserScripts:
        return jsValueForDecodedArguments<Messages::WebPage::NotifyUserScripts::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DidReceivePolicyDecision:
        return jsValueForDecodedArguments<Messages::WebPage::DidReceivePolicyDecision::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ContinueWillSubmitForm:
        return jsValueForDecodedArguments<Messages::WebPage::ContinueWillSubmitForm::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ClearSelection:
        return jsValueForDecodedArguments<Messages::WebPage::ClearSelection::Arguments>(globalObject, decoder);
    case MessageName::WebPage_RestoreSelectionInFocusedEditableElement:
        return jsValueForDecodedArguments<Messages::WebPage::RestoreSelectionInFocusedEditableElement::Arguments>(globalObject, decoder);
    case MessageName::WebPage_GetContentsAsString:
        return jsValueForDecodedArguments<Messages::WebPage::GetContentsAsString::Arguments>(globalObject, decoder);
    case MessageName::WebPage_GetAllFrames:
        return jsValueForDecodedArguments<Messages::WebPage::GetAllFrames::Arguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::WebPage_GetContentsAsAttributedString:
        return jsValueForDecodedArguments<Messages::WebPage::GetContentsAsAttributedString::Arguments>(globalObject, decoder);
#endif
#if ENABLE(MHTML)
    case MessageName::WebPage_GetContentsAsMHTMLData:
        return jsValueForDecodedArguments<Messages::WebPage::GetContentsAsMHTMLData::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_GetMainResourceDataOfFrame:
        return jsValueForDecodedArguments<Messages::WebPage::GetMainResourceDataOfFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPage_GetResourceDataFromFrame:
        return jsValueForDecodedArguments<Messages::WebPage::GetResourceDataFromFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPage_GetRenderTreeExternalRepresentation:
        return jsValueForDecodedArguments<Messages::WebPage::GetRenderTreeExternalRepresentation::Arguments>(globalObject, decoder);
    case MessageName::WebPage_GetSelectionOrContentsAsString:
        return jsValueForDecodedArguments<Messages::WebPage::GetSelectionOrContentsAsString::Arguments>(globalObject, decoder);
    case MessageName::WebPage_GetSelectionAsWebArchiveData:
        return jsValueForDecodedArguments<Messages::WebPage::GetSelectionAsWebArchiveData::Arguments>(globalObject, decoder);
    case MessageName::WebPage_GetSourceForFrame:
        return jsValueForDecodedArguments<Messages::WebPage::GetSourceForFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPage_GetWebArchiveOfFrame:
        return jsValueForDecodedArguments<Messages::WebPage::GetWebArchiveOfFrame::Arguments>(globalObject, decoder);
    case MessageName::WebPage_RunJavaScriptInFrameInScriptWorld:
        return jsValueForDecodedArguments<Messages::WebPage::RunJavaScriptInFrameInScriptWorld::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ForceRepaint:
        return jsValueForDecodedArguments<Messages::WebPage::ForceRepaint::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SelectAll:
        return jsValueForDecodedArguments<Messages::WebPage::SelectAll::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ScheduleFullEditorStateUpdate:
        return jsValueForDecodedArguments<Messages::WebPage::ScheduleFullEditorStateUpdate::Arguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::WebPage_PerformDictionaryLookupOfCurrentSelection:
        return jsValueForDecodedArguments<Messages::WebPage::PerformDictionaryLookupOfCurrentSelection::Arguments>(globalObject, decoder);
    case MessageName::WebPage_PerformDictionaryLookupAtLocation:
        return jsValueForDecodedArguments<Messages::WebPage::PerformDictionaryLookupAtLocation::Arguments>(globalObject, decoder);
#endif
#if ENABLE(DATA_DETECTION)
    case MessageName::WebPage_DetectDataInAllFrames:
        return jsValueForDecodedArguments<Messages::WebPage::DetectDataInAllFrames::Arguments>(globalObject, decoder);
    case MessageName::WebPage_RemoveDataDetectedLinks:
        return jsValueForDecodedArguments<Messages::WebPage::RemoveDataDetectedLinks::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_ChangeFont:
        return jsValueForDecodedArguments<Messages::WebPage::ChangeFont::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ChangeFontAttributes:
        return jsValueForDecodedArguments<Messages::WebPage::ChangeFontAttributes::Arguments>(globalObject, decoder);
    case MessageName::WebPage_PreferencesDidChange:
        return jsValueForDecodedArguments<Messages::WebPage::PreferencesDidChange::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetUserAgent:
        return jsValueForDecodedArguments<Messages::WebPage::SetUserAgent::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetCustomTextEncodingName:
        return jsValueForDecodedArguments<Messages::WebPage::SetCustomTextEncodingName::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SuspendActiveDOMObjectsAndAnimations:
        return jsValueForDecodedArguments<Messages::WebPage::SuspendActiveDOMObjectsAndAnimations::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ResumeActiveDOMObjectsAndAnimations:
        return jsValueForDecodedArguments<Messages::WebPage::ResumeActiveDOMObjectsAndAnimations::Arguments>(globalObject, decoder);
    case MessageName::WebPage_Suspend:
        return jsValueForDecodedArguments<Messages::WebPage::Suspend::Arguments>(globalObject, decoder);
    case MessageName::WebPage_Resume:
        return jsValueForDecodedArguments<Messages::WebPage::Resume::Arguments>(globalObject, decoder);
    case MessageName::WebPage_Close:
        return jsValueForDecodedArguments<Messages::WebPage::Close::Arguments>(globalObject, decoder);
    case MessageName::WebPage_TryClose:
        return jsValueForDecodedArguments<Messages::WebPage::TryClose::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetEditable:
        return jsValueForDecodedArguments<Messages::WebPage::SetEditable::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ValidateCommand:
        return jsValueForDecodedArguments<Messages::WebPage::ValidateCommand::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ExecuteEditCommand:
        return jsValueForDecodedArguments<Messages::WebPage::ExecuteEditCommand::Arguments>(globalObject, decoder);
    case MessageName::WebPage_IncreaseListLevel:
        return jsValueForDecodedArguments<Messages::WebPage::IncreaseListLevel::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DecreaseListLevel:
        return jsValueForDecodedArguments<Messages::WebPage::DecreaseListLevel::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ChangeListType:
        return jsValueForDecodedArguments<Messages::WebPage::ChangeListType::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetBaseWritingDirection:
        return jsValueForDecodedArguments<Messages::WebPage::SetBaseWritingDirection::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetNeedsFontAttributes:
        return jsValueForDecodedArguments<Messages::WebPage::SetNeedsFontAttributes::Arguments>(globalObject, decoder);
    case MessageName::WebPage_RequestFontAttributesAtSelectionStart:
        return jsValueForDecodedArguments<Messages::WebPage::RequestFontAttributesAtSelectionStart::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DidRemoveEditCommand:
        return jsValueForDecodedArguments<Messages::WebPage::DidRemoveEditCommand::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ReapplyEditCommand:
        return jsValueForDecodedArguments<Messages::WebPage::ReapplyEditCommand::Arguments>(globalObject, decoder);
    case MessageName::WebPage_UnapplyEditCommand:
        return jsValueForDecodedArguments<Messages::WebPage::UnapplyEditCommand::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetPageAndTextZoomFactors:
        return jsValueForDecodedArguments<Messages::WebPage::SetPageAndTextZoomFactors::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetPageZoomFactor:
        return jsValueForDecodedArguments<Messages::WebPage::SetPageZoomFactor::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetTextZoomFactor:
        return jsValueForDecodedArguments<Messages::WebPage::SetTextZoomFactor::Arguments>(globalObject, decoder);
    case MessageName::WebPage_WindowScreenDidChange:
        return jsValueForDecodedArguments<Messages::WebPage::WindowScreenDidChange::Arguments>(globalObject, decoder);
    case MessageName::WebPage_AccessibilitySettingsDidChange:
        return jsValueForDecodedArguments<Messages::WebPage::AccessibilitySettingsDidChange::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ScalePage:
        return jsValueForDecodedArguments<Messages::WebPage::ScalePage::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ScalePageInViewCoordinates:
        return jsValueForDecodedArguments<Messages::WebPage::ScalePageInViewCoordinates::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ScaleView:
        return jsValueForDecodedArguments<Messages::WebPage::ScaleView::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetUseFixedLayout:
        return jsValueForDecodedArguments<Messages::WebPage::SetUseFixedLayout::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetFixedLayoutSize:
        return jsValueForDecodedArguments<Messages::WebPage::SetFixedLayoutSize::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ListenForLayoutMilestones:
        return jsValueForDecodedArguments<Messages::WebPage::ListenForLayoutMilestones::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetSuppressScrollbarAnimations:
        return jsValueForDecodedArguments<Messages::WebPage::SetSuppressScrollbarAnimations::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetEnableVerticalRubberBanding:
        return jsValueForDecodedArguments<Messages::WebPage::SetEnableVerticalRubberBanding::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetEnableHorizontalRubberBanding:
        return jsValueForDecodedArguments<Messages::WebPage::SetEnableHorizontalRubberBanding::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetBackgroundExtendsBeyondPage:
        return jsValueForDecodedArguments<Messages::WebPage::SetBackgroundExtendsBeyondPage::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetPaginationMode:
        return jsValueForDecodedArguments<Messages::WebPage::SetPaginationMode::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetPaginationBehavesLikeColumns:
        return jsValueForDecodedArguments<Messages::WebPage::SetPaginationBehavesLikeColumns::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetPageLength:
        return jsValueForDecodedArguments<Messages::WebPage::SetPageLength::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetGapBetweenPages:
        return jsValueForDecodedArguments<Messages::WebPage::SetGapBetweenPages::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetPaginationLineGridEnabled:
        return jsValueForDecodedArguments<Messages::WebPage::SetPaginationLineGridEnabled::Arguments>(globalObject, decoder);
    case MessageName::WebPage_PostInjectedBundleMessage:
        return jsValueForDecodedArguments<Messages::WebPage::PostInjectedBundleMessage::Arguments>(globalObject, decoder);
    case MessageName::WebPage_FindString:
        return jsValueForDecodedArguments<Messages::WebPage::FindString::Arguments>(globalObject, decoder);
    case MessageName::WebPage_FindStringMatches:
        return jsValueForDecodedArguments<Messages::WebPage::FindStringMatches::Arguments>(globalObject, decoder);
    case MessageName::WebPage_GetImageForFindMatch:
        return jsValueForDecodedArguments<Messages::WebPage::GetImageForFindMatch::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SelectFindMatch:
        return jsValueForDecodedArguments<Messages::WebPage::SelectFindMatch::Arguments>(globalObject, decoder);
    case MessageName::WebPage_IndicateFindMatch:
        return jsValueForDecodedArguments<Messages::WebPage::IndicateFindMatch::Arguments>(globalObject, decoder);
    case MessageName::WebPage_HideFindUI:
        return jsValueForDecodedArguments<Messages::WebPage::HideFindUI::Arguments>(globalObject, decoder);
    case MessageName::WebPage_CountStringMatches:
        return jsValueForDecodedArguments<Messages::WebPage::CountStringMatches::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ReplaceMatches:
        return jsValueForDecodedArguments<Messages::WebPage::ReplaceMatches::Arguments>(globalObject, decoder);
    case MessageName::WebPage_FindRectsForStringMatches:
        return jsValueForDecodedArguments<Messages::WebPage::FindRectsForStringMatches::Arguments>(globalObject, decoder);
    case MessageName::WebPage_HideFindIndicator:
        return jsValueForDecodedArguments<Messages::WebPage::HideFindIndicator::Arguments>(globalObject, decoder);
    case MessageName::WebPage_FindTextRangesForStringMatches:
        return jsValueForDecodedArguments<Messages::WebPage::FindTextRangesForStringMatches::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DecorateTextRangeWithStyle:
        return jsValueForDecodedArguments<Messages::WebPage::DecorateTextRangeWithStyle::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ScrollTextRangeToVisible:
        return jsValueForDecodedArguments<Messages::WebPage::ScrollTextRangeToVisible::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ClearAllDecoratedFoundText:
        return jsValueForDecodedArguments<Messages::WebPage::ClearAllDecoratedFoundText::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DidBeginTextSearchOperation:
        return jsValueForDecodedArguments<Messages::WebPage::DidBeginTextSearchOperation::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DidEndTextSearchOperation:
        return jsValueForDecodedArguments<Messages::WebPage::DidEndTextSearchOperation::Arguments>(globalObject, decoder);
    case MessageName::WebPage_RequestRectForFoundTextRange:
        return jsValueForDecodedArguments<Messages::WebPage::RequestRectForFoundTextRange::Arguments>(globalObject, decoder);
    case MessageName::WebPage_AddMIMETypeWithCustomContentProvider:
        return jsValueForDecodedArguments<Messages::WebPage::AddMIMETypeWithCustomContentProvider::Arguments>(globalObject, decoder);
#if PLATFORM(GTK) && ENABLE(DRAG_SUPPORT)
    case MessageName::WebPage_PerformDragControllerAction:
        return jsValueForDecodedArguments<Messages::WebPage::PerformDragControllerAction::Arguments>(globalObject, decoder);
#endif
#if !PLATFORM(GTK) && ENABLE(DRAG_SUPPORT)
    case MessageName::WebPage_PerformDragControllerAction:
        return jsValueForDecodedArguments<Messages::WebPage::PerformDragControllerAction::Arguments>(globalObject, decoder);
#endif
#if ENABLE(DRAG_SUPPORT)
    case MessageName::WebPage_DidStartDrag:
        return jsValueForDecodedArguments<Messages::WebPage::DidStartDrag::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DragEnded:
        return jsValueForDecodedArguments<Messages::WebPage::DragEnded::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DragCancelled:
        return jsValueForDecodedArguments<Messages::WebPage::DragCancelled::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(IOS_FAMILY) && ENABLE(DRAG_SUPPORT)
    case MessageName::WebPage_RequestDragStart:
        return jsValueForDecodedArguments<Messages::WebPage::RequestDragStart::Arguments>(globalObject, decoder);
    case MessageName::WebPage_RequestAdditionalItemsForDragSession:
        return jsValueForDecodedArguments<Messages::WebPage::RequestAdditionalItemsForDragSession::Arguments>(globalObject, decoder);
    case MessageName::WebPage_InsertDroppedImagePlaceholders:
        return jsValueForDecodedArguments<Messages::WebPage::InsertDroppedImagePlaceholders::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DidConcludeDrop:
        return jsValueForDecodedArguments<Messages::WebPage::DidConcludeDrop::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_DidChangeSelectedIndexForActivePopupMenu:
        return jsValueForDecodedArguments<Messages::WebPage::DidChangeSelectedIndexForActivePopupMenu::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetTextForActivePopupMenu:
        return jsValueForDecodedArguments<Messages::WebPage::SetTextForActivePopupMenu::Arguments>(globalObject, decoder);
#if PLATFORM(GTK)
    case MessageName::WebPage_FailedToShowPopupMenu:
        return jsValueForDecodedArguments<Messages::WebPage::FailedToShowPopupMenu::Arguments>(globalObject, decoder);
#endif
#if ENABLE(CONTEXT_MENUS)
    case MessageName::WebPage_DidShowContextMenu:
        return jsValueForDecodedArguments<Messages::WebPage::DidShowContextMenu::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DidDismissContextMenu:
        return jsValueForDecodedArguments<Messages::WebPage::DidDismissContextMenu::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DidSelectItemFromActiveContextMenu:
        return jsValueForDecodedArguments<Messages::WebPage::DidSelectItemFromActiveContextMenu::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ContextMenuForKeyEvent:
        return jsValueForDecodedArguments<Messages::WebPage::ContextMenuForKeyEvent::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(IOS_FAMILY)
    case MessageName::WebPage_DidChooseFilesForOpenPanelWithDisplayStringAndIcon:
        return jsValueForDecodedArguments<Messages::WebPage::DidChooseFilesForOpenPanelWithDisplayStringAndIcon::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_DidChooseFilesForOpenPanel:
        return jsValueForDecodedArguments<Messages::WebPage::DidChooseFilesForOpenPanel::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DidCancelForOpenPanel:
        return jsValueForDecodedArguments<Messages::WebPage::DidCancelForOpenPanel::Arguments>(globalObject, decoder);
#if ENABLE(SANDBOX_EXTENSIONS)
    case MessageName::WebPage_ExtendSandboxForFilesFromOpenPanel:
        return jsValueForDecodedArguments<Messages::WebPage::ExtendSandboxForFilesFromOpenPanel::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_AdvanceToNextMisspelling:
        return jsValueForDecodedArguments<Messages::WebPage::AdvanceToNextMisspelling::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ChangeSpellingToWord:
        return jsValueForDecodedArguments<Messages::WebPage::ChangeSpellingToWord::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DidFinishCheckingText:
        return jsValueForDecodedArguments<Messages::WebPage::DidFinishCheckingText::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DidCancelCheckingText:
        return jsValueForDecodedArguments<Messages::WebPage::DidCancelCheckingText::Arguments>(globalObject, decoder);
#if USE(APPKIT)
    case MessageName::WebPage_UppercaseWord:
        return jsValueForDecodedArguments<Messages::WebPage::UppercaseWord::Arguments>(globalObject, decoder);
    case MessageName::WebPage_LowercaseWord:
        return jsValueForDecodedArguments<Messages::WebPage::LowercaseWord::Arguments>(globalObject, decoder);
    case MessageName::WebPage_CapitalizeWord:
        return jsValueForDecodedArguments<Messages::WebPage::CapitalizeWord::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(COCOA)
    case MessageName::WebPage_SetSmartInsertDeleteEnabled:
        return jsValueForDecodedArguments<Messages::WebPage::SetSmartInsertDeleteEnabled::Arguments>(globalObject, decoder);
#endif
#if ENABLE(GEOLOCATION)
    case MessageName::WebPage_DidReceiveGeolocationPermissionDecision:
        return jsValueForDecodedArguments<Messages::WebPage::DidReceiveGeolocationPermissionDecision::Arguments>(globalObject, decoder);
#endif
#if ENABLE(MEDIA_STREAM)
    case MessageName::WebPage_UserMediaAccessWasGranted:
        return jsValueForDecodedArguments<Messages::WebPage::UserMediaAccessWasGranted::Arguments>(globalObject, decoder);
    case MessageName::WebPage_UserMediaAccessWasDenied:
        return jsValueForDecodedArguments<Messages::WebPage::UserMediaAccessWasDenied::Arguments>(globalObject, decoder);
    case MessageName::WebPage_CaptureDevicesChanged:
        return jsValueForDecodedArguments<Messages::WebPage::CaptureDevicesChanged::Arguments>(globalObject, decoder);
#endif
#if (ENABLE(MEDIA_STREAM) && USE(GSTREAMER))
    case MessageName::WebPage_SetOrientationForMediaCapture:
        return jsValueForDecodedArguments<Messages::WebPage::SetOrientationForMediaCapture::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetMockCaptureDevicesInterrupted:
        return jsValueForDecodedArguments<Messages::WebPage::SetMockCaptureDevicesInterrupted::Arguments>(globalObject, decoder);
#endif
#if ENABLE(ENCRYPTED_MEDIA)
    case MessageName::WebPage_MediaKeySystemWasGranted:
        return jsValueForDecodedArguments<Messages::WebPage::MediaKeySystemWasGranted::Arguments>(globalObject, decoder);
    case MessageName::WebPage_MediaKeySystemWasDenied:
        return jsValueForDecodedArguments<Messages::WebPage::MediaKeySystemWasDenied::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_RequestMediaPlaybackState:
        return jsValueForDecodedArguments<Messages::WebPage::RequestMediaPlaybackState::Arguments>(globalObject, decoder);
    case MessageName::WebPage_PauseAllMediaPlayback:
        return jsValueForDecodedArguments<Messages::WebPage::PauseAllMediaPlayback::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SuspendAllMediaPlayback:
        return jsValueForDecodedArguments<Messages::WebPage::SuspendAllMediaPlayback::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ResumeAllMediaPlayback:
        return jsValueForDecodedArguments<Messages::WebPage::ResumeAllMediaPlayback::Arguments>(globalObject, decoder);
    case MessageName::WebPage_FreezeLayerTreeDueToSwipeAnimation:
        return jsValueForDecodedArguments<Messages::WebPage::FreezeLayerTreeDueToSwipeAnimation::Arguments>(globalObject, decoder);
    case MessageName::WebPage_UnfreezeLayerTreeDueToSwipeAnimation:
        return jsValueForDecodedArguments<Messages::WebPage::UnfreezeLayerTreeDueToSwipeAnimation::Arguments>(globalObject, decoder);
    case MessageName::WebPage_IsLayerTreeFrozen:
        return jsValueForDecodedArguments<Messages::WebPage::IsLayerTreeFrozen::Arguments>(globalObject, decoder);
    case MessageName::WebPage_BeginPrinting:
        return jsValueForDecodedArguments<Messages::WebPage::BeginPrinting::Arguments>(globalObject, decoder);
    case MessageName::WebPage_EndPrinting:
        return jsValueForDecodedArguments<Messages::WebPage::EndPrinting::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ComputePagesForPrinting:
        return jsValueForDecodedArguments<Messages::WebPage::ComputePagesForPrinting::Arguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::WebPage_DrawRectToImage:
        return jsValueForDecodedArguments<Messages::WebPage::DrawRectToImage::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DrawPagesToPDF:
        return jsValueForDecodedArguments<Messages::WebPage::DrawPagesToPDF::Arguments>(globalObject, decoder);
#endif
#if (PLATFORM(COCOA) && PLATFORM(IOS_FAMILY) && !HAVE(UIKIT_BACKGROUND_THREAD_PRINTING))
    case MessageName::WebPage_ComputePagesForPrintingiOS:
        return jsValueForDecodedArguments<Messages::WebPage::ComputePagesForPrintingiOS::Arguments>(globalObject, decoder);
#endif
#if (PLATFORM(COCOA) && PLATFORM(IOS_FAMILY))
    case MessageName::WebPage_DrawToPDFiOS:
        return jsValueForDecodedArguments<Messages::WebPage::DrawToPDFiOS::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(COCOA)
    case MessageName::WebPage_DrawToPDF:
        return jsValueForDecodedArguments<Messages::WebPage::DrawToPDF::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(GTK)
    case MessageName::WebPage_DrawPagesForPrinting:
        return jsValueForDecodedArguments<Messages::WebPage::DrawPagesForPrinting::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_SetMediaVolume:
        return jsValueForDecodedArguments<Messages::WebPage::SetMediaVolume::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetMuted:
        return jsValueForDecodedArguments<Messages::WebPage::SetMuted::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetMayStartMediaWhenInWindow:
        return jsValueForDecodedArguments<Messages::WebPage::SetMayStartMediaWhenInWindow::Arguments>(globalObject, decoder);
    case MessageName::WebPage_StopMediaCapture:
        return jsValueForDecodedArguments<Messages::WebPage::StopMediaCapture::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetCanRunBeforeUnloadConfirmPanel:
        return jsValueForDecodedArguments<Messages::WebPage::SetCanRunBeforeUnloadConfirmPanel::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetCanRunModal:
        return jsValueForDecodedArguments<Messages::WebPage::SetCanRunModal::Arguments>(globalObject, decoder);
#if PLATFORM(GTK) || PLATFORM(WPE)
    case MessageName::WebPage_CancelComposition:
        return jsValueForDecodedArguments<Messages::WebPage::CancelComposition::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DeleteSurrounding:
        return jsValueForDecodedArguments<Messages::WebPage::DeleteSurrounding::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(GTK)
    case MessageName::WebPage_CollapseSelectionInFrame:
        return jsValueForDecodedArguments<Messages::WebPage::CollapseSelectionInFrame::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(COCOA)
    case MessageName::WebPage_WindowAndViewFramesChanged:
        return jsValueForDecodedArguments<Messages::WebPage::WindowAndViewFramesChanged::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetMainFrameIsScrollable:
        return jsValueForDecodedArguments<Messages::WebPage::SetMainFrameIsScrollable::Arguments>(globalObject, decoder);
    case MessageName::WebPage_RegisterUIProcessAccessibilityTokens:
        return jsValueForDecodedArguments<Messages::WebPage::RegisterUIProcessAccessibilityTokens::Arguments>(globalObject, decoder);
    case MessageName::WebPage_GetStringSelectionForPasteboard:
        return jsValueForDecodedArguments<Messages::WebPage::GetStringSelectionForPasteboard::Arguments>(globalObject, decoder);
    case MessageName::WebPage_GetDataSelectionForPasteboard:
        return jsValueForDecodedArguments<Messages::WebPage::GetDataSelectionForPasteboard::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ReadSelectionFromPasteboard:
        return jsValueForDecodedArguments<Messages::WebPage::ReadSelectionFromPasteboard::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ReplaceWithPasteboardData:
        return jsValueForDecodedArguments<Messages::WebPage::ReplaceWithPasteboardData::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ReplaceSelectionWithPasteboardData:
        return jsValueForDecodedArguments<Messages::WebPage::ReplaceSelectionWithPasteboardData::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ShouldDelayWindowOrderingEvent:
        return jsValueForDecodedArguments<Messages::WebPage::ShouldDelayWindowOrderingEvent::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetTextAsync:
        return jsValueForDecodedArguments<Messages::WebPage::SetTextAsync::Arguments>(globalObject, decoder);
    case MessageName::WebPage_InsertTextAsync:
        return jsValueForDecodedArguments<Messages::WebPage::InsertTextAsync::Arguments>(globalObject, decoder);
    case MessageName::WebPage_InsertDictatedTextAsync:
        return jsValueForDecodedArguments<Messages::WebPage::InsertDictatedTextAsync::Arguments>(globalObject, decoder);
    case MessageName::WebPage_HasMarkedText:
        return jsValueForDecodedArguments<Messages::WebPage::HasMarkedText::Arguments>(globalObject, decoder);
    case MessageName::WebPage_GetMarkedRangeAsync:
        return jsValueForDecodedArguments<Messages::WebPage::GetMarkedRangeAsync::Arguments>(globalObject, decoder);
    case MessageName::WebPage_GetSelectedRangeAsync:
        return jsValueForDecodedArguments<Messages::WebPage::GetSelectedRangeAsync::Arguments>(globalObject, decoder);
    case MessageName::WebPage_CharacterIndexForPointAsync:
        return jsValueForDecodedArguments<Messages::WebPage::CharacterIndexForPointAsync::Arguments>(globalObject, decoder);
    case MessageName::WebPage_FirstRectForCharacterRangeAsync:
        return jsValueForDecodedArguments<Messages::WebPage::FirstRectForCharacterRangeAsync::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetCompositionAsync:
        return jsValueForDecodedArguments<Messages::WebPage::SetCompositionAsync::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ConfirmCompositionAsync:
        return jsValueForDecodedArguments<Messages::WebPage::ConfirmCompositionAsync::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(MAC)
    case MessageName::WebPage_AttributedSubstringForCharacterRangeAsync:
        return jsValueForDecodedArguments<Messages::WebPage::AttributedSubstringForCharacterRangeAsync::Arguments>(globalObject, decoder);
    case MessageName::WebPage_RequestAcceptsFirstMouse:
        return jsValueForDecodedArguments<Messages::WebPage::RequestAcceptsFirstMouse::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_SetAlwaysShowsHorizontalScroller:
        return jsValueForDecodedArguments<Messages::WebPage::SetAlwaysShowsHorizontalScroller::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetAlwaysShowsVerticalScroller:
        return jsValueForDecodedArguments<Messages::WebPage::SetAlwaysShowsVerticalScroller::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetMinimumSizeForAutoLayout:
        return jsValueForDecodedArguments<Messages::WebPage::SetMinimumSizeForAutoLayout::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetSizeToContentAutoSizeMaximumSize:
        return jsValueForDecodedArguments<Messages::WebPage::SetSizeToContentAutoSizeMaximumSize::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetAutoSizingShouldExpandToViewHeight:
        return jsValueForDecodedArguments<Messages::WebPage::SetAutoSizingShouldExpandToViewHeight::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetViewportSizeForCSSViewportUnits:
        return jsValueForDecodedArguments<Messages::WebPage::SetViewportSizeForCSSViewportUnits::Arguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::WebPage_HandleAlternativeTextUIResult:
        return jsValueForDecodedArguments<Messages::WebPage::HandleAlternativeTextUIResult::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(IOS_FAMILY)
    case MessageName::WebPage_WillStartUserTriggeredZooming:
        return jsValueForDecodedArguments<Messages::WebPage::WillStartUserTriggeredZooming::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_SetScrollPinningBehavior:
        return jsValueForDecodedArguments<Messages::WebPage::SetScrollPinningBehavior::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetScrollbarOverlayStyle:
        return jsValueForDecodedArguments<Messages::WebPage::SetScrollbarOverlayStyle::Arguments>(globalObject, decoder);
    case MessageName::WebPage_GetBytecodeProfile:
        return jsValueForDecodedArguments<Messages::WebPage::GetBytecodeProfile::Arguments>(globalObject, decoder);
    case MessageName::WebPage_GetSamplingProfilerOutput:
        return jsValueForDecodedArguments<Messages::WebPage::GetSamplingProfilerOutput::Arguments>(globalObject, decoder);
    case MessageName::WebPage_TakeSnapshot:
        return jsValueForDecodedArguments<Messages::WebPage::TakeSnapshot::Arguments>(globalObject, decoder);
#if PLATFORM(MAC)
    case MessageName::WebPage_PerformImmediateActionHitTestAtLocation:
        return jsValueForDecodedArguments<Messages::WebPage::PerformImmediateActionHitTestAtLocation::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ImmediateActionDidUpdate:
        return jsValueForDecodedArguments<Messages::WebPage::ImmediateActionDidUpdate::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ImmediateActionDidCancel:
        return jsValueForDecodedArguments<Messages::WebPage::ImmediateActionDidCancel::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ImmediateActionDidComplete:
        return jsValueForDecodedArguments<Messages::WebPage::ImmediateActionDidComplete::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DataDetectorsDidPresentUI:
        return jsValueForDecodedArguments<Messages::WebPage::DataDetectorsDidPresentUI::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DataDetectorsDidChangeUI:
        return jsValueForDecodedArguments<Messages::WebPage::DataDetectorsDidChangeUI::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DataDetectorsDidHideUI:
        return jsValueForDecodedArguments<Messages::WebPage::DataDetectorsDidHideUI::Arguments>(globalObject, decoder);
    case MessageName::WebPage_HandleAcceptedCandidate:
        return jsValueForDecodedArguments<Messages::WebPage::HandleAcceptedCandidate::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetUseSystemAppearance:
        return jsValueForDecodedArguments<Messages::WebPage::SetUseSystemAppearance::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetHeaderBannerHeightForTesting:
        return jsValueForDecodedArguments<Messages::WebPage::SetHeaderBannerHeightForTesting::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetFooterBannerHeightForTesting:
        return jsValueForDecodedArguments<Messages::WebPage::SetFooterBannerHeightForTesting::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DidEndMagnificationGesture:
        return jsValueForDecodedArguments<Messages::WebPage::DidEndMagnificationGesture::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_EffectiveAppearanceDidChange:
        return jsValueForDecodedArguments<Messages::WebPage::EffectiveAppearanceDidChange::Arguments>(globalObject, decoder);
#if HAVE(APP_ACCENT_COLORS)
    case MessageName::WebPage_SetAccentColor:
        return jsValueForDecodedArguments<Messages::WebPage::SetAccentColor::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(COCOA)
    case MessageName::WebPage_RequestActiveNowPlayingSessionInfo:
        return jsValueForDecodedArguments<Messages::WebPage::RequestActiveNowPlayingSessionInfo::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_SetShouldDispatchFakeMouseMoveEvents:
        return jsValueForDecodedArguments<Messages::WebPage::SetShouldDispatchFakeMouseMoveEvents::Arguments>(globalObject, decoder);
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    case MessageName::WebPage_PlaybackTargetSelected:
        return jsValueForDecodedArguments<Messages::WebPage::PlaybackTargetSelected::Arguments>(globalObject, decoder);
    case MessageName::WebPage_PlaybackTargetAvailabilityDidChange:
        return jsValueForDecodedArguments<Messages::WebPage::PlaybackTargetAvailabilityDidChange::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetShouldPlayToPlaybackTarget:
        return jsValueForDecodedArguments<Messages::WebPage::SetShouldPlayToPlaybackTarget::Arguments>(globalObject, decoder);
    case MessageName::WebPage_PlaybackTargetPickerWasDismissed:
        return jsValueForDecodedArguments<Messages::WebPage::PlaybackTargetPickerWasDismissed::Arguments>(globalObject, decoder);
#endif
#if ENABLE(POINTER_LOCK)
    case MessageName::WebPage_DidAcquirePointerLock:
        return jsValueForDecodedArguments<Messages::WebPage::DidAcquirePointerLock::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DidNotAcquirePointerLock:
        return jsValueForDecodedArguments<Messages::WebPage::DidNotAcquirePointerLock::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DidLosePointerLock:
        return jsValueForDecodedArguments<Messages::WebPage::DidLosePointerLock::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_ClearWheelEventTestMonitor:
        return jsValueForDecodedArguments<Messages::WebPage::ClearWheelEventTestMonitor::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetShouldScaleViewToFitDocument:
        return jsValueForDecodedArguments<Messages::WebPage::SetShouldScaleViewToFitDocument::Arguments>(globalObject, decoder);
#if ENABLE(VIDEO) && USE(GSTREAMER)
    case MessageName::WebPage_DidEndRequestInstallMissingMediaPlugins:
        return jsValueForDecodedArguments<Messages::WebPage::DidEndRequestInstallMissingMediaPlugins::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_SetUserInterfaceLayoutDirection:
        return jsValueForDecodedArguments<Messages::WebPage::SetUserInterfaceLayoutDirection::Arguments>(globalObject, decoder);
    case MessageName::WebPage_DidGetLoadDecisionForIcon:
        return jsValueForDecodedArguments<Messages::WebPage::DidGetLoadDecisionForIcon::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetUseIconLoadingClient:
        return jsValueForDecodedArguments<Messages::WebPage::SetUseIconLoadingClient::Arguments>(globalObject, decoder);
#if ENABLE(GAMEPAD)
    case MessageName::WebPage_GamepadActivity:
        return jsValueForDecodedArguments<Messages::WebPage::GamepadActivity::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_FrameBecameRemote:
        return jsValueForDecodedArguments<Messages::WebPage::FrameBecameRemote::Arguments>(globalObject, decoder);
    case MessageName::WebPage_RegisterURLSchemeHandler:
        return jsValueForDecodedArguments<Messages::WebPage::RegisterURLSchemeHandler::Arguments>(globalObject, decoder);
    case MessageName::WebPage_URLSchemeTaskWillPerformRedirection:
        return jsValueForDecodedArguments<Messages::WebPage::URLSchemeTaskWillPerformRedirection::Arguments>(globalObject, decoder);
    case MessageName::WebPage_URLSchemeTaskDidPerformRedirection:
        return jsValueForDecodedArguments<Messages::WebPage::URLSchemeTaskDidPerformRedirection::Arguments>(globalObject, decoder);
    case MessageName::WebPage_URLSchemeTaskDidReceiveResponse:
        return jsValueForDecodedArguments<Messages::WebPage::URLSchemeTaskDidReceiveResponse::Arguments>(globalObject, decoder);
    case MessageName::WebPage_URLSchemeTaskDidReceiveData:
        return jsValueForDecodedArguments<Messages::WebPage::URLSchemeTaskDidReceiveData::Arguments>(globalObject, decoder);
    case MessageName::WebPage_URLSchemeTaskDidComplete:
        return jsValueForDecodedArguments<Messages::WebPage::URLSchemeTaskDidComplete::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetIsSuspended:
        return jsValueForDecodedArguments<Messages::WebPage::SetIsSuspended::Arguments>(globalObject, decoder);
#if ENABLE(ATTACHMENT_ELEMENT)
    case MessageName::WebPage_InsertAttachment:
        return jsValueForDecodedArguments<Messages::WebPage::InsertAttachment::Arguments>(globalObject, decoder);
    case MessageName::WebPage_UpdateAttachmentAttributes:
        return jsValueForDecodedArguments<Messages::WebPage::UpdateAttachmentAttributes::Arguments>(globalObject, decoder);
    case MessageName::WebPage_UpdateAttachmentThumbnail:
        return jsValueForDecodedArguments<Messages::WebPage::UpdateAttachmentThumbnail::Arguments>(globalObject, decoder);
    case MessageName::WebPage_UpdateAttachmentIcon:
        return jsValueForDecodedArguments<Messages::WebPage::UpdateAttachmentIcon::Arguments>(globalObject, decoder);
#endif
#if ENABLE(APPLICATION_MANIFEST)
    case MessageName::WebPage_GetApplicationManifest:
        return jsValueForDecodedArguments<Messages::WebPage::GetApplicationManifest::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_SetDefersLoading:
        return jsValueForDecodedArguments<Messages::WebPage::SetDefersLoading::Arguments>(globalObject, decoder);
#if ENABLE(UI_PROCESS_PDF_HUD)
    case MessageName::WebPage_ZoomPDFIn:
        return jsValueForDecodedArguments<Messages::WebPage::ZoomPDFIn::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ZoomPDFOut:
        return jsValueForDecodedArguments<Messages::WebPage::ZoomPDFOut::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SavePDF:
        return jsValueForDecodedArguments<Messages::WebPage::SavePDF::Arguments>(globalObject, decoder);
    case MessageName::WebPage_OpenPDFWithPreview:
        return jsValueForDecodedArguments<Messages::WebPage::OpenPDFWithPreview::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_UpdateCurrentModifierState:
        return jsValueForDecodedArguments<Messages::WebPage::UpdateCurrentModifierState::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SimulateDeviceOrientationChange:
        return jsValueForDecodedArguments<Messages::WebPage::SimulateDeviceOrientationChange::Arguments>(globalObject, decoder);
#if ENABLE(SPEECH_SYNTHESIS)
    case MessageName::WebPage_SpeakingErrorOccurred:
        return jsValueForDecodedArguments<Messages::WebPage::SpeakingErrorOccurred::Arguments>(globalObject, decoder);
    case MessageName::WebPage_BoundaryEventOccurred:
        return jsValueForDecodedArguments<Messages::WebPage::BoundaryEventOccurred::Arguments>(globalObject, decoder);
    case MessageName::WebPage_VoicesDidChange:
        return jsValueForDecodedArguments<Messages::WebPage::VoicesDidChange::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_SetCanShowPlaceholder:
        return jsValueForDecodedArguments<Messages::WebPage::SetCanShowPlaceholder::Arguments>(globalObject, decoder);
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
    case MessageName::WebPage_WasLoadedWithDataTransferFromPrevalentResource:
        return jsValueForDecodedArguments<Messages::WebPage::WasLoadedWithDataTransferFromPrevalentResource::Arguments>(globalObject, decoder);
    case MessageName::WebPage_ClearLoadedSubresourceDomains:
        return jsValueForDecodedArguments<Messages::WebPage::ClearLoadedSubresourceDomains::Arguments>(globalObject, decoder);
    case MessageName::WebPage_GetLoadedSubresourceDomains:
        return jsValueForDecodedArguments<Messages::WebPage::GetLoadedSubresourceDomains::Arguments>(globalObject, decoder);
#endif
#if USE(SYSTEM_PREVIEW)
    case MessageName::WebPage_SystemPreviewActionTriggered:
        return jsValueForDecodedArguments<Messages::WebPage::SystemPreviewActionTriggered::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    case MessageName::WebPage_SendMessageToWebExtension:
        return jsValueForDecodedArguments<Messages::WebPage::SendMessageToWebExtension::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SendMessageToWebExtensionWithReply:
        return jsValueForDecodedArguments<Messages::WebPage::SendMessageToWebExtensionWithReply::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_StartTextManipulations:
        return jsValueForDecodedArguments<Messages::WebPage::StartTextManipulations::Arguments>(globalObject, decoder);
    case MessageName::WebPage_CompleteTextManipulation:
        return jsValueForDecodedArguments<Messages::WebPage::CompleteTextManipulation::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetOverriddenMediaType:
        return jsValueForDecodedArguments<Messages::WebPage::SetOverriddenMediaType::Arguments>(globalObject, decoder);
    case MessageName::WebPage_GetProcessDisplayName:
        return jsValueForDecodedArguments<Messages::WebPage::GetProcessDisplayName::Arguments>(globalObject, decoder);
    case MessageName::WebPage_UpdateCORSDisablingPatterns:
        return jsValueForDecodedArguments<Messages::WebPage::UpdateCORSDisablingPatterns::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetIsTakingSnapshotsForApplicationSuspension:
        return jsValueForDecodedArguments<Messages::WebPage::SetIsTakingSnapshotsForApplicationSuspension::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetNeedsDOMWindowResizeEvent:
        return jsValueForDecodedArguments<Messages::WebPage::SetNeedsDOMWindowResizeEvent::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetHasResourceLoadClient:
        return jsValueForDecodedArguments<Messages::WebPage::SetHasResourceLoadClient::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetCanUseCredentialStorage:
        return jsValueForDecodedArguments<Messages::WebPage::SetCanUseCredentialStorage::Arguments>(globalObject, decoder);
#if ENABLE(APP_HIGHLIGHTS)
    case MessageName::WebPage_CreateAppHighlightInSelectedRange:
        return jsValueForDecodedArguments<Messages::WebPage::CreateAppHighlightInSelectedRange::Arguments>(globalObject, decoder);
    case MessageName::WebPage_RestoreAppHighlightsAndScrollToIndex:
        return jsValueForDecodedArguments<Messages::WebPage::RestoreAppHighlightsAndScrollToIndex::Arguments>(globalObject, decoder);
    case MessageName::WebPage_SetAppHighlightsVisibility:
        return jsValueForDecodedArguments<Messages::WebPage::SetAppHighlightsVisibility::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_DispatchWheelEventWithoutScrolling:
        return jsValueForDecodedArguments<Messages::WebPage::DispatchWheelEventWithoutScrolling::Arguments>(globalObject, decoder);
    case MessageName::WebPage_LastNavigationWasAppInitiated:
        return jsValueForDecodedArguments<Messages::WebPage::LastNavigationWasAppInitiated::Arguments>(globalObject, decoder);
#if ENABLE(MEDIA_SESSION_COORDINATOR)
    case MessageName::WebPage_CreateMediaSessionCoordinator:
        return jsValueForDecodedArguments<Messages::WebPage::CreateMediaSessionCoordinator::Arguments>(globalObject, decoder);
    case MessageName::WebPage_InvalidateMediaSessionCoordinator:
        return jsValueForDecodedArguments<Messages::WebPage::InvalidateMediaSessionCoordinator::Arguments>(globalObject, decoder);
#endif
#if ENABLE(IMAGE_ANALYSIS)
    case MessageName::WebPage_UpdateWithTextRecognitionResult:
        return jsValueForDecodedArguments<Messages::WebPage::UpdateWithTextRecognitionResult::Arguments>(globalObject, decoder);
    case MessageName::WebPage_StartImageAnalysis:
        return jsValueForDecodedArguments<Messages::WebPage::StartImageAnalysis::Arguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_ScrollToRect:
        return jsValueForDecodedArguments<Messages::WebPage::ScrollToRect::Arguments>(globalObject, decoder);
    case MessageName::WebPage_InteractableRegionsInRootViewCoordinates:
        return jsValueForDecodedArguments<Messages::WebPage::InteractableRegionsInRootViewCoordinates::Arguments>(globalObject, decoder);
    case MessageName::StorageAreaMap_DispatchStorageEvent:
        return jsValueForDecodedArguments<Messages::StorageAreaMap::DispatchStorageEvent::Arguments>(globalObject, decoder);
    case MessageName::StorageAreaMap_ClearCache:
        return jsValueForDecodedArguments<Messages::StorageAreaMap::ClearCache::Arguments>(globalObject, decoder);
#if ENABLE(WEBXR)
    case MessageName::PlatformXRSystemProxy_SessionDidEnd:
        return jsValueForDecodedArguments<Messages::PlatformXRSystemProxy::SessionDidEnd::Arguments>(globalObject, decoder);
    case MessageName::PlatformXRSystemProxy_SessionDidUpdateVisibilityState:
        return jsValueForDecodedArguments<Messages::PlatformXRSystemProxy::SessionDidUpdateVisibilityState::Arguments>(globalObject, decoder);
#endif
#if PLATFORM(MAC)
    case MessageName::ViewGestureController_DidCollectGeometryForSmartMagnificationGesture:
        return jsValueForDecodedArguments<Messages::ViewGestureController::DidCollectGeometryForSmartMagnificationGesture::Arguments>(globalObject, decoder);
#endif
#if !PLATFORM(IOS_FAMILY)
    case MessageName::ViewGestureController_DidCollectGeometryForMagnificationGesture:
        return jsValueForDecodedArguments<Messages::ViewGestureController::DidCollectGeometryForMagnificationGesture::Arguments>(globalObject, decoder);
    case MessageName::ViewGestureController_DidHitRenderTreeSizeThreshold:
        return jsValueForDecodedArguments<Messages::ViewGestureController::DidHitRenderTreeSizeThreshold::Arguments>(globalObject, decoder);
#endif
    case MessageName::GtkSettingsManagerProxy_SettingsDidChange:
        return jsValueForDecodedArguments<Messages::GtkSettingsManagerProxy::SettingsDidChange::Arguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::ViewGestureGeometryCollector_CollectGeometryForSmartMagnificationGesture:
        return jsValueForDecodedArguments<Messages::ViewGestureGeometryCollector::CollectGeometryForSmartMagnificationGesture::Arguments>(globalObject, decoder);
#endif
#if !PLATFORM(IOS_FAMILY)
    case MessageName::ViewGestureGeometryCollector_CollectGeometryForMagnificationGesture:
        return jsValueForDecodedArguments<Messages::ViewGestureGeometryCollector::CollectGeometryForMagnificationGesture::Arguments>(globalObject, decoder);
    case MessageName::ViewGestureGeometryCollector_SetRenderTreeSizeNotificationThreshold:
        return jsValueForDecodedArguments<Messages::ViewGestureGeometryCollector::SetRenderTreeSizeNotificationThreshold::Arguments>(globalObject, decoder);
#endif
    default:
        break;
    }
    return std::nullopt;
}

std::optional<JSC::JSValue> jsValueForReplyArguments(JSC::JSGlobalObject* globalObject, MessageName name, Decoder& decoder)
{
    switch (name) {
#if ENABLE(GPU_PROCESS)
#if USE(AUDIO_SESSION)
    case MessageName::GPUConnectionToWebProcess_EnsureAudioSession:
        return jsValueForDecodedArguments<Messages::GPUConnectionToWebProcess::EnsureAudioSession::ReplyArguments>(globalObject, decoder);
#endif
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::GPUProcess_CreateGPUConnectionToWebProcess:
        return jsValueForDecodedArguments<Messages::GPUProcess::CreateGPUConnectionToWebProcess::ReplyArguments>(globalObject, decoder);
    case MessageName::GPUProcess_PrepareToSuspend:
        return jsValueForDecodedArguments<Messages::GPUProcess::PrepareToSuspend::ReplyArguments>(globalObject, decoder);
#if ENABLE(MEDIA_STREAM)
    case MessageName::GPUProcess_UpdateCaptureAccess:
        return jsValueForDecodedArguments<Messages::GPUProcess::UpdateCaptureAccess::ReplyArguments>(globalObject, decoder);
#endif
#if HAVE(SC_CONTENT_SHARING_SESSION)
    case MessageName::GPUProcess_ShowWindowPicker:
        return jsValueForDecodedArguments<Messages::GPUProcess::ShowWindowPicker::ReplyArguments>(globalObject, decoder);
    case MessageName::GPUProcess_ShowScreenPicker:
        return jsValueForDecodedArguments<Messages::GPUProcess::ShowScreenPicker::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::GPUProcess_RequestBitmapImageForCurrentTime:
        return jsValueForDecodedArguments<Messages::GPUProcess::RequestBitmapImageForCurrentTime::ReplyArguments>(globalObject, decoder);
    case MessageName::GPUProcess_WebProcessConnectionCountForTesting:
        return jsValueForDecodedArguments<Messages::GPUProcess::WebProcessConnectionCountForTesting::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(WEBGL)
#if PLATFORM(COCOA)
    case MessageName::RemoteGraphicsContextGL_PrepareForDisplay:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::PrepareForDisplay::ReplyArguments>(globalObject, decoder);
#endif
#if USE(GRAPHICS_LAYER_WC)
    case MessageName::RemoteGraphicsContextGL_PrepareForDisplay:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::PrepareForDisplay::ReplyArguments>(globalObject, decoder);
#endif
#if !PLATFORM(COCOA) && !USE(GRAPHICS_LAYER_WC)
    case MessageName::RemoteGraphicsContextGL_PrepareForDisplay:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::PrepareForDisplay::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::RemoteGraphicsContextGL_GetError:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetError::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_PaintRenderingResultsToCanvas:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::PaintRenderingResultsToCanvas::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_PaintCompositedResultsToCanvas:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::PaintCompositedResultsToCanvas::ReplyArguments>(globalObject, decoder);
#if ENABLE(VIDEO)
    case MessageName::RemoteGraphicsContextGL_CopyTextureFromVideoFrame:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CopyTextureFromVideoFrame::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(MEDIA_STREAM)
    case MessageName::RemoteGraphicsContextGL_PaintCompositedResultsToMediaSample:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::PaintCompositedResultsToMediaSample::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::RemoteGraphicsContextGL_MoveErrorsToSyntheticErrorList:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::MoveErrorsToSyntheticErrorList::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CheckFramebufferStatus:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CheckFramebufferStatus::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CreateBuffer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CreateBuffer::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CreateFramebuffer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CreateFramebuffer::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CreateProgram:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CreateProgram::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CreateRenderbuffer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CreateRenderbuffer::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CreateShader:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CreateShader::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CreateTexture:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CreateTexture::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetActiveAttrib:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetActiveAttrib::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetActiveUniform:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetActiveUniform::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetAttribLocation:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetAttribLocation::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetBufferParameteri:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetBufferParameteri::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetString:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetString::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetFloatv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetFloatv::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetIntegerv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetIntegerv::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetInteger64:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetInteger64::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetInteger64i:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetInteger64i::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetProgrami:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetProgrami::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetBooleanv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetBooleanv::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetFramebufferAttachmentParameteri:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetFramebufferAttachmentParameteri::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetProgramInfoLog:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetProgramInfoLog::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetRenderbufferParameteri:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetRenderbufferParameteri::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetShaderi:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetShaderi::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetShaderInfoLog:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetShaderInfoLog::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetShaderPrecisionFormat:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetShaderPrecisionFormat::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetShaderSource:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetShaderSource::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetTexParameterf:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetTexParameterf::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetTexParameteri:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetTexParameteri::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetUniformfv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetUniformfv::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetUniformiv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetUniformiv::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetUniformuiv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetUniformuiv::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetUniformLocation:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetUniformLocation::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetVertexAttribOffset:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetVertexAttribOffset::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_IsBuffer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::IsBuffer::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_IsEnabled:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::IsEnabled::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_IsFramebuffer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::IsFramebuffer::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_IsProgram:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::IsProgram::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_IsRenderbuffer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::IsRenderbuffer::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_IsShader:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::IsShader::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_IsTexture:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::IsTexture::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_ReadnPixels0:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::ReadnPixels0::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CreateVertexArray:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CreateVertexArray::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_IsVertexArray:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::IsVertexArray::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetBufferSubData:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetBufferSubData::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetFragDataLocation:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetFragDataLocation::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CreateQuery:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CreateQuery::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_IsQuery:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::IsQuery::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetQuery:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetQuery::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetQueryObjectui:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetQueryObjectui::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CreateSampler:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CreateSampler::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_IsSampler:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::IsSampler::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetSamplerParameterf:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetSamplerParameterf::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetSamplerParameteri:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetSamplerParameteri::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_FenceSync:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::FenceSync::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_IsSync:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::IsSync::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_ClientWaitSync:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::ClientWaitSync::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetSynci:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetSynci::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_CreateTransformFeedback:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::CreateTransformFeedback::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_IsTransformFeedback:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::IsTransformFeedback::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetTransformFeedbackVarying:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetTransformFeedbackVarying::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetUniformIndices:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetUniformIndices::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetActiveUniforms:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetActiveUniforms::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetUniformBlockIndex:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetUniformBlockIndex::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetActiveUniformBlockName:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetActiveUniformBlockName::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetActiveUniformBlockiv:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetActiveUniformBlockiv::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetGraphicsResetStatusARB:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetGraphicsResetStatusARB::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetTranslatedShaderSourceANGLE:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetTranslatedShaderSourceANGLE::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_GetInternalformativ:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::GetInternalformativ::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteGraphicsContextGL_PaintRenderingResultsToPixelBuffer:
        return jsValueForDecodedArguments<Messages::RemoteGraphicsContextGL::PaintRenderingResultsToPixelBuffer::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteRenderingBackend_GetPixelBufferForImageBuffer:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::GetPixelBufferForImageBuffer::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackend_GetPixelBufferForImageBufferWithNewMemory:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::GetPixelBufferForImageBufferWithNewMemory::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackend_GetDataURLForImageBuffer:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::GetDataURLForImageBuffer::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackend_GetDataForImageBuffer:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::GetDataForImageBuffer::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackend_GetShareableBitmapForImageBuffer:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::GetShareableBitmapForImageBuffer::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackend_GetFilteredImageForImageBuffer:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::GetFilteredImageForImageBuffer::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackend_MarkSurfaceNonVolatile:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::MarkSurfaceNonVolatile::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackend_SwapToValidFrontBuffer:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::SwapToValidFrontBuffer::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteRenderingBackend_MarkSurfacesVolatile:
        return jsValueForDecodedArguments<Messages::RemoteRenderingBackend::MarkSurfacesVolatile::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteAdapter_RequestDevice:
        return jsValueForDecodedArguments<Messages::RemoteAdapter::RequestDevice::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteBuffer_MapAsync:
        return jsValueForDecodedArguments<Messages::RemoteBuffer::MapAsync::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteDevice_CreateComputePipelineAsync:
        return jsValueForDecodedArguments<Messages::RemoteDevice::CreateComputePipelineAsync::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteDevice_CreateRenderPipelineAsync:
        return jsValueForDecodedArguments<Messages::RemoteDevice::CreateRenderPipelineAsync::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteDevice_PopErrorScope:
        return jsValueForDecodedArguments<Messages::RemoteDevice::PopErrorScope::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteGPU_RequestAdapter:
        return jsValueForDecodedArguments<Messages::RemoteGPU::RequestAdapter::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteQueue_OnSubmittedWorkDone:
        return jsValueForDecodedArguments<Messages::RemoteQueue::OnSubmittedWorkDone::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteShaderModule_CompilationInfo:
        return jsValueForDecodedArguments<Messages::RemoteShaderModule::CompilationInfo::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(WEB_AUDIO)
    case MessageName::RemoteAudioDestinationManager_CreateAudioDestination:
        return jsValueForDecodedArguments<Messages::RemoteAudioDestinationManager::CreateAudioDestination::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteAudioDestinationManager_DeleteAudioDestination:
        return jsValueForDecodedArguments<Messages::RemoteAudioDestinationManager::DeleteAudioDestination::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteAudioDestinationManager_StartAudioDestination:
        return jsValueForDecodedArguments<Messages::RemoteAudioDestinationManager::StartAudioDestination::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteAudioDestinationManager_StopAudioDestination:
        return jsValueForDecodedArguments<Messages::RemoteAudioDestinationManager::StopAudioDestination::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && USE(AUDIO_SESSION)
    case MessageName::RemoteAudioSessionProxy_TryToSetActive:
        return jsValueForDecodedArguments<Messages::RemoteAudioSessionProxy::TryToSetActive::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
    case MessageName::RemoteCDMFactoryProxy_CreateCDM:
        return jsValueForDecodedArguments<Messages::RemoteCDMFactoryProxy::CreateCDM::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteCDMFactoryProxy_SupportsKeySystem:
        return jsValueForDecodedArguments<Messages::RemoteCDMFactoryProxy::SupportsKeySystem::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
    case MessageName::RemoteCDMInstanceProxy_CreateSession:
        return jsValueForDecodedArguments<Messages::RemoteCDMInstanceProxy::CreateSession::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteCDMInstanceProxy_InitializeWithConfiguration:
        return jsValueForDecodedArguments<Messages::RemoteCDMInstanceProxy::InitializeWithConfiguration::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteCDMInstanceProxy_SetServerCertificate:
        return jsValueForDecodedArguments<Messages::RemoteCDMInstanceProxy::SetServerCertificate::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
    case MessageName::RemoteCDMInstanceSessionProxy_RequestLicense:
        return jsValueForDecodedArguments<Messages::RemoteCDMInstanceSessionProxy::RequestLicense::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteCDMInstanceSessionProxy_UpdateLicense:
        return jsValueForDecodedArguments<Messages::RemoteCDMInstanceSessionProxy::UpdateLicense::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteCDMInstanceSessionProxy_LoadSession:
        return jsValueForDecodedArguments<Messages::RemoteCDMInstanceSessionProxy::LoadSession::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteCDMInstanceSessionProxy_CloseSession:
        return jsValueForDecodedArguments<Messages::RemoteCDMInstanceSessionProxy::CloseSession::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteCDMInstanceSessionProxy_RemoveSessionData:
        return jsValueForDecodedArguments<Messages::RemoteCDMInstanceSessionProxy::RemoveSessionData::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
    case MessageName::RemoteCDMProxy_GetSupportedConfiguration:
        return jsValueForDecodedArguments<Messages::RemoteCDMProxy::GetSupportedConfiguration::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteCDMProxy_CreateInstance:
        return jsValueForDecodedArguments<Messages::RemoteCDMProxy::CreateInstance::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(LEGACY_ENCRYPTED_MEDIA)
    case MessageName::RemoteLegacyCDMFactoryProxy_CreateCDM:
        return jsValueForDecodedArguments<Messages::RemoteLegacyCDMFactoryProxy::CreateCDM::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteLegacyCDMFactoryProxy_SupportsKeySystem:
        return jsValueForDecodedArguments<Messages::RemoteLegacyCDMFactoryProxy::SupportsKeySystem::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(LEGACY_ENCRYPTED_MEDIA)
    case MessageName::RemoteLegacyCDMProxy_SupportsMIMEType:
        return jsValueForDecodedArguments<Messages::RemoteLegacyCDMProxy::SupportsMIMEType::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteLegacyCDMProxy_CreateSession:
        return jsValueForDecodedArguments<Messages::RemoteLegacyCDMProxy::CreateSession::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(LEGACY_ENCRYPTED_MEDIA)
    case MessageName::RemoteLegacyCDMSessionProxy_GenerateKeyRequest:
        return jsValueForDecodedArguments<Messages::RemoteLegacyCDMSessionProxy::GenerateKeyRequest::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteLegacyCDMSessionProxy_Update:
        return jsValueForDecodedArguments<Messages::RemoteLegacyCDMSessionProxy::Update::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteLegacyCDMSessionProxy_CachedKeyForKeyID:
        return jsValueForDecodedArguments<Messages::RemoteLegacyCDMSessionProxy::CachedKeyForKeyID::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteMediaEngineConfigurationFactoryProxy_CreateDecodingConfiguration:
        return jsValueForDecodedArguments<Messages::RemoteMediaEngineConfigurationFactoryProxy::CreateDecodingConfiguration::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteMediaEngineConfigurationFactoryProxy_CreateEncodingConfiguration:
        return jsValueForDecodedArguments<Messages::RemoteMediaEngineConfigurationFactoryProxy::CreateEncodingConfiguration::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteMediaPlayerManagerProxy_GetSupportedTypes:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerManagerProxy::GetSupportedTypes::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerManagerProxy_SupportsTypeAndCodecs:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerManagerProxy::SupportsTypeAndCodecs::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerManagerProxy_OriginsInMediaCache:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerManagerProxy::OriginsInMediaCache::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerManagerProxy_SupportsKeySystem:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerManagerProxy::SupportsKeySystem::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteMediaPlayerProxy_PrepareForPlayback:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::PrepareForPlayback::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_Load:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::Load::ReplyArguments>(globalObject, decoder);
#if ENABLE(MEDIA_SOURCE)
    case MessageName::RemoteMediaPlayerProxy_LoadMediaSource:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::LoadMediaSource::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::RemoteMediaPlayerProxy_DidLoadingProgress:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::DidLoadingProgress::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_PerformTaskAtMediaTime:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::PerformTaskAtMediaTime::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_WouldTaintOrigin:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::WouldTaintOrigin::ReplyArguments>(globalObject, decoder);
#if PLATFORM(IOS_FAMILY)
    case MessageName::RemoteMediaPlayerProxy_ErrorLog:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::ErrorLog::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_AccessLog:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::AccessLog::ReplyArguments>(globalObject, decoder);
#endif
#if PLATFORM(COCOA)
    case MessageName::RemoteMediaPlayerProxy_NativeImageForCurrentTime:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::NativeImageForCurrentTime::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteMediaPlayerProxy_ColorSpace:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::ColorSpace::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::RemoteMediaPlayerProxy_VideoFrameForCurrentTimeIfChanged:
        return jsValueForDecodedArguments<Messages::RemoteMediaPlayerProxy::VideoFrameForCurrentTimeIfChanged::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteMediaResourceManager_ResponseReceived:
        return jsValueForDecodedArguments<Messages::RemoteMediaResourceManager::ResponseReceived::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteMediaResourceManager_RedirectReceived:
        return jsValueForDecodedArguments<Messages::RemoteMediaResourceManager::RedirectReceived::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)
    case MessageName::RemoteMediaSourceProxy_AddSourceBuffer:
        return jsValueForDecodedArguments<Messages::RemoteMediaSourceProxy::AddSourceBuffer::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)
    case MessageName::RemoteSourceBufferProxy_CanSwitchToType:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::CanSwitchToType::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_UpdateBufferedFromTrackBuffers:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::UpdateBufferedFromTrackBuffers::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_RemoveCodedFrames:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::RemoveCodedFrames::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_EvictCodedFrames:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::EvictCodedFrames::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_BufferedSamplesForTrackId:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::BufferedSamplesForTrackId::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteSourceBufferProxy_EnqueuedSamplesForTrackID:
        return jsValueForDecodedArguments<Messages::RemoteSourceBufferProxy::EnqueuedSamplesForTrackID::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(VIDEO)
#endif
#if USE(LIBWEBRTC) && PLATFORM(COCOA) && ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
    case MessageName::RemoteAudioMediaStreamTrackRendererInternalUnitManager_CreateUnit:
        return jsValueForDecodedArguments<Messages::RemoteAudioMediaStreamTrackRendererInternalUnitManager::CreateUnit::ReplyArguments>(globalObject, decoder);
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
    case MessageName::RemoteMediaRecorder_FetchData:
        return jsValueForDecodedArguments<Messages::RemoteMediaRecorder::FetchData::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteMediaRecorder_StopRecording:
        return jsValueForDecodedArguments<Messages::RemoteMediaRecorder::StopRecording::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteMediaRecorder_Pause:
        return jsValueForDecodedArguments<Messages::RemoteMediaRecorder::Pause::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteMediaRecorder_Resume:
        return jsValueForDecodedArguments<Messages::RemoteMediaRecorder::Resume::ReplyArguments>(globalObject, decoder);
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
    case MessageName::RemoteMediaRecorderManager_CreateRecorder:
        return jsValueForDecodedArguments<Messages::RemoteMediaRecorderManager::CreateRecorder::ReplyArguments>(globalObject, decoder);
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
    case MessageName::RemoteSampleBufferDisplayLayerManager_CreateLayer:
        return jsValueForDecodedArguments<Messages::RemoteSampleBufferDisplayLayerManager::CreateLayer::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebCookieManager_GetHostnamesWithCookies:
        return jsValueForDecodedArguments<Messages::WebCookieManager::GetHostnamesWithCookies::ReplyArguments>(globalObject, decoder);
    case MessageName::WebCookieManager_SetCookie:
        return jsValueForDecodedArguments<Messages::WebCookieManager::SetCookie::ReplyArguments>(globalObject, decoder);
    case MessageName::WebCookieManager_SetCookies:
        return jsValueForDecodedArguments<Messages::WebCookieManager::SetCookies::ReplyArguments>(globalObject, decoder);
    case MessageName::WebCookieManager_GetAllCookies:
        return jsValueForDecodedArguments<Messages::WebCookieManager::GetAllCookies::ReplyArguments>(globalObject, decoder);
    case MessageName::WebCookieManager_GetCookies:
        return jsValueForDecodedArguments<Messages::WebCookieManager::GetCookies::ReplyArguments>(globalObject, decoder);
    case MessageName::WebCookieManager_DeleteCookie:
        return jsValueForDecodedArguments<Messages::WebCookieManager::DeleteCookie::ReplyArguments>(globalObject, decoder);
    case MessageName::WebCookieManager_DeleteAllCookiesModifiedSince:
        return jsValueForDecodedArguments<Messages::WebCookieManager::DeleteAllCookiesModifiedSince::ReplyArguments>(globalObject, decoder);
    case MessageName::WebCookieManager_SetHTTPCookieAcceptPolicy:
        return jsValueForDecodedArguments<Messages::WebCookieManager::SetHTTPCookieAcceptPolicy::ReplyArguments>(globalObject, decoder);
    case MessageName::WebCookieManager_GetHTTPCookieAcceptPolicy:
        return jsValueForDecodedArguments<Messages::WebCookieManager::GetHTTPCookieAcceptPolicy::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkBroadcastChannelRegistry_PostMessage:
        return jsValueForDecodedArguments<Messages::NetworkBroadcastChannelRegistry::PostMessage::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_PerformSynchronousLoad:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::PerformSynchronousLoad::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_TestProcessIncomingSyncMessagesWhenWaitingForSyncReply:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::TestProcessIncomingSyncMessagesWhenWaitingForSyncReply::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_SendH2Ping:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::SendH2Ping::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_IsResourceLoadFinished:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::IsResourceLoadFinished::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_CookiesForDOM:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::CookiesForDOM::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_CookieRequestHeaderFieldValue:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::CookieRequestHeaderFieldValue::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_GetRawCookies:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::GetRawCookies::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_DomCookiesForHost:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::DomCookiesForHost::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_BlobSize:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::BlobSize::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_WriteBlobsToTemporaryFilesForIndexedDB:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::WriteBlobsToTemporaryFilesForIndexedDB::ReplyArguments>(globalObject, decoder);
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
    case MessageName::NetworkConnectionToWebProcess_ResourceLoadStatisticsUpdated:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::ResourceLoadStatisticsUpdated::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_HasStorageAccess:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::HasStorageAccess::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_RequestStorageAccess:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::RequestStorageAccess::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::NetworkConnectionToWebProcess_GetNetworkLoadInformationResponse:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::GetNetworkLoadInformationResponse::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_GetNetworkLoadIntermediateInformation:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::GetNetworkLoadIntermediateInformation::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_TakeNetworkLoadInformationMetrics:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::TakeNetworkLoadInformationMetrics::ReplyArguments>(globalObject, decoder);
#if ENABLE(SERVICE_WORKER)
    case MessageName::NetworkConnectionToWebProcess_EstablishSWContextConnection:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::EstablishSWContextConnection::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::NetworkConnectionToWebProcess_EstablishSharedWorkerContextConnection:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::EstablishSharedWorkerContextConnection::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_CreateRTCProvider:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::CreateRTCProvider::ReplyArguments>(globalObject, decoder);
#if ENABLE(WEB_RTC)
    case MessageName::NetworkConnectionToWebProcess_ConnectToRTCDataChannelRemoteSource:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::ConnectToRTCDataChannelRemoteSource::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::NetworkConnectionToWebProcess_TakeAllMessagesForPort:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::TakeAllMessagesForPort::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkConnectionToWebProcess_CheckRemotePortForActivity:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::CheckRemotePortForActivity::ReplyArguments>(globalObject, decoder);
#if PLATFORM(MAC)
    case MessageName::NetworkConnectionToWebProcess_GetProcessDisplayName:
        return jsValueForDecodedArguments<Messages::NetworkConnectionToWebProcess::GetProcessDisplayName::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(CONTENT_EXTENSIONS)
#endif
    case MessageName::NetworkProcess_CreateNetworkConnectionToWebProcess:
        return jsValueForDecodedArguments<Messages::NetworkProcess::CreateNetworkConnectionToWebProcess::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_FetchWebsiteData:
        return jsValueForDecodedArguments<Messages::NetworkProcess::FetchWebsiteData::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_DeleteWebsiteData:
        return jsValueForDecodedArguments<Messages::NetworkProcess::DeleteWebsiteData::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_DeleteWebsiteDataForOrigins:
        return jsValueForDecodedArguments<Messages::NetworkProcess::DeleteWebsiteDataForOrigins::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_RenameOriginInWebsiteData:
        return jsValueForDecodedArguments<Messages::NetworkProcess::RenameOriginInWebsiteData::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_CancelDownload:
        return jsValueForDecodedArguments<Messages::NetworkProcess::CancelDownload::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_RequestResource:
        return jsValueForDecodedArguments<Messages::NetworkProcess::RequestResource::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetAllowsAnySSLCertificateForWebSocket:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetAllowsAnySSLCertificateForWebSocket::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_FlushCookies:
        return jsValueForDecodedArguments<Messages::NetworkProcess::FlushCookies::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetCacheModelSynchronouslyForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetCacheModelSynchronouslyForTesting::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ProcessWillSuspendImminentlyForTestingSync:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ProcessWillSuspendImminentlyForTestingSync::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_PrepareToSuspend:
        return jsValueForDecodedArguments<Messages::NetworkProcess::PrepareToSuspend::ReplyArguments>(globalObject, decoder);
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
    case MessageName::NetworkProcess_ClearPrevalentResource:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ClearPrevalentResource::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ClearUserInteraction:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ClearUserInteraction::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_DumpResourceLoadStatistics:
        return jsValueForDecodedArguments<Messages::NetworkProcess::DumpResourceLoadStatistics::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_UpdatePrevalentDomainsToBlockCookiesFor:
        return jsValueForDecodedArguments<Messages::NetworkProcess::UpdatePrevalentDomainsToBlockCookiesFor::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_IsGrandfathered:
        return jsValueForDecodedArguments<Messages::NetworkProcess::IsGrandfathered::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_IsPrevalentResource:
        return jsValueForDecodedArguments<Messages::NetworkProcess::IsPrevalentResource::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_IsVeryPrevalentResource:
        return jsValueForDecodedArguments<Messages::NetworkProcess::IsVeryPrevalentResource::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetAgeCapForClientSideCookies:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetAgeCapForClientSideCookies::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetLastSeen:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetLastSeen::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_MergeStatisticForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::MergeStatisticForTesting::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_InsertExpiredStatisticForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::InsertExpiredStatisticForTesting::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetPrevalentResource:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetPrevalentResource::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetPrevalentResourceForDebugMode:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetPrevalentResourceForDebugMode::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_IsResourceLoadStatisticsEphemeral:
        return jsValueForDecodedArguments<Messages::NetworkProcess::IsResourceLoadStatisticsEphemeral::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_HadUserInteraction:
        return jsValueForDecodedArguments<Messages::NetworkProcess::HadUserInteraction::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_IsRelationshipOnlyInDatabaseOnce:
        return jsValueForDecodedArguments<Messages::NetworkProcess::IsRelationshipOnlyInDatabaseOnce::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_HasLocalStorage:
        return jsValueForDecodedArguments<Messages::NetworkProcess::HasLocalStorage::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_GetAllStorageAccessEntries:
        return jsValueForDecodedArguments<Messages::NetworkProcess::GetAllStorageAccessEntries::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_IsRegisteredAsRedirectingTo:
        return jsValueForDecodedArguments<Messages::NetworkProcess::IsRegisteredAsRedirectingTo::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_IsRegisteredAsSubFrameUnder:
        return jsValueForDecodedArguments<Messages::NetworkProcess::IsRegisteredAsSubFrameUnder::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_IsRegisteredAsSubresourceUnder:
        return jsValueForDecodedArguments<Messages::NetworkProcess::IsRegisteredAsSubresourceUnder::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_DomainIDExistsInDatabase:
        return jsValueForDecodedArguments<Messages::NetworkProcess::DomainIDExistsInDatabase::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_LogUserInteraction:
        return jsValueForDecodedArguments<Messages::NetworkProcess::LogUserInteraction::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ResetParametersToDefaultValues:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ResetParametersToDefaultValues::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ScheduleClearInMemoryAndPersistent:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ScheduleClearInMemoryAndPersistent::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ScheduleCookieBlockingUpdate:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ScheduleCookieBlockingUpdate::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ScheduleStatisticsAndDataRecordsProcessing:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ScheduleStatisticsAndDataRecordsProcessing::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_StatisticsDatabaseHasAllTables:
        return jsValueForDecodedArguments<Messages::NetworkProcess::StatisticsDatabaseHasAllTables::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetCacheMaxAgeCapForPrevalentResources:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetCacheMaxAgeCapForPrevalentResources::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetGrandfathered:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetGrandfathered::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_GetResourceLoadStatisticsDataSummary:
        return jsValueForDecodedArguments<Messages::NetworkProcess::GetResourceLoadStatisticsDataSummary::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetGrandfatheringTime:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetGrandfatheringTime::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetMaxStatisticsEntries:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetMaxStatisticsEntries::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetMinimumTimeBetweenDataRecordsRemoval:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetMinimumTimeBetweenDataRecordsRemoval::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetPruneEntriesDownTo:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetPruneEntriesDownTo::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetShouldClassifyResourcesBeforeDataRecordsRemoval:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetShouldClassifyResourcesBeforeDataRecordsRemoval::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetNotifyPagesWhenDataRecordsWereScanned:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetNotifyPagesWhenDataRecordsWereScanned::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetIsRunningResourceLoadStatisticsTest:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetIsRunningResourceLoadStatisticsTest::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetResourceLoadStatisticsDebugMode:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetResourceLoadStatisticsDebugMode::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetVeryPrevalentResource:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetVeryPrevalentResource::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetSubframeUnderTopFrameDomain:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetSubframeUnderTopFrameDomain::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetSubresourceUnderTopFrameDomain:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetSubresourceUnderTopFrameDomain::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetSubresourceUniqueRedirectTo:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetSubresourceUniqueRedirectTo::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetSubresourceUniqueRedirectFrom:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetSubresourceUniqueRedirectFrom::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetTimeToLiveUserInteraction:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetTimeToLiveUserInteraction::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetTopFrameUniqueRedirectTo:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetTopFrameUniqueRedirectTo::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetTopFrameUniqueRedirectFrom:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetTopFrameUniqueRedirectFrom::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ResetCacheMaxAgeCapForPrevalentResources:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ResetCacheMaxAgeCapForPrevalentResources::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetCrossSiteLoadWithLinkDecorationForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetCrossSiteLoadWithLinkDecorationForTesting::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ResetCrossSiteLoadsWithLinkDecorationForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ResetCrossSiteLoadsWithLinkDecorationForTesting::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_DeleteCookiesForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::DeleteCookiesForTesting::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_HasIsolatedSession:
        return jsValueForDecodedArguments<Messages::NetworkProcess::HasIsolatedSession::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_CloseITPDatabase:
        return jsValueForDecodedArguments<Messages::NetworkProcess::CloseITPDatabase::ReplyArguments>(globalObject, decoder);
#endif
#if (ENABLE(INTELLIGENT_TRACKING_PREVENTION) && ENABLE(APP_BOUND_DOMAINS))
    case MessageName::NetworkProcess_SetAppBoundDomainsForResourceLoadStatistics:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetAppBoundDomainsForResourceLoadStatistics::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
    case MessageName::NetworkProcess_SetShouldDowngradeReferrerForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetShouldDowngradeReferrerForTesting::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetThirdPartyCookieBlockingMode:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetThirdPartyCookieBlockingMode::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetShouldEnbleSameSiteStrictEnforcementForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetShouldEnbleSameSiteStrictEnforcementForTesting::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetFirstPartyWebsiteDataRemovalModeForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetFirstPartyWebsiteDataRemovalModeForTesting::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetToSameSiteStrictCookiesForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetToSameSiteStrictCookiesForTesting::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetFirstPartyHostCNAMEDomainForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetFirstPartyHostCNAMEDomainForTesting::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetThirdPartyCNAMEDomainForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetThirdPartyCNAMEDomainForTesting::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::NetworkProcess_SyncLocalStorage:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SyncLocalStorage::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_DumpPrivateClickMeasurement:
        return jsValueForDecodedArguments<Messages::NetworkProcess::DumpPrivateClickMeasurement::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ClearPrivateClickMeasurement:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ClearPrivateClickMeasurement::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetPrivateClickMeasurementOverrideTimerForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetPrivateClickMeasurementOverrideTimerForTesting::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_MarkAttributedPrivateClickMeasurementsAsExpiredForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::MarkAttributedPrivateClickMeasurementsAsExpiredForTesting::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetPrivateClickMeasurementEphemeralMeasurementForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetPrivateClickMeasurementEphemeralMeasurementForTesting::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SimulatePrivateClickMeasurementSessionRestart:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SimulatePrivateClickMeasurementSessionRestart::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetPrivateClickMeasurementTokenPublicKeyURLForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetPrivateClickMeasurementTokenPublicKeyURLForTesting::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetPrivateClickMeasurementTokenSignatureURLForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetPrivateClickMeasurementTokenSignatureURLForTesting::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetPrivateClickMeasurementAttributionReportURLsForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetPrivateClickMeasurementAttributionReportURLsForTesting::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_MarkPrivateClickMeasurementsAsExpiredForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::MarkPrivateClickMeasurementsAsExpiredForTesting::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetPCMFraudPreventionValuesForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetPCMFraudPreventionValuesForTesting::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetPrivateClickMeasurementAppBundleIDForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetPrivateClickMeasurementAppBundleIDForTesting::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ClosePCMDatabase:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ClosePCMDatabase::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_SetServiceWorkerFetchTimeoutForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::SetServiceWorkerFetchTimeoutForTesting::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ResetServiceWorkerFetchTimeoutForTesting:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ResetServiceWorkerFetchTimeoutForTesting::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ResetQuota:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ResetQuota::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ClearStorage:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ClearStorage::ReplyArguments>(globalObject, decoder);
#if ENABLE(APP_BOUND_DOMAINS)
    case MessageName::NetworkProcess_HasAppBoundSession:
        return jsValueForDecodedArguments<Messages::NetworkProcess::HasAppBoundSession::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ClearAppBoundSession:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ClearAppBoundSession::ReplyArguments>(globalObject, decoder);
#endif
#if PLATFORM(IOS_FAMILY) && !PLATFORM(MACCATALYST)
    case MessageName::NetworkProcess_ClearServiceWorkerEntitlementOverride:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ClearServiceWorkerEntitlementOverride::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::NetworkProcess_UpdateBundleIdentifier:
        return jsValueForDecodedArguments<Messages::NetworkProcess::UpdateBundleIdentifier::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ClearBundleIdentifier:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ClearBundleIdentifier::ReplyArguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::NetworkProcess_AppPrivacyReportTestingData:
        return jsValueForDecodedArguments<Messages::NetworkProcess::AppPrivacyReportTestingData::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ClearAppPrivacyReportTestingData:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ClearAppPrivacyReportTestingData::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::NetworkProcess_CountNonDefaultSessionSets:
        return jsValueForDecodedArguments<Messages::NetworkProcess::CountNonDefaultSessionSets::ReplyArguments>(globalObject, decoder);
#if ENABLE(SERVICE_WORKER)
    case MessageName::NetworkProcess_GetPendingPushMessages:
        return jsValueForDecodedArguments<Messages::NetworkProcess::GetPendingPushMessages::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_ProcessPushMessage:
        return jsValueForDecodedArguments<Messages::NetworkProcess::ProcessPushMessage::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::NetworkProcess_DeletePushAndNotificationRegistration:
        return jsValueForDecodedArguments<Messages::NetworkProcess::DeletePushAndNotificationRegistration::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcess_GetOriginsWithPushAndNotificationPermissions:
        return jsValueForDecodedArguments<Messages::NetworkProcess::GetOriginsWithPushAndNotificationPermissions::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkSocketChannel_SendString:
        return jsValueForDecodedArguments<Messages::NetworkSocketChannel::SendString::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkSocketChannel_SendData:
        return jsValueForDecodedArguments<Messages::NetworkSocketChannel::SendData::ReplyArguments>(globalObject, decoder);
#if ENABLE(SERVICE_WORKER)
#endif
#if ENABLE(SERVICE_WORKER)
#endif
#if ENABLE(SERVICE_WORKER)
    case MessageName::WebSWServerConnection_ScheduleUnregisterJobInServer:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::ScheduleUnregisterJobInServer::ReplyArguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_MatchRegistration:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::MatchRegistration::ReplyArguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_WhenRegistrationReady:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::WhenRegistrationReady::ReplyArguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_GetRegistrations:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::GetRegistrations::ReplyArguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_TerminateWorkerFromClient:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::TerminateWorkerFromClient::ReplyArguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_WhenServiceWorkerIsTerminatedForTesting:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::WhenServiceWorkerIsTerminatedForTesting::ReplyArguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_StoreRegistrationsOnDisk:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::StoreRegistrationsOnDisk::ReplyArguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_SubscribeToPushService:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::SubscribeToPushService::ReplyArguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_UnsubscribeFromPushService:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::UnsubscribeFromPushService::ReplyArguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_GetPushSubscription:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::GetPushSubscription::ReplyArguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_GetPushPermissionState:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::GetPushPermissionState::ReplyArguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_EnableNavigationPreload:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::EnableNavigationPreload::ReplyArguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_DisableNavigationPreload:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::DisableNavigationPreload::ReplyArguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_SetNavigationPreloadHeaderValue:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::SetNavigationPreloadHeaderValue::ReplyArguments>(globalObject, decoder);
    case MessageName::WebSWServerConnection_GetNavigationPreloadState:
        return jsValueForDecodedArguments<Messages::WebSWServerConnection::GetNavigationPreloadState::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(SERVICE_WORKER)
    case MessageName::WebSWServerToContextConnection_SkipWaiting:
        return jsValueForDecodedArguments<Messages::WebSWServerToContextConnection::SkipWaiting::ReplyArguments>(globalObject, decoder);
    case MessageName::WebSWServerToContextConnection_FindClientByVisibleIdentifier:
        return jsValueForDecodedArguments<Messages::WebSWServerToContextConnection::FindClientByVisibleIdentifier::ReplyArguments>(globalObject, decoder);
    case MessageName::WebSWServerToContextConnection_Claim:
        return jsValueForDecodedArguments<Messages::WebSWServerToContextConnection::Claim::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::StorageManagerSet_ConnectToLocalStorageArea:
        return jsValueForDecodedArguments<Messages::StorageManagerSet::ConnectToLocalStorageArea::ReplyArguments>(globalObject, decoder);
    case MessageName::StorageManagerSet_ConnectToTransientLocalStorageArea:
        return jsValueForDecodedArguments<Messages::StorageManagerSet::ConnectToTransientLocalStorageArea::ReplyArguments>(globalObject, decoder);
    case MessageName::StorageManagerSet_ConnectToSessionStorageArea:
        return jsValueForDecodedArguments<Messages::StorageManagerSet::ConnectToSessionStorageArea::ReplyArguments>(globalObject, decoder);
    case MessageName::StorageManagerSet_GetValues:
        return jsValueForDecodedArguments<Messages::StorageManagerSet::GetValues::ReplyArguments>(globalObject, decoder);
    case MessageName::StorageManagerSet_SetItem:
        return jsValueForDecodedArguments<Messages::StorageManagerSet::SetItem::ReplyArguments>(globalObject, decoder);
    case MessageName::StorageManagerSet_RemoveItem:
        return jsValueForDecodedArguments<Messages::StorageManagerSet::RemoveItem::ReplyArguments>(globalObject, decoder);
    case MessageName::StorageManagerSet_Clear:
        return jsValueForDecodedArguments<Messages::StorageManagerSet::Clear::ReplyArguments>(globalObject, decoder);
    case MessageName::CacheStorageEngineConnection_Open:
        return jsValueForDecodedArguments<Messages::CacheStorageEngineConnection::Open::ReplyArguments>(globalObject, decoder);
    case MessageName::CacheStorageEngineConnection_Remove:
        return jsValueForDecodedArguments<Messages::CacheStorageEngineConnection::Remove::ReplyArguments>(globalObject, decoder);
    case MessageName::CacheStorageEngineConnection_Caches:
        return jsValueForDecodedArguments<Messages::CacheStorageEngineConnection::Caches::ReplyArguments>(globalObject, decoder);
    case MessageName::CacheStorageEngineConnection_RetrieveRecords:
        return jsValueForDecodedArguments<Messages::CacheStorageEngineConnection::RetrieveRecords::ReplyArguments>(globalObject, decoder);
    case MessageName::CacheStorageEngineConnection_DeleteMatchingRecords:
        return jsValueForDecodedArguments<Messages::CacheStorageEngineConnection::DeleteMatchingRecords::ReplyArguments>(globalObject, decoder);
    case MessageName::CacheStorageEngineConnection_PutRecords:
        return jsValueForDecodedArguments<Messages::CacheStorageEngineConnection::PutRecords::ReplyArguments>(globalObject, decoder);
    case MessageName::CacheStorageEngineConnection_ClearMemoryRepresentation:
        return jsValueForDecodedArguments<Messages::CacheStorageEngineConnection::ClearMemoryRepresentation::ReplyArguments>(globalObject, decoder);
    case MessageName::CacheStorageEngineConnection_EngineRepresentation:
        return jsValueForDecodedArguments<Messages::CacheStorageEngineConnection::EngineRepresentation::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_Persisted:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::Persisted::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_Persist:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::Persist::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_FileSystemGetDirectory:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::FileSystemGetDirectory::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_IsSameEntry:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::IsSameEntry::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_GetFileHandle:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::GetFileHandle::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_GetDirectoryHandle:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::GetDirectoryHandle::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_RemoveEntry:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::RemoveEntry::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_Resolve:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::Resolve::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_Move:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::Move::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_GetFile:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::GetFile::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_CreateSyncAccessHandle:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::CreateSyncAccessHandle::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_CloseSyncAccessHandle:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::CloseSyncAccessHandle::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_GetHandleNames:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::GetHandleNames::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_GetHandle:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::GetHandle::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_ConnectToStorageArea:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::ConnectToStorageArea::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_ConnectToStorageAreaSync:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::ConnectToStorageAreaSync::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_SetItem:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::SetItem::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_RemoveItem:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::RemoveItem::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkStorageManager_Clear:
        return jsValueForDecodedArguments<Messages::NetworkStorageManager::Clear::ReplyArguments>(globalObject, decoder);
#if ENABLE(WEB_RTC)
#endif
#if USE(LIBWEBRTC)
#endif
#if USE(LIBWEBRTC)
#endif
#if ENABLE(WEB_RTC)
#endif
    case MessageName::AuxiliaryProcess_MainThreadPing:
        return jsValueForDecodedArguments<Messages::AuxiliaryProcess::MainThreadPing::ReplyArguments>(globalObject, decoder);
#if ENABLE(IPC_TESTING_API)
    case MessageName::IPCTester_StopMessageTesting:
        return jsValueForDecodedArguments<Messages::IPCTester::StopMessageTesting::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::NotificationManagerMessageHandler_RequestSystemNotificationPermission:
        return jsValueForDecodedArguments<Messages::NotificationManagerMessageHandler::RequestSystemNotificationPermission::ReplyArguments>(globalObject, decoder);
#if ENABLE(MEDIA_SESSION_COORDINATOR)
    case MessageName::RemoteMediaSessionCoordinatorProxy_Join:
        return jsValueForDecodedArguments<Messages::RemoteMediaSessionCoordinatorProxy::Join::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteMediaSessionCoordinatorProxy_CoordinateSeekTo:
        return jsValueForDecodedArguments<Messages::RemoteMediaSessionCoordinatorProxy::CoordinateSeekTo::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteMediaSessionCoordinatorProxy_CoordinatePlay:
        return jsValueForDecodedArguments<Messages::RemoteMediaSessionCoordinatorProxy::CoordinatePlay::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteMediaSessionCoordinatorProxy_CoordinatePause:
        return jsValueForDecodedArguments<Messages::RemoteMediaSessionCoordinatorProxy::CoordinatePause::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteMediaSessionCoordinatorProxy_CoordinateSetTrack:
        return jsValueForDecodedArguments<Messages::RemoteMediaSessionCoordinatorProxy::CoordinateSetTrack::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(MEDIA_STREAM)
#endif
#if ENABLE(FULLSCREEN_API)
    case MessageName::WebFullScreenManagerProxy_SupportsFullScreen:
        return jsValueForDecodedArguments<Messages::WebFullScreenManagerProxy::SupportsFullScreen::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebLockRegistryProxy_AbortLockRequest:
        return jsValueForDecodedArguments<Messages::WebLockRegistryProxy::AbortLockRequest::ReplyArguments>(globalObject, decoder);
    case MessageName::WebLockRegistryProxy_Snapshot:
        return jsValueForDecodedArguments<Messages::WebLockRegistryProxy::Snapshot::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_CreateNewPage:
        return jsValueForDecodedArguments<Messages::WebPageProxy::CreateNewPage::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RunJavaScriptAlert:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RunJavaScriptAlert::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RunJavaScriptConfirm:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RunJavaScriptConfirm::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RunJavaScriptPrompt:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RunJavaScriptPrompt::ReplyArguments>(globalObject, decoder);
#if ENABLE(WEBGL)
    case MessageName::WebPageProxy_WebGLPolicyForURL:
        return jsValueForDecodedArguments<Messages::WebPageProxy::WebGLPolicyForURL::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ResolveWebGLPolicyForURL:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ResolveWebGLPolicyForURL::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_GetToolbarsAreVisible:
        return jsValueForDecodedArguments<Messages::WebPageProxy::GetToolbarsAreVisible::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_GetMenuBarIsVisible:
        return jsValueForDecodedArguments<Messages::WebPageProxy::GetMenuBarIsVisible::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_GetStatusBarIsVisible:
        return jsValueForDecodedArguments<Messages::WebPageProxy::GetStatusBarIsVisible::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_GetWindowFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::GetWindowFrame::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ScreenToRootView:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ScreenToRootView::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RootViewToScreen:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RootViewToScreen::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_AccessibilityScreenToRootView:
        return jsValueForDecodedArguments<Messages::WebPageProxy::AccessibilityScreenToRootView::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RootViewToAccessibilityScreen:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RootViewToAccessibilityScreen::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_RunBeforeUnloadConfirmPanel:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RunBeforeUnloadConfirmPanel::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ShowShareSheet:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShowShareSheet::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ShowContactPicker:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShowContactPicker::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_PrintFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::PrintFrame::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DecidePolicyForNavigationActionSync:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DecidePolicyForNavigationActionSync::ReplyArguments>(globalObject, decoder);
#if PLATFORM(IOS_FAMILY)
    case MessageName::WebPageProxy_InterpretKeyEvent:
        return jsValueForDecodedArguments<Messages::WebPageProxy::InterpretKeyEvent::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_BackForwardGoToItem:
        return jsValueForDecodedArguments<Messages::WebPageProxy::BackForwardGoToItem::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_BackForwardItemAtIndex:
        return jsValueForDecodedArguments<Messages::WebPageProxy::BackForwardItemAtIndex::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_BackForwardListCounts:
        return jsValueForDecodedArguments<Messages::WebPageProxy::BackForwardListCounts::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_CanUndoRedo:
        return jsValueForDecodedArguments<Messages::WebPageProxy::CanUndoRedo::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ExecuteUndoRedo:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ExecuteUndoRedo::ReplyArguments>(globalObject, decoder);
#if ENABLE(IMAGE_ANALYSIS)
    case MessageName::WebPageProxy_RequestTextRecognition:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RequestTextRecognition::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(MEDIA_CONTROLS_CONTEXT_MENUS) && USE(UICONTEXTMENU)
    case MessageName::WebPageProxy_ShowMediaControlsContextMenu:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShowMediaControlsContextMenu::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_RequestDOMPasteAccess:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RequestDOMPasteAccess::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ExceededDatabaseQuota:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ExceededDatabaseQuota::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ReachedApplicationCacheOriginQuota:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ReachedApplicationCacheOriginQuota::ReplyArguments>(globalObject, decoder);
#if ENABLE(MEDIA_STREAM)
    case MessageName::WebPageProxy_EnumerateMediaDevicesForFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::EnumerateMediaDevicesForFrame::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_RequestNotificationPermission:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RequestNotificationPermission::ReplyArguments>(globalObject, decoder);
#if USE(UNIFIED_TEXT_CHECKING)
    case MessageName::WebPageProxy_CheckTextOfParagraph:
        return jsValueForDecodedArguments<Messages::WebPageProxy::CheckTextOfParagraph::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_CheckSpellingOfString:
        return jsValueForDecodedArguments<Messages::WebPageProxy::CheckSpellingOfString::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_CheckGrammarOfString:
        return jsValueForDecodedArguments<Messages::WebPageProxy::CheckGrammarOfString::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SpellingUIIsShowing:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SpellingUIIsShowing::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_GetGuessesForWord:
        return jsValueForDecodedArguments<Messages::WebPageProxy::GetGuessesForWord::ReplyArguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::WebPageProxy_ExecuteSavedCommandBySelector:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ExecuteSavedCommandBySelector::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_GetIsSpeaking:
        return jsValueForDecodedArguments<Messages::WebPageProxy::GetIsSpeaking::ReplyArguments>(globalObject, decoder);
#endif
#if USE(APPKIT)
    case MessageName::WebPageProxy_SubstitutionsPanelIsShowing:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SubstitutionsPanelIsShowing::ReplyArguments>(globalObject, decoder);
#endif
#if PLATFORM(MAC)
    case MessageName::WebPageProxy_DismissCorrectionPanelSoon:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DismissCorrectionPanelSoon::ReplyArguments>(globalObject, decoder);
#endif
#if USE(DICTATION_ALTERNATIVES)
    case MessageName::WebPageProxy_DictationAlternatives:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DictationAlternatives::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_LoadRecentSearches:
        return jsValueForDecodedArguments<Messages::WebPageProxy::LoadRecentSearches::ReplyArguments>(globalObject, decoder);
#if ENABLE(PDFKIT_PLUGIN)
    case MessageName::WebPageProxy_ShowPDFContextMenu:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShowPDFContextMenu::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(WEB_CRYPTO)
    case MessageName::WebPageProxy_WrapCryptoKey:
        return jsValueForDecodedArguments<Messages::WebPageProxy::WrapCryptoKey::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_UnwrapCryptoKey:
        return jsValueForDecodedArguments<Messages::WebPageProxy::UnwrapCryptoKey::ReplyArguments>(globalObject, decoder);
#endif
#if USE(QUICK_LOOK)
    case MessageName::WebPageProxy_RequestPasswordForQuickLookDocumentInMainFrame:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RequestPasswordForQuickLookDocumentInMainFrame::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_HandleSynchronousMessage:
        return jsValueForDecodedArguments<Messages::WebPageProxy::HandleSynchronousMessage::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_LoadSynchronousURLSchemeTask:
        return jsValueForDecodedArguments<Messages::WebPageProxy::LoadSynchronousURLSchemeTask::ReplyArguments>(globalObject, decoder);
#if ENABLE(DEVICE_ORIENTATION)
    case MessageName::WebPageProxy_ShouldAllowDeviceOrientationAndMotionAccess:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShouldAllowDeviceOrientationAndMotionAccess::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    case MessageName::WebPageProxy_SerializedAttachmentDataForIdentifiers:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SerializedAttachmentDataForIdentifiers::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_SignedPublicKeyAndChallengeString:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SignedPublicKeyAndChallengeString::ReplyArguments>(globalObject, decoder);
#if ENABLE(SPEECH_SYNTHESIS)
    case MessageName::WebPageProxy_SpeechSynthesisVoiceList:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SpeechSynthesisVoiceList::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SpeechSynthesisSpeak:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SpeechSynthesisSpeak::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SpeechSynthesisSetFinishedCallback:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SpeechSynthesisSetFinishedCallback::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SpeechSynthesisPause:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SpeechSynthesisPause::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_SpeechSynthesisResume:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SpeechSynthesisResume::ReplyArguments>(globalObject, decoder);
#endif
#if PLATFORM(GTK)
    case MessageName::WebPageProxy_ShowEmojiPicker:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ShowEmojiPicker::ReplyArguments>(globalObject, decoder);
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    case MessageName::WebPageProxy_SendMessageToWebViewWithReply:
        return jsValueForDecodedArguments<Messages::WebPageProxy::SendMessageToWebViewWithReply::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(ARKIT_INLINE_PREVIEW_MAC)
    case MessageName::WebPageProxy_ModelElementDidCreatePreview:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementDidCreatePreview::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ModelElementSizeDidChange:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementSizeDidChange::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(ARKIT_INLINE_PREVIEW)
    case MessageName::WebPageProxy_ModelElementGetCamera:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementGetCamera::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ModelElementSetCamera:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementSetCamera::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ModelElementIsPlayingAnimation:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementIsPlayingAnimation::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ModelElementSetAnimationIsPlaying:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementSetAnimationIsPlaying::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ModelElementIsLoopingAnimation:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementIsLoopingAnimation::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ModelElementSetIsLoopingAnimation:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementSetIsLoopingAnimation::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ModelElementAnimationDuration:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementAnimationDuration::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ModelElementAnimationCurrentTime:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementAnimationCurrentTime::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ModelElementSetAnimationCurrentTime:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementSetAnimationCurrentTime::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ModelElementHasAudio:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementHasAudio::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ModelElementIsMuted:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementIsMuted::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ModelElementSetIsMuted:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ModelElementSetIsMuted::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_QueryPermission:
        return jsValueForDecodedArguments<Messages::WebPageProxy::QueryPermission::ReplyArguments>(globalObject, decoder);
#if ENABLE(APPLE_PAY_AMS_UI)
    case MessageName::WebPageProxy_StartApplePayAMSUISession:
        return jsValueForDecodedArguments<Messages::WebPageProxy::StartApplePayAMSUISession::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebPageProxy_RequestCookieConsent:
        return jsValueForDecodedArguments<Messages::WebPageProxy::RequestCookieConsent::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_ClassifyModalContainerControls:
        return jsValueForDecodedArguments<Messages::WebPageProxy::ClassifyModalContainerControls::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPageProxy_DecidePolicyForModalContainer:
        return jsValueForDecodedArguments<Messages::WebPageProxy::DecidePolicyForModalContainer::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_WriteCustomData:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::WriteCustomData::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_TypesSafeForDOMToReadAndWrite:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::TypesSafeForDOMToReadAndWrite::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_AllPasteboardItemInfo:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::AllPasteboardItemInfo::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_InformationForItemAtIndex:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::InformationForItemAtIndex::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_GetPasteboardItemsCount:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::GetPasteboardItemsCount::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_ReadStringFromPasteboard:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::ReadStringFromPasteboard::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_ReadURLFromPasteboard:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::ReadURLFromPasteboard::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_ReadBufferFromPasteboard:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::ReadBufferFromPasteboard::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_ContainsStringSafeForDOMToReadForType:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::ContainsStringSafeForDOMToReadForType::ReplyArguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::WebPasteboardProxy_GetNumberOfFiles:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::GetNumberOfFiles::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_GetPasteboardTypes:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::GetPasteboardTypes::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_GetPasteboardPathnamesForType:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::GetPasteboardPathnamesForType::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_GetPasteboardStringForType:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::GetPasteboardStringForType::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_GetPasteboardStringsForType:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::GetPasteboardStringsForType::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_GetPasteboardBufferForType:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::GetPasteboardBufferForType::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_GetPasteboardChangeCount:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::GetPasteboardChangeCount::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_GetPasteboardColor:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::GetPasteboardColor::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_GetPasteboardURL:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::GetPasteboardURL::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_AddPasteboardTypes:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::AddPasteboardTypes::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_SetPasteboardTypes:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::SetPasteboardTypes::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_SetPasteboardURL:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::SetPasteboardURL::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_SetPasteboardColor:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::SetPasteboardColor::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_SetPasteboardStringForType:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::SetPasteboardStringForType::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_SetPasteboardBufferForType:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::SetPasteboardBufferForType::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_ContainsURLStringSuitableForLoading:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::ContainsURLStringSuitableForLoading::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_URLStringSuitableForLoading:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::URLStringSuitableForLoading::ReplyArguments>(globalObject, decoder);
#endif
#if PLATFORM(GTK)
    case MessageName::WebPasteboardProxy_GetTypes:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::GetTypes::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_ReadText:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::ReadText::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_ReadFilePaths:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::ReadFilePaths::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPasteboardProxy_ReadBuffer:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::ReadBuffer::ReplyArguments>(globalObject, decoder);
#endif
#if USE(LIBWPE)
    case MessageName::WebPasteboardProxy_GetPasteboardTypes:
        return jsValueForDecodedArguments<Messages::WebPasteboardProxy::GetPasteboardTypes::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebProcessPool_HandleSynchronousMessage:
        return jsValueForDecodedArguments<Messages::WebProcessPool::HandleSynchronousMessage::ReplyArguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_ShouldTerminate:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::ShouldTerminate::ReplyArguments>(globalObject, decoder);
    case MessageName::WebProcessProxy_GetNetworkProcessConnection:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::GetNetworkProcessConnection::ReplyArguments>(globalObject, decoder);
#if ENABLE(GPU_PROCESS)
    case MessageName::WebProcessProxy_GetGPUProcessConnection:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::GetGPUProcessConnection::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(WEB_AUTHN)
    case MessageName::WebProcessProxy_GetWebAuthnProcessConnection:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::GetWebAuthnProcessConnection::ReplyArguments>(globalObject, decoder);
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    case MessageName::WebProcessProxy_SendMessageToWebContextWithReply:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::SendMessageToWebContextWithReply::ReplyArguments>(globalObject, decoder);
#endif
#if PLATFORM(MAC)
    case MessageName::WebProcessProxy_IsAXAuthenticated:
        return jsValueForDecodedArguments<Messages::WebProcessProxy::IsAXAuthenticated::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::DownloadProxy_DecideDestinationWithSuggestedFilename:
        return jsValueForDecodedArguments<Messages::DownloadProxy::DecideDestinationWithSuggestedFilename::ReplyArguments>(globalObject, decoder);
#if ENABLE(GPU_PROCESS)
#endif
    case MessageName::NetworkProcessProxy_TestProcessIncomingSyncMessagesWhenWaitingForSyncReply:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::TestProcessIncomingSyncMessagesWhenWaitingForSyncReply::ReplyArguments>(globalObject, decoder);
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
    case MessageName::NetworkProcessProxy_RequestStorageAccessConfirm:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::RequestStorageAccessConfirm::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_DeleteWebsiteDataInUIProcessForRegistrableDomains:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::DeleteWebsiteDataInUIProcessForRegistrableDomains::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_SetDomainsWithCrossPageStorageAccess:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::SetDomainsWithCrossPageStorageAccess::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::NetworkProcessProxy_RetrieveCacheStorageParameters:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::RetrieveCacheStorageParameters::ReplyArguments>(globalObject, decoder);
#if ENABLE(SERVICE_WORKER)
    case MessageName::NetworkProcessProxy_EstablishServiceWorkerContextConnectionToNetworkProcess:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::EstablishServiceWorkerContextConnectionToNetworkProcess::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::NetworkProcessProxy_EstablishSharedWorkerContextConnectionToNetworkProcess:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::EstablishSharedWorkerContextConnectionToNetworkProcess::ReplyArguments>(globalObject, decoder);
#if ENABLE(APP_BOUND_DOMAINS)
    case MessageName::NetworkProcessProxy_GetAppBoundDomains:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::GetAppBoundDomains::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::NetworkProcessProxy_RequestStorageSpace:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::RequestStorageSpace::ReplyArguments>(globalObject, decoder);
    case MessageName::NetworkProcessProxy_TriggerBrowsingContextGroupSwitchForNavigation:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::TriggerBrowsingContextGroupSwitchForNavigation::ReplyArguments>(globalObject, decoder);
#if ENABLE(APPLE_PAY_REMOTE_UI_USES_SCENE)
    case MessageName::NetworkProcessProxy_GetWindowSceneIdentifierForPaymentPresentation:
        return jsValueForDecodedArguments<Messages::NetworkProcessProxy::GetWindowSceneIdentifierForPaymentPresentation::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebUserContentControllerProxy_DidPostMessage:
        return jsValueForDecodedArguments<Messages::WebUserContentControllerProxy::DidPostMessage::ReplyArguments>(globalObject, decoder);
#if ENABLE(WEBXR)
    case MessageName::PlatformXRSystem_EnumerateImmersiveXRDevices:
        return jsValueForDecodedArguments<Messages::PlatformXRSystem::EnumerateImmersiveXRDevices::ReplyArguments>(globalObject, decoder);
    case MessageName::PlatformXRSystem_RequestPermissionOnSessionFeatures:
        return jsValueForDecodedArguments<Messages::PlatformXRSystem::RequestPermissionOnSessionFeatures::ReplyArguments>(globalObject, decoder);
    case MessageName::PlatformXRSystem_RequestFrame:
        return jsValueForDecodedArguments<Messages::PlatformXRSystem::RequestFrame::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebProcess_FetchWebsiteData:
        return jsValueForDecodedArguments<Messages::WebProcess::FetchWebsiteData::ReplyArguments>(globalObject, decoder);
    case MessageName::WebProcess_DeleteWebsiteData:
        return jsValueForDecodedArguments<Messages::WebProcess::DeleteWebsiteData::ReplyArguments>(globalObject, decoder);
    case MessageName::WebProcess_DeleteWebsiteDataForOrigins:
        return jsValueForDecodedArguments<Messages::WebProcess::DeleteWebsiteDataForOrigins::ReplyArguments>(globalObject, decoder);
    case MessageName::WebProcess_PrepareToSuspend:
        return jsValueForDecodedArguments<Messages::WebProcess::PrepareToSuspend::ReplyArguments>(globalObject, decoder);
    case MessageName::WebProcess_EstablishSharedWorkerContextConnectionToNetworkProcess:
        return jsValueForDecodedArguments<Messages::WebProcess::EstablishSharedWorkerContextConnectionToNetworkProcess::ReplyArguments>(globalObject, decoder);
#if ENABLE(SERVICE_WORKER)
    case MessageName::WebProcess_EstablishServiceWorkerContextConnectionToNetworkProcess:
        return jsValueForDecodedArguments<Messages::WebProcess::EstablishServiceWorkerContextConnectionToNetworkProcess::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebProcess_GetActivePagesOriginsForTesting:
        return jsValueForDecodedArguments<Messages::WebProcess::GetActivePagesOriginsForTesting::ReplyArguments>(globalObject, decoder);
    case MessageName::WebProcess_IsJITEnabled:
        return jsValueForDecodedArguments<Messages::WebProcess::IsJITEnabled::ReplyArguments>(globalObject, decoder);
    case MessageName::WebProcess_ClearCachedPage:
        return jsValueForDecodedArguments<Messages::WebProcess::ClearCachedPage::ReplyArguments>(globalObject, decoder);
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
    case MessageName::WebProcess_SeedResourceLoadStatisticsForTesting:
        return jsValueForDecodedArguments<Messages::WebProcess::SeedResourceLoadStatisticsForTesting::ReplyArguments>(globalObject, decoder);
    case MessageName::WebProcess_SetThirdPartyCookieBlockingMode:
        return jsValueForDecodedArguments<Messages::WebProcess::SetThirdPartyCookieBlockingMode::ReplyArguments>(globalObject, decoder);
    case MessageName::WebProcess_SetDomainsWithCrossPageStorageAccess:
        return jsValueForDecodedArguments<Messages::WebProcess::SetDomainsWithCrossPageStorageAccess::ReplyArguments>(globalObject, decoder);
    case MessageName::WebProcess_SendResourceLoadStatisticsDataImmediately:
        return jsValueForDecodedArguments<Messages::WebProcess::SendResourceLoadStatisticsDataImmediately::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebAutomationSessionProxy_ResolveChildFrameWithOrdinal:
        return jsValueForDecodedArguments<Messages::WebAutomationSessionProxy::ResolveChildFrameWithOrdinal::ReplyArguments>(globalObject, decoder);
    case MessageName::WebAutomationSessionProxy_ResolveChildFrameWithNodeHandle:
        return jsValueForDecodedArguments<Messages::WebAutomationSessionProxy::ResolveChildFrameWithNodeHandle::ReplyArguments>(globalObject, decoder);
    case MessageName::WebAutomationSessionProxy_ResolveChildFrameWithName:
        return jsValueForDecodedArguments<Messages::WebAutomationSessionProxy::ResolveChildFrameWithName::ReplyArguments>(globalObject, decoder);
    case MessageName::WebAutomationSessionProxy_ResolveParentFrame:
        return jsValueForDecodedArguments<Messages::WebAutomationSessionProxy::ResolveParentFrame::ReplyArguments>(globalObject, decoder);
    case MessageName::WebAutomationSessionProxy_ComputeElementLayout:
        return jsValueForDecodedArguments<Messages::WebAutomationSessionProxy::ComputeElementLayout::ReplyArguments>(globalObject, decoder);
    case MessageName::WebAutomationSessionProxy_SelectOptionElement:
        return jsValueForDecodedArguments<Messages::WebAutomationSessionProxy::SelectOptionElement::ReplyArguments>(globalObject, decoder);
    case MessageName::WebAutomationSessionProxy_SetFilesForInputFileUpload:
        return jsValueForDecodedArguments<Messages::WebAutomationSessionProxy::SetFilesForInputFileUpload::ReplyArguments>(globalObject, decoder);
    case MessageName::WebAutomationSessionProxy_SnapshotRectForScreenshot:
        return jsValueForDecodedArguments<Messages::WebAutomationSessionProxy::SnapshotRectForScreenshot::ReplyArguments>(globalObject, decoder);
    case MessageName::WebAutomationSessionProxy_GetCookiesForFrame:
        return jsValueForDecodedArguments<Messages::WebAutomationSessionProxy::GetCookiesForFrame::ReplyArguments>(globalObject, decoder);
    case MessageName::WebAutomationSessionProxy_DeleteCookie:
        return jsValueForDecodedArguments<Messages::WebAutomationSessionProxy::DeleteCookie::ReplyArguments>(globalObject, decoder);
#if ENABLE(FULLSCREEN_API)
#endif
#if ENABLE(GPU_PROCESS)
#if ENABLE(ROUTING_ARBITRATION)
    case MessageName::GPUProcessConnection_BeginRoutingArbitrationWithCategory:
        return jsValueForDecodedArguments<Messages::GPUProcessConnection::BeginRoutingArbitrationWithCategory::ReplyArguments>(globalObject, decoder);
#endif
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(WEBGL)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::MediaPlayerPrivateRemote_RequestResource:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::RequestResource::ReplyArguments>(globalObject, decoder);
    case MessageName::MediaPlayerPrivateRemote_SendH2Ping:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::SendH2Ping::ReplyArguments>(globalObject, decoder);
#if PLATFORM(IOS_FAMILY)
    case MessageName::MediaPlayerPrivateRemote_GetRawCookies:
        return jsValueForDecodedArguments<Messages::MediaPlayerPrivateRemote::GetRawCookies::ReplyArguments>(globalObject, decoder);
#endif
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)
#endif
#if ENABLE(GPU_PROCESS) && USE(AUDIO_SESSION)
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(LEGACY_ENCRYPTED_MEDIA)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)
    case MessageName::SourceBufferPrivateRemote_SourceBufferPrivateDidReceiveInitializationSegment:
        return jsValueForDecodedArguments<Messages::SourceBufferPrivateRemote::SourceBufferPrivateDidReceiveInitializationSegment::ReplyArguments>(globalObject, decoder);
#endif
#if USE(LIBWEBRTC) && PLATFORM(COCOA) && ENABLE(GPU_PROCESS)
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(VIDEO)
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
#endif
#if ENABLE(MEDIA_SESSION_COORDINATOR)
    case MessageName::RemoteMediaSessionCoordinator_SeekSessionToTime:
        return jsValueForDecodedArguments<Messages::RemoteMediaSessionCoordinator::SeekSessionToTime::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteMediaSessionCoordinator_PlaySession:
        return jsValueForDecodedArguments<Messages::RemoteMediaSessionCoordinator::PlaySession::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteMediaSessionCoordinator_PauseSession:
        return jsValueForDecodedArguments<Messages::RemoteMediaSessionCoordinator::PauseSession::ReplyArguments>(globalObject, decoder);
    case MessageName::RemoteMediaSessionCoordinator_SetSessionTrack:
        return jsValueForDecodedArguments<Messages::RemoteMediaSessionCoordinator::SetSessionTrack::ReplyArguments>(globalObject, decoder);
#endif
#if USE(LIBWEBRTC)
#endif
#if ENABLE(WEB_RTC)
#endif
#if ENABLE(WEB_RTC)
#endif
#if USE(LIBWEBRTC)
#endif
#if USE(LIBWEBRTC)
#endif
#if ENABLE(WEB_RTC)
    case MessageName::NetworkProcessConnection_ConnectToRTCDataChannelRemoteSource:
        return jsValueForDecodedArguments<Messages::NetworkProcessConnection::ConnectToRTCDataChannelRemoteSource::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::NetworkProcessConnection_CheckProcessLocalPortForActivity:
        return jsValueForDecodedArguments<Messages::NetworkProcessConnection::CheckProcessLocalPortForActivity::ReplyArguments>(globalObject, decoder);
#if ENABLE(MEDIA_STREAM)
#endif
    case MessageName::WebSharedWorkerObjectConnection_FetchScriptInClient:
        return jsValueForDecodedArguments<Messages::WebSharedWorkerObjectConnection::FetchScriptInClient::ReplyArguments>(globalObject, decoder);
#if ENABLE(SERVICE_WORKER)
    case MessageName::WebSWClientConnection_SetDocumentIsControlled:
        return jsValueForDecodedArguments<Messages::WebSWClientConnection::SetDocumentIsControlled::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(SERVICE_WORKER)
    case MessageName::WebSWContextManagerConnection_FirePushEvent:
        return jsValueForDecodedArguments<Messages::WebSWContextManagerConnection::FirePushEvent::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebBroadcastChannelRegistry_PostMessageToRemote:
        return jsValueForDecodedArguments<Messages::WebBroadcastChannelRegistry::PostMessageToRemote::ReplyArguments>(globalObject, decoder);
#if ENABLE(IOS_TOUCH_EVENTS)
    case MessageName::EventDispatcher_TouchEvent:
        return jsValueForDecodedArguments<Messages::EventDispatcher::TouchEvent::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_SetInitialFocus:
        return jsValueForDecodedArguments<Messages::WebPage::SetInitialFocus::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_SetActivityState:
        return jsValueForDecodedArguments<Messages::WebPage::SetActivityState::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_TestProcessIncomingSyncMessagesWhenWaitingForSyncReply:
        return jsValueForDecodedArguments<Messages::WebPage::TestProcessIncomingSyncMessagesWhenWaitingForSyncReply::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_ExecuteEditCommandWithCallback:
        return jsValueForDecodedArguments<Messages::WebPage::ExecuteEditCommandWithCallback::ReplyArguments>(globalObject, decoder);
#if PLATFORM(IOS_FAMILY)
    case MessageName::WebPage_SelectWithGesture:
        return jsValueForDecodedArguments<Messages::WebPage::SelectWithGesture::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_UpdateSelectionWithTouches:
        return jsValueForDecodedArguments<Messages::WebPage::UpdateSelectionWithTouches::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_SelectWithTwoTouches:
        return jsValueForDecodedArguments<Messages::WebPage::SelectWithTwoTouches::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_ExtendSelection:
        return jsValueForDecodedArguments<Messages::WebPage::ExtendSelection::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_MoveSelectionByOffset:
        return jsValueForDecodedArguments<Messages::WebPage::MoveSelectionByOffset::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_SelectTextWithGranularityAtPoint:
        return jsValueForDecodedArguments<Messages::WebPage::SelectTextWithGranularityAtPoint::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_SelectPositionAtBoundaryWithDirection:
        return jsValueForDecodedArguments<Messages::WebPage::SelectPositionAtBoundaryWithDirection::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_MoveSelectionAtBoundaryWithDirection:
        return jsValueForDecodedArguments<Messages::WebPage::MoveSelectionAtBoundaryWithDirection::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_SelectPositionAtPoint:
        return jsValueForDecodedArguments<Messages::WebPage::SelectPositionAtPoint::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_BeginSelectionInDirection:
        return jsValueForDecodedArguments<Messages::WebPage::BeginSelectionInDirection::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_UpdateSelectionWithExtentPoint:
        return jsValueForDecodedArguments<Messages::WebPage::UpdateSelectionWithExtentPoint::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_UpdateSelectionWithExtentPointAndBoundary:
        return jsValueForDecodedArguments<Messages::WebPage::UpdateSelectionWithExtentPointAndBoundary::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_RequestDictationContext:
        return jsValueForDecodedArguments<Messages::WebPage::RequestDictationContext::ReplyArguments>(globalObject, decoder);
#endif
#if (PLATFORM(IOS_FAMILY) && ENABLE(REVEAL))
    case MessageName::WebPage_RequestRVItemInCurrentSelectedRange:
        return jsValueForDecodedArguments<Messages::WebPage::RequestRVItemInCurrentSelectedRange::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_PrepareSelectionForContextMenuWithLocationInView:
        return jsValueForDecodedArguments<Messages::WebPage::PrepareSelectionForContextMenuWithLocationInView::ReplyArguments>(globalObject, decoder);
#endif
#if PLATFORM(IOS_FAMILY)
    case MessageName::WebPage_RequestAutocorrectionData:
        return jsValueForDecodedArguments<Messages::WebPage::RequestAutocorrectionData::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_ApplyAutocorrection:
        return jsValueForDecodedArguments<Messages::WebPage::ApplyAutocorrection::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_SyncApplyAutocorrection:
        return jsValueForDecodedArguments<Messages::WebPage::SyncApplyAutocorrection::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_RequestEvasionRectsAboveSelection:
        return jsValueForDecodedArguments<Messages::WebPage::RequestEvasionRectsAboveSelection::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_GetPositionInformation:
        return jsValueForDecodedArguments<Messages::WebPage::GetPositionInformation::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_FocusNextFocusedElement:
        return jsValueForDecodedArguments<Messages::WebPage::FocusNextFocusedElement::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_GetSelectionContext:
        return jsValueForDecodedArguments<Messages::WebPage::GetSelectionContext::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_GetRectsForGranularityWithSelectionOffset:
        return jsValueForDecodedArguments<Messages::WebPage::GetRectsForGranularityWithSelectionOffset::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_GetRectsAtSelectionOffsetWithText:
        return jsValueForDecodedArguments<Messages::WebPage::GetRectsAtSelectionOffsetWithText::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_RequestFocusedElementInformation:
        return jsValueForDecodedArguments<Messages::WebPage::RequestFocusedElementInformation::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_UpdateSelectionWithDelta:
        return jsValueForDecodedArguments<Messages::WebPage::UpdateSelectionWithDelta::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_RequestDocumentEditingContext:
        return jsValueForDecodedArguments<Messages::WebPage::RequestDocumentEditingContext::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_InsertTextPlaceholder:
        return jsValueForDecodedArguments<Messages::WebPage::InsertTextPlaceholder::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_RemoveTextPlaceholder:
        return jsValueForDecodedArguments<Messages::WebPage::RemoveTextPlaceholder::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_TextInputContextsInRect:
        return jsValueForDecodedArguments<Messages::WebPage::TextInputContextsInRect::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_FocusTextInputContextAndPlaceCaret:
        return jsValueForDecodedArguments<Messages::WebPage::FocusTextInputContextAndPlaceCaret::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_ClearServiceWorkerEntitlementOverride:
        return jsValueForDecodedArguments<Messages::WebPage::ClearServiceWorkerEntitlementOverride::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_RequestImageBitmap:
        return jsValueForDecodedArguments<Messages::WebPage::RequestImageBitmap::ReplyArguments>(globalObject, decoder);
#if ENABLE(IOS_TOUCH_EVENTS)
    case MessageName::WebPage_TouchEventSync:
        return jsValueForDecodedArguments<Messages::WebPage::TouchEventSync::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_GetPDFFirstPageSize:
        return jsValueForDecodedArguments<Messages::WebPage::GetPDFFirstPageSize::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_GetContentsAsString:
        return jsValueForDecodedArguments<Messages::WebPage::GetContentsAsString::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_GetAllFrames:
        return jsValueForDecodedArguments<Messages::WebPage::GetAllFrames::ReplyArguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::WebPage_GetContentsAsAttributedString:
        return jsValueForDecodedArguments<Messages::WebPage::GetContentsAsAttributedString::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(MHTML)
    case MessageName::WebPage_GetContentsAsMHTMLData:
        return jsValueForDecodedArguments<Messages::WebPage::GetContentsAsMHTMLData::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_GetMainResourceDataOfFrame:
        return jsValueForDecodedArguments<Messages::WebPage::GetMainResourceDataOfFrame::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_GetResourceDataFromFrame:
        return jsValueForDecodedArguments<Messages::WebPage::GetResourceDataFromFrame::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_GetRenderTreeExternalRepresentation:
        return jsValueForDecodedArguments<Messages::WebPage::GetRenderTreeExternalRepresentation::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_GetSelectionOrContentsAsString:
        return jsValueForDecodedArguments<Messages::WebPage::GetSelectionOrContentsAsString::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_GetSelectionAsWebArchiveData:
        return jsValueForDecodedArguments<Messages::WebPage::GetSelectionAsWebArchiveData::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_GetSourceForFrame:
        return jsValueForDecodedArguments<Messages::WebPage::GetSourceForFrame::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_GetWebArchiveOfFrame:
        return jsValueForDecodedArguments<Messages::WebPage::GetWebArchiveOfFrame::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_RunJavaScriptInFrameInScriptWorld:
        return jsValueForDecodedArguments<Messages::WebPage::RunJavaScriptInFrameInScriptWorld::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_ForceRepaint:
        return jsValueForDecodedArguments<Messages::WebPage::ForceRepaint::ReplyArguments>(globalObject, decoder);
#if ENABLE(DATA_DETECTION)
    case MessageName::WebPage_DetectDataInAllFrames:
        return jsValueForDecodedArguments<Messages::WebPage::DetectDataInAllFrames::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_RemoveDataDetectedLinks:
        return jsValueForDecodedArguments<Messages::WebPage::RemoveDataDetectedLinks::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_Suspend:
        return jsValueForDecodedArguments<Messages::WebPage::Suspend::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_Resume:
        return jsValueForDecodedArguments<Messages::WebPage::Resume::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_TryClose:
        return jsValueForDecodedArguments<Messages::WebPage::TryClose::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_ValidateCommand:
        return jsValueForDecodedArguments<Messages::WebPage::ValidateCommand::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_RequestFontAttributesAtSelectionStart:
        return jsValueForDecodedArguments<Messages::WebPage::RequestFontAttributesAtSelectionStart::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_FindString:
        return jsValueForDecodedArguments<Messages::WebPage::FindString::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_ReplaceMatches:
        return jsValueForDecodedArguments<Messages::WebPage::ReplaceMatches::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_FindRectsForStringMatches:
        return jsValueForDecodedArguments<Messages::WebPage::FindRectsForStringMatches::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_FindTextRangesForStringMatches:
        return jsValueForDecodedArguments<Messages::WebPage::FindTextRangesForStringMatches::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_RequestRectForFoundTextRange:
        return jsValueForDecodedArguments<Messages::WebPage::RequestRectForFoundTextRange::ReplyArguments>(globalObject, decoder);
#if PLATFORM(IOS_FAMILY) && ENABLE(DRAG_SUPPORT)
    case MessageName::WebPage_InsertDroppedImagePlaceholders:
        return jsValueForDecodedArguments<Messages::WebPage::InsertDroppedImagePlaceholders::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(MEDIA_STREAM)
    case MessageName::WebPage_UserMediaAccessWasGranted:
        return jsValueForDecodedArguments<Messages::WebPage::UserMediaAccessWasGranted::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(ENCRYPTED_MEDIA)
    case MessageName::WebPage_MediaKeySystemWasGranted:
        return jsValueForDecodedArguments<Messages::WebPage::MediaKeySystemWasGranted::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_RequestMediaPlaybackState:
        return jsValueForDecodedArguments<Messages::WebPage::RequestMediaPlaybackState::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_PauseAllMediaPlayback:
        return jsValueForDecodedArguments<Messages::WebPage::PauseAllMediaPlayback::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_SuspendAllMediaPlayback:
        return jsValueForDecodedArguments<Messages::WebPage::SuspendAllMediaPlayback::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_ResumeAllMediaPlayback:
        return jsValueForDecodedArguments<Messages::WebPage::ResumeAllMediaPlayback::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_IsLayerTreeFrozen:
        return jsValueForDecodedArguments<Messages::WebPage::IsLayerTreeFrozen::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_ComputePagesForPrinting:
        return jsValueForDecodedArguments<Messages::WebPage::ComputePagesForPrinting::ReplyArguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::WebPage_DrawRectToImage:
        return jsValueForDecodedArguments<Messages::WebPage::DrawRectToImage::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_DrawPagesToPDF:
        return jsValueForDecodedArguments<Messages::WebPage::DrawPagesToPDF::ReplyArguments>(globalObject, decoder);
#endif
#if (PLATFORM(COCOA) && PLATFORM(IOS_FAMILY) && !HAVE(UIKIT_BACKGROUND_THREAD_PRINTING))
    case MessageName::WebPage_ComputePagesForPrintingiOS:
        return jsValueForDecodedArguments<Messages::WebPage::ComputePagesForPrintingiOS::ReplyArguments>(globalObject, decoder);
#endif
#if (PLATFORM(COCOA) && PLATFORM(IOS_FAMILY))
    case MessageName::WebPage_DrawToPDFiOS:
        return jsValueForDecodedArguments<Messages::WebPage::DrawToPDFiOS::ReplyArguments>(globalObject, decoder);
#endif
#if PLATFORM(COCOA)
    case MessageName::WebPage_DrawToPDF:
        return jsValueForDecodedArguments<Messages::WebPage::DrawToPDF::ReplyArguments>(globalObject, decoder);
#endif
#if PLATFORM(GTK)
    case MessageName::WebPage_DrawPagesForPrinting:
        return jsValueForDecodedArguments<Messages::WebPage::DrawPagesForPrinting::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_SetMuted:
        return jsValueForDecodedArguments<Messages::WebPage::SetMuted::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_StopMediaCapture:
        return jsValueForDecodedArguments<Messages::WebPage::StopMediaCapture::ReplyArguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::WebPage_GetStringSelectionForPasteboard:
        return jsValueForDecodedArguments<Messages::WebPage::GetStringSelectionForPasteboard::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_GetDataSelectionForPasteboard:
        return jsValueForDecodedArguments<Messages::WebPage::GetDataSelectionForPasteboard::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_ReadSelectionFromPasteboard:
        return jsValueForDecodedArguments<Messages::WebPage::ReadSelectionFromPasteboard::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_ShouldDelayWindowOrderingEvent:
        return jsValueForDecodedArguments<Messages::WebPage::ShouldDelayWindowOrderingEvent::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_HasMarkedText:
        return jsValueForDecodedArguments<Messages::WebPage::HasMarkedText::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_GetMarkedRangeAsync:
        return jsValueForDecodedArguments<Messages::WebPage::GetMarkedRangeAsync::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_GetSelectedRangeAsync:
        return jsValueForDecodedArguments<Messages::WebPage::GetSelectedRangeAsync::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_CharacterIndexForPointAsync:
        return jsValueForDecodedArguments<Messages::WebPage::CharacterIndexForPointAsync::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_FirstRectForCharacterRangeAsync:
        return jsValueForDecodedArguments<Messages::WebPage::FirstRectForCharacterRangeAsync::ReplyArguments>(globalObject, decoder);
#endif
#if PLATFORM(MAC)
    case MessageName::WebPage_AttributedSubstringForCharacterRangeAsync:
        return jsValueForDecodedArguments<Messages::WebPage::AttributedSubstringForCharacterRangeAsync::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_GetBytecodeProfile:
        return jsValueForDecodedArguments<Messages::WebPage::GetBytecodeProfile::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_GetSamplingProfilerOutput:
        return jsValueForDecodedArguments<Messages::WebPage::GetSamplingProfilerOutput::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_TakeSnapshot:
        return jsValueForDecodedArguments<Messages::WebPage::TakeSnapshot::ReplyArguments>(globalObject, decoder);
#if PLATFORM(COCOA)
    case MessageName::WebPage_RequestActiveNowPlayingSessionInfo:
        return jsValueForDecodedArguments<Messages::WebPage::RequestActiveNowPlayingSessionInfo::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_DidGetLoadDecisionForIcon:
        return jsValueForDecodedArguments<Messages::WebPage::DidGetLoadDecisionForIcon::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_URLSchemeTaskWillPerformRedirection:
        return jsValueForDecodedArguments<Messages::WebPage::URLSchemeTaskWillPerformRedirection::ReplyArguments>(globalObject, decoder);
#if ENABLE(ATTACHMENT_ELEMENT)
    case MessageName::WebPage_InsertAttachment:
        return jsValueForDecodedArguments<Messages::WebPage::InsertAttachment::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_UpdateAttachmentAttributes:
        return jsValueForDecodedArguments<Messages::WebPage::UpdateAttachmentAttributes::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(APPLICATION_MANIFEST)
    case MessageName::WebPage_GetApplicationManifest:
        return jsValueForDecodedArguments<Messages::WebPage::GetApplicationManifest::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(UI_PROCESS_PDF_HUD)
    case MessageName::WebPage_SavePDF:
        return jsValueForDecodedArguments<Messages::WebPage::SavePDF::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_OpenPDFWithPreview:
        return jsValueForDecodedArguments<Messages::WebPage::OpenPDFWithPreview::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
    case MessageName::WebPage_GetLoadedSubresourceDomains:
        return jsValueForDecodedArguments<Messages::WebPage::GetLoadedSubresourceDomains::ReplyArguments>(globalObject, decoder);
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    case MessageName::WebPage_SendMessageToWebExtensionWithReply:
        return jsValueForDecodedArguments<Messages::WebPage::SendMessageToWebExtensionWithReply::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_StartTextManipulations:
        return jsValueForDecodedArguments<Messages::WebPage::StartTextManipulations::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_CompleteTextManipulation:
        return jsValueForDecodedArguments<Messages::WebPage::CompleteTextManipulation::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_GetProcessDisplayName:
        return jsValueForDecodedArguments<Messages::WebPage::GetProcessDisplayName::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_DispatchWheelEventWithoutScrolling:
        return jsValueForDecodedArguments<Messages::WebPage::DispatchWheelEventWithoutScrolling::ReplyArguments>(globalObject, decoder);
    case MessageName::WebPage_LastNavigationWasAppInitiated:
        return jsValueForDecodedArguments<Messages::WebPage::LastNavigationWasAppInitiated::ReplyArguments>(globalObject, decoder);
#if ENABLE(MEDIA_SESSION_COORDINATOR)
    case MessageName::WebPage_CreateMediaSessionCoordinator:
        return jsValueForDecodedArguments<Messages::WebPage::CreateMediaSessionCoordinator::ReplyArguments>(globalObject, decoder);
#endif
#if ENABLE(IMAGE_ANALYSIS)
    case MessageName::WebPage_UpdateWithTextRecognitionResult:
        return jsValueForDecodedArguments<Messages::WebPage::UpdateWithTextRecognitionResult::ReplyArguments>(globalObject, decoder);
#endif
    case MessageName::WebPage_InteractableRegionsInRootViewCoordinates:
        return jsValueForDecodedArguments<Messages::WebPage::InteractableRegionsInRootViewCoordinates::ReplyArguments>(globalObject, decoder);
#if ENABLE(WEBXR)
#endif
    default:
        break;
    }
    return std::nullopt;
}

#endif // ENABLE(IPC_TESTING_API)

std::optional<Vector<ArgumentDescription>> messageArgumentDescriptions(MessageName name)
{
    switch (name) {
#if ENABLE(GPU_PROCESS)
    case MessageName::GPUConnectionToWebProcess_CreateRenderingBackend:
        return Vector<ArgumentDescription> {
            {"creationParameters", "WebKit::RemoteRenderingBackendCreationParameters", nullptr, false},
            {"streamBuffer", "IPC::StreamConnectionBuffer", nullptr, false},
        };
    case MessageName::GPUConnectionToWebProcess_ReleaseRenderingBackend:
        return Vector<ArgumentDescription> {
            {"renderingBackendIdentifier", "WebKit::RenderingBackendIdentifier", nullptr, false},
        };
#if ENABLE(WEBGL)
    case MessageName::GPUConnectionToWebProcess_CreateGraphicsContextGL:
        return Vector<ArgumentDescription> {
            {"attributes", "WebCore::GraphicsContextGLAttributes", nullptr, false},
            {"graphicsContextGLIdentifier", "WebKit::GraphicsContextGLIdentifier", nullptr, false},
            {"renderingBackendIdentifier", "WebKit::RenderingBackendIdentifier", nullptr, false},
            {"stream", "IPC::StreamConnectionBuffer", nullptr, false},
        };
    case MessageName::GPUConnectionToWebProcess_ReleaseGraphicsContextGL:
        return Vector<ArgumentDescription> {
            {"graphicsContextGLIdentifier", "WebKit::GraphicsContextGLIdentifier", nullptr, false},
        };
#endif
    case MessageName::GPUConnectionToWebProcess_CreateRemoteGPU:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
            {"renderingBackendIdentifier", "WebKit::RenderingBackendIdentifier", nullptr, false},
            {"stream", "IPC::StreamConnectionBuffer", nullptr, false},
        };
    case MessageName::GPUConnectionToWebProcess_ClearNowPlayingInfo:
        return Vector<ArgumentDescription> { };
    case MessageName::GPUConnectionToWebProcess_SetNowPlayingInfo:
        return Vector<ArgumentDescription> {
            {"nowPlayingInfo", "WebCore::NowPlayingInfo", nullptr, false},
        };
#if USE(AUDIO_SESSION)
    case MessageName::GPUConnectionToWebProcess_EnsureAudioSession:
        return Vector<ArgumentDescription> { };
#endif
#if PLATFORM(IOS_FAMILY)
    case MessageName::GPUConnectionToWebProcess_EnsureMediaSessionHelper:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(VP9)
    case MessageName::GPUConnectionToWebProcess_EnableVP9Decoders:
        return Vector<ArgumentDescription> {
            {"shouldEnableVP8Decoder", "bool", nullptr, false},
            {"shouldEnableVP9Decoder", "bool", nullptr, false},
            {"shouldEnableVP9SWDecoder", "bool", nullptr, false},
        };
#endif
#if HAVE(VISIBILITY_PROPAGATION_VIEW)
    case MessageName::GPUConnectionToWebProcess_CreateVisibilityPropagationContextForPage:
        return Vector<ArgumentDescription> {
            {"pageProxyID", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
            {"canShowWhileLocked", "bool", nullptr, false},
        };
    case MessageName::GPUConnectionToWebProcess_DestroyVisibilityPropagationContextForPage:
        return Vector<ArgumentDescription> {
            {"pageProxyID", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
        };
#endif
    case MessageName::GPUConnectionToWebProcess_SetMediaOverridesForTesting:
        return Vector<ArgumentDescription> {
            {"configuration", "WebKit::MediaOverridesForTesting", nullptr, false},
        };
    case MessageName::GPUConnectionToWebProcess_CreateAudioHardwareListener:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RemoteAudioHardwareListenerIdentifier", nullptr, false},
        };
    case MessageName::GPUConnectionToWebProcess_ReleaseAudioHardwareListener:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RemoteAudioHardwareListenerIdentifier", nullptr, false},
        };
    case MessageName::GPUConnectionToWebProcess_CreateRemoteCommandListener:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RemoteRemoteCommandListenerIdentifier", nullptr, false},
        };
    case MessageName::GPUConnectionToWebProcess_ReleaseRemoteCommandListener:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RemoteRemoteCommandListenerIdentifier", nullptr, false},
        };
    case MessageName::GPUConnectionToWebProcess_SetUserPreferredLanguages:
        return Vector<ArgumentDescription> {
            {"languages", "Vector<String>", nullptr, false},
        };
    case MessageName::GPUConnectionToWebProcess_ConfigureLoggingChannel:
        return Vector<ArgumentDescription> {
            {"channelName", "String", nullptr, false},
            {"state", "uint8_t", "WTFLogChannelState", false},
            {"level", "uint8_t", "WTFLogLevel", false},
        };
#if USE(GRAPHICS_LAYER_WC)
    case MessageName::GPUConnectionToWebProcess_CreateWCLayerTreeHost:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::WCLayerTreeHostIdentifier", nullptr, false},
            {"nativeWindow", "uint64_t", nullptr, false},
            {"usesOffscreenRendering", "bool", nullptr, false},
        };
    case MessageName::GPUConnectionToWebProcess_ReleaseWCLayerTreeHost:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::WCLayerTreeHostIdentifier", nullptr, false},
        };
#endif
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::GPUProcess_InitializeGPUProcess:
        return Vector<ArgumentDescription> {
            {"processCreationParameters", "WebKit::GPUProcessCreationParameters", nullptr, false},
        };
    case MessageName::GPUProcess_CreateGPUConnectionToWebProcess:
        return Vector<ArgumentDescription> {
            {"processIdentifier", "WebCore::ProcessIdentifier", nullptr, false},
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"parameters", "WebKit::GPUProcessConnectionParameters", nullptr, false},
        };
    case MessageName::GPUProcess_PrepareToSuspend:
        return Vector<ArgumentDescription> {
            {"isSuspensionImminent", "bool", nullptr, false},
        };
    case MessageName::GPUProcess_ProcessDidResume:
        return Vector<ArgumentDescription> { };
    case MessageName::GPUProcess_AddSession:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"parameters", "WebKit::GPUProcessSessionParameters", nullptr, false},
        };
    case MessageName::GPUProcess_RemoveSession:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
#if ENABLE(MEDIA_STREAM)
    case MessageName::GPUProcess_SetMockCaptureDevicesEnabled:
        return Vector<ArgumentDescription> {
            {"isEnabled", "bool", nullptr, false},
        };
    case MessageName::GPUProcess_SetOrientationForMediaCapture:
        return Vector<ArgumentDescription> {
            {"orientation", "uint64_t", nullptr, false},
        };
    case MessageName::GPUProcess_UpdateSandboxAccess:
        return Vector<ArgumentDescription> {
            {"extensions", "Vector<WebKit::SandboxExtension::Handle>", nullptr, false},
        };
    case MessageName::GPUProcess_UpdateCaptureAccess:
        return Vector<ArgumentDescription> {
            {"allowAudioCapture", "bool", nullptr, false},
            {"allowVideoCapture", "bool", nullptr, false},
            {"allowDisplayCapture", "bool", nullptr, false},
            {"processID", "WebCore::ProcessIdentifier", nullptr, false},
        };
    case MessageName::GPUProcess_UpdateCaptureOrigin:
        return Vector<ArgumentDescription> {
            {"originData", "WebCore::SecurityOriginData", nullptr, false},
            {"processID", "WebCore::ProcessIdentifier", nullptr, false},
        };
    case MessageName::GPUProcess_AddMockMediaDevice:
        return Vector<ArgumentDescription> {
            {"device", "WebCore::MockMediaDevice", nullptr, false},
        };
    case MessageName::GPUProcess_ClearMockMediaDevices:
        return Vector<ArgumentDescription> { };
    case MessageName::GPUProcess_RemoveMockMediaDevice:
        return Vector<ArgumentDescription> {
            {"persistentId", "String", nullptr, false},
        };
    case MessageName::GPUProcess_ResetMockMediaDevices:
        return Vector<ArgumentDescription> { };
    case MessageName::GPUProcess_SetMockCaptureDevicesInterrupted:
        return Vector<ArgumentDescription> {
            {"isCameraInterrupted", "bool", nullptr, false},
            {"isMicrophoneInterrupted", "bool", nullptr, false},
        };
#endif
#if PLATFORM(MAC)
    case MessageName::GPUProcess_DisplayConfigurationChanged:
        return Vector<ArgumentDescription> {
            {"displayID", "CGDirectDisplayID", nullptr, false},
            {"flags", "CGDisplayChangeSummaryFlags", nullptr, false},
        };
    case MessageName::GPUProcess_SetScreenProperties:
        return Vector<ArgumentDescription> {
            {"screenProperties", "WebCore::ScreenProperties", nullptr, false},
        };
#endif
#if HAVE(SC_CONTENT_SHARING_SESSION)
    case MessageName::GPUProcess_ShowWindowPicker:
        return Vector<ArgumentDescription> { };
    case MessageName::GPUProcess_ShowScreenPicker:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(MEDIA_SOURCE)
    case MessageName::GPUProcess_SetWebMParserEnabled:
        return Vector<ArgumentDescription> {
            {"enabled", "bool", nullptr, false},
        };
#endif
#if ENABLE(WEBM_FORMAT_READER)
    case MessageName::GPUProcess_SetWebMFormatReaderEnabled:
        return Vector<ArgumentDescription> {
            {"enabled", "bool", nullptr, false},
        };
#endif
#if ENABLE(OPUS)
    case MessageName::GPUProcess_SetOpusDecoderEnabled:
        return Vector<ArgumentDescription> {
            {"enabled", "bool", nullptr, false},
        };
#endif
#if ENABLE(VORBIS)
    case MessageName::GPUProcess_SetVorbisDecoderEnabled:
        return Vector<ArgumentDescription> {
            {"enabled", "bool", nullptr, false},
        };
#endif
#if ENABLE(MEDIA_SOURCE) && HAVE(AVSAMPLEBUFFERVIDEOOUTPUT)
    case MessageName::GPUProcess_SetMediaSourceInlinePaintingEnabled:
        return Vector<ArgumentDescription> {
            {"enabled", "bool", nullptr, false},
        };
#endif
#if HAVE(SCREEN_CAPTURE_KIT)
    case MessageName::GPUProcess_SetUseScreenCaptureKit:
        return Vector<ArgumentDescription> {
            {"use", "bool", nullptr, false},
        };
#endif
    case MessageName::GPUProcess_RequestBitmapImageForCurrentTime:
        return Vector<ArgumentDescription> {
            {"processIdentifier", "WebCore::ProcessIdentifier", nullptr, false},
            {"playerIdentifier", "WebCore::MediaPlayerIdentifier", nullptr, false},
        };
#if ENABLE(CFPREFS_DIRECT_MODE)
    case MessageName::GPUProcess_NotifyPreferencesChanged:
        return Vector<ArgumentDescription> {
            {"domain", "String", nullptr, false},
            {"key", "String", nullptr, false},
            {"encodedValue", "String", nullptr, true},
        };
#endif
    case MessageName::GPUProcess_WebProcessConnectionCountForTesting:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteDisplayListRecorder_Save:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteDisplayListRecorder_Restore:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteDisplayListRecorder_Translate:
        return Vector<ArgumentDescription> {
            {"x", "float", nullptr, false},
            {"y", "float", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_Rotate:
        return Vector<ArgumentDescription> {
            {"angle", "float", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_Scale:
        return Vector<ArgumentDescription> {
            {"scale", "WebCore::FloatSize", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_SetCTM:
        return Vector<ArgumentDescription> {
            {"ctm", "WebCore::AffineTransform", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_ConcatenateCTM:
        return Vector<ArgumentDescription> {
            {"ctm", "WebCore::AffineTransform", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_SetInlineFillColor:
        return Vector<ArgumentDescription> {
            {"item", "WebCore::DisplayList::SetInlineFillColor", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_SetInlineStrokeColor:
        return Vector<ArgumentDescription> {
            {"item", "WebCore::DisplayList::SetInlineStrokeColor", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_SetStrokeThickness:
        return Vector<ArgumentDescription> {
            {"thickness", "float", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_SetState:
        return Vector<ArgumentDescription> {
            {"item", "WebCore::DisplayList::SetState", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_SetLineCap:
        return Vector<ArgumentDescription> {
            {"lineCap", "uint8_t", "WebCore::LineCap", false},
        };
    case MessageName::RemoteDisplayListRecorder_SetLineDash:
        return Vector<ArgumentDescription> {
            {"item", "WebCore::DisplayList::SetLineDash", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_SetLineJoin:
        return Vector<ArgumentDescription> {
            {"lineJoin", "uint8_t", "WebCore::LineJoin", false},
        };
    case MessageName::RemoteDisplayListRecorder_SetMiterLimit:
        return Vector<ArgumentDescription> {
            {"limit", "float", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_ClearShadow:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteDisplayListRecorder_Clip:
        return Vector<ArgumentDescription> {
            {"rect", "WebCore::FloatRect", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_ClipOut:
        return Vector<ArgumentDescription> {
            {"rect", "WebCore::FloatRect", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_ClipToImageBuffer:
        return Vector<ArgumentDescription> {
            {"renderingResourceIdentifier", "WebCore::RenderingResourceIdentifier", nullptr, false},
            {"destinationRect", "WebCore::FloatRect", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_ClipOutToPath:
        return Vector<ArgumentDescription> {
            {"path", "WebCore::Path", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_ClipPath:
        return Vector<ArgumentDescription> {
            {"path", "WebCore::Path", nullptr, false},
            {"windRule", "uint8_t", "WebCore::WindRule", false},
        };
    case MessageName::RemoteDisplayListRecorder_DrawGlyphs:
        return Vector<ArgumentDescription> {
            {"item", "WebCore::DisplayList::DrawGlyphs", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_DrawFilteredImageBuffer:
        return Vector<ArgumentDescription> {
            {"sourceImageIdentifier", "WebCore::RenderingResourceIdentifier", nullptr, true},
            {"sourceImageRect", "WebCore::FloatRect", nullptr, false},
            {"filter", "IPC::FilterReference", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_DrawImageBuffer:
        return Vector<ArgumentDescription> {
            {"imageBufferIdentifier", "WebCore::RenderingResourceIdentifier", nullptr, false},
            {"destinationRect", "WebCore::FloatRect", nullptr, false},
            {"srcRect", "WebCore::FloatRect", nullptr, false},
            {"options", "WebCore::ImagePaintingOptions", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_DrawNativeImage:
        return Vector<ArgumentDescription> {
            {"imageIdentifier", "WebCore::RenderingResourceIdentifier", nullptr, false},
            {"imageSize", "WebCore::FloatSize", nullptr, false},
            {"destRect", "WebCore::FloatRect", nullptr, false},
            {"srcRect", "WebCore::FloatRect", nullptr, false},
            {"options", "WebCore::ImagePaintingOptions", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_DrawPattern:
        return Vector<ArgumentDescription> {
            {"imageIdentifier", "WebCore::RenderingResourceIdentifier", nullptr, false},
            {"destRect", "WebCore::FloatRect", nullptr, false},
            {"tileRect", "WebCore::FloatRect", nullptr, false},
            {"transform", "WebCore::AffineTransform", nullptr, false},
            {"phase", "WebCore::FloatPoint", nullptr, false},
            {"spacing", "WebCore::FloatSize", nullptr, false},
            {"options", "WebCore::ImagePaintingOptions", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_BeginTransparencyLayer:
        return Vector<ArgumentDescription> {
            {"opacity", "float", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_EndTransparencyLayer:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteDisplayListRecorder_DrawRect:
        return Vector<ArgumentDescription> {
            {"rect", "WebCore::FloatRect", nullptr, false},
            {"borderThickness", "float", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_DrawLine:
        return Vector<ArgumentDescription> {
            {"point1", "WebCore::FloatPoint", nullptr, false},
            {"point2", "WebCore::FloatPoint", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_DrawLinesForText:
        return Vector<ArgumentDescription> {
            {"item", "WebCore::DisplayList::DrawLinesForText", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_DrawDotsForDocumentMarker:
        return Vector<ArgumentDescription> {
            {"rect", "WebCore::FloatRect", nullptr, false},
            {"style", "WebCore::DocumentMarkerLineStyle", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_DrawEllipse:
        return Vector<ArgumentDescription> {
            {"rect", "WebCore::FloatRect", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_DrawPath:
        return Vector<ArgumentDescription> {
            {"path", "WebCore::Path", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_DrawFocusRingPath:
        return Vector<ArgumentDescription> {
            {"path", "WebCore::Path", nullptr, false},
            {"width", "float", nullptr, false},
            {"offset", "float", nullptr, false},
            {"color", "WebCore::Color", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_DrawFocusRingRects:
        return Vector<ArgumentDescription> {
            {"rects", "Vector<WebCore::FloatRect>", nullptr, false},
            {"width", "float", nullptr, false},
            {"offset", "float", nullptr, false},
            {"color", "WebCore::Color", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_FillRect:
        return Vector<ArgumentDescription> {
            {"rect", "WebCore::FloatRect", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_FillRectWithColor:
        return Vector<ArgumentDescription> {
            {"rect", "WebCore::FloatRect", nullptr, false},
            {"color", "WebCore::Color", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_FillRectWithGradient:
        return Vector<ArgumentDescription> {
            {"item", "WebCore::DisplayList::FillRectWithGradient", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_FillCompositedRect:
        return Vector<ArgumentDescription> {
            {"rect", "WebCore::FloatRect", nullptr, false},
            {"color", "WebCore::Color", nullptr, false},
            {"op", "uint8_t", "WebCore::CompositeOperator", false},
            {"blendMode", "uint8_t", "WebCore::BlendMode", false},
        };
    case MessageName::RemoteDisplayListRecorder_FillRoundedRect:
        return Vector<ArgumentDescription> {
            {"rect", "WebCore::FloatRoundedRect", nullptr, false},
            {"color", "WebCore::Color", nullptr, false},
            {"blendMode", "uint8_t", "WebCore::BlendMode", false},
        };
    case MessageName::RemoteDisplayListRecorder_FillRectWithRoundedHole:
        return Vector<ArgumentDescription> {
            {"rect", "WebCore::FloatRect", nullptr, false},
            {"roundedHoleRect", "WebCore::FloatRoundedRect", nullptr, false},
            {"color", "WebCore::Color", nullptr, false},
        };
#if ENABLE(INLINE_PATH_DATA)
    case MessageName::RemoteDisplayListRecorder_FillLine:
        return Vector<ArgumentDescription> {
            {"data", "WebCore::LineData", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_FillArc:
        return Vector<ArgumentDescription> {
            {"data", "WebCore::ArcData", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_FillQuadCurve:
        return Vector<ArgumentDescription> {
            {"data", "WebCore::QuadCurveData", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_FillBezierCurve:
        return Vector<ArgumentDescription> {
            {"data", "WebCore::BezierCurveData", nullptr, false},
        };
#endif
    case MessageName::RemoteDisplayListRecorder_FillPath:
        return Vector<ArgumentDescription> {
            {"path", "WebCore::Path", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_FillEllipse:
        return Vector<ArgumentDescription> {
            {"rect", "WebCore::FloatRect", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_ConvertToLuminanceMask:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteDisplayListRecorder_TransformToColorSpace:
        return Vector<ArgumentDescription> {
            {"colorSpace", "WebCore::DestinationColorSpace", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_PaintFrameForMedia:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::MediaPlayerIdentifier", nullptr, false},
            {"destination", "WebCore::FloatRect", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_StrokeRect:
        return Vector<ArgumentDescription> {
            {"rect", "WebCore::FloatRect", nullptr, false},
            {"lineWidth", "float", nullptr, false},
        };
#if ENABLE(INLINE_PATH_DATA)
    case MessageName::RemoteDisplayListRecorder_StrokeLine:
        return Vector<ArgumentDescription> {
            {"data", "WebCore::LineData", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_StrokeArc:
        return Vector<ArgumentDescription> {
            {"data", "WebCore::ArcData", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_StrokeQuadCurve:
        return Vector<ArgumentDescription> {
            {"data", "WebCore::QuadCurveData", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_StrokeBezierCurve:
        return Vector<ArgumentDescription> {
            {"data", "WebCore::BezierCurveData", nullptr, false},
        };
#endif
    case MessageName::RemoteDisplayListRecorder_StrokePath:
        return Vector<ArgumentDescription> {
            {"path", "WebCore::Path", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_StrokeEllipse:
        return Vector<ArgumentDescription> {
            {"rect", "WebCore::FloatRect", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_ClearRect:
        return Vector<ArgumentDescription> {
            {"rect", "WebCore::FloatRect", nullptr, false},
        };
#if USE(CG)
    case MessageName::RemoteDisplayListRecorder_ApplyStrokePattern:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteDisplayListRecorder_ApplyFillPattern:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::RemoteDisplayListRecorder_ApplyDeviceScaleFactor:
        return Vector<ArgumentDescription> {
            {"scaleFactor", "float", nullptr, false},
        };
    case MessageName::RemoteDisplayListRecorder_FlushContext:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::GraphicsContextFlushIdentifier", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(WEBGL)
    case MessageName::RemoteGraphicsContextGL_Reshape:
        return Vector<ArgumentDescription> {
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
        };
#if PLATFORM(COCOA)
    case MessageName::RemoteGraphicsContextGL_PrepareForDisplay:
        return Vector<ArgumentDescription> { };
#endif
#if USE(GRAPHICS_LAYER_WC)
    case MessageName::RemoteGraphicsContextGL_PrepareForDisplay:
        return Vector<ArgumentDescription> { };
#endif
#if !PLATFORM(COCOA) && !USE(GRAPHICS_LAYER_WC)
    case MessageName::RemoteGraphicsContextGL_PrepareForDisplay:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::RemoteGraphicsContextGL_EnsureExtensionEnabled:
        return Vector<ArgumentDescription> {
            {"extension", "String", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_MarkContextChanged:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteGraphicsContextGL_SynthesizeGLError:
        return Vector<ArgumentDescription> {
            {"error", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetError:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteGraphicsContextGL_PaintRenderingResultsToCanvas:
        return Vector<ArgumentDescription> {
            {"imageBuffer", "WebCore::RenderingResourceIdentifier", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_PaintCompositedResultsToCanvas:
        return Vector<ArgumentDescription> {
            {"imageBuffer", "WebCore::RenderingResourceIdentifier", nullptr, false},
        };
#if ENABLE(VIDEO)
    case MessageName::RemoteGraphicsContextGL_CopyTextureFromVideoFrame:
        return Vector<ArgumentDescription> {
            {"videoFrame", "WebKit::RemoteVideoFrameReadReference", nullptr, false},
            {"texture", "uint32_t", nullptr, false},
            {"target", "uint32_t", nullptr, false},
            {"level", "int32_t", nullptr, false},
            {"internalFormat", "uint32_t", nullptr, false},
            {"format", "uint32_t", nullptr, false},
            {"type", "uint32_t", nullptr, false},
            {"premultiplyAlpha", "bool", nullptr, false},
            {"flipY", "bool", nullptr, false},
        };
#endif
#if ENABLE(MEDIA_STREAM)
    case MessageName::RemoteGraphicsContextGL_PaintCompositedResultsToMediaSample:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::RemoteGraphicsContextGL_SimulateEventForTesting:
        return Vector<ArgumentDescription> {
            {"event", "WebCore::GraphicsContextGL::SimulatedEventForTesting", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_MoveErrorsToSyntheticErrorList:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteGraphicsContextGL_ActiveTexture:
        return Vector<ArgumentDescription> {
            {"texture", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_AttachShader:
        return Vector<ArgumentDescription> {
            {"program", "uint32_t", nullptr, false},
            {"shader", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_BindAttribLocation:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
            {"index", "uint32_t", nullptr, false},
            {"name", "String", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_BindBuffer:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"arg1", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_BindFramebuffer:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"arg1", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_BindRenderbuffer:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"arg1", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_BindTexture:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"arg1", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_BlendColor:
        return Vector<ArgumentDescription> {
            {"red", "float", nullptr, false},
            {"green", "float", nullptr, false},
            {"blue", "float", nullptr, false},
            {"alpha", "float", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_BlendEquation:
        return Vector<ArgumentDescription> {
            {"mode", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_BlendEquationSeparate:
        return Vector<ArgumentDescription> {
            {"modeRGB", "uint32_t", nullptr, false},
            {"modeAlpha", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_BlendFunc:
        return Vector<ArgumentDescription> {
            {"sfactor", "uint32_t", nullptr, false},
            {"dfactor", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_BlendFuncSeparate:
        return Vector<ArgumentDescription> {
            {"srcRGB", "uint32_t", nullptr, false},
            {"dstRGB", "uint32_t", nullptr, false},
            {"srcAlpha", "uint32_t", nullptr, false},
            {"dstAlpha", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CheckFramebufferStatus:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Clear:
        return Vector<ArgumentDescription> {
            {"mask", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_ClearColor:
        return Vector<ArgumentDescription> {
            {"red", "float", nullptr, false},
            {"green", "float", nullptr, false},
            {"blue", "float", nullptr, false},
            {"alpha", "float", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_ClearDepth:
        return Vector<ArgumentDescription> {
            {"depth", "float", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_ClearStencil:
        return Vector<ArgumentDescription> {
            {"s", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_ColorMask:
        return Vector<ArgumentDescription> {
            {"red", "bool", nullptr, false},
            {"green", "bool", nullptr, false},
            {"blue", "bool", nullptr, false},
            {"alpha", "bool", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CompileShader:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CopyTexImage2D:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"level", "int32_t", nullptr, false},
            {"internalformat", "uint32_t", nullptr, false},
            {"x", "int32_t", nullptr, false},
            {"y", "int32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
            {"border", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CopyTexSubImage2D:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"level", "int32_t", nullptr, false},
            {"xoffset", "int32_t", nullptr, false},
            {"yoffset", "int32_t", nullptr, false},
            {"x", "int32_t", nullptr, false},
            {"y", "int32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CreateBuffer:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteGraphicsContextGL_CreateFramebuffer:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteGraphicsContextGL_CreateProgram:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteGraphicsContextGL_CreateRenderbuffer:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteGraphicsContextGL_CreateShader:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CreateTexture:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteGraphicsContextGL_CullFace:
        return Vector<ArgumentDescription> {
            {"mode", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_DeleteBuffer:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_DeleteFramebuffer:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_DeleteProgram:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_DeleteRenderbuffer:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_DeleteShader:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_DeleteTexture:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_DepthFunc:
        return Vector<ArgumentDescription> {
            {"func", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_DepthMask:
        return Vector<ArgumentDescription> {
            {"flag", "bool", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_DepthRange:
        return Vector<ArgumentDescription> {
            {"zNear", "float", nullptr, false},
            {"zFar", "float", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_DetachShader:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
            {"arg1", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Disable:
        return Vector<ArgumentDescription> {
            {"cap", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_DisableVertexAttribArray:
        return Vector<ArgumentDescription> {
            {"index", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_DrawArrays:
        return Vector<ArgumentDescription> {
            {"mode", "uint32_t", nullptr, false},
            {"first", "int32_t", nullptr, false},
            {"count", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_DrawElements:
        return Vector<ArgumentDescription> {
            {"mode", "uint32_t", nullptr, false},
            {"count", "int32_t", nullptr, false},
            {"type", "uint32_t", nullptr, false},
            {"offset", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Enable:
        return Vector<ArgumentDescription> {
            {"cap", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_EnableVertexAttribArray:
        return Vector<ArgumentDescription> {
            {"index", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Finish:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteGraphicsContextGL_Flush:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteGraphicsContextGL_FramebufferRenderbuffer:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"attachment", "uint32_t", nullptr, false},
            {"renderbuffertarget", "uint32_t", nullptr, false},
            {"arg3", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_FramebufferTexture2D:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"attachment", "uint32_t", nullptr, false},
            {"textarget", "uint32_t", nullptr, false},
            {"arg3", "uint32_t", nullptr, false},
            {"level", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_FrontFace:
        return Vector<ArgumentDescription> {
            {"mode", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GenerateMipmap:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetActiveAttrib:
        return Vector<ArgumentDescription> {
            {"program", "uint32_t", nullptr, false},
            {"index", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetActiveUniform:
        return Vector<ArgumentDescription> {
            {"program", "uint32_t", nullptr, false},
            {"index", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetAttribLocation:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
            {"name", "String", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetBufferParameteri:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"pname", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetString:
        return Vector<ArgumentDescription> {
            {"name", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetFloatv:
        return Vector<ArgumentDescription> {
            {"pname", "uint32_t", nullptr, false},
            {"valueSize", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetIntegerv:
        return Vector<ArgumentDescription> {
            {"pname", "uint32_t", nullptr, false},
            {"valueSize", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetInteger64:
        return Vector<ArgumentDescription> {
            {"pname", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetInteger64i:
        return Vector<ArgumentDescription> {
            {"pname", "uint32_t", nullptr, false},
            {"index", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetProgrami:
        return Vector<ArgumentDescription> {
            {"program", "uint32_t", nullptr, false},
            {"pname", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetBooleanv:
        return Vector<ArgumentDescription> {
            {"pname", "uint32_t", nullptr, false},
            {"valueSize", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetFramebufferAttachmentParameteri:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"attachment", "uint32_t", nullptr, false},
            {"pname", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetProgramInfoLog:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetRenderbufferParameteri:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"pname", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetShaderi:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
            {"pname", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetShaderInfoLog:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetShaderPrecisionFormat:
        return Vector<ArgumentDescription> {
            {"shaderType", "uint32_t", nullptr, false},
            {"precisionType", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetShaderSource:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetTexParameterf:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"pname", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetTexParameteri:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"pname", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetUniformfv:
        return Vector<ArgumentDescription> {
            {"program", "uint32_t", nullptr, false},
            {"location", "int32_t", nullptr, false},
            {"valueSize", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetUniformiv:
        return Vector<ArgumentDescription> {
            {"program", "uint32_t", nullptr, false},
            {"location", "int32_t", nullptr, false},
            {"valueSize", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetUniformuiv:
        return Vector<ArgumentDescription> {
            {"program", "uint32_t", nullptr, false},
            {"location", "int32_t", nullptr, false},
            {"valueSize", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetUniformLocation:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
            {"name", "String", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetVertexAttribOffset:
        return Vector<ArgumentDescription> {
            {"index", "uint32_t", nullptr, false},
            {"pname", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Hint:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"mode", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_IsBuffer:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_IsEnabled:
        return Vector<ArgumentDescription> {
            {"cap", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_IsFramebuffer:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_IsProgram:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_IsRenderbuffer:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_IsShader:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_IsTexture:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_LineWidth:
        return Vector<ArgumentDescription> {
            {"arg0", "float", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_LinkProgram:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_PixelStorei:
        return Vector<ArgumentDescription> {
            {"pname", "uint32_t", nullptr, false},
            {"param", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_PolygonOffset:
        return Vector<ArgumentDescription> {
            {"factor", "float", nullptr, false},
            {"units", "float", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_RenderbufferStorage:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"internalformat", "uint32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_SampleCoverage:
        return Vector<ArgumentDescription> {
            {"value", "float", nullptr, false},
            {"invert", "bool", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Scissor:
        return Vector<ArgumentDescription> {
            {"x", "int32_t", nullptr, false},
            {"y", "int32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_ShaderSource:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
            {"arg1", "String", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_StencilFunc:
        return Vector<ArgumentDescription> {
            {"func", "uint32_t", nullptr, false},
            {"ref", "int32_t", nullptr, false},
            {"mask", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_StencilFuncSeparate:
        return Vector<ArgumentDescription> {
            {"face", "uint32_t", nullptr, false},
            {"func", "uint32_t", nullptr, false},
            {"ref", "int32_t", nullptr, false},
            {"mask", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_StencilMask:
        return Vector<ArgumentDescription> {
            {"mask", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_StencilMaskSeparate:
        return Vector<ArgumentDescription> {
            {"face", "uint32_t", nullptr, false},
            {"mask", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_StencilOp:
        return Vector<ArgumentDescription> {
            {"fail", "uint32_t", nullptr, false},
            {"zfail", "uint32_t", nullptr, false},
            {"zpass", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_StencilOpSeparate:
        return Vector<ArgumentDescription> {
            {"face", "uint32_t", nullptr, false},
            {"fail", "uint32_t", nullptr, false},
            {"zfail", "uint32_t", nullptr, false},
            {"zpass", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_TexParameterf:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"pname", "uint32_t", nullptr, false},
            {"param", "float", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_TexParameteri:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"pname", "uint32_t", nullptr, false},
            {"param", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Uniform1f:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"x", "float", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Uniform1fv:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"v", "IPC::ArrayReference<float>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Uniform1i:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"x", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Uniform1iv:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"v", "IPC::ArrayReference<int32_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Uniform2f:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"x", "float", nullptr, false},
            {"y", "float", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Uniform2fv:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"v", "IPC::ArrayReference<float>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Uniform2i:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"x", "int32_t", nullptr, false},
            {"y", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Uniform2iv:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"v", "IPC::ArrayReference<int32_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Uniform3f:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"x", "float", nullptr, false},
            {"y", "float", nullptr, false},
            {"z", "float", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Uniform3fv:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"v", "IPC::ArrayReference<float>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Uniform3i:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"x", "int32_t", nullptr, false},
            {"y", "int32_t", nullptr, false},
            {"z", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Uniform3iv:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"v", "IPC::ArrayReference<int32_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Uniform4f:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"x", "float", nullptr, false},
            {"y", "float", nullptr, false},
            {"z", "float", nullptr, false},
            {"w", "float", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Uniform4fv:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"v", "IPC::ArrayReference<float>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Uniform4i:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"x", "int32_t", nullptr, false},
            {"y", "int32_t", nullptr, false},
            {"z", "int32_t", nullptr, false},
            {"w", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Uniform4iv:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"v", "IPC::ArrayReference<int32_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_UniformMatrix2fv:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"transpose", "bool", nullptr, false},
            {"value", "IPC::ArrayReference<float>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_UniformMatrix3fv:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"transpose", "bool", nullptr, false},
            {"value", "IPC::ArrayReference<float>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_UniformMatrix4fv:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"transpose", "bool", nullptr, false},
            {"value", "IPC::ArrayReference<float>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_UseProgram:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_ValidateProgram:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_VertexAttrib1f:
        return Vector<ArgumentDescription> {
            {"index", "uint32_t", nullptr, false},
            {"x", "float", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_VertexAttrib1fv:
        return Vector<ArgumentDescription> {
            {"index", "uint32_t", nullptr, false},
            {"values", "IPC::ArrayReference<float, 1>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_VertexAttrib2f:
        return Vector<ArgumentDescription> {
            {"index", "uint32_t", nullptr, false},
            {"x", "float", nullptr, false},
            {"y", "float", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_VertexAttrib2fv:
        return Vector<ArgumentDescription> {
            {"index", "uint32_t", nullptr, false},
            {"values", "IPC::ArrayReference<float, 2>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_VertexAttrib3f:
        return Vector<ArgumentDescription> {
            {"index", "uint32_t", nullptr, false},
            {"x", "float", nullptr, false},
            {"y", "float", nullptr, false},
            {"z", "float", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_VertexAttrib3fv:
        return Vector<ArgumentDescription> {
            {"index", "uint32_t", nullptr, false},
            {"values", "IPC::ArrayReference<float, 3>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_VertexAttrib4f:
        return Vector<ArgumentDescription> {
            {"index", "uint32_t", nullptr, false},
            {"x", "float", nullptr, false},
            {"y", "float", nullptr, false},
            {"z", "float", nullptr, false},
            {"w", "float", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_VertexAttrib4fv:
        return Vector<ArgumentDescription> {
            {"index", "uint32_t", nullptr, false},
            {"values", "IPC::ArrayReference<float, 4>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_VertexAttribPointer:
        return Vector<ArgumentDescription> {
            {"index", "uint32_t", nullptr, false},
            {"size", "int32_t", nullptr, false},
            {"type", "uint32_t", nullptr, false},
            {"normalized", "bool", nullptr, false},
            {"stride", "int32_t", nullptr, false},
            {"offset", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Viewport:
        return Vector<ArgumentDescription> {
            {"x", "int32_t", nullptr, false},
            {"y", "int32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_BufferData0:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"arg1", "uint64_t", nullptr, false},
            {"usage", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_BufferData1:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"data", "IPC::ArrayReference<uint8_t>", nullptr, false},
            {"usage", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_BufferSubData:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"offset", "uint64_t", nullptr, false},
            {"data", "IPC::ArrayReference<uint8_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_ReadnPixels0:
        return Vector<ArgumentDescription> {
            {"x", "int32_t", nullptr, false},
            {"y", "int32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
            {"format", "uint32_t", nullptr, false},
            {"type", "uint32_t", nullptr, false},
            {"dataSize", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_ReadnPixels1:
        return Vector<ArgumentDescription> {
            {"x", "int32_t", nullptr, false},
            {"y", "int32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
            {"format", "uint32_t", nullptr, false},
            {"type", "uint32_t", nullptr, false},
            {"offset", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_TexImage2D0:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"level", "int32_t", nullptr, false},
            {"internalformat", "uint32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
            {"border", "int32_t", nullptr, false},
            {"format", "uint32_t", nullptr, false},
            {"type", "uint32_t", nullptr, false},
            {"pixels", "IPC::ArrayReference<uint8_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_TexImage2D1:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"level", "int32_t", nullptr, false},
            {"internalformat", "uint32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
            {"border", "int32_t", nullptr, false},
            {"format", "uint32_t", nullptr, false},
            {"type", "uint32_t", nullptr, false},
            {"offset", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_TexSubImage2D0:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"level", "int32_t", nullptr, false},
            {"xoffset", "int32_t", nullptr, false},
            {"yoffset", "int32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
            {"format", "uint32_t", nullptr, false},
            {"type", "uint32_t", nullptr, false},
            {"pixels", "IPC::ArrayReference<uint8_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_TexSubImage2D1:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"level", "int32_t", nullptr, false},
            {"xoffset", "int32_t", nullptr, false},
            {"yoffset", "int32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
            {"format", "uint32_t", nullptr, false},
            {"type", "uint32_t", nullptr, false},
            {"offset", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CompressedTexImage2D0:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"level", "int32_t", nullptr, false},
            {"internalformat", "uint32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
            {"border", "int32_t", nullptr, false},
            {"imageSize", "int32_t", nullptr, false},
            {"data", "IPC::ArrayReference<uint8_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CompressedTexImage2D1:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"level", "int32_t", nullptr, false},
            {"internalformat", "uint32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
            {"border", "int32_t", nullptr, false},
            {"imageSize", "int32_t", nullptr, false},
            {"offset", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CompressedTexSubImage2D0:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"level", "int32_t", nullptr, false},
            {"xoffset", "int32_t", nullptr, false},
            {"yoffset", "int32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
            {"format", "uint32_t", nullptr, false},
            {"imageSize", "int32_t", nullptr, false},
            {"data", "IPC::ArrayReference<uint8_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CompressedTexSubImage2D1:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"level", "int32_t", nullptr, false},
            {"xoffset", "int32_t", nullptr, false},
            {"yoffset", "int32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
            {"format", "uint32_t", nullptr, false},
            {"imageSize", "int32_t", nullptr, false},
            {"offset", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_DrawArraysInstanced:
        return Vector<ArgumentDescription> {
            {"mode", "uint32_t", nullptr, false},
            {"first", "int32_t", nullptr, false},
            {"count", "int32_t", nullptr, false},
            {"primcount", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_DrawElementsInstanced:
        return Vector<ArgumentDescription> {
            {"mode", "uint32_t", nullptr, false},
            {"count", "int32_t", nullptr, false},
            {"type", "uint32_t", nullptr, false},
            {"offset", "uint64_t", nullptr, false},
            {"primcount", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_VertexAttribDivisor:
        return Vector<ArgumentDescription> {
            {"index", "uint32_t", nullptr, false},
            {"divisor", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CreateVertexArray:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteGraphicsContextGL_DeleteVertexArray:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_IsVertexArray:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_BindVertexArray:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CopyBufferSubData:
        return Vector<ArgumentDescription> {
            {"readTarget", "uint32_t", nullptr, false},
            {"writeTarget", "uint32_t", nullptr, false},
            {"readOffset", "uint64_t", nullptr, false},
            {"writeOffset", "uint64_t", nullptr, false},
            {"arg4", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetBufferSubData:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"offset", "uint64_t", nullptr, false},
            {"dataSize", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_BlitFramebuffer:
        return Vector<ArgumentDescription> {
            {"srcX0", "int32_t", nullptr, false},
            {"srcY0", "int32_t", nullptr, false},
            {"srcX1", "int32_t", nullptr, false},
            {"srcY1", "int32_t", nullptr, false},
            {"dstX0", "int32_t", nullptr, false},
            {"dstY0", "int32_t", nullptr, false},
            {"dstX1", "int32_t", nullptr, false},
            {"dstY1", "int32_t", nullptr, false},
            {"mask", "uint32_t", nullptr, false},
            {"filter", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_FramebufferTextureLayer:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"attachment", "uint32_t", nullptr, false},
            {"texture", "uint32_t", nullptr, false},
            {"level", "int32_t", nullptr, false},
            {"layer", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_InvalidateFramebuffer:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"attachments", "IPC::ArrayReference<uint32_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_InvalidateSubFramebuffer:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"attachments", "IPC::ArrayReference<uint32_t>", nullptr, false},
            {"x", "int32_t", nullptr, false},
            {"y", "int32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_ReadBuffer:
        return Vector<ArgumentDescription> {
            {"src", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_RenderbufferStorageMultisample:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"samples", "int32_t", nullptr, false},
            {"internalformat", "uint32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_TexStorage2D:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"levels", "int32_t", nullptr, false},
            {"internalformat", "uint32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_TexStorage3D:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"levels", "int32_t", nullptr, false},
            {"internalformat", "uint32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
            {"depth", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_TexImage3D0:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"level", "int32_t", nullptr, false},
            {"internalformat", "int32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
            {"depth", "int32_t", nullptr, false},
            {"border", "int32_t", nullptr, false},
            {"format", "uint32_t", nullptr, false},
            {"type", "uint32_t", nullptr, false},
            {"pixels", "IPC::ArrayReference<uint8_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_TexImage3D1:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"level", "int32_t", nullptr, false},
            {"internalformat", "int32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
            {"depth", "int32_t", nullptr, false},
            {"border", "int32_t", nullptr, false},
            {"format", "uint32_t", nullptr, false},
            {"type", "uint32_t", nullptr, false},
            {"offset", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_TexSubImage3D0:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"level", "int32_t", nullptr, false},
            {"xoffset", "int32_t", nullptr, false},
            {"yoffset", "int32_t", nullptr, false},
            {"zoffset", "int32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
            {"depth", "int32_t", nullptr, false},
            {"format", "uint32_t", nullptr, false},
            {"type", "uint32_t", nullptr, false},
            {"pixels", "IPC::ArrayReference<uint8_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_TexSubImage3D1:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"level", "int32_t", nullptr, false},
            {"xoffset", "int32_t", nullptr, false},
            {"yoffset", "int32_t", nullptr, false},
            {"zoffset", "int32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
            {"depth", "int32_t", nullptr, false},
            {"format", "uint32_t", nullptr, false},
            {"type", "uint32_t", nullptr, false},
            {"offset", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CopyTexSubImage3D:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"level", "int32_t", nullptr, false},
            {"xoffset", "int32_t", nullptr, false},
            {"yoffset", "int32_t", nullptr, false},
            {"zoffset", "int32_t", nullptr, false},
            {"x", "int32_t", nullptr, false},
            {"y", "int32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CompressedTexImage3D0:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"level", "int32_t", nullptr, false},
            {"internalformat", "uint32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
            {"depth", "int32_t", nullptr, false},
            {"border", "int32_t", nullptr, false},
            {"imageSize", "int32_t", nullptr, false},
            {"data", "IPC::ArrayReference<uint8_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CompressedTexImage3D1:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"level", "int32_t", nullptr, false},
            {"internalformat", "uint32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
            {"depth", "int32_t", nullptr, false},
            {"border", "int32_t", nullptr, false},
            {"imageSize", "int32_t", nullptr, false},
            {"offset", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CompressedTexSubImage3D0:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"level", "int32_t", nullptr, false},
            {"xoffset", "int32_t", nullptr, false},
            {"yoffset", "int32_t", nullptr, false},
            {"zoffset", "int32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
            {"depth", "int32_t", nullptr, false},
            {"format", "uint32_t", nullptr, false},
            {"imageSize", "int32_t", nullptr, false},
            {"data", "IPC::ArrayReference<uint8_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CompressedTexSubImage3D1:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"level", "int32_t", nullptr, false},
            {"xoffset", "int32_t", nullptr, false},
            {"yoffset", "int32_t", nullptr, false},
            {"zoffset", "int32_t", nullptr, false},
            {"width", "int32_t", nullptr, false},
            {"height", "int32_t", nullptr, false},
            {"depth", "int32_t", nullptr, false},
            {"format", "uint32_t", nullptr, false},
            {"imageSize", "int32_t", nullptr, false},
            {"offset", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetFragDataLocation:
        return Vector<ArgumentDescription> {
            {"program", "uint32_t", nullptr, false},
            {"name", "String", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Uniform1ui:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"v0", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Uniform2ui:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"v0", "uint32_t", nullptr, false},
            {"v1", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Uniform3ui:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"v0", "uint32_t", nullptr, false},
            {"v1", "uint32_t", nullptr, false},
            {"v2", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Uniform4ui:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"v0", "uint32_t", nullptr, false},
            {"v1", "uint32_t", nullptr, false},
            {"v2", "uint32_t", nullptr, false},
            {"v3", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Uniform1uiv:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"data", "IPC::ArrayReference<uint32_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Uniform2uiv:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"data", "IPC::ArrayReference<uint32_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Uniform3uiv:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"data", "IPC::ArrayReference<uint32_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_Uniform4uiv:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"data", "IPC::ArrayReference<uint32_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_UniformMatrix2x3fv:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"transpose", "bool", nullptr, false},
            {"data", "IPC::ArrayReference<float>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_UniformMatrix3x2fv:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"transpose", "bool", nullptr, false},
            {"data", "IPC::ArrayReference<float>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_UniformMatrix2x4fv:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"transpose", "bool", nullptr, false},
            {"data", "IPC::ArrayReference<float>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_UniformMatrix4x2fv:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"transpose", "bool", nullptr, false},
            {"data", "IPC::ArrayReference<float>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_UniformMatrix3x4fv:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"transpose", "bool", nullptr, false},
            {"data", "IPC::ArrayReference<float>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_UniformMatrix4x3fv:
        return Vector<ArgumentDescription> {
            {"location", "int32_t", nullptr, false},
            {"transpose", "bool", nullptr, false},
            {"data", "IPC::ArrayReference<float>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_VertexAttribI4i:
        return Vector<ArgumentDescription> {
            {"index", "uint32_t", nullptr, false},
            {"x", "int32_t", nullptr, false},
            {"y", "int32_t", nullptr, false},
            {"z", "int32_t", nullptr, false},
            {"w", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_VertexAttribI4iv:
        return Vector<ArgumentDescription> {
            {"index", "uint32_t", nullptr, false},
            {"values", "IPC::ArrayReference<int32_t, 4>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_VertexAttribI4ui:
        return Vector<ArgumentDescription> {
            {"index", "uint32_t", nullptr, false},
            {"x", "uint32_t", nullptr, false},
            {"y", "uint32_t", nullptr, false},
            {"z", "uint32_t", nullptr, false},
            {"w", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_VertexAttribI4uiv:
        return Vector<ArgumentDescription> {
            {"index", "uint32_t", nullptr, false},
            {"values", "IPC::ArrayReference<uint32_t, 4>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_VertexAttribIPointer:
        return Vector<ArgumentDescription> {
            {"index", "uint32_t", nullptr, false},
            {"size", "int32_t", nullptr, false},
            {"type", "uint32_t", nullptr, false},
            {"stride", "int32_t", nullptr, false},
            {"offset", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_DrawRangeElements:
        return Vector<ArgumentDescription> {
            {"mode", "uint32_t", nullptr, false},
            {"start", "uint32_t", nullptr, false},
            {"end", "uint32_t", nullptr, false},
            {"count", "int32_t", nullptr, false},
            {"type", "uint32_t", nullptr, false},
            {"offset", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_DrawBuffers:
        return Vector<ArgumentDescription> {
            {"bufs", "IPC::ArrayReference<uint32_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_ClearBufferiv:
        return Vector<ArgumentDescription> {
            {"buffer", "uint32_t", nullptr, false},
            {"drawbuffer", "int32_t", nullptr, false},
            {"values", "IPC::ArrayReference<int32_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_ClearBufferuiv:
        return Vector<ArgumentDescription> {
            {"buffer", "uint32_t", nullptr, false},
            {"drawbuffer", "int32_t", nullptr, false},
            {"values", "IPC::ArrayReference<uint32_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_ClearBufferfv:
        return Vector<ArgumentDescription> {
            {"buffer", "uint32_t", nullptr, false},
            {"drawbuffer", "int32_t", nullptr, false},
            {"values", "IPC::ArrayReference<float>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_ClearBufferfi:
        return Vector<ArgumentDescription> {
            {"buffer", "uint32_t", nullptr, false},
            {"drawbuffer", "int32_t", nullptr, false},
            {"depth", "float", nullptr, false},
            {"stencil", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CreateQuery:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteGraphicsContextGL_DeleteQuery:
        return Vector<ArgumentDescription> {
            {"query", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_IsQuery:
        return Vector<ArgumentDescription> {
            {"query", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_BeginQuery:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"query", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_EndQuery:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetQuery:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"pname", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetQueryObjectui:
        return Vector<ArgumentDescription> {
            {"query", "uint32_t", nullptr, false},
            {"pname", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CreateSampler:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteGraphicsContextGL_DeleteSampler:
        return Vector<ArgumentDescription> {
            {"sampler", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_IsSampler:
        return Vector<ArgumentDescription> {
            {"sampler", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_BindSampler:
        return Vector<ArgumentDescription> {
            {"unit", "uint32_t", nullptr, false},
            {"sampler", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_SamplerParameteri:
        return Vector<ArgumentDescription> {
            {"sampler", "uint32_t", nullptr, false},
            {"pname", "uint32_t", nullptr, false},
            {"param", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_SamplerParameterf:
        return Vector<ArgumentDescription> {
            {"sampler", "uint32_t", nullptr, false},
            {"pname", "uint32_t", nullptr, false},
            {"param", "float", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetSamplerParameterf:
        return Vector<ArgumentDescription> {
            {"sampler", "uint32_t", nullptr, false},
            {"pname", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetSamplerParameteri:
        return Vector<ArgumentDescription> {
            {"sampler", "uint32_t", nullptr, false},
            {"pname", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_FenceSync:
        return Vector<ArgumentDescription> {
            {"condition", "uint32_t", nullptr, false},
            {"flags", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_IsSync:
        return Vector<ArgumentDescription> {
            {"arg0", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_DeleteSync:
        return Vector<ArgumentDescription> {
            {"arg0", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_ClientWaitSync:
        return Vector<ArgumentDescription> {
            {"arg0", "uint64_t", nullptr, false},
            {"flags", "uint32_t", nullptr, false},
            {"timeout", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_WaitSync:
        return Vector<ArgumentDescription> {
            {"arg0", "uint64_t", nullptr, false},
            {"flags", "uint32_t", nullptr, false},
            {"timeout", "int64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetSynci:
        return Vector<ArgumentDescription> {
            {"arg0", "uint64_t", nullptr, false},
            {"pname", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CreateTransformFeedback:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteGraphicsContextGL_DeleteTransformFeedback:
        return Vector<ArgumentDescription> {
            {"id", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_IsTransformFeedback:
        return Vector<ArgumentDescription> {
            {"id", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_BindTransformFeedback:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"id", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_BeginTransformFeedback:
        return Vector<ArgumentDescription> {
            {"primitiveMode", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_EndTransformFeedback:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteGraphicsContextGL_TransformFeedbackVaryings:
        return Vector<ArgumentDescription> {
            {"program", "uint32_t", nullptr, false},
            {"varyings", "Vector<String>", nullptr, false},
            {"bufferMode", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetTransformFeedbackVarying:
        return Vector<ArgumentDescription> {
            {"program", "uint32_t", nullptr, false},
            {"index", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_PauseTransformFeedback:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteGraphicsContextGL_ResumeTransformFeedback:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteGraphicsContextGL_BindBufferBase:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"index", "uint32_t", nullptr, false},
            {"buffer", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_BindBufferRange:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"index", "uint32_t", nullptr, false},
            {"buffer", "uint32_t", nullptr, false},
            {"offset", "uint64_t", nullptr, false},
            {"arg4", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetUniformIndices:
        return Vector<ArgumentDescription> {
            {"program", "uint32_t", nullptr, false},
            {"uniformNames", "Vector<String>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetActiveUniforms:
        return Vector<ArgumentDescription> {
            {"program", "uint32_t", nullptr, false},
            {"uniformIndices", "Vector<uint32_t>", nullptr, false},
            {"pname", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetUniformBlockIndex:
        return Vector<ArgumentDescription> {
            {"program", "uint32_t", nullptr, false},
            {"uniformBlockName", "String", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetActiveUniformBlockName:
        return Vector<ArgumentDescription> {
            {"program", "uint32_t", nullptr, false},
            {"uniformBlockIndex", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_UniformBlockBinding:
        return Vector<ArgumentDescription> {
            {"program", "uint32_t", nullptr, false},
            {"uniformBlockIndex", "uint32_t", nullptr, false},
            {"uniformBlockBinding", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetActiveUniformBlockiv:
        return Vector<ArgumentDescription> {
            {"program", "uint32_t", nullptr, false},
            {"uniformBlockIndex", "uint32_t", nullptr, false},
            {"pname", "uint32_t", nullptr, false},
            {"paramsSize", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetGraphicsResetStatusARB:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteGraphicsContextGL_GetTranslatedShaderSourceANGLE:
        return Vector<ArgumentDescription> {
            {"arg0", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_DrawBuffersEXT:
        return Vector<ArgumentDescription> {
            {"bufs", "IPC::ArrayReference<uint32_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetInternalformativ:
        return Vector<ArgumentDescription> {
            {"target", "uint32_t", nullptr, false},
            {"internalformat", "uint32_t", nullptr, false},
            {"pname", "uint32_t", nullptr, false},
            {"paramsSize", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_MultiDrawArraysANGLE:
        return Vector<ArgumentDescription> {
            {"mode", "uint32_t", nullptr, false},
            {"firsts", "IPC::ArrayReference<int32_t>", nullptr, false},
            {"counts", "IPC::ArrayReference<int32_t>", nullptr, false},
            {"drawcount", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_MultiDrawArraysInstancedANGLE:
        return Vector<ArgumentDescription> {
            {"mode", "uint32_t", nullptr, false},
            {"firsts", "IPC::ArrayReference<int32_t>", nullptr, false},
            {"counts", "IPC::ArrayReference<int32_t>", nullptr, false},
            {"instanceCounts", "IPC::ArrayReference<int32_t>", nullptr, false},
            {"drawcount", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_MultiDrawElementsANGLE:
        return Vector<ArgumentDescription> {
            {"mode", "uint32_t", nullptr, false},
            {"counts", "IPC::ArrayReference<int32_t>", nullptr, false},
            {"type", "uint32_t", nullptr, false},
            {"offsets", "IPC::ArrayReference<int32_t>", nullptr, false},
            {"drawcount", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_MultiDrawElementsInstancedANGLE:
        return Vector<ArgumentDescription> {
            {"mode", "uint32_t", nullptr, false},
            {"counts", "IPC::ArrayReference<int32_t>", nullptr, false},
            {"type", "uint32_t", nullptr, false},
            {"offsets", "IPC::ArrayReference<int32_t>", nullptr, false},
            {"instanceCounts", "IPC::ArrayReference<int32_t>", nullptr, false},
            {"drawcount", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_PaintRenderingResultsToPixelBuffer:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteRenderingBackend_CreateImageBuffer:
        return Vector<ArgumentDescription> {
            {"logicalSize", "WebCore::FloatSize", nullptr, false},
            {"renderingMode", "WebCore::RenderingMode", nullptr, false},
            {"resolutionScale", "float", nullptr, false},
            {"colorSpace", "WebCore::DestinationColorSpace", nullptr, false},
            {"pixelFormat", "uint8_t", "WebCore::PixelFormat", false},
            {"renderingResourceIdentifier", "WebCore::RenderingResourceIdentifier", nullptr, false},
        };
    case MessageName::RemoteRenderingBackend_GetPixelBufferForImageBuffer:
        return Vector<ArgumentDescription> {
            {"imageBuffer", "WebCore::RenderingResourceIdentifier", nullptr, false},
            {"outputFormat", "WebCore::PixelBufferFormat", nullptr, false},
            {"srcRect", "WebCore::IntRect", nullptr, false},
        };
    case MessageName::RemoteRenderingBackend_GetPixelBufferForImageBufferWithNewMemory:
        return Vector<ArgumentDescription> {
            {"imageBuffer", "WebCore::RenderingResourceIdentifier", nullptr, false},
            {"handle", "WebKit::SharedMemory::IPCHandle", nullptr, false},
            {"outputFormat", "WebCore::PixelBufferFormat", nullptr, false},
            {"srcRect", "WebCore::IntRect", nullptr, false},
        };
    case MessageName::RemoteRenderingBackend_DestroyGetPixelBufferSharedMemory:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteRenderingBackend_PutPixelBufferForImageBuffer:
        return Vector<ArgumentDescription> {
            {"imageBuffer", "WebCore::RenderingResourceIdentifier", nullptr, false},
            {"pixelBuffer", "WebCore::PixelBuffer", nullptr, false},
            {"srcRect", "WebCore::IntRect", nullptr, false},
            {"destPoint", "WebCore::IntPoint", nullptr, false},
            {"destFormat", "uint8_t", "WebCore::AlphaPremultiplication", false},
        };
    case MessageName::RemoteRenderingBackend_GetDataURLForImageBuffer:
        return Vector<ArgumentDescription> {
            {"mimeType", "String", nullptr, false},
            {"quality", "double", nullptr, true},
            {"preserveResolution", "uint8_t", "WebCore::PreserveResolution", false},
            {"renderingResourceIdentifier", "WebCore::RenderingResourceIdentifier", nullptr, false},
        };
    case MessageName::RemoteRenderingBackend_GetDataForImageBuffer:
        return Vector<ArgumentDescription> {
            {"mimeType", "String", nullptr, false},
            {"quality", "double", nullptr, true},
            {"renderingResourceIdentifier", "WebCore::RenderingResourceIdentifier", nullptr, false},
        };
    case MessageName::RemoteRenderingBackend_GetShareableBitmapForImageBuffer:
        return Vector<ArgumentDescription> {
            {"imageBuffer", "WebCore::RenderingResourceIdentifier", nullptr, false},
            {"preserveResolution", "uint8_t", "WebCore::PreserveResolution", false},
        };
    case MessageName::RemoteRenderingBackend_GetFilteredImageForImageBuffer:
        return Vector<ArgumentDescription> {
            {"imageBuffer", "WebCore::RenderingResourceIdentifier", nullptr, false},
            {"filter", "IPC::FilterReference", nullptr, false},
        };
    case MessageName::RemoteRenderingBackend_CacheNativeImage:
        return Vector<ArgumentDescription> {
            {"handle", "WebKit::ShareableBitmap::Handle", nullptr, false},
            {"renderingResourceIdentifier", "WebCore::RenderingResourceIdentifier", nullptr, false},
        };
    case MessageName::RemoteRenderingBackend_CacheFont:
        return Vector<ArgumentDescription> {
            {"font", "IPC::FontReference", nullptr, false},
        };
    case MessageName::RemoteRenderingBackend_DeleteAllFonts:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteRenderingBackend_ReleaseRemoteResource:
        return Vector<ArgumentDescription> {
            {"renderingResourceIdentifier", "WebCore::RenderingResourceIdentifier", nullptr, false},
        };
    case MessageName::RemoteRenderingBackend_MarkSurfaceNonVolatile:
        return Vector<ArgumentDescription> {
            {"renderingResourceIdentifier", "WebCore::RenderingResourceIdentifier", nullptr, false},
        };
    case MessageName::RemoteRenderingBackend_SwapToValidFrontBuffer:
        return Vector<ArgumentDescription> {
            {"bufferSet", "WebKit::BufferIdentifierSet", nullptr, false},
        };
    case MessageName::RemoteRenderingBackend_MarkSurfacesVolatile:
        return Vector<ArgumentDescription> {
            {"renderingResourceIdentifiers", "Vector<WebCore::RenderingResourceIdentifier>", nullptr, false},
        };
    case MessageName::RemoteRenderingBackend_FinalizeRenderingUpdate:
        return Vector<ArgumentDescription> {
            {"renderingUpdateID", "WebKit::RenderingUpdateID", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteAdapter_RequestDevice:
        return Vector<ArgumentDescription> {
            {"deviceDescriptor", "WebKit::WebGPU::DeviceDescriptor", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteBindGroup_SetLabel:
        return Vector<ArgumentDescription> {
            {"label", "String", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteBindGroupLayout_SetLabel:
        return Vector<ArgumentDescription> {
            {"label", "String", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteBuffer_MapAsync:
        return Vector<ArgumentDescription> {
            {"mapModeFlags", "PAL::WebGPU::MapModeFlags", nullptr, false},
            {"offset", "PAL::WebGPU::Size64", nullptr, false},
            {"size", "PAL::WebGPU::Size64", nullptr, true},
        };
    case MessageName::RemoteBuffer_Unmap:
        return Vector<ArgumentDescription> {
            {"data", "Vector<uint8_t>", nullptr, false},
        };
    case MessageName::RemoteBuffer_Destroy:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteBuffer_SetLabel:
        return Vector<ArgumentDescription> {
            {"label", "String", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteCommandBuffer_SetLabel:
        return Vector<ArgumentDescription> {
            {"label", "String", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteCommandEncoder_BeginRenderPass:
        return Vector<ArgumentDescription> {
            {"descriptor", "WebKit::WebGPU::RenderPassDescriptor", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
    case MessageName::RemoteCommandEncoder_BeginComputePass:
        return Vector<ArgumentDescription> {
            {"descriptor", "WebKit::WebGPU::ComputePassDescriptor", nullptr, true},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
    case MessageName::RemoteCommandEncoder_CopyBufferToBuffer:
        return Vector<ArgumentDescription> {
            {"source", "WebKit::WebGPUIdentifier", nullptr, false},
            {"sourceOffset", "PAL::WebGPU::Size64", nullptr, false},
            {"destination", "WebKit::WebGPUIdentifier", nullptr, false},
            {"destinationOffset", "PAL::WebGPU::Size64", nullptr, false},
            {"size", "PAL::WebGPU::Size64", nullptr, false},
        };
    case MessageName::RemoteCommandEncoder_CopyBufferToTexture:
        return Vector<ArgumentDescription> {
            {"source", "WebKit::WebGPU::ImageCopyBuffer", nullptr, false},
            {"destination", "WebKit::WebGPU::ImageCopyTexture", nullptr, false},
            {"copySize", "WebKit::WebGPU::Extent3D", nullptr, false},
        };
    case MessageName::RemoteCommandEncoder_CopyTextureToBuffer:
        return Vector<ArgumentDescription> {
            {"source", "WebKit::WebGPU::ImageCopyTexture", nullptr, false},
            {"destination", "WebKit::WebGPU::ImageCopyBuffer", nullptr, false},
            {"copySize", "WebKit::WebGPU::Extent3D", nullptr, false},
        };
    case MessageName::RemoteCommandEncoder_CopyTextureToTexture:
        return Vector<ArgumentDescription> {
            {"source", "WebKit::WebGPU::ImageCopyTexture", nullptr, false},
            {"destination", "WebKit::WebGPU::ImageCopyTexture", nullptr, false},
            {"copySize", "WebKit::WebGPU::Extent3D", nullptr, false},
        };
    case MessageName::RemoteCommandEncoder_ClearBuffer:
        return Vector<ArgumentDescription> {
            {"buffer", "WebKit::WebGPUIdentifier", nullptr, false},
            {"offset", "PAL::WebGPU::Size64", nullptr, false},
            {"size", "PAL::WebGPU::Size64", nullptr, true},
        };
    case MessageName::RemoteCommandEncoder_PushDebugGroup:
        return Vector<ArgumentDescription> {
            {"groupLabel", "String", nullptr, false},
        };
    case MessageName::RemoteCommandEncoder_PopDebugGroup:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteCommandEncoder_InsertDebugMarker:
        return Vector<ArgumentDescription> {
            {"markerLabel", "String", nullptr, false},
        };
    case MessageName::RemoteCommandEncoder_WriteTimestamp:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
            {"queryIndex", "PAL::WebGPU::Size32", nullptr, false},
        };
    case MessageName::RemoteCommandEncoder_ResolveQuerySet:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
            {"firstQuery", "PAL::WebGPU::Size32", nullptr, false},
            {"queryCount", "PAL::WebGPU::Size32", nullptr, false},
            {"destination", "WebKit::WebGPUIdentifier", nullptr, false},
            {"destinationOffset", "PAL::WebGPU::Size64", nullptr, false},
        };
    case MessageName::RemoteCommandEncoder_Finish:
        return Vector<ArgumentDescription> {
            {"descriptor", "WebKit::WebGPU::CommandBufferDescriptor", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
    case MessageName::RemoteCommandEncoder_SetLabel:
        return Vector<ArgumentDescription> {
            {"label", "String", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteComputePassEncoder_SetPipeline:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
    case MessageName::RemoteComputePassEncoder_Dispatch:
        return Vector<ArgumentDescription> {
            {"workgroupCountX", "PAL::WebGPU::Size32", nullptr, false},
            {"workgroupCountY", "PAL::WebGPU::Size32", nullptr, false},
            {"workgroupCountZ", "PAL::WebGPU::Size32", nullptr, false},
        };
    case MessageName::RemoteComputePassEncoder_DispatchIndirect:
        return Vector<ArgumentDescription> {
            {"indirectBuffer", "WebKit::WebGPUIdentifier", nullptr, false},
            {"indirectOffset", "PAL::WebGPU::Size64", nullptr, false},
        };
    case MessageName::RemoteComputePassEncoder_End:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteComputePassEncoder_SetBindGroup:
        return Vector<ArgumentDescription> {
            {"index", "PAL::WebGPU::Index32", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
            {"dynamicOffsets", "Vector<PAL::WebGPU::BufferDynamicOffset>", nullptr, true},
        };
    case MessageName::RemoteComputePassEncoder_PushDebugGroup:
        return Vector<ArgumentDescription> {
            {"groupLabel", "String", nullptr, false},
        };
    case MessageName::RemoteComputePassEncoder_PopDebugGroup:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteComputePassEncoder_InsertDebugMarker:
        return Vector<ArgumentDescription> {
            {"markerLabel", "String", nullptr, false},
        };
    case MessageName::RemoteComputePassEncoder_SetLabel:
        return Vector<ArgumentDescription> {
            {"label", "String", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteComputePipeline_GetBindGroupLayout:
        return Vector<ArgumentDescription> {
            {"index", "uint32_t", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
    case MessageName::RemoteComputePipeline_SetLabel:
        return Vector<ArgumentDescription> {
            {"label", "String", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteDevice_Destroy:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteDevice_CreateBuffer:
        return Vector<ArgumentDescription> {
            {"descriptor", "WebKit::WebGPU::BufferDescriptor", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
    case MessageName::RemoteDevice_CreateTexture:
        return Vector<ArgumentDescription> {
            {"descriptor", "WebKit::WebGPU::TextureDescriptor", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
    case MessageName::RemoteDevice_CreateSampler:
        return Vector<ArgumentDescription> {
            {"descriptor", "WebKit::WebGPU::SamplerDescriptor", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
    case MessageName::RemoteDevice_ImportExternalTexture:
        return Vector<ArgumentDescription> {
            {"descriptor", "WebKit::WebGPU::ExternalTextureDescriptor", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
    case MessageName::RemoteDevice_CreateBindGroupLayout:
        return Vector<ArgumentDescription> {
            {"descriptor", "WebKit::WebGPU::BindGroupLayoutDescriptor", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
    case MessageName::RemoteDevice_CreatePipelineLayout:
        return Vector<ArgumentDescription> {
            {"descriptor", "WebKit::WebGPU::PipelineLayoutDescriptor", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
    case MessageName::RemoteDevice_CreateBindGroup:
        return Vector<ArgumentDescription> {
            {"descriptor", "WebKit::WebGPU::BindGroupDescriptor", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
    case MessageName::RemoteDevice_CreateShaderModule:
        return Vector<ArgumentDescription> {
            {"descriptor", "WebKit::WebGPU::ShaderModuleDescriptor", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
    case MessageName::RemoteDevice_CreateComputePipeline:
        return Vector<ArgumentDescription> {
            {"descriptor", "WebKit::WebGPU::ComputePipelineDescriptor", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
    case MessageName::RemoteDevice_CreateRenderPipeline:
        return Vector<ArgumentDescription> {
            {"descriptor", "WebKit::WebGPU::RenderPipelineDescriptor", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
    case MessageName::RemoteDevice_CreateComputePipelineAsync:
        return Vector<ArgumentDescription> {
            {"descriptor", "WebKit::WebGPU::ComputePipelineDescriptor", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
    case MessageName::RemoteDevice_CreateRenderPipelineAsync:
        return Vector<ArgumentDescription> {
            {"descriptor", "WebKit::WebGPU::RenderPipelineDescriptor", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
    case MessageName::RemoteDevice_CreateCommandEncoder:
        return Vector<ArgumentDescription> {
            {"descriptor", "WebKit::WebGPU::CommandEncoderDescriptor", nullptr, true},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
    case MessageName::RemoteDevice_CreateRenderBundleEncoder:
        return Vector<ArgumentDescription> {
            {"descriptor", "WebKit::WebGPU::RenderBundleEncoderDescriptor", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
    case MessageName::RemoteDevice_CreateQuerySet:
        return Vector<ArgumentDescription> {
            {"descriptor", "WebKit::WebGPU::QuerySetDescriptor", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
    case MessageName::RemoteDevice_PushErrorScope:
        return Vector<ArgumentDescription> {
            {"errorFilter", "PAL::WebGPU::ErrorFilter", nullptr, false},
        };
    case MessageName::RemoteDevice_PopErrorScope:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteDevice_SetLabel:
        return Vector<ArgumentDescription> {
            {"label", "String", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteExternalTexture_SetLabel:
        return Vector<ArgumentDescription> {
            {"label", "String", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteGPU_RequestAdapter:
        return Vector<ArgumentDescription> {
            {"options", "WebKit::WebGPU::RequestAdapterOptions", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemotePipelineLayout_SetLabel:
        return Vector<ArgumentDescription> {
            {"label", "String", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteQuerySet_Destroy:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteQuerySet_SetLabel:
        return Vector<ArgumentDescription> {
            {"label", "String", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteQueue_Submit:
        return Vector<ArgumentDescription> {
            {"commandBuffers", "Vector<WebKit::WebGPUIdentifier>", nullptr, false},
        };
    case MessageName::RemoteQueue_OnSubmittedWorkDone:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteQueue_WriteBuffer:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
            {"bufferOffset", "PAL::WebGPU::Size64", nullptr, false},
            {"data", "Vector<uint8_t>", nullptr, false},
        };
    case MessageName::RemoteQueue_WriteTexture:
        return Vector<ArgumentDescription> {
            {"destination", "WebKit::WebGPU::ImageCopyTexture", nullptr, false},
            {"data", "Vector<uint8_t>", nullptr, false},
            {"imageDataLayout", "WebKit::WebGPU::ImageDataLayout", nullptr, false},
            {"size", "WebKit::WebGPU::Extent3D", nullptr, false},
        };
    case MessageName::RemoteQueue_CopyExternalImageToTexture:
        return Vector<ArgumentDescription> {
            {"source", "WebKit::WebGPU::ImageCopyExternalImage", nullptr, false},
            {"destination", "WebKit::WebGPU::ImageCopyTextureTagged", nullptr, false},
            {"copySize", "WebKit::WebGPU::Extent3D", nullptr, false},
        };
    case MessageName::RemoteQueue_SetLabel:
        return Vector<ArgumentDescription> {
            {"label", "String", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteRenderBundle_SetLabel:
        return Vector<ArgumentDescription> {
            {"label", "String", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteRenderBundleEncoder_SetPipeline:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
    case MessageName::RemoteRenderBundleEncoder_SetIndexBuffer:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
            {"indexFormat", "PAL::WebGPU::IndexFormat", nullptr, false},
            {"offset", "PAL::WebGPU::Size64", nullptr, false},
            {"size", "PAL::WebGPU::Size64", nullptr, true},
        };
    case MessageName::RemoteRenderBundleEncoder_SetVertexBuffer:
        return Vector<ArgumentDescription> {
            {"slot", "PAL::WebGPU::Index32", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
            {"offset", "PAL::WebGPU::Size64", nullptr, false},
            {"size", "PAL::WebGPU::Size64", nullptr, true},
        };
    case MessageName::RemoteRenderBundleEncoder_Draw:
        return Vector<ArgumentDescription> {
            {"vertexCount", "PAL::WebGPU::Size32", nullptr, false},
            {"instanceCount", "PAL::WebGPU::Size32", nullptr, false},
            {"firstVertex", "PAL::WebGPU::Size32", nullptr, false},
            {"firstInstance", "PAL::WebGPU::Size32", nullptr, false},
        };
    case MessageName::RemoteRenderBundleEncoder_DrawIndexed:
        return Vector<ArgumentDescription> {
            {"indexCount", "PAL::WebGPU::Size32", nullptr, false},
            {"instanceCount", "PAL::WebGPU::Size32", nullptr, false},
            {"firstIndex", "PAL::WebGPU::Size32", nullptr, false},
            {"baseVertex", "PAL::WebGPU::SignedOffset32", nullptr, false},
            {"firstInstance", "PAL::WebGPU::Size32", nullptr, false},
        };
    case MessageName::RemoteRenderBundleEncoder_DrawIndirect:
        return Vector<ArgumentDescription> {
            {"indirectBuffer", "WebKit::WebGPUIdentifier", nullptr, false},
            {"indirectOffset", "PAL::WebGPU::Size64", nullptr, false},
        };
    case MessageName::RemoteRenderBundleEncoder_DrawIndexedIndirect:
        return Vector<ArgumentDescription> {
            {"indirectBuffer", "WebKit::WebGPUIdentifier", nullptr, false},
            {"indirectOffset", "PAL::WebGPU::Size64", nullptr, false},
        };
    case MessageName::RemoteRenderBundleEncoder_SetBindGroup:
        return Vector<ArgumentDescription> {
            {"index", "PAL::WebGPU::Index32", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
            {"dynamicOffsets", "Vector<PAL::WebGPU::BufferDynamicOffset>", nullptr, true},
        };
    case MessageName::RemoteRenderBundleEncoder_PushDebugGroup:
        return Vector<ArgumentDescription> {
            {"groupLabel", "String", nullptr, false},
        };
    case MessageName::RemoteRenderBundleEncoder_PopDebugGroup:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteRenderBundleEncoder_InsertDebugMarker:
        return Vector<ArgumentDescription> {
            {"markerLabel", "String", nullptr, false},
        };
    case MessageName::RemoteRenderBundleEncoder_Finish:
        return Vector<ArgumentDescription> {
            {"descriptor", "WebKit::WebGPU::RenderBundleDescriptor", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
    case MessageName::RemoteRenderBundleEncoder_SetLabel:
        return Vector<ArgumentDescription> {
            {"label", "String", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteRenderPassEncoder_SetPipeline:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
    case MessageName::RemoteRenderPassEncoder_SetIndexBuffer:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
            {"indexFormat", "PAL::WebGPU::IndexFormat", nullptr, false},
            {"offset", "PAL::WebGPU::Size64", nullptr, false},
            {"size", "PAL::WebGPU::Size64", nullptr, true},
        };
    case MessageName::RemoteRenderPassEncoder_SetVertexBuffer:
        return Vector<ArgumentDescription> {
            {"slot", "PAL::WebGPU::Index32", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
            {"offset", "PAL::WebGPU::Size64", nullptr, false},
            {"size", "PAL::WebGPU::Size64", nullptr, true},
        };
    case MessageName::RemoteRenderPassEncoder_Draw:
        return Vector<ArgumentDescription> {
            {"vertexCount", "PAL::WebGPU::Size32", nullptr, false},
            {"instanceCount", "PAL::WebGPU::Size32", nullptr, false},
            {"firstVertex", "PAL::WebGPU::Size32", nullptr, false},
            {"firstInstance", "PAL::WebGPU::Size32", nullptr, false},
        };
    case MessageName::RemoteRenderPassEncoder_DrawIndexed:
        return Vector<ArgumentDescription> {
            {"indexCount", "PAL::WebGPU::Size32", nullptr, false},
            {"instanceCount", "PAL::WebGPU::Size32", nullptr, false},
            {"firstIndex", "PAL::WebGPU::Size32", nullptr, false},
            {"baseVertex", "PAL::WebGPU::SignedOffset32", nullptr, false},
            {"firstInstance", "PAL::WebGPU::Size32", nullptr, false},
        };
    case MessageName::RemoteRenderPassEncoder_DrawIndirect:
        return Vector<ArgumentDescription> {
            {"indirectBuffer", "WebKit::WebGPUIdentifier", nullptr, false},
            {"indirectOffset", "PAL::WebGPU::Size64", nullptr, false},
        };
    case MessageName::RemoteRenderPassEncoder_DrawIndexedIndirect:
        return Vector<ArgumentDescription> {
            {"indirectBuffer", "WebKit::WebGPUIdentifier", nullptr, false},
            {"indirectOffset", "PAL::WebGPU::Size64", nullptr, false},
        };
    case MessageName::RemoteRenderPassEncoder_SetBindGroup:
        return Vector<ArgumentDescription> {
            {"index", "PAL::WebGPU::Index32", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
            {"dynamicOffsets", "Vector<PAL::WebGPU::BufferDynamicOffset>", nullptr, true},
        };
    case MessageName::RemoteRenderPassEncoder_PushDebugGroup:
        return Vector<ArgumentDescription> {
            {"groupLabel", "String", nullptr, false},
        };
    case MessageName::RemoteRenderPassEncoder_PopDebugGroup:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteRenderPassEncoder_InsertDebugMarker:
        return Vector<ArgumentDescription> {
            {"markerLabel", "String", nullptr, false},
        };
    case MessageName::RemoteRenderPassEncoder_SetViewport:
        return Vector<ArgumentDescription> {
            {"x", "float", nullptr, false},
            {"y", "float", nullptr, false},
            {"width", "float", nullptr, false},
            {"height", "float", nullptr, false},
            {"minDepth", "float", nullptr, false},
            {"maxDepth", "float", nullptr, false},
        };
    case MessageName::RemoteRenderPassEncoder_SetScissorRect:
        return Vector<ArgumentDescription> {
            {"x", "PAL::WebGPU::IntegerCoordinate", nullptr, false},
            {"y", "PAL::WebGPU::IntegerCoordinate", nullptr, false},
            {"width", "PAL::WebGPU::IntegerCoordinate", nullptr, false},
            {"height", "PAL::WebGPU::IntegerCoordinate", nullptr, false},
        };
    case MessageName::RemoteRenderPassEncoder_SetBlendConstant:
        return Vector<ArgumentDescription> {
            {"color", "WebKit::WebGPU::Color", nullptr, false},
        };
    case MessageName::RemoteRenderPassEncoder_SetStencilReference:
        return Vector<ArgumentDescription> {
            {"stencilValue", "PAL::WebGPU::StencilValue", nullptr, false},
        };
    case MessageName::RemoteRenderPassEncoder_BeginOcclusionQuery:
        return Vector<ArgumentDescription> {
            {"queryIndex", "PAL::WebGPU::Size32", nullptr, false},
        };
    case MessageName::RemoteRenderPassEncoder_EndOcclusionQuery:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteRenderPassEncoder_ExecuteBundles:
        return Vector<ArgumentDescription> {
            {"bundles", "Vector<WebKit::WebGPUIdentifier>", nullptr, false},
        };
    case MessageName::RemoteRenderPassEncoder_End:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteRenderPassEncoder_SetLabel:
        return Vector<ArgumentDescription> {
            {"label", "String", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteRenderPipeline_GetBindGroupLayout:
        return Vector<ArgumentDescription> {
            {"index", "uint32_t", nullptr, false},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
    case MessageName::RemoteRenderPipeline_SetLabel:
        return Vector<ArgumentDescription> {
            {"label", "String", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteSampler_SetLabel:
        return Vector<ArgumentDescription> {
            {"label", "String", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteShaderModule_CompilationInfo:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteShaderModule_SetLabel:
        return Vector<ArgumentDescription> {
            {"label", "String", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteTexture_CreateView:
        return Vector<ArgumentDescription> {
            {"descriptor", "WebKit::WebGPU::TextureViewDescriptor", nullptr, true},
            {"identifier", "WebKit::WebGPUIdentifier", nullptr, false},
        };
    case MessageName::RemoteTexture_Destroy:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteTexture_SetLabel:
        return Vector<ArgumentDescription> {
            {"label", "String", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteTextureView_SetLabel:
        return Vector<ArgumentDescription> {
            {"label", "String", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(WEB_AUDIO)
    case MessageName::RemoteAudioDestinationManager_CreateAudioDestination:
        return Vector<ArgumentDescription> {
            {"inputDeviceId", "String", nullptr, false},
            {"numberOfInputChannels", "uint32_t", nullptr, false},
            {"numberOfOutputChannels", "uint32_t", nullptr, false},
            {"sampleRate", "float", nullptr, false},
            {"hardwareSampleRate", "float", nullptr, false},
            {"renderSemaphore", "IPC::Semaphore", nullptr, false},
        };
    case MessageName::RemoteAudioDestinationManager_DeleteAudioDestination:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RemoteAudioDestinationIdentifier", nullptr, false},
        };
    case MessageName::RemoteAudioDestinationManager_StartAudioDestination:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RemoteAudioDestinationIdentifier", nullptr, false},
        };
    case MessageName::RemoteAudioDestinationManager_StopAudioDestination:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RemoteAudioDestinationIdentifier", nullptr, false},
        };
#if PLATFORM(COCOA)
    case MessageName::RemoteAudioDestinationManager_AudioSamplesStorageChanged:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RemoteAudioDestinationIdentifier", nullptr, false},
            {"storageHandle", "WebKit::SharedMemory::IPCHandle", nullptr, false},
            {"description", "WebCore::CAAudioStreamDescription", nullptr, false},
            {"numberOfFrames", "uint64_t", nullptr, false},
        };
#endif
#endif
#if ENABLE(GPU_PROCESS) && USE(AUDIO_SESSION)
    case MessageName::RemoteAudioSessionProxy_SetCategory:
        return Vector<ArgumentDescription> {
            {"type", "uint8_t", "WebCore::AudioSession::CategoryType", false},
            {"policy", "uint8_t", "WebCore::RouteSharingPolicy", false},
        };
    case MessageName::RemoteAudioSessionProxy_SetPreferredBufferSize:
        return Vector<ArgumentDescription> {
            {"preferredBufferSize", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteAudioSessionProxy_TryToSetActive:
        return Vector<ArgumentDescription> {
            {"active", "bool", nullptr, false},
        };
    case MessageName::RemoteAudioSessionProxy_SetIsPlayingToBluetoothOverride:
        return Vector<ArgumentDescription> {
            {"value", "bool", nullptr, true},
        };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
    case MessageName::RemoteCDMFactoryProxy_CreateCDM:
        return Vector<ArgumentDescription> {
            {"keySystem", "String", nullptr, false},
        };
    case MessageName::RemoteCDMFactoryProxy_SupportsKeySystem:
        return Vector<ArgumentDescription> {
            {"keySystem", "String", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
    case MessageName::RemoteCDMInstanceProxy_CreateSession:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteCDMInstanceProxy_InitializeWithConfiguration:
        return Vector<ArgumentDescription> {
            {"configuration", "WebCore::CDMKeySystemConfiguration", nullptr, false},
            {"distinctiveIdentifiersAllowed", "bool", "WebCore::CDMInstance::AllowDistinctiveIdentifiers", false},
            {"persistentStateAllowed", "bool", "WebCore::CDMInstance::AllowPersistentState", false},
        };
    case MessageName::RemoteCDMInstanceProxy_SetServerCertificate:
        return Vector<ArgumentDescription> {
            {"certificate", "IPC::SharedBufferCopy", nullptr, false},
        };
    case MessageName::RemoteCDMInstanceProxy_SetStorageDirectory:
        return Vector<ArgumentDescription> {
            {"directory", "String", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
    case MessageName::RemoteCDMInstanceSessionProxy_RequestLicense:
        return Vector<ArgumentDescription> {
            {"type", "WebCore::CDMInstanceSession::LicenseType", nullptr, false},
            {"initDataType", "AtomString", nullptr, false},
            {"initData", "IPC::SharedBufferCopy", nullptr, false},
        };
    case MessageName::RemoteCDMInstanceSessionProxy_UpdateLicense:
        return Vector<ArgumentDescription> {
            {"sessionId", "String", nullptr, false},
            {"type", "WebCore::CDMInstanceSession::LicenseType", nullptr, false},
            {"response", "IPC::SharedBufferCopy", nullptr, false},
        };
    case MessageName::RemoteCDMInstanceSessionProxy_LoadSession:
        return Vector<ArgumentDescription> {
            {"type", "WebCore::CDMInstanceSession::LicenseType", nullptr, false},
            {"sessionId", "String", nullptr, false},
            {"origin", "String", nullptr, false},
        };
    case MessageName::RemoteCDMInstanceSessionProxy_CloseSession:
        return Vector<ArgumentDescription> {
            {"sessionId", "String", nullptr, false},
        };
    case MessageName::RemoteCDMInstanceSessionProxy_RemoveSessionData:
        return Vector<ArgumentDescription> {
            {"sessionId", "String", nullptr, false},
            {"type", "WebCore::CDMInstanceSession::LicenseType", nullptr, false},
        };
    case MessageName::RemoteCDMInstanceSessionProxy_StoreRecordOfKeyUsage:
        return Vector<ArgumentDescription> {
            {"sessionId", "String", nullptr, false},
        };
    case MessageName::RemoteCDMInstanceSessionProxy_DisplayIDChanged:
        return Vector<ArgumentDescription> {
            {"displayID", "uint32_t", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
    case MessageName::RemoteCDMProxy_GetSupportedConfiguration:
        return Vector<ArgumentDescription> {
            {"candidateConfiguration", "WebCore::CDMKeySystemConfiguration", nullptr, false},
            {"access", "bool", "WebCore::CDMPrivate::LocalStorageAccess", false},
        };
    case MessageName::RemoteCDMProxy_CreateInstance:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteCDMProxy_LoadAndInitialize:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(LEGACY_ENCRYPTED_MEDIA)
    case MessageName::RemoteLegacyCDMFactoryProxy_CreateCDM:
        return Vector<ArgumentDescription> {
            {"keySystem", "String", nullptr, false},
            {"playerId", "WebCore::MediaPlayerIdentifier", nullptr, true},
        };
    case MessageName::RemoteLegacyCDMFactoryProxy_SupportsKeySystem:
        return Vector<ArgumentDescription> {
            {"keySystem", "String", nullptr, false},
            {"mimeType", "String", nullptr, true},
        };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(LEGACY_ENCRYPTED_MEDIA)
    case MessageName::RemoteLegacyCDMProxy_SupportsMIMEType:
        return Vector<ArgumentDescription> {
            {"mimeType", "String", nullptr, false},
        };
    case MessageName::RemoteLegacyCDMProxy_CreateSession:
        return Vector<ArgumentDescription> {
            {"mediaKeysStorageDirectory", "String", nullptr, false},
        };
    case MessageName::RemoteLegacyCDMProxy_SetPlayerId:
        return Vector<ArgumentDescription> {
            {"playerId", "WebCore::MediaPlayerIdentifier", nullptr, true},
        };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(LEGACY_ENCRYPTED_MEDIA)
    case MessageName::RemoteLegacyCDMSessionProxy_GenerateKeyRequest:
        return Vector<ArgumentDescription> {
            {"mimeType", "String", nullptr, false},
            {"initData", "IPC::SharedBufferCopy", nullptr, false},
        };
    case MessageName::RemoteLegacyCDMSessionProxy_ReleaseKeys:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteLegacyCDMSessionProxy_Update:
        return Vector<ArgumentDescription> {
            {"update", "IPC::SharedBufferCopy", nullptr, false},
        };
    case MessageName::RemoteLegacyCDMSessionProxy_CachedKeyForKeyID:
        return Vector<ArgumentDescription> {
            {"keyId", "String", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteMediaEngineConfigurationFactoryProxy_CreateDecodingConfiguration:
        return Vector<ArgumentDescription> {
            {"configuration", "WebCore::MediaDecodingConfiguration", nullptr, false},
        };
    case MessageName::RemoteMediaEngineConfigurationFactoryProxy_CreateEncodingConfiguration:
        return Vector<ArgumentDescription> {
            {"configuration", "WebCore::MediaEncodingConfiguration", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteMediaPlayerManagerProxy_CreateMediaPlayer:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::MediaPlayerIdentifier", nullptr, false},
            {"remoteEngineIdentifier", "uint8_t", "WebCore::MediaPlayerEnums::MediaEngineIdentifier", false},
            {"proxyConfiguration", "WebKit::RemoteMediaPlayerProxyConfiguration", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerManagerProxy_DeleteMediaPlayer:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::MediaPlayerIdentifier", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerManagerProxy_GetSupportedTypes:
        return Vector<ArgumentDescription> {
            {"remoteEngineIdentifier", "uint8_t", "WebCore::MediaPlayerEnums::MediaEngineIdentifier", false},
        };
    case MessageName::RemoteMediaPlayerManagerProxy_SupportsTypeAndCodecs:
        return Vector<ArgumentDescription> {
            {"remoteEngineIdentifier", "uint8_t", "WebCore::MediaPlayerEnums::MediaEngineIdentifier", false},
            {"type", "WebCore::MediaEngineSupportParameters", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerManagerProxy_OriginsInMediaCache:
        return Vector<ArgumentDescription> {
            {"remoteEngineIdentifier", "uint8_t", "WebCore::MediaPlayerEnums::MediaEngineIdentifier", false},
            {"path", "String", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerManagerProxy_ClearMediaCache:
        return Vector<ArgumentDescription> {
            {"remoteEngineIdentifier", "uint8_t", "WebCore::MediaPlayerEnums::MediaEngineIdentifier", false},
            {"path", "String", nullptr, false},
            {"modifiedSince", "WallTime", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerManagerProxy_ClearMediaCacheForOrigins:
        return Vector<ArgumentDescription> {
            {"remoteEngineIdentifier", "uint8_t", "WebCore::MediaPlayerEnums::MediaEngineIdentifier", false},
            {"path", "String", nullptr, false},
            {"origins", "HashSet<WebCore::SecurityOriginData>", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerManagerProxy_SupportsKeySystem:
        return Vector<ArgumentDescription> {
            {"remoteEngineIdentifier", "uint8_t", "WebCore::MediaPlayerEnums::MediaEngineIdentifier", false},
            {"keySystem", "String", nullptr, false},
            {"mimeType", "String", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteMediaPlayerProxy_PrepareForPlayback:
        return Vector<ArgumentDescription> {
            {"privateMode", "bool", nullptr, false},
            {"preload", "uint8_t", "WebCore::MediaPlayerEnums::Preload", false},
            {"preservesPitch", "bool", nullptr, false},
            {"prepareForRendering", "bool", nullptr, false},
            {"videoContentScale", "float", nullptr, false},
            {"mode", "uint8_t", "WebCore::DynamicRangeMode", false},
        };
    case MessageName::RemoteMediaPlayerProxy_Load:
        return Vector<ArgumentDescription> {
            {"url", "URL", nullptr, false},
            {"sandboxExtension", "WebKit::SandboxExtension::Handle", nullptr, true},
            {"contentType", "WebCore::ContentType", nullptr, false},
            {"keySystem", "String", nullptr, false},
        };
#if ENABLE(MEDIA_SOURCE)
    case MessageName::RemoteMediaPlayerProxy_LoadMediaSource:
        return Vector<ArgumentDescription> {
            {"url", "URL", nullptr, false},
            {"contentType", "WebCore::ContentType", nullptr, false},
            {"webMParserEnabled", "bool", nullptr, false},
            {"mediaSourceIdentifier", "WebKit::RemoteMediaSourceIdentifier", nullptr, false},
        };
#endif
    case MessageName::RemoteMediaPlayerProxy_CancelLoad:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaPlayerProxy_PrepareToPlay:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaPlayerProxy_Play:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaPlayerProxy_Pause:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaPlayerProxy_SetVolume:
        return Vector<ArgumentDescription> {
            {"volume", "double", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_SetMuted:
        return Vector<ArgumentDescription> {
            {"muted", "bool", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_Seek:
        return Vector<ArgumentDescription> {
            {"time", "MediaTime", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_SeekWithTolerance:
        return Vector<ArgumentDescription> {
            {"time", "MediaTime", nullptr, false},
            {"negativeTolerance", "MediaTime", nullptr, false},
            {"positiveTolerance", "MediaTime", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_SetPreload:
        return Vector<ArgumentDescription> {
            {"preload", "uint8_t", "WebCore::MediaPlayerEnums::Preload", false},
        };
    case MessageName::RemoteMediaPlayerProxy_SetPrivateBrowsingMode:
        return Vector<ArgumentDescription> {
            {"privateMode", "bool", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_SetPreservesPitch:
        return Vector<ArgumentDescription> {
            {"preservesPitch", "bool", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_SetPitchCorrectionAlgorithm:
        return Vector<ArgumentDescription> {
            {"algorithm", "WebCore::MediaPlayer::PitchCorrectionAlgorithm", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_PrepareForRendering:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaPlayerProxy_SetPageIsVisible:
        return Vector<ArgumentDescription> {
            {"visible", "bool", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_SetShouldMaintainAspectRatio:
        return Vector<ArgumentDescription> {
            {"maintainAspectRatio", "bool", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_AcceleratedRenderingStateChanged:
        return Vector<ArgumentDescription> {
            {"canBeAccelerated", "bool", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_SetShouldDisableSleep:
        return Vector<ArgumentDescription> {
            {"disable", "bool", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_SetRate:
        return Vector<ArgumentDescription> {
            {"rate", "double", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_DidLoadingProgress:
        return Vector<ArgumentDescription> { };
#if ENABLE(VIDEO_PRESENTATION_MODE)
    case MessageName::RemoteMediaPlayerProxy_UpdateVideoFullscreenInlineImage:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaPlayerProxy_SetVideoFullscreenMode:
        return Vector<ArgumentDescription> {
            {"mode", "WebCore::MediaPlayer::VideoFullscreenMode", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_SetVideoFullscreenGravity:
        return Vector<ArgumentDescription> {
            {"gravity", "uint8_t", "WebCore::MediaPlayerEnums::VideoGravity", false},
        };
    case MessageName::RemoteMediaPlayerProxy_VideoFullscreenStandbyChanged:
        return Vector<ArgumentDescription> {
            {"standby", "bool", nullptr, false},
        };
#endif
    case MessageName::RemoteMediaPlayerProxy_SetBufferingPolicy:
        return Vector<ArgumentDescription> {
            {"policy", "WebCore::MediaPlayer::BufferingPolicy", nullptr, false},
        };
#if PLATFORM(COCOA)
    case MessageName::RemoteMediaPlayerProxy_SetVideoInlineSizeFenced:
        return Vector<ArgumentDescription> {
            {"size", "WebCore::FloatSize", nullptr, false},
            {"machSendRight", "MachSendRight", nullptr, false},
        };
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET)
    case MessageName::RemoteMediaPlayerProxy_SetWirelessVideoPlaybackDisabled:
        return Vector<ArgumentDescription> {
            {"disabled", "bool", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_SetWirelessPlaybackTarget:
        return Vector<ArgumentDescription> {
            {"target", "WebCore::MediaPlaybackTargetContext", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_SetShouldPlayToPlaybackTarget:
        return Vector<ArgumentDescription> {
            {"shouldPlay", "bool", nullptr, false},
        };
#endif
#if ENABLE(LEGACY_ENCRYPTED_MEDIA)
    case MessageName::RemoteMediaPlayerProxy_SetLegacyCDMSession:
        return Vector<ArgumentDescription> {
            {"instanceId", "WebKit::RemoteLegacyCDMSessionIdentifier", nullptr, true},
        };
    case MessageName::RemoteMediaPlayerProxy_KeyAdded:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(ENCRYPTED_MEDIA)
    case MessageName::RemoteMediaPlayerProxy_CdmInstanceAttached:
        return Vector<ArgumentDescription> {
            {"instanceId", "WebKit::RemoteCDMInstanceIdentifier", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_CdmInstanceDetached:
        return Vector<ArgumentDescription> {
            {"instanceId", "WebKit::RemoteCDMInstanceIdentifier", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_AttemptToDecryptWithInstance:
        return Vector<ArgumentDescription> {
            {"instanceId", "WebKit::RemoteCDMInstanceIdentifier", nullptr, false},
        };
#endif
#if ENABLE(LEGACY_ENCRYPTED_MEDIA) && ENABLE(ENCRYPTED_MEDIA)
    case MessageName::RemoteMediaPlayerProxy_SetShouldContinueAfterKeyNeeded:
        return Vector<ArgumentDescription> {
            {"should", "bool", nullptr, false},
        };
#endif
    case MessageName::RemoteMediaPlayerProxy_BeginSimulatedHDCPError:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaPlayerProxy_EndSimulatedHDCPError:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaPlayerProxy_NotifyActiveSourceBuffersChanged:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaPlayerProxy_ApplicationWillResignActive:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaPlayerProxy_ApplicationDidBecomeActive:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaPlayerProxy_NotifyTrackModeChanged:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaPlayerProxy_TracksChanged:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaPlayerProxy_AudioTrackSetEnabled:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::TrackPrivateRemoteIdentifier", nullptr, false},
            {"enabled", "bool", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_VideoTrackSetSelected:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::TrackPrivateRemoteIdentifier", nullptr, false},
            {"selected", "bool", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_TextTrackSetMode:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::TrackPrivateRemoteIdentifier", nullptr, false},
            {"mode", "uint8_t", "WebCore::InbandTextTrackPrivate::Mode", false},
        };
    case MessageName::RemoteMediaPlayerProxy_PerformTaskAtMediaTime:
        return Vector<ArgumentDescription> {
            {"mediaTime", "MediaTime", nullptr, false},
            {"messageTime", "MonotonicTime", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_WouldTaintOrigin:
        return Vector<ArgumentDescription> {
            {"origin", "WebCore::SecurityOriginData", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_SetVideoPlaybackMetricsUpdateInterval:
        return Vector<ArgumentDescription> {
            {"interval", "double", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_SetPreferredDynamicRangeMode:
        return Vector<ArgumentDescription> {
            {"mode", "uint8_t", "WebCore::DynamicRangeMode", false},
        };
#if PLATFORM(IOS_FAMILY)
    case MessageName::RemoteMediaPlayerProxy_ErrorLog:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaPlayerProxy_AccessLog:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(WEB_AUDIO)
    case MessageName::RemoteMediaPlayerProxy_CreateAudioSourceProvider:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaPlayerProxy_SetShouldEnableAudioSourceProvider:
        return Vector<ArgumentDescription> {
            {"shouldEnable", "bool", nullptr, false},
        };
#endif
#if PLATFORM(COCOA)
    case MessageName::RemoteMediaPlayerProxy_NativeImageForCurrentTime:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaPlayerProxy_ColorSpace:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::RemoteMediaPlayerProxy_VideoFrameForCurrentTimeIfChanged:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaPlayerProxy_PlayAtHostTime:
        return Vector<ArgumentDescription> {
            {"time", "MonotonicTime", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_PauseAtHostTime:
        return Vector<ArgumentDescription> {
            {"time", "MonotonicTime", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_StartVideoFrameMetadataGathering:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaPlayerProxy_StopVideoFrameMetadataGathering:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteMediaResourceManager_ResponseReceived:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RemoteMediaResourceIdentifier", nullptr, false},
            {"response", "WebCore::ResourceResponse", nullptr, false},
            {"didPassAccessControlCheck", "bool", nullptr, false},
        };
    case MessageName::RemoteMediaResourceManager_RedirectReceived:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RemoteMediaResourceIdentifier", nullptr, false},
            {"request", "WebCore::ResourceRequest", nullptr, false},
            {"response", "WebCore::ResourceResponse", nullptr, false},
        };
    case MessageName::RemoteMediaResourceManager_DataSent:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RemoteMediaResourceIdentifier", nullptr, false},
            {"bytesSent", "uint64_t", nullptr, false},
            {"totalBytesToBeSent", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteMediaResourceManager_DataReceived:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RemoteMediaResourceIdentifier", nullptr, false},
            {"data", "WebKit::SharedMemory::IPCHandle", nullptr, false},
        };
    case MessageName::RemoteMediaResourceManager_AccessControlCheckFailed:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RemoteMediaResourceIdentifier", nullptr, false},
            {"error", "WebCore::ResourceError", nullptr, false},
        };
    case MessageName::RemoteMediaResourceManager_LoadFailed:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RemoteMediaResourceIdentifier", nullptr, false},
            {"error", "WebCore::ResourceError", nullptr, false},
        };
    case MessageName::RemoteMediaResourceManager_LoadFinished:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RemoteMediaResourceIdentifier", nullptr, false},
            {"metrics", "WebCore::NetworkLoadMetrics", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)
    case MessageName::RemoteMediaSourceProxy_AddSourceBuffer:
        return Vector<ArgumentDescription> {
            {"contentType", "WebCore::ContentType", nullptr, false},
        };
    case MessageName::RemoteMediaSourceProxy_DurationChanged:
        return Vector<ArgumentDescription> {
            {"duration", "MediaTime", nullptr, false},
        };
    case MessageName::RemoteMediaSourceProxy_BufferedChanged:
        return Vector<ArgumentDescription> {
            {"buffered", "WebCore::PlatformTimeRanges", nullptr, false},
        };
    case MessageName::RemoteMediaSourceProxy_SetReadyState:
        return Vector<ArgumentDescription> {
            {"readyState", "WebCore::MediaPlayerEnums::ReadyState", nullptr, false},
        };
    case MessageName::RemoteMediaSourceProxy_SetIsSeeking:
        return Vector<ArgumentDescription> {
            {"isSeeking", "bool", nullptr, false},
        };
    case MessageName::RemoteMediaSourceProxy_WaitForSeekCompleted:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaSourceProxy_SeekCompleted:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaSourceProxy_SetTimeFudgeFactor:
        return Vector<ArgumentDescription> {
            {"fudgeFactor", "MediaTime", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteRemoteCommandListenerProxy_UpdateSupportedCommands:
        return Vector<ArgumentDescription> {
            {"commands", "Vector<WebCore::PlatformMediaSession::RemoteControlCommandType>", nullptr, false},
            {"supportsSeeking", "bool", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)
    case MessageName::RemoteSourceBufferProxy_SetActive:
        return Vector<ArgumentDescription> {
            {"active", "bool", nullptr, false},
        };
    case MessageName::RemoteSourceBufferProxy_CanSwitchToType:
        return Vector<ArgumentDescription> {
            {"contentType", "WebCore::ContentType", nullptr, false},
        };
    case MessageName::RemoteSourceBufferProxy_SetMode:
        return Vector<ArgumentDescription> {
            {"appendMode", "WebCore::SourceBufferAppendMode", nullptr, false},
        };
    case MessageName::RemoteSourceBufferProxy_Append:
        return Vector<ArgumentDescription> {
            {"data", "WebKit::SharedMemory::IPCHandle", nullptr, false},
        };
    case MessageName::RemoteSourceBufferProxy_Abort:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteSourceBufferProxy_ResetParserState:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteSourceBufferProxy_RemovedFromMediaSource:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteSourceBufferProxy_SetMediaSourceEnded:
        return Vector<ArgumentDescription> {
            {"isEnded", "bool", nullptr, false},
        };
    case MessageName::RemoteSourceBufferProxy_SetReadyState:
        return Vector<ArgumentDescription> {
            {"state", "WebCore::MediaPlayer::ReadyState", nullptr, false},
        };
    case MessageName::RemoteSourceBufferProxy_StartChangingType:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteSourceBufferProxy_UpdateBufferedFromTrackBuffers:
        return Vector<ArgumentDescription> {
            {"sourceIsEnded", "bool", nullptr, false},
        };
    case MessageName::RemoteSourceBufferProxy_AddTrackBuffer:
        return Vector<ArgumentDescription> {
            {"remoteIdentifier", "WebKit::TrackPrivateRemoteIdentifier", nullptr, false},
        };
    case MessageName::RemoteSourceBufferProxy_ResetTrackBuffers:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteSourceBufferProxy_ClearTrackBuffers:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteSourceBufferProxy_SetAllTrackBuffersNeedRandomAccess:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteSourceBufferProxy_RemoveCodedFrames:
        return Vector<ArgumentDescription> {
            {"start", "MediaTime", nullptr, false},
            {"end", "MediaTime", nullptr, false},
            {"currentTime", "MediaTime", nullptr, false},
            {"isEnded", "bool", nullptr, false},
        };
    case MessageName::RemoteSourceBufferProxy_EvictCodedFrames:
        return Vector<ArgumentDescription> {
            {"newDataSize", "uint64_t", nullptr, false},
            {"maximumBufferSize", "uint64_t", nullptr, false},
            {"currentTime", "MediaTime", nullptr, false},
            {"duration", "MediaTime", nullptr, false},
            {"isEnded", "bool", nullptr, false},
        };
    case MessageName::RemoteSourceBufferProxy_ReenqueueMediaIfNeeded:
        return Vector<ArgumentDescription> {
            {"currentMediaTime", "MediaTime", nullptr, false},
        };
    case MessageName::RemoteSourceBufferProxy_SetGroupStartTimestamp:
        return Vector<ArgumentDescription> {
            {"timestamp", "MediaTime", nullptr, false},
        };
    case MessageName::RemoteSourceBufferProxy_SetGroupStartTimestampToEndTimestamp:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteSourceBufferProxy_SetShouldGenerateTimestamps:
        return Vector<ArgumentDescription> {
            {"shouldGenerateTimestamps", "bool", nullptr, false},
        };
    case MessageName::RemoteSourceBufferProxy_ResetTimestampOffsetInTrackBuffers:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteSourceBufferProxy_SetTimestampOffset:
        return Vector<ArgumentDescription> {
            {"timestampOffset", "MediaTime", nullptr, false},
        };
    case MessageName::RemoteSourceBufferProxy_SetAppendWindowStart:
        return Vector<ArgumentDescription> {
            {"appendWindowStart", "MediaTime", nullptr, false},
        };
    case MessageName::RemoteSourceBufferProxy_SetAppendWindowEnd:
        return Vector<ArgumentDescription> {
            {"appendWindowEnd", "MediaTime", nullptr, false},
        };
    case MessageName::RemoteSourceBufferProxy_SeekToTime:
        return Vector<ArgumentDescription> {
            {"mediaTime", "MediaTime", nullptr, false},
        };
    case MessageName::RemoteSourceBufferProxy_UpdateTrackIds:
        return Vector<ArgumentDescription> {
            {"identifierPairs", "Vector<std::pair<WebKit::TrackPrivateRemoteIdentifier, WebKit::TrackPrivateRemoteIdentifier>>", nullptr, false},
        };
    case MessageName::RemoteSourceBufferProxy_BufferedSamplesForTrackId:
        return Vector<ArgumentDescription> {
            {"remoteIdentifier", "WebKit::TrackPrivateRemoteIdentifier", nullptr, false},
        };
    case MessageName::RemoteSourceBufferProxy_EnqueuedSamplesForTrackID:
        return Vector<ArgumentDescription> {
            {"remoteIdentifier", "WebKit::TrackPrivateRemoteIdentifier", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(VIDEO)
#if PLATFORM(COCOA)
    case MessageName::RemoteVideoFrameObjectHeap_GetVideoFrameBuffer:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RemoteVideoFrameReadReference", nullptr, false},
        };
#endif
    case MessageName::RemoteVideoFrameObjectHeap_ReleaseVideoFrame:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RemoteVideoFrameWriteReference", nullptr, false},
        };
#endif
#if USE(LIBWEBRTC) && PLATFORM(COCOA) && ENABLE(GPU_PROCESS)
    case MessageName::LibWebRTCCodecsProxy_CreateH264Decoder:
        return Vector<ArgumentDescription> {
            {"id", "WebKit::RTCDecoderIdentifier", nullptr, false},
            {"useRemoteFrames", "bool", nullptr, false},
        };
    case MessageName::LibWebRTCCodecsProxy_CreateH265Decoder:
        return Vector<ArgumentDescription> {
            {"id", "WebKit::RTCDecoderIdentifier", nullptr, false},
            {"useRemoteFrames", "bool", nullptr, false},
        };
    case MessageName::LibWebRTCCodecsProxy_CreateVP9Decoder:
        return Vector<ArgumentDescription> {
            {"id", "WebKit::RTCDecoderIdentifier", nullptr, false},
            {"useRemoteFrames", "bool", nullptr, false},
        };
    case MessageName::LibWebRTCCodecsProxy_ReleaseDecoder:
        return Vector<ArgumentDescription> {
            {"id", "WebKit::RTCDecoderIdentifier", nullptr, false},
        };
    case MessageName::LibWebRTCCodecsProxy_DecodeFrame:
        return Vector<ArgumentDescription> {
            {"id", "WebKit::RTCDecoderIdentifier", nullptr, false},
            {"timeStamp", "uint32_t", nullptr, false},
            {"data", "IPC::DataReference", nullptr, false},
        };
    case MessageName::LibWebRTCCodecsProxy_SetFrameSize:
        return Vector<ArgumentDescription> {
            {"id", "WebKit::RTCDecoderIdentifier", nullptr, false},
            {"width", "uint16_t", nullptr, false},
            {"height", "uint16_t", nullptr, false},
        };
    case MessageName::LibWebRTCCodecsProxy_CreateEncoder:
        return Vector<ArgumentDescription> {
            {"id", "WebKit::RTCEncoderIdentifier", nullptr, false},
            {"formatName", "String", nullptr, false},
            {"parameters", "Vector<std::pair<String, String>>", nullptr, false},
            {"useLowLatency", "bool", nullptr, false},
        };
    case MessageName::LibWebRTCCodecsProxy_ReleaseEncoder:
        return Vector<ArgumentDescription> {
            {"id", "WebKit::RTCEncoderIdentifier", nullptr, false},
        };
    case MessageName::LibWebRTCCodecsProxy_InitializeEncoder:
        return Vector<ArgumentDescription> {
            {"id", "WebKit::RTCEncoderIdentifier", nullptr, false},
            {"width", "uint16_t", nullptr, false},
            {"height", "uint16_t", nullptr, false},
            {"startBitrate", "unsigned", nullptr, false},
            {"maxBitrate", "unsigned", nullptr, false},
            {"minBitrate", "unsigned", nullptr, false},
            {"maxFramerate", "uint32_t", nullptr, false},
        };
    case MessageName::LibWebRTCCodecsProxy_EncodeFrame:
        return Vector<ArgumentDescription> {
            {"id", "WebKit::RTCEncoderIdentifier", nullptr, false},
            {"sample", "WebCore::RemoteVideoSample", nullptr, false},
            {"timeStamp", "uint32_t", nullptr, false},
            {"shouldEncodeAsKeyFrame", "bool", nullptr, false},
            {"sampleReference", "WebKit::RemoteVideoFrameReadReference", nullptr, true},
        };
    case MessageName::LibWebRTCCodecsProxy_SetEncodeRates:
        return Vector<ArgumentDescription> {
            {"id", "WebKit::RTCEncoderIdentifier", nullptr, false},
            {"bitRate", "uint32_t", nullptr, false},
            {"frameRate", "uint32_t", nullptr, false},
        };
    case MessageName::LibWebRTCCodecsProxy_SetSharedVideoFrameSemaphore:
        return Vector<ArgumentDescription> {
            {"id", "WebKit::RTCEncoderIdentifier", nullptr, false},
            {"semaphore", "IPC::Semaphore", nullptr, false},
        };
    case MessageName::LibWebRTCCodecsProxy_SetSharedVideoFrameMemory:
        return Vector<ArgumentDescription> {
            {"id", "WebKit::RTCEncoderIdentifier", nullptr, false},
            {"storageHandle", "WebKit::SharedMemory::IPCHandle", nullptr, false},
        };
    case MessageName::LibWebRTCCodecsProxy_SetRTCLoggingLevel:
        return Vector<ArgumentDescription> {
            {"level", "WTFLogLevel", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
    case MessageName::RemoteAudioMediaStreamTrackRendererInternalUnitManager_CreateUnit:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::AudioMediaStreamTrackRendererInternalUnitIdentifier", nullptr, false},
        };
    case MessageName::RemoteAudioMediaStreamTrackRendererInternalUnitManager_DeleteUnit:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::AudioMediaStreamTrackRendererInternalUnitIdentifier", nullptr, false},
        };
    case MessageName::RemoteAudioMediaStreamTrackRendererInternalUnitManager_StartUnit:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::AudioMediaStreamTrackRendererInternalUnitIdentifier", nullptr, false},
            {"storageHandle", "WebKit::SharedMemory::IPCHandle", nullptr, false},
            {"description", "WebCore::CAAudioStreamDescription", nullptr, false},
            {"numberOfFrames", "uint64_t", nullptr, false},
            {"renderSemaphore", "IPC::Semaphore", nullptr, false},
        };
    case MessageName::RemoteAudioMediaStreamTrackRendererInternalUnitManager_StopUnit:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::AudioMediaStreamTrackRendererInternalUnitIdentifier", nullptr, false},
        };
    case MessageName::RemoteAudioMediaStreamTrackRendererInternalUnitManager_SetAudioOutputDevice:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::AudioMediaStreamTrackRendererInternalUnitIdentifier", nullptr, false},
            {"deviceId", "String", nullptr, false},
        };
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
    case MessageName::RemoteMediaRecorder_AudioSamplesStorageChanged:
        return Vector<ArgumentDescription> {
            {"storageHandle", "WebKit::SharedMemory::IPCHandle", nullptr, false},
            {"description", "WebCore::CAAudioStreamDescription", nullptr, false},
            {"numberOfFrames", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteMediaRecorder_AudioSamplesAvailable:
        return Vector<ArgumentDescription> {
            {"time", "MediaTime", nullptr, false},
            {"numberOfFrames", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteMediaRecorder_VideoSampleAvailable:
        return Vector<ArgumentDescription> {
            {"sample", "WebCore::RemoteVideoSample", nullptr, false},
            {"remoteVideoFrameReadReference", "WebKit::RemoteVideoFrameReadReference", nullptr, true},
        };
    case MessageName::RemoteMediaRecorder_FetchData:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaRecorder_StopRecording:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaRecorder_Pause:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaRecorder_Resume:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaRecorder_SetSharedVideoFrameSemaphore:
        return Vector<ArgumentDescription> {
            {"semaphore", "IPC::Semaphore", nullptr, false},
        };
    case MessageName::RemoteMediaRecorder_SetSharedVideoFrameMemory:
        return Vector<ArgumentDescription> {
            {"storageHandle", "WebKit::SharedMemory::IPCHandle", nullptr, false},
        };
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
    case MessageName::RemoteMediaRecorderManager_CreateRecorder:
        return Vector<ArgumentDescription> {
            {"id", "WebKit::MediaRecorderIdentifier", nullptr, false},
            {"hasAudio", "bool", nullptr, false},
            {"hasVideo", "bool", nullptr, false},
            {"options", "WebCore::MediaRecorderPrivateOptions", nullptr, false},
        };
    case MessageName::RemoteMediaRecorderManager_ReleaseRecorder:
        return Vector<ArgumentDescription> {
            {"id", "WebKit::MediaRecorderIdentifier", nullptr, false},
        };
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
#if !RELEASE_LOG_DISABLED
    case MessageName::RemoteSampleBufferDisplayLayer_SetLogIdentifier:
        return Vector<ArgumentDescription> {
            {"logIdentifier", "String", nullptr, false},
        };
#endif
    case MessageName::RemoteSampleBufferDisplayLayer_UpdateDisplayMode:
        return Vector<ArgumentDescription> {
            {"hideDisplayLayer", "bool", nullptr, false},
            {"hideRootLayer", "bool", nullptr, false},
        };
    case MessageName::RemoteSampleBufferDisplayLayer_UpdateAffineTransform:
        return Vector<ArgumentDescription> {
            {"transform", "CGAffineTransform", nullptr, false},
        };
    case MessageName::RemoteSampleBufferDisplayLayer_UpdateBoundsAndPosition:
        return Vector<ArgumentDescription> {
            {"bounds", "CGRect", nullptr, false},
            {"rotation", "WebCore::MediaSample::VideoRotation", nullptr, false},
        };
    case MessageName::RemoteSampleBufferDisplayLayer_Flush:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteSampleBufferDisplayLayer_FlushAndRemoveImage:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteSampleBufferDisplayLayer_EnqueueSample:
        return Vector<ArgumentDescription> {
            {"sample", "WebKit::RemoteVideoFrameReadReference", nullptr, false},
        };
    case MessageName::RemoteSampleBufferDisplayLayer_EnqueueSampleCV:
        return Vector<ArgumentDescription> {
            {"sample", "WebCore::RemoteVideoSample", nullptr, false},
        };
    case MessageName::RemoteSampleBufferDisplayLayer_ClearEnqueuedSamples:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteSampleBufferDisplayLayer_Play:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteSampleBufferDisplayLayer_Pause:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteSampleBufferDisplayLayer_SetSharedVideoFrameSemaphore:
        return Vector<ArgumentDescription> {
            {"semaphore", "IPC::Semaphore", nullptr, false},
        };
    case MessageName::RemoteSampleBufferDisplayLayer_SetSharedVideoFrameMemory:
        return Vector<ArgumentDescription> {
            {"storageHandle", "WebKit::SharedMemory::IPCHandle", nullptr, false},
        };
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
    case MessageName::RemoteSampleBufferDisplayLayerManager_CreateLayer:
        return Vector<ArgumentDescription> {
            {"id", "WebKit::SampleBufferDisplayLayerIdentifier", nullptr, false},
            {"hideRootLayer", "bool", nullptr, false},
            {"size", "WebCore::IntSize", nullptr, false},
        };
    case MessageName::RemoteSampleBufferDisplayLayerManager_ReleaseLayer:
        return Vector<ArgumentDescription> {
            {"id", "WebKit::SampleBufferDisplayLayerIdentifier", nullptr, false},
        };
#endif
    case MessageName::WebCookieManager_GetHostnamesWithCookies:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::WebCookieManager_DeleteCookiesForHostnames:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"hostnames", "Vector<String>", nullptr, false},
        };
    case MessageName::WebCookieManager_DeleteAllCookies:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::WebCookieManager_SetCookie:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"cookie", "Vector<WebCore::Cookie>", nullptr, false},
        };
    case MessageName::WebCookieManager_SetCookies:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"cookies", "Vector<WebCore::Cookie>", nullptr, false},
            {"url", "URL", nullptr, false},
            {"mainDocumentURL", "URL", nullptr, false},
        };
    case MessageName::WebCookieManager_GetAllCookies:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::WebCookieManager_GetCookies:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"url", "URL", nullptr, false},
        };
    case MessageName::WebCookieManager_DeleteCookie:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"cookie", "WebCore::Cookie", nullptr, false},
        };
    case MessageName::WebCookieManager_DeleteAllCookiesModifiedSince:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"time", "WallTime", nullptr, false},
        };
    case MessageName::WebCookieManager_SetHTTPCookieAcceptPolicy:
        return Vector<ArgumentDescription> {
            {"policy", "uint8_t", "WebCore::HTTPCookieAcceptPolicy", false},
        };
    case MessageName::WebCookieManager_GetHTTPCookieAcceptPolicy:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::WebCookieManager_StartObservingCookieChanges:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::WebCookieManager_StopObservingCookieChanges:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
#if USE(SOUP)
    case MessageName::WebCookieManager_SetCookiePersistentStorage:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"storagePath", "String", nullptr, false},
            {"storageType", "bool", "WebKit::SoupCookiePersistentStorageType", false},
        };
#endif
    case MessageName::WebIDBServer_DeleteDatabase:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
        };
    case MessageName::WebIDBServer_OpenDatabase:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
        };
    case MessageName::WebIDBServer_AbortTransaction:
        return Vector<ArgumentDescription> {
            {"transactionIdentifier", "WebCore::IDBResourceIdentifier", nullptr, false},
        };
    case MessageName::WebIDBServer_CommitTransaction:
        return Vector<ArgumentDescription> {
            {"transactionIdentifier", "WebCore::IDBResourceIdentifier", nullptr, false},
            {"pendingRequestCount", "uint64_t", nullptr, false},
        };
    case MessageName::WebIDBServer_DidFinishHandlingVersionChangeTransaction:
        return Vector<ArgumentDescription> {
            {"databaseConnectionIdentifier", "uint64_t", nullptr, false},
            {"transactionIdentifier", "WebCore::IDBResourceIdentifier", nullptr, false},
        };
    case MessageName::WebIDBServer_CreateObjectStore:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"info", "WebCore::IDBObjectStoreInfo", nullptr, false},
        };
    case MessageName::WebIDBServer_DeleteObjectStore:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"objectStoreName", "String", nullptr, false},
        };
    case MessageName::WebIDBServer_RenameObjectStore:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"objectStoreIdentifier", "uint64_t", nullptr, false},
            {"newName", "String", nullptr, false},
        };
    case MessageName::WebIDBServer_ClearObjectStore:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"objectStoreIdentifier", "uint64_t", nullptr, false},
        };
    case MessageName::WebIDBServer_CreateIndex:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"info", "WebCore::IDBIndexInfo", nullptr, false},
        };
    case MessageName::WebIDBServer_DeleteIndex:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"objectStoreIdentifier", "uint64_t", nullptr, false},
            {"indexName", "String", nullptr, false},
        };
    case MessageName::WebIDBServer_RenameIndex:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"objectStoreIdentifier", "uint64_t", nullptr, false},
            {"indexIdentifier", "uint64_t", nullptr, false},
            {"newName", "String", nullptr, false},
        };
    case MessageName::WebIDBServer_PutOrAdd:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"key", "WebCore::IDBKeyData", nullptr, false},
            {"value", "WebCore::IDBValue", nullptr, false},
            {"overwriteMode", "WebCore::IndexedDB::ObjectStoreOverwriteMode", nullptr, false},
        };
    case MessageName::WebIDBServer_GetRecord:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"getRecordData", "WebCore::IDBGetRecordData", nullptr, false},
        };
    case MessageName::WebIDBServer_GetAllRecords:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"getAllRecordsData", "WebCore::IDBGetAllRecordsData", nullptr, false},
        };
    case MessageName::WebIDBServer_GetCount:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"range", "WebCore::IDBKeyRangeData", nullptr, false},
        };
    case MessageName::WebIDBServer_DeleteRecord:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"range", "WebCore::IDBKeyRangeData", nullptr, false},
        };
    case MessageName::WebIDBServer_OpenCursor:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"info", "WebCore::IDBCursorInfo", nullptr, false},
        };
    case MessageName::WebIDBServer_IterateCursor:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"data", "WebCore::IDBIterateCursorData", nullptr, false},
        };
    case MessageName::WebIDBServer_EstablishTransaction:
        return Vector<ArgumentDescription> {
            {"databaseConnectionIdentifier", "uint64_t", nullptr, false},
            {"info", "WebCore::IDBTransactionInfo", nullptr, false},
        };
    case MessageName::WebIDBServer_DatabaseConnectionPendingClose:
        return Vector<ArgumentDescription> {
            {"databaseConnectionIdentifier", "uint64_t", nullptr, false},
        };
    case MessageName::WebIDBServer_DatabaseConnectionClosed:
        return Vector<ArgumentDescription> {
            {"databaseConnectionIdentifier", "uint64_t", nullptr, false},
        };
    case MessageName::WebIDBServer_AbortOpenAndUpgradeNeeded:
        return Vector<ArgumentDescription> {
            {"databaseConnectionIdentifier", "uint64_t", nullptr, false},
            {"transactionIdentifier", "WebCore::IDBResourceIdentifier", nullptr, false},
        };
    case MessageName::WebIDBServer_DidFireVersionChangeEvent:
        return Vector<ArgumentDescription> {
            {"databaseConnectionIdentifier", "uint64_t", nullptr, false},
            {"requestIdentifier", "WebCore::IDBResourceIdentifier", nullptr, false},
            {"connectionClosedOnBehalfOfServer", "WebCore::IndexedDB::ConnectionClosedOnBehalfOfServer", nullptr, false},
        };
    case MessageName::WebIDBServer_OpenDBRequestCancelled:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
        };
    case MessageName::WebIDBServer_GetAllDatabaseNamesAndVersions:
        return Vector<ArgumentDescription> {
            {"requestIdentifier", "WebCore::IDBResourceIdentifier", nullptr, false},
            {"origin", "WebCore::ClientOrigin", nullptr, false},
        };
    case MessageName::NetworkBroadcastChannelRegistry_RegisterChannel:
        return Vector<ArgumentDescription> {
            {"origin", "WebCore::ClientOrigin", nullptr, false},
            {"name", "String", nullptr, false},
        };
    case MessageName::NetworkBroadcastChannelRegistry_UnregisterChannel:
        return Vector<ArgumentDescription> {
            {"origin", "WebCore::ClientOrigin", nullptr, false},
            {"name", "String", nullptr, false},
        };
    case MessageName::NetworkBroadcastChannelRegistry_PostMessage:
        return Vector<ArgumentDescription> {
            {"origin", "WebCore::ClientOrigin", nullptr, false},
            {"name", "String", nullptr, false},
            {"message", "WebCore::MessageWithMessagePorts", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_ScheduleResourceLoad:
        return Vector<ArgumentDescription> {
            {"resourceLoadParameters", "WebKit::NetworkResourceLoadParameters", nullptr, false},
            {"existingLoaderToResume", "WebKit::NetworkResourceLoadIdentifier", nullptr, true},
        };
    case MessageName::NetworkConnectionToWebProcess_PerformSynchronousLoad:
        return Vector<ArgumentDescription> {
            {"resourceLoadParameters", "WebKit::NetworkResourceLoadParameters", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_TestProcessIncomingSyncMessagesWhenWaitingForSyncReply:
        return Vector<ArgumentDescription> {
            {"pageID", "WebKit::WebPageProxyIdentifier", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_LoadPing:
        return Vector<ArgumentDescription> {
            {"resourceLoadParameters", "WebKit::NetworkResourceLoadParameters", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_RemoveLoadIdentifier:
        return Vector<ArgumentDescription> {
            {"resourceLoadIdentifier", "WebCore::ResourceLoaderIdentifier", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_PageLoadCompleted:
        return Vector<ArgumentDescription> {
            {"webPageID", "WebCore::PageIdentifier", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_BrowsingContextRemoved:
        return Vector<ArgumentDescription> {
            {"webPageProxyID", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"webPageID", "WebCore::PageIdentifier", nullptr, false},
            {"webFrameID", "WebCore::FrameIdentifier", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_PrefetchDNS:
        return Vector<ArgumentDescription> {
            {"hostname", "String", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_SendH2Ping:
        return Vector<ArgumentDescription> {
            {"parameters", "WebKit::NetworkResourceLoadParameters", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_PreconnectTo:
        return Vector<ArgumentDescription> {
            {"preconnectionIdentifier", "WebCore::ResourceLoaderIdentifier", nullptr, true},
            {"loadParameters", "WebKit::NetworkResourceLoadParameters", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_IsResourceLoadFinished:
        return Vector<ArgumentDescription> {
            {"resourceLoadIdentifier", "WebCore::ResourceLoaderIdentifier", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_StartDownload:
        return Vector<ArgumentDescription> {
            {"downloadID", "WebKit::DownloadID", nullptr, false},
            {"request", "WebCore::ResourceRequest", nullptr, false},
            {"isNavigatingToAppBoundDomain", "bool", "std::optional<WebKit::NavigatingToAppBoundDomain>", false},
            {"suggestedName", "String", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_ConvertMainResourceLoadToDownload:
        return Vector<ArgumentDescription> {
            {"mainResourceLoadIdentifier", "WebCore::ResourceLoaderIdentifier", nullptr, true},
            {"downloadID", "WebKit::DownloadID", nullptr, false},
            {"request", "WebCore::ResourceRequest", nullptr, false},
            {"response", "WebCore::ResourceResponse", nullptr, false},
            {"isNavigatingToAppBoundDomain", "bool", "std::optional<WebKit::NavigatingToAppBoundDomain>", false},
        };
    case MessageName::NetworkConnectionToWebProcess_CookiesForDOM:
        return Vector<ArgumentDescription> {
            {"firstParty", "URL", nullptr, false},
            {"sameSiteInfo", "WebCore::SameSiteInfo", nullptr, false},
            {"url", "URL", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
            {"includeSecureCookies", "bool", "WebCore::IncludeSecureCookies", false},
            {"shouldAskITP", "bool", "WebCore::ShouldAskITP", false},
            {"shouldRelaxThirdPartyCookieBlocking", "bool", "WebCore::ShouldRelaxThirdPartyCookieBlocking", false},
        };
    case MessageName::NetworkConnectionToWebProcess_SetCookiesFromDOM:
        return Vector<ArgumentDescription> {
            {"firstParty", "URL", nullptr, false},
            {"sameSiteInfo", "WebCore::SameSiteInfo", nullptr, false},
            {"url", "URL", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
            {"shouldAskITP", "bool", "WebCore::ShouldAskITP", false},
            {"cookieString", "String", nullptr, false},
            {"shouldRelaxThirdPartyCookieBlocking", "bool", "WebCore::ShouldRelaxThirdPartyCookieBlocking", false},
        };
    case MessageName::NetworkConnectionToWebProcess_CookieRequestHeaderFieldValue:
        return Vector<ArgumentDescription> {
            {"firstParty", "URL", nullptr, false},
            {"sameSiteInfo", "WebCore::SameSiteInfo", nullptr, false},
            {"url", "URL", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, true},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
            {"includeSecureCookies", "bool", "WebCore::IncludeSecureCookies", false},
            {"shouldAskITP", "bool", "WebCore::ShouldAskITP", false},
            {"shouldRelaxThirdPartyCookieBlocking", "bool", "WebCore::ShouldRelaxThirdPartyCookieBlocking", false},
        };
    case MessageName::NetworkConnectionToWebProcess_GetRawCookies:
        return Vector<ArgumentDescription> {
            {"firstParty", "URL", nullptr, false},
            {"sameSiteInfo", "WebCore::SameSiteInfo", nullptr, false},
            {"url", "URL", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, true},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
            {"shouldAskITP", "bool", "WebCore::ShouldAskITP", false},
            {"shouldRelaxThirdPartyCookieBlocking", "bool", "WebCore::ShouldRelaxThirdPartyCookieBlocking", false},
        };
    case MessageName::NetworkConnectionToWebProcess_SetRawCookie:
        return Vector<ArgumentDescription> {
            {"cookie", "WebCore::Cookie", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_DeleteCookie:
        return Vector<ArgumentDescription> {
            {"url", "URL", nullptr, false},
            {"cookieName", "String", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_DomCookiesForHost:
        return Vector<ArgumentDescription> {
            {"host", "String", nullptr, false},
            {"subscribeToCookieChangeNotifications", "bool", nullptr, false},
        };
#if HAVE(COOKIE_CHANGE_LISTENER_API)
    case MessageName::NetworkConnectionToWebProcess_UnsubscribeFromCookieChangeNotifications:
        return Vector<ArgumentDescription> {
            {"hosts", "HashSet<String>", nullptr, false},
        };
#endif
    case MessageName::NetworkConnectionToWebProcess_RegisterFileBlobURL:
        return Vector<ArgumentDescription> {
            {"url", "URL", nullptr, false},
            {"path", "String", nullptr, false},
            {"replacementPath", "String", nullptr, false},
            {"extensionHandle", "WebKit::SandboxExtension::Handle", nullptr, false},
            {"contentType", "String", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_RegisterBlobURL:
        return Vector<ArgumentDescription> {
            {"url", "URL", nullptr, false},
            {"blobParts", "Vector<WebCore::BlobPart>", nullptr, false},
            {"contentType", "String", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_RegisterBlobURLFromURL:
        return Vector<ArgumentDescription> {
            {"url", "URL", nullptr, false},
            {"srcURL", "URL", nullptr, false},
            {"policyContainer", "WebCore::PolicyContainer", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_RegisterBlobURLOptionallyFileBacked:
        return Vector<ArgumentDescription> {
            {"url", "URL", nullptr, false},
            {"srcURL", "URL", nullptr, false},
            {"fileBackedPath", "String", nullptr, false},
            {"contentType", "String", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_RegisterBlobURLForSlice:
        return Vector<ArgumentDescription> {
            {"url", "URL", nullptr, false},
            {"srcURL", "URL", nullptr, false},
            {"start", "int64_t", nullptr, false},
            {"end", "int64_t", nullptr, false},
            {"contentType", "String", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_UnregisterBlobURL:
        return Vector<ArgumentDescription> {
            {"url", "URL", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_BlobSize:
        return Vector<ArgumentDescription> {
            {"url", "URL", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_WriteBlobsToTemporaryFilesForIndexedDB:
        return Vector<ArgumentDescription> {
            {"blobURLs", "Vector<String>", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_RegisterBlobURLHandle:
        return Vector<ArgumentDescription> {
            {"url", "URL", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_UnregisterBlobURLHandle:
        return Vector<ArgumentDescription> {
            {"url", "URL", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_SetCaptureExtraNetworkLoadMetricsEnabled:
        return Vector<ArgumentDescription> {
            {"enabled", "bool", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_CreateSocketStream:
        return Vector<ArgumentDescription> {
            {"url", "URL", nullptr, false},
            {"cachePartition", "String", nullptr, false},
            {"identifier", "WebCore::WebSocketIdentifier", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_CreateSocketChannel:
        return Vector<ArgumentDescription> {
            {"request", "WebCore::ResourceRequest", nullptr, false},
            {"protocol", "String", nullptr, false},
            {"identifier", "WebCore::WebSocketIdentifier", nullptr, false},
            {"webPageProxyID", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"clientOrigin", "WebCore::ClientOrigin", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_ClearPageSpecificData:
        return Vector<ArgumentDescription> {
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
        };
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
    case MessageName::NetworkConnectionToWebProcess_RemoveStorageAccessForFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_LogUserInteraction:
        return Vector<ArgumentDescription> {
            {"domain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_ResourceLoadStatisticsUpdated:
        return Vector<ArgumentDescription> {
            {"statistics", "Vector<WebCore::ResourceLoadStatistics>", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_HasStorageAccess:
        return Vector<ArgumentDescription> {
            {"subFrameDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"topFrameDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_RequestStorageAccess:
        return Vector<ArgumentDescription> {
            {"subFrameDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"topFrameDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"webPageID", "WebCore::PageIdentifier", nullptr, false},
            {"webPageProxyID", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"scope", "bool", "WebCore::StorageAccessScope", false},
        };
    case MessageName::NetworkConnectionToWebProcess_RequestStorageAccessUnderOpener:
        return Vector<ArgumentDescription> {
            {"domainInNeedOfStorageAccess", "WebCore::RegistrableDomain", nullptr, false},
            {"openerPageID", "WebCore::PageIdentifier", nullptr, false},
            {"openerDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
#endif
    case MessageName::NetworkConnectionToWebProcess_AddOriginAccessAllowListEntry:
        return Vector<ArgumentDescription> {
            {"sourceOrigin", "String", nullptr, false},
            {"destinationProtocol", "String", nullptr, false},
            {"destinationHost", "String", nullptr, false},
            {"allowDestinationSubdomains", "bool", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_RemoveOriginAccessAllowListEntry:
        return Vector<ArgumentDescription> {
            {"sourceOrigin", "String", nullptr, false},
            {"destinationProtocol", "String", nullptr, false},
            {"destinationHost", "String", nullptr, false},
            {"allowDestinationSubdomains", "bool", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_ResetOriginAccessAllowLists:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkConnectionToWebProcess_GetNetworkLoadInformationResponse:
        return Vector<ArgumentDescription> {
            {"resourceLoadIdentifier", "WebCore::ResourceLoaderIdentifier", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_GetNetworkLoadIntermediateInformation:
        return Vector<ArgumentDescription> {
            {"resourceLoadIdentifier", "WebCore::ResourceLoaderIdentifier", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_TakeNetworkLoadInformationMetrics:
        return Vector<ArgumentDescription> {
            {"resourceLoadIdentifier", "WebCore::ResourceLoaderIdentifier", nullptr, false},
        };
#if ENABLE(SERVICE_WORKER)
    case MessageName::NetworkConnectionToWebProcess_EstablishSWContextConnection:
        return Vector<ArgumentDescription> {
            {"webPageProxyID", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"domain", "WebCore::RegistrableDomain", nullptr, false},
            {"serviceWorkerPageIdentifier", "WebCore::ScriptExecutionContextIdentifier", nullptr, true},
        };
    case MessageName::NetworkConnectionToWebProcess_CloseSWContextConnection:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::NetworkConnectionToWebProcess_EstablishSharedWorkerContextConnection:
        return Vector<ArgumentDescription> {
            {"webPageProxyID", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"domain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_CloseSharedWorkerContextConnection:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkConnectionToWebProcess_CreateRTCProvider:
        return Vector<ArgumentDescription> { };
#if ENABLE(WEB_RTC)
    case MessageName::NetworkConnectionToWebProcess_ConnectToRTCDataChannelRemoteSource:
        return Vector<ArgumentDescription> {
            {"source", "WebCore::RTCDataChannelIdentifier", nullptr, false},
            {"handler", "WebCore::RTCDataChannelIdentifier", nullptr, false},
        };
#endif
    case MessageName::NetworkConnectionToWebProcess_UpdateQuotaBasedOnSpaceUsageForTesting:
        return Vector<ArgumentDescription> {
            {"origin", "WebCore::ClientOrigin", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_CreateNewMessagePortChannel:
        return Vector<ArgumentDescription> {
            {"port1", "WebCore::MessagePortIdentifier", nullptr, false},
            {"port2", "WebCore::MessagePortIdentifier", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_EntangleLocalPortInThisProcessToRemote:
        return Vector<ArgumentDescription> {
            {"local", "WebCore::MessagePortIdentifier", nullptr, false},
            {"remote", "WebCore::MessagePortIdentifier", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_MessagePortDisentangled:
        return Vector<ArgumentDescription> {
            {"local", "WebCore::MessagePortIdentifier", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_MessagePortClosed:
        return Vector<ArgumentDescription> {
            {"local", "WebCore::MessagePortIdentifier", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_TakeAllMessagesForPort:
        return Vector<ArgumentDescription> {
            {"port", "WebCore::MessagePortIdentifier", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_PostMessageToRemote:
        return Vector<ArgumentDescription> {
            {"message", "WebCore::MessageWithMessagePorts", nullptr, false},
            {"remote", "WebCore::MessagePortIdentifier", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_CheckRemotePortForActivity:
        return Vector<ArgumentDescription> {
            {"port", "WebCore::MessagePortIdentifier", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_DidDeliverMessagePortMessages:
        return Vector<ArgumentDescription> {
            {"messageBatchIdentifier", "uint64_t", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_RegisterURLSchemesAsCORSEnabled:
        return Vector<ArgumentDescription> {
            {"schemes", "Vector<String>", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_SetCORSDisablingPatterns:
        return Vector<ArgumentDescription> {
            {"pageIdentifier", "WebCore::PageIdentifier", nullptr, false},
            {"patterns", "Vector<String>", nullptr, false},
        };
#if PLATFORM(MAC)
    case MessageName::NetworkConnectionToWebProcess_GetProcessDisplayName:
        return Vector<ArgumentDescription> {
            {"auditToken", "audit_token_t", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_UpdateActivePages:
        return Vector<ArgumentDescription> {
            {"name", "String", nullptr, false},
            {"activePagesOrigins", "Vector<String>", nullptr, false},
            {"auditToken", "audit_token_t", nullptr, false},
        };
#endif
    case MessageName::NetworkConnectionToWebProcess_SetResourceLoadSchedulingMode:
        return Vector<ArgumentDescription> {
            {"webPageID", "WebCore::PageIdentifier", nullptr, false},
            {"mode", "uint8_t", "WebCore::LoadSchedulingMode", false},
        };
    case MessageName::NetworkConnectionToWebProcess_PrioritizeResourceLoads:
        return Vector<ArgumentDescription> {
            {"loadIdentifiers", "Vector<WebCore::ResourceLoaderIdentifier>", nullptr, false},
        };
#if ENABLE(CONTENT_EXTENSIONS)
    case MessageName::NetworkContentRuleListManager_Remove:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::UserContentControllerIdentifier", nullptr, false},
        };
    case MessageName::NetworkContentRuleListManager_AddContentRuleLists:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::UserContentControllerIdentifier", nullptr, false},
            {"contentFilters", "Vector<std::pair<WebKit::WebCompiledContentRuleListData, URL>>", nullptr, false},
        };
    case MessageName::NetworkContentRuleListManager_RemoveContentRuleList:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::UserContentControllerIdentifier", nullptr, false},
            {"name", "String", nullptr, false},
        };
    case MessageName::NetworkContentRuleListManager_RemoveAllContentRuleLists:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::UserContentControllerIdentifier", nullptr, false},
        };
#endif
    case MessageName::NetworkProcess_InitializeNetworkProcess:
        return Vector<ArgumentDescription> {
            {"processCreationParameters", "WebKit::NetworkProcessCreationParameters", nullptr, false},
        };
    case MessageName::NetworkProcess_CreateNetworkConnectionToWebProcess:
        return Vector<ArgumentDescription> {
            {"processIdentifier", "WebCore::ProcessIdentifier", nullptr, false},
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
#if USE(SOUP)
    case MessageName::NetworkProcess_SetIgnoreTLSErrors:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"ignoreTLSErrors", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_UserPreferredLanguagesChanged:
        return Vector<ArgumentDescription> {
            {"languages", "Vector<String>", nullptr, false},
        };
    case MessageName::NetworkProcess_SetNetworkProxySettings:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"settings", "WebCore::SoupNetworkProxySettings", nullptr, false},
        };
    case MessageName::NetworkProcess_PrefetchDNS:
        return Vector<ArgumentDescription> {
            {"hostname", "String", nullptr, false},
        };
    case MessageName::NetworkProcess_SetPersistentCredentialStorageEnabled:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"enabled", "bool", nullptr, false},
        };
#endif
#if USE(CURL)
    case MessageName::NetworkProcess_SetNetworkProxySettings:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"settings", "WebCore::CurlProxySettings", nullptr, false},
        };
#endif
    case MessageName::NetworkProcess_ClearCachedCredentials:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcess_AddWebsiteDataStore:
        return Vector<ArgumentDescription> {
            {"websiteDataStoreParameters", "WebKit::WebsiteDataStoreParameters", nullptr, false},
        };
    case MessageName::NetworkProcess_DestroySession:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcess_FetchWebsiteData:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"websiteDataTypes", "OptionSet<WebKit::WebsiteDataType>", nullptr, false},
            {"fetchOptions", "OptionSet<WebKit::WebsiteDataFetchOption>", nullptr, false},
        };
    case MessageName::NetworkProcess_DeleteWebsiteData:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"websiteDataTypes", "OptionSet<WebKit::WebsiteDataType>", nullptr, false},
            {"modifiedSince", "WallTime", nullptr, false},
        };
    case MessageName::NetworkProcess_DeleteWebsiteDataForOrigins:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"websiteDataTypes", "OptionSet<WebKit::WebsiteDataType>", nullptr, false},
            {"origins", "Vector<WebCore::SecurityOriginData>", nullptr, false},
            {"cookieHostNames", "Vector<String>", nullptr, false},
            {"HSTSCacheHostNames", "Vector<String>", nullptr, false},
            {"registrableDomains", "Vector<WebCore::RegistrableDomain>", nullptr, false},
        };
    case MessageName::NetworkProcess_RenameOriginInWebsiteData:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"oldDomain", "URL", nullptr, false},
            {"newDomain", "URL", nullptr, false},
            {"websiteDataTypes", "OptionSet<WebKit::WebsiteDataType>", nullptr, false},
        };
    case MessageName::NetworkProcess_DownloadRequest:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"downloadID", "WebKit::DownloadID", nullptr, false},
            {"request", "WebCore::ResourceRequest", nullptr, false},
            {"isNavigatingToAppBoundDomain", "bool", "std::optional<WebKit::NavigatingToAppBoundDomain>", false},
            {"suggestedFilename", "String", nullptr, false},
        };
    case MessageName::NetworkProcess_ResumeDownload:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"downloadID", "WebKit::DownloadID", nullptr, false},
            {"resumeData", "IPC::DataReference", nullptr, false},
            {"path", "String", nullptr, false},
            {"sandboxExtensionHandle", "WebKit::SandboxExtension::Handle", nullptr, false},
            {"callDownloadDidStart", "bool", "WebKit::CallDownloadDidStart", false},
        };
    case MessageName::NetworkProcess_CancelDownload:
        return Vector<ArgumentDescription> {
            {"downloadID", "WebKit::DownloadID", nullptr, false},
        };
#if PLATFORM(COCOA)
    case MessageName::NetworkProcess_PublishDownloadProgress:
        return Vector<ArgumentDescription> {
            {"downloadID", "WebKit::DownloadID", nullptr, false},
            {"url", "URL", nullptr, false},
            {"sandboxExtensionHandle", "WebKit::SandboxExtension::Handle", nullptr, false},
        };
#endif
    case MessageName::NetworkProcess_RequestResource:
        return Vector<ArgumentDescription> {
            {"pageID", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"request", "WebCore::ResourceRequest", nullptr, false},
            {"requestBody", "IPC::FormDataReference", nullptr, false},
        };
    case MessageName::NetworkProcess_ApplicationDidEnterBackground:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_ApplicationWillEnterForeground:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_ContinueWillSendRequest:
        return Vector<ArgumentDescription> {
            {"downloadID", "WebKit::DownloadID", nullptr, false},
            {"request", "WebCore::ResourceRequest", nullptr, false},
        };
#if PLATFORM(COCOA)
    case MessageName::NetworkProcess_SetQOS:
        return Vector<ArgumentDescription> {
            {"latencyQOS", "int", nullptr, false},
            {"throughputQOS", "int", nullptr, false},
        };
#endif
    case MessageName::NetworkProcess_SetAllowsAnySSLCertificateForWebSocket:
        return Vector<ArgumentDescription> {
            {"enabled", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_FlushCookies:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcess_AllowSpecificHTTPSCertificateForHost:
        return Vector<ArgumentDescription> {
            {"certificate", "WebCore::CertificateInfo", nullptr, false},
            {"host", "String", nullptr, false},
        };
    case MessageName::NetworkProcess_AllowTLSCertificateChainForLocalPCMTesting:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"certificate", "WebCore::CertificateInfo", nullptr, false},
        };
    case MessageName::NetworkProcess_SetCacheModel:
        return Vector<ArgumentDescription> {
            {"cacheModel", "uint8_t", "WebKit::CacheModel", false},
        };
    case MessageName::NetworkProcess_SetCacheModelSynchronouslyForTesting:
        return Vector<ArgumentDescription> {
            {"cacheModel", "uint8_t", "WebKit::CacheModel", false},
        };
    case MessageName::NetworkProcess_ProcessWillSuspendImminentlyForTestingSync:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_PrepareToSuspend:
        return Vector<ArgumentDescription> {
            {"isSuspensionImminent", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_ProcessDidResume:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_PreconnectTo:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"webPageProxyID", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"webPageID", "WebCore::PageIdentifier", nullptr, false},
            {"url", "URL", nullptr, false},
            {"userAgent", "String", nullptr, false},
            {"storedCredentialsPolicy", "uint8_t", "WebCore::StoredCredentialsPolicy", false},
            {"isNavigatingToAppBoundDomain", "bool", "std::optional<WebKit::NavigatingToAppBoundDomain>", false},
            {"lastNavigationWasAppInitiated", "bool", "WebKit::LastNavigationWasAppInitiated", false},
        };
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
    case MessageName::NetworkProcess_ClearPrevalentResource:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"resourceDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcess_ClearUserInteraction:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"resourceDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcess_DumpResourceLoadStatistics:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcess_SetResourceLoadStatisticsEnabled:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"enabled", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_SetResourceLoadStatisticsLogTestingEvent:
        return Vector<ArgumentDescription> {
            {"enabled", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_UpdatePrevalentDomainsToBlockCookiesFor:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"domainsToBlock", "Vector<WebCore::RegistrableDomain>", nullptr, false},
        };
    case MessageName::NetworkProcess_IsGrandfathered:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"targetDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcess_IsPrevalentResource:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"targetDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcess_IsVeryPrevalentResource:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"targetDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcess_SetAgeCapForClientSideCookies:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"seconds", "Seconds", nullptr, true},
        };
    case MessageName::NetworkProcess_SetLastSeen:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"resourceDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"seconds", "Seconds", nullptr, false},
        };
    case MessageName::NetworkProcess_MergeStatisticForTesting:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"resourceDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"topFrameDomain1", "WebCore::RegistrableDomain", nullptr, false},
            {"topFrameDomain2", "WebCore::RegistrableDomain", nullptr, false},
            {"lastSeen", "Seconds", nullptr, false},
            {"hadUserInteraction", "bool", nullptr, false},
            {"mostRecentUserInteraction", "Seconds", nullptr, false},
            {"isGrandfathered", "bool", nullptr, false},
            {"isPrevalent", "bool", nullptr, false},
            {"isVeryPrevalent", "bool", nullptr, false},
            {"dataRecordsRemoved", "uint64_t", nullptr, false},
        };
    case MessageName::NetworkProcess_InsertExpiredStatisticForTesting:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"resourceDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"numberOfOperatingDaysPassed", "uint64_t", nullptr, false},
            {"hadUserInteraction", "bool", nullptr, false},
            {"isScheduledForAllButCookieDataRemoval", "bool", nullptr, false},
            {"isPrevalent", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_SetPrevalentResource:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"resourceDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcess_SetPrevalentResourceForDebugMode:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"resourceDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcess_IsResourceLoadStatisticsEphemeral:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcess_HadUserInteraction:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"resourceDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcess_IsRelationshipOnlyInDatabaseOnce:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"subDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"topDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcess_HasLocalStorage:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"resourceDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcess_GetAllStorageAccessEntries:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcess_IsRegisteredAsRedirectingTo:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"redirectedFromDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"redirectedToDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcess_IsRegisteredAsSubFrameUnder:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"subFrameDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"topFrameDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcess_IsRegisteredAsSubresourceUnder:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"subresourceDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"topFrameDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcess_DomainIDExistsInDatabase:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"domainID", "int", nullptr, false},
        };
    case MessageName::NetworkProcess_LogFrameNavigation:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"targetDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"topFrameDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"sourceDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"isRedirect", "bool", nullptr, false},
            {"isMainFrame", "bool", nullptr, false},
            {"delayAfterMainFrameDocumentLoad", "Seconds", nullptr, false},
            {"wasPotentiallyInitiatedByUser", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_LogUserInteraction:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"topFrameDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcess_ResetParametersToDefaultValues:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcess_ScheduleClearInMemoryAndPersistent:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"modifiedSince", "WallTime", nullptr, true},
            {"shouldGrandfather", "bool", "WebKit::ShouldGrandfatherStatistics", false},
        };
    case MessageName::NetworkProcess_ScheduleCookieBlockingUpdate:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcess_ScheduleStatisticsAndDataRecordsProcessing:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcess_StatisticsDatabaseHasAllTables:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcess_SetCacheMaxAgeCapForPrevalentResources:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"seconds", "Seconds", nullptr, false},
        };
    case MessageName::NetworkProcess_SetGrandfathered:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"resourceDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"isGrandfathered", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_GetResourceLoadStatisticsDataSummary:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcess_SetGrandfatheringTime:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"seconds", "Seconds", nullptr, false},
        };
    case MessageName::NetworkProcess_SetMaxStatisticsEntries:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"maximumEntryCount", "uint64_t", nullptr, false},
        };
    case MessageName::NetworkProcess_SetMinimumTimeBetweenDataRecordsRemoval:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"seconds", "Seconds", nullptr, false},
        };
    case MessageName::NetworkProcess_SetPruneEntriesDownTo:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"maximumEntryCount", "uint64_t", nullptr, false},
        };
    case MessageName::NetworkProcess_SetShouldClassifyResourcesBeforeDataRecordsRemoval:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"value", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_SetNotifyPagesWhenDataRecordsWereScanned:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"value", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_SetIsRunningResourceLoadStatisticsTest:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"value", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_SetResourceLoadStatisticsDebugMode:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"debugMode", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_SetVeryPrevalentResource:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"resourceDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcess_SetSubframeUnderTopFrameDomain:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"subFrameDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"topFrameDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcess_SetSubresourceUnderTopFrameDomain:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"subresourceDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"topFrameDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcess_SetSubresourceUniqueRedirectTo:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"subresourceDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"redirectedToDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcess_SetSubresourceUniqueRedirectFrom:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"subresourceDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"redirectedFromDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcess_SetTimeToLiveUserInteraction:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"seconds", "Seconds", nullptr, false},
        };
    case MessageName::NetworkProcess_SetTopFrameUniqueRedirectTo:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"topFrameDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"redirectedToDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcess_SetTopFrameUniqueRedirectFrom:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"topFrameDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"redirectedFromDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcess_ResetCacheMaxAgeCapForPrevalentResources:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcess_DidCommitCrossSiteLoadWithDataTransfer:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"fromDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"toDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"navigationDataTransfer", "OptionSet<WebCore::CrossSiteNavigationDataTransfer::Flag>", nullptr, false},
            {"webPageProxyID", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"webPageID", "WebCore::PageIdentifier", nullptr, false},
        };
    case MessageName::NetworkProcess_SetCrossSiteLoadWithLinkDecorationForTesting:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"fromDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"toDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcess_ResetCrossSiteLoadsWithLinkDecorationForTesting:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcess_DeleteCookiesForTesting:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"domain", "WebCore::RegistrableDomain", nullptr, false},
            {"includeHttpOnlyCookies", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_HasIsolatedSession:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"domain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcess_CloseITPDatabase:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
#endif
#if (ENABLE(INTELLIGENT_TRACKING_PREVENTION) && ENABLE(APP_BOUND_DOMAINS))
    case MessageName::NetworkProcess_SetAppBoundDomainsForResourceLoadStatistics:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"appBoundDomains", "HashSet<WebCore::RegistrableDomain>", nullptr, false},
        };
#endif
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
    case MessageName::NetworkProcess_SetShouldDowngradeReferrerForTesting:
        return Vector<ArgumentDescription> {
            {"enabled", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_SetThirdPartyCookieBlockingMode:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"blockingMode", "uint8_t", "WebCore::ThirdPartyCookieBlockingMode", false},
        };
    case MessageName::NetworkProcess_SetShouldEnbleSameSiteStrictEnforcementForTesting:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"enabled", "bool", "WebCore::SameSiteStrictEnforcementEnabled", false},
        };
    case MessageName::NetworkProcess_SetFirstPartyWebsiteDataRemovalModeForTesting:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"mode", "uint8_t", "WebCore::FirstPartyWebsiteDataRemovalMode", false},
        };
    case MessageName::NetworkProcess_SetToSameSiteStrictCookiesForTesting:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"domain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcess_SetFirstPartyHostCNAMEDomainForTesting:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"firstPartyHost", "String", nullptr, false},
            {"cnameDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcess_SetThirdPartyCNAMEDomainForTesting:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"domain", "WebCore::RegistrableDomain", nullptr, false},
        };
#endif
    case MessageName::NetworkProcess_SetPrivateClickMeasurementDebugMode:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"debugMode", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_SetSessionIsControlledByAutomation:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"controlled", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_RegisterURLSchemeAsSecure:
        return Vector<ArgumentDescription> {
            {"scheme", "String", nullptr, false},
        };
    case MessageName::NetworkProcess_RegisterURLSchemeAsBypassingContentSecurityPolicy:
        return Vector<ArgumentDescription> {
            {"scheme", "String", nullptr, false},
        };
    case MessageName::NetworkProcess_RegisterURLSchemeAsLocal:
        return Vector<ArgumentDescription> {
            {"scheme", "String", nullptr, false},
        };
    case MessageName::NetworkProcess_RegisterURLSchemeAsNoAccess:
        return Vector<ArgumentDescription> {
            {"scheme", "String", nullptr, false},
        };
    case MessageName::NetworkProcess_SyncLocalStorage:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_StorePrivateClickMeasurement:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"privateClickMeasurement", "WebCore::PrivateClickMeasurement", nullptr, false},
        };
    case MessageName::NetworkProcess_DumpPrivateClickMeasurement:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcess_ClearPrivateClickMeasurement:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcess_SetPrivateClickMeasurementOverrideTimerForTesting:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"value", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_MarkAttributedPrivateClickMeasurementsAsExpiredForTesting:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcess_SetPrivateClickMeasurementEphemeralMeasurementForTesting:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"value", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_SimulatePrivateClickMeasurementSessionRestart:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcess_SetPrivateClickMeasurementTokenPublicKeyURLForTesting:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"url", "URL", nullptr, false},
        };
    case MessageName::NetworkProcess_SetPrivateClickMeasurementTokenSignatureURLForTesting:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"url", "URL", nullptr, false},
        };
    case MessageName::NetworkProcess_SetPrivateClickMeasurementAttributionReportURLsForTesting:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"sourceURL", "URL", nullptr, false},
            {"destinationURL", "URL", nullptr, false},
        };
    case MessageName::NetworkProcess_MarkPrivateClickMeasurementsAsExpiredForTesting:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcess_SetPCMFraudPreventionValuesForTesting:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"secretToken", "String", nullptr, false},
            {"unlinkableToken", "String", nullptr, false},
            {"signature", "String", nullptr, false},
            {"keyID", "String", nullptr, false},
        };
    case MessageName::NetworkProcess_SetPrivateClickMeasurementAppBundleIDForTesting:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"appBundleIDForTesting", "String", nullptr, false},
        };
    case MessageName::NetworkProcess_ClosePCMDatabase:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcess_SetServiceWorkerFetchTimeoutForTesting:
        return Vector<ArgumentDescription> {
            {"seconds", "Seconds", nullptr, false},
        };
    case MessageName::NetworkProcess_ResetServiceWorkerFetchTimeoutForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_ResetQuota:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcess_ClearStorage:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcess_DidIncreaseQuota:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"origin", "WebCore::ClientOrigin", nullptr, false},
            {"identifier", "WebKit::QuotaIncreaseRequestIdentifier", nullptr, false},
            {"newQuota", "uint64_t", nullptr, true},
        };
#if ENABLE(APP_BOUND_DOMAINS)
    case MessageName::NetworkProcess_HasAppBoundSession:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcess_ClearAppBoundSession:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
#endif
#if PLATFORM(IOS_FAMILY) && !PLATFORM(MACCATALYST)
    case MessageName::NetworkProcess_DisableServiceWorkerEntitlement:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_ClearServiceWorkerEntitlementOverride:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::NetworkProcess_UpdateBundleIdentifier:
        return Vector<ArgumentDescription> {
            {"bundleIdentifier", "String", nullptr, false},
        };
    case MessageName::NetworkProcess_ClearBundleIdentifier:
        return Vector<ArgumentDescription> { };
#if PLATFORM(COCOA)
    case MessageName::NetworkProcess_AppPrivacyReportTestingData:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcess_ClearAppPrivacyReportTestingData:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
#endif
    case MessageName::NetworkProcess_AddWebPageNetworkParameters:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"pageID", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"parameters", "WebKit::WebPageNetworkParameters", nullptr, false},
        };
    case MessageName::NetworkProcess_RemoveWebPageNetworkParameters:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"pageID", "WebKit::WebPageProxyIdentifier", nullptr, false},
        };
    case MessageName::NetworkProcess_CountNonDefaultSessionSets:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
#if ENABLE(CFPREFS_DIRECT_MODE)
    case MessageName::NetworkProcess_NotifyPreferencesChanged:
        return Vector<ArgumentDescription> {
            {"domain", "String", nullptr, false},
            {"key", "String", nullptr, false},
            {"encodedValue", "String", nullptr, true},
        };
#endif
#if ENABLE(SERVICE_WORKER)
    case MessageName::NetworkProcess_GetPendingPushMessages:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcess_ProcessPushMessage:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"pushMessage", "WebKit::WebPushMessage", nullptr, false},
        };
#endif
    case MessageName::NetworkProcess_DeletePushAndNotificationRegistration:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"origin", "WebCore::SecurityOriginData", nullptr, false},
        };
    case MessageName::NetworkProcess_GetOriginsWithPushAndNotificationPermissions:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkResourceLoader_ContinueWillSendRequest:
        return Vector<ArgumentDescription> {
            {"request", "WebCore::ResourceRequest", nullptr, false},
            {"isAllowedToAskUserForCredentials", "bool", nullptr, false},
        };
    case MessageName::NetworkResourceLoader_ContinueDidReceiveResponse:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkSocketChannel_SendString:
        return Vector<ArgumentDescription> {
            {"message", "IPC::DataReference", nullptr, false},
        };
    case MessageName::NetworkSocketChannel_SendData:
        return Vector<ArgumentDescription> {
            {"data", "IPC::DataReference", nullptr, false},
        };
    case MessageName::NetworkSocketChannel_Close:
        return Vector<ArgumentDescription> {
            {"code", "int32_t", nullptr, false},
            {"reason", "String", nullptr, false},
        };
    case MessageName::NetworkSocketStream_SendData:
        return Vector<ArgumentDescription> {
            {"data", "IPC::DataReference", nullptr, false},
            {"identifier", "uint64_t", nullptr, false},
        };
    case MessageName::NetworkSocketStream_SendHandshake:
        return Vector<ArgumentDescription> {
            {"data", "IPC::DataReference", nullptr, false},
            {"headerFieldProxy", "WebCore::CookieRequestHeaderFieldProxy", nullptr, true},
            {"identifier", "uint64_t", nullptr, false},
        };
    case MessageName::NetworkSocketStream_Close:
        return Vector<ArgumentDescription> { };
#if ENABLE(SERVICE_WORKER)
    case MessageName::ServiceWorkerDownloadTask_DidFail:
        return Vector<ArgumentDescription> {
            {"error", "WebCore::ResourceError", nullptr, false},
        };
    case MessageName::ServiceWorkerDownloadTask_DidReceiveData:
        return Vector<ArgumentDescription> {
            {"data", "IPC::SharedBufferCopy", nullptr, false},
            {"encodedDataLength", "int64_t", nullptr, false},
        };
    case MessageName::ServiceWorkerDownloadTask_DidReceiveFormData:
        return Vector<ArgumentDescription> {
            {"data", "IPC::FormDataReference", nullptr, false},
        };
    case MessageName::ServiceWorkerDownloadTask_DidFinish:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(SERVICE_WORKER)
    case MessageName::ServiceWorkerFetchTask_DidNotHandle:
        return Vector<ArgumentDescription> { };
    case MessageName::ServiceWorkerFetchTask_DidFail:
        return Vector<ArgumentDescription> {
            {"error", "WebCore::ResourceError", nullptr, false},
        };
    case MessageName::ServiceWorkerFetchTask_DidReceiveRedirectResponse:
        return Vector<ArgumentDescription> {
            {"response", "WebCore::ResourceResponse", nullptr, false},
        };
    case MessageName::ServiceWorkerFetchTask_DidReceiveResponse:
        return Vector<ArgumentDescription> {
            {"response", "WebCore::ResourceResponse", nullptr, false},
            {"needsContinueDidReceiveResponseMessage", "bool", nullptr, false},
        };
    case MessageName::ServiceWorkerFetchTask_DidReceiveData:
        return Vector<ArgumentDescription> {
            {"data", "IPC::SharedBufferCopy", nullptr, false},
            {"encodedDataLength", "int64_t", nullptr, false},
        };
    case MessageName::ServiceWorkerFetchTask_DidReceiveFormData:
        return Vector<ArgumentDescription> {
            {"data", "IPC::FormDataReference", nullptr, false},
        };
    case MessageName::ServiceWorkerFetchTask_DidFinish:
        return Vector<ArgumentDescription> {
            {"metrics", "WebCore::NetworkLoadMetrics", nullptr, false},
        };
#endif
#if ENABLE(SERVICE_WORKER)
    case MessageName::WebSWServerConnection_ScheduleJobInServer:
        return Vector<ArgumentDescription> {
            {"jobData", "WebCore::ServiceWorkerJobData", nullptr, false},
        };
    case MessageName::WebSWServerConnection_ScheduleUnregisterJobInServer:
        return Vector<ArgumentDescription> {
            {"jobIdentifier", "WebCore::ServiceWorkerJobIdentifier", nullptr, false},
            {"identifier", "WebCore::ServiceWorkerRegistrationIdentifier", nullptr, false},
            {"documentIdentifier", "WebCore::ServiceWorkerOrClientIdentifier", nullptr, false},
        };
    case MessageName::WebSWServerConnection_FinishFetchingScriptInServer:
        return Vector<ArgumentDescription> {
            {"jobDataIdentifier", "WebCore::ServiceWorkerJobDataIdentifier", nullptr, false},
            {"registrationKey", "WebCore::ServiceWorkerRegistrationKey", nullptr, false},
            {"result", "WebCore::WorkerFetchResult", nullptr, false},
        };
    case MessageName::WebSWServerConnection_AddServiceWorkerRegistrationInServer:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::ServiceWorkerRegistrationIdentifier", nullptr, false},
        };
    case MessageName::WebSWServerConnection_RemoveServiceWorkerRegistrationInServer:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::ServiceWorkerRegistrationIdentifier", nullptr, false},
        };
    case MessageName::WebSWServerConnection_PostMessageToServiceWorker:
        return Vector<ArgumentDescription> {
            {"destination", "WebCore::ServiceWorkerIdentifier", nullptr, false},
            {"message", "WebCore::MessageWithMessagePorts", nullptr, false},
            {"source", "WebCore::ServiceWorkerOrClientIdentifier", nullptr, false},
        };
    case MessageName::WebSWServerConnection_DidResolveRegistrationPromise:
        return Vector<ArgumentDescription> {
            {"key", "WebCore::ServiceWorkerRegistrationKey", nullptr, false},
        };
    case MessageName::WebSWServerConnection_MatchRegistration:
        return Vector<ArgumentDescription> {
            {"topOrigin", "WebCore::SecurityOriginData", nullptr, false},
            {"clientURL", "URL", nullptr, false},
        };
    case MessageName::WebSWServerConnection_WhenRegistrationReady:
        return Vector<ArgumentDescription> {
            {"topOrigin", "WebCore::SecurityOriginData", nullptr, false},
            {"clientURL", "URL", nullptr, false},
        };
    case MessageName::WebSWServerConnection_GetRegistrations:
        return Vector<ArgumentDescription> {
            {"topOrigin", "WebCore::SecurityOriginData", nullptr, false},
            {"clientURL", "URL", nullptr, false},
        };
    case MessageName::WebSWServerConnection_RegisterServiceWorkerClient:
        return Vector<ArgumentDescription> {
            {"topOrigin", "WebCore::SecurityOriginData", nullptr, false},
            {"data", "WebCore::ServiceWorkerClientData", nullptr, false},
            {"controllingServiceWorkerRegistrationIdentifier", "WebCore::ServiceWorkerRegistrationIdentifier", nullptr, true},
            {"userAgent", "String", nullptr, false},
        };
    case MessageName::WebSWServerConnection_UnregisterServiceWorkerClient:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::ScriptExecutionContextIdentifier", nullptr, false},
        };
    case MessageName::WebSWServerConnection_TerminateWorkerFromClient:
        return Vector<ArgumentDescription> {
            {"workerIdentifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
        };
    case MessageName::WebSWServerConnection_WhenServiceWorkerIsTerminatedForTesting:
        return Vector<ArgumentDescription> {
            {"workerIdentifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
        };
    case MessageName::WebSWServerConnection_SetThrottleState:
        return Vector<ArgumentDescription> {
            {"isThrottleable", "bool", nullptr, false},
        };
    case MessageName::WebSWServerConnection_StoreRegistrationsOnDisk:
        return Vector<ArgumentDescription> { };
    case MessageName::WebSWServerConnection_SubscribeToPushService:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::ServiceWorkerRegistrationIdentifier", nullptr, false},
            {"applicationServerKey", "Vector<uint8_t>", nullptr, false},
        };
    case MessageName::WebSWServerConnection_UnsubscribeFromPushService:
        return Vector<ArgumentDescription> {
            {"serviceWorkerRegistrationIdentifier", "WebCore::ServiceWorkerRegistrationIdentifier", nullptr, false},
            {"pushSubscriptionIdentifier", "WebCore::PushSubscriptionIdentifier", nullptr, false},
        };
    case MessageName::WebSWServerConnection_GetPushSubscription:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::ServiceWorkerRegistrationIdentifier", nullptr, false},
        };
    case MessageName::WebSWServerConnection_GetPushPermissionState:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::ServiceWorkerRegistrationIdentifier", nullptr, false},
        };
    case MessageName::WebSWServerConnection_EnableNavigationPreload:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::ServiceWorkerRegistrationIdentifier", nullptr, false},
        };
    case MessageName::WebSWServerConnection_DisableNavigationPreload:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::ServiceWorkerRegistrationIdentifier", nullptr, false},
        };
    case MessageName::WebSWServerConnection_SetNavigationPreloadHeaderValue:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::ServiceWorkerRegistrationIdentifier", nullptr, false},
            {"value", "String", nullptr, false},
        };
    case MessageName::WebSWServerConnection_GetNavigationPreloadState:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::ServiceWorkerRegistrationIdentifier", nullptr, false},
        };
#endif
#if ENABLE(SERVICE_WORKER)
    case MessageName::WebSWServerToContextConnection_ScriptContextFailedToStart:
        return Vector<ArgumentDescription> {
            {"jobDataIdentifier", "WebCore::ServiceWorkerJobDataIdentifier", nullptr, true},
            {"serviceWorkerIdentifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
            {"message", "String", nullptr, false},
        };
    case MessageName::WebSWServerToContextConnection_ScriptContextStarted:
        return Vector<ArgumentDescription> {
            {"jobDataIdentifier", "WebCore::ServiceWorkerJobDataIdentifier", nullptr, true},
            {"serviceWorkerIdentifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
            {"doesHandleFetch", "bool", nullptr, false},
        };
    case MessageName::WebSWServerToContextConnection_DidFinishInstall:
        return Vector<ArgumentDescription> {
            {"jobDataIdentifier", "WebCore::ServiceWorkerJobDataIdentifier", nullptr, true},
            {"serviceWorkerIdentifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
            {"wasSuccessful", "bool", nullptr, false},
        };
    case MessageName::WebSWServerToContextConnection_DidFinishActivation:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
        };
    case MessageName::WebSWServerToContextConnection_SetServiceWorkerHasPendingEvents:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
            {"hasPendingEvents", "bool", nullptr, false},
        };
    case MessageName::WebSWServerToContextConnection_SkipWaiting:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
        };
    case MessageName::WebSWServerToContextConnection_WorkerTerminated:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
        };
    case MessageName::WebSWServerToContextConnection_FindClientByVisibleIdentifier:
        return Vector<ArgumentDescription> {
            {"serviceWorkerIdentifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
            {"clientIdentifier", "String", nullptr, false},
        };
    case MessageName::WebSWServerToContextConnection_MatchAll:
        return Vector<ArgumentDescription> {
            {"matchAllRequestIdentifier", "uint64_t", nullptr, false},
            {"serviceWorkerIdentifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
            {"options", "WebCore::ServiceWorkerClientQueryOptions", nullptr, false},
        };
    case MessageName::WebSWServerToContextConnection_Claim:
        return Vector<ArgumentDescription> {
            {"serviceWorkerIdentifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
        };
    case MessageName::WebSWServerToContextConnection_SetScriptResource:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
            {"scriptURL", "URL", nullptr, false},
            {"script", "WebCore::ServiceWorkerContextData::ImportedScript", nullptr, false},
        };
    case MessageName::WebSWServerToContextConnection_PostMessageToServiceWorkerClient:
        return Vector<ArgumentDescription> {
            {"destination", "WebCore::ScriptExecutionContextIdentifier", nullptr, false},
            {"message", "WebCore::MessageWithMessagePorts", nullptr, false},
            {"source", "WebCore::ServiceWorkerIdentifier", nullptr, false},
            {"sourceOrigin", "String", nullptr, false},
        };
    case MessageName::WebSWServerToContextConnection_DidFailHeartBeatCheck:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
        };
#endif
    case MessageName::WebSharedWorkerServerConnection_RequestSharedWorker:
        return Vector<ArgumentDescription> {
            {"sharedWorkerKey", "WebCore::SharedWorkerKey", nullptr, false},
            {"sharedWorkerObjectIdentifier", "WebCore::SharedWorkerObjectIdentifier", nullptr, false},
            {"port", "WebCore::TransferredMessagePort", nullptr, false},
            {"workerOptions", "WebCore::WorkerOptions", nullptr, false},
        };
    case MessageName::WebSharedWorkerServerConnection_SharedWorkerObjectIsGoingAway:
        return Vector<ArgumentDescription> {
            {"sharedWorkerKey", "WebCore::SharedWorkerKey", nullptr, false},
            {"sharedWorkerObjectIdentifier", "WebCore::SharedWorkerObjectIdentifier", nullptr, false},
        };
    case MessageName::WebSharedWorkerServerToContextConnection_PostExceptionToWorkerObject:
        return Vector<ArgumentDescription> {
            {"sharedWorkerIdentifier", "WebCore::SharedWorkerIdentifier", nullptr, false},
            {"errorMessage", "String", nullptr, false},
            {"lineNumber", "int", nullptr, false},
            {"columnNumber", "int", nullptr, false},
            {"sourceURL", "String", nullptr, false},
        };
    case MessageName::StorageManagerSet_ConnectToLocalStorageArea:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"storageNamespaceID", "WebKit::StorageNamespaceIdentifier", nullptr, false},
            {"securityOriginData", "WebCore::SecurityOriginData", nullptr, false},
        };
    case MessageName::StorageManagerSet_ConnectToTransientLocalStorageArea:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"storageNamespaceID", "WebKit::StorageNamespaceIdentifier", nullptr, false},
            {"topLevelSecurityOriginData", "WebCore::SecurityOriginData", nullptr, false},
            {"securityOriginData", "WebCore::SecurityOriginData", nullptr, false},
        };
    case MessageName::StorageManagerSet_ConnectToSessionStorageArea:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"storageNamespaceID", "WebKit::StorageNamespaceIdentifier", nullptr, false},
            {"securityOriginData", "WebCore::SecurityOriginData", nullptr, false},
        };
    case MessageName::StorageManagerSet_DisconnectFromStorageArea:
        return Vector<ArgumentDescription> {
            {"storageAreaID", "WebKit::StorageAreaIdentifier", nullptr, false},
        };
    case MessageName::StorageManagerSet_GetValues:
        return Vector<ArgumentDescription> {
            {"storageAreaID", "WebKit::StorageAreaIdentifier", nullptr, false},
        };
    case MessageName::StorageManagerSet_CloneSessionStorageNamespace:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"fromStorageNamespaceID", "WebKit::StorageNamespaceIdentifier", nullptr, false},
            {"toStorageNamespaceID", "WebKit::StorageNamespaceIdentifier", nullptr, false},
        };
    case MessageName::StorageManagerSet_SetItem:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::StorageAreaIdentifier", nullptr, false},
            {"implIdentifier", "WebKit::StorageAreaImplIdentifier", nullptr, false},
            {"key", "String", nullptr, false},
            {"value", "String", nullptr, false},
            {"urlString", "String", nullptr, false},
        };
    case MessageName::StorageManagerSet_RemoveItem:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::StorageAreaIdentifier", nullptr, false},
            {"implIdentifier", "WebKit::StorageAreaImplIdentifier", nullptr, false},
            {"key", "String", nullptr, false},
            {"urlString", "String", nullptr, false},
        };
    case MessageName::StorageManagerSet_Clear:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::StorageAreaIdentifier", nullptr, false},
            {"implIdentifier", "WebKit::StorageAreaImplIdentifier", nullptr, false},
            {"urlString", "String", nullptr, false},
        };
    case MessageName::CacheStorageEngineConnection_Reference:
        return Vector<ArgumentDescription> {
            {"cacheIdentifier", "uint64_t", nullptr, false},
        };
    case MessageName::CacheStorageEngineConnection_Dereference:
        return Vector<ArgumentDescription> {
            {"cacheIdentifier", "uint64_t", nullptr, false},
        };
    case MessageName::CacheStorageEngineConnection_Open:
        return Vector<ArgumentDescription> {
            {"origin", "WebCore::ClientOrigin", nullptr, false},
            {"cacheName", "String", nullptr, false},
        };
    case MessageName::CacheStorageEngineConnection_Remove:
        return Vector<ArgumentDescription> {
            {"cacheIdentifier", "uint64_t", nullptr, false},
        };
    case MessageName::CacheStorageEngineConnection_Caches:
        return Vector<ArgumentDescription> {
            {"origin", "WebCore::ClientOrigin", nullptr, false},
            {"updateCounter", "uint64_t", nullptr, false},
        };
    case MessageName::CacheStorageEngineConnection_RetrieveRecords:
        return Vector<ArgumentDescription> {
            {"cacheIdentifier", "uint64_t", nullptr, false},
            {"options", "WebCore::RetrieveRecordsOptions", nullptr, false},
        };
    case MessageName::CacheStorageEngineConnection_DeleteMatchingRecords:
        return Vector<ArgumentDescription> {
            {"cacheIdentifier", "uint64_t", nullptr, false},
            {"request", "WebCore::ResourceRequest", nullptr, false},
            {"options", "WebCore::CacheQueryOptions", nullptr, false},
        };
    case MessageName::CacheStorageEngineConnection_PutRecords:
        return Vector<ArgumentDescription> {
            {"cacheIdentifier", "uint64_t", nullptr, false},
            {"record", "Vector<WebCore::DOMCacheEngine::Record>", nullptr, false},
        };
    case MessageName::CacheStorageEngineConnection_ClearMemoryRepresentation:
        return Vector<ArgumentDescription> {
            {"origin", "WebCore::ClientOrigin", nullptr, false},
        };
    case MessageName::CacheStorageEngineConnection_EngineRepresentation:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkStorageManager_Persisted:
        return Vector<ArgumentDescription> {
            {"origin", "WebCore::ClientOrigin", nullptr, false},
        };
    case MessageName::NetworkStorageManager_Persist:
        return Vector<ArgumentDescription> {
            {"origin", "WebCore::ClientOrigin", nullptr, false},
        };
    case MessageName::NetworkStorageManager_FileSystemGetDirectory:
        return Vector<ArgumentDescription> {
            {"origin", "WebCore::ClientOrigin", nullptr, false},
        };
    case MessageName::NetworkStorageManager_CloseHandle:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::FileSystemHandleIdentifier", nullptr, false},
        };
    case MessageName::NetworkStorageManager_IsSameEntry:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::FileSystemHandleIdentifier", nullptr, false},
            {"targetIdentifier", "WebCore::FileSystemHandleIdentifier", nullptr, false},
        };
    case MessageName::NetworkStorageManager_GetFileHandle:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::FileSystemHandleIdentifier", nullptr, false},
            {"name", "String", nullptr, false},
            {"createIfNecessary", "bool", nullptr, false},
        };
    case MessageName::NetworkStorageManager_GetDirectoryHandle:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::FileSystemHandleIdentifier", nullptr, false},
            {"name", "String", nullptr, false},
            {"createIfNecessary", "bool", nullptr, false},
        };
    case MessageName::NetworkStorageManager_RemoveEntry:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::FileSystemHandleIdentifier", nullptr, false},
            {"name", "String", nullptr, false},
            {"deleteRecursively", "bool", nullptr, false},
        };
    case MessageName::NetworkStorageManager_Resolve:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::FileSystemHandleIdentifier", nullptr, false},
            {"targetIdentifier", "WebCore::FileSystemHandleIdentifier", nullptr, false},
        };
    case MessageName::NetworkStorageManager_Move:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::FileSystemHandleIdentifier", nullptr, false},
            {"destinationIdentifier", "WebCore::FileSystemHandleIdentifier", nullptr, false},
            {"newName", "String", nullptr, false},
        };
    case MessageName::NetworkStorageManager_GetFile:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::FileSystemHandleIdentifier", nullptr, false},
        };
    case MessageName::NetworkStorageManager_CreateSyncAccessHandle:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::FileSystemHandleIdentifier", nullptr, false},
        };
    case MessageName::NetworkStorageManager_CloseSyncAccessHandle:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::FileSystemHandleIdentifier", nullptr, false},
            {"accessHandleIdentifier", "WebCore::FileSystemSyncAccessHandleIdentifier", nullptr, false},
        };
    case MessageName::NetworkStorageManager_GetHandleNames:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::FileSystemHandleIdentifier", nullptr, false},
        };
    case MessageName::NetworkStorageManager_GetHandle:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::FileSystemHandleIdentifier", nullptr, false},
            {"name", "String", nullptr, false},
        };
    case MessageName::NetworkStorageManager_ConnectToStorageArea:
        return Vector<ArgumentDescription> {
            {"type", "WebCore::StorageType", nullptr, false},
            {"sourceIdentifier", "WebKit::StorageAreaMapIdentifier", nullptr, false},
            {"namespaceIdentifier", "WebKit::StorageNamespaceIdentifier", nullptr, false},
            {"origin", "WebCore::ClientOrigin", nullptr, false},
        };
    case MessageName::NetworkStorageManager_ConnectToStorageAreaSync:
        return Vector<ArgumentDescription> {
            {"type", "WebCore::StorageType", nullptr, false},
            {"sourceIdentifier", "WebKit::StorageAreaMapIdentifier", nullptr, false},
            {"namespaceIdentifier", "WebKit::StorageNamespaceIdentifier", nullptr, false},
            {"origin", "WebCore::ClientOrigin", nullptr, false},
        };
    case MessageName::NetworkStorageManager_DisconnectFromStorageArea:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::StorageAreaIdentifier", nullptr, false},
        };
    case MessageName::NetworkStorageManager_CloneSessionStorageNamespace:
        return Vector<ArgumentDescription> {
            {"fromStorageNamespaceID", "WebKit::StorageNamespaceIdentifier", nullptr, false},
            {"toStorageNamespaceID", "WebKit::StorageNamespaceIdentifier", nullptr, false},
        };
    case MessageName::NetworkStorageManager_SetItem:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::StorageAreaIdentifier", nullptr, false},
            {"implIdentifier", "WebKit::StorageAreaImplIdentifier", nullptr, false},
            {"key", "String", nullptr, false},
            {"value", "String", nullptr, false},
            {"urlString", "String", nullptr, false},
        };
    case MessageName::NetworkStorageManager_RemoveItem:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::StorageAreaIdentifier", nullptr, false},
            {"implIdentifier", "WebKit::StorageAreaImplIdentifier", nullptr, false},
            {"key", "String", nullptr, false},
            {"urlString", "String", nullptr, false},
        };
    case MessageName::NetworkStorageManager_Clear:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::StorageAreaIdentifier", nullptr, false},
            {"implIdentifier", "WebKit::StorageAreaImplIdentifier", nullptr, false},
            {"urlString", "String", nullptr, false},
        };
    case MessageName::NetworkStorageManager_OpenDatabase:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
        };
    case MessageName::NetworkStorageManager_OpenDBRequestCancelled:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
        };
    case MessageName::NetworkStorageManager_DeleteDatabase:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
        };
    case MessageName::NetworkStorageManager_EstablishTransaction:
        return Vector<ArgumentDescription> {
            {"databaseConnectionIdentifier", "uint64_t", nullptr, false},
            {"info", "WebCore::IDBTransactionInfo", nullptr, false},
        };
    case MessageName::NetworkStorageManager_DatabaseConnectionPendingClose:
        return Vector<ArgumentDescription> {
            {"databaseConnectionIdentifier", "uint64_t", nullptr, false},
        };
    case MessageName::NetworkStorageManager_DatabaseConnectionClosed:
        return Vector<ArgumentDescription> {
            {"databaseConnectionIdentifier", "uint64_t", nullptr, false},
        };
    case MessageName::NetworkStorageManager_AbortOpenAndUpgradeNeeded:
        return Vector<ArgumentDescription> {
            {"databaseConnectionIdentifier", "uint64_t", nullptr, false},
            {"transactionIdentifier", "WebCore::IDBResourceIdentifier", nullptr, false},
        };
    case MessageName::NetworkStorageManager_DidFireVersionChangeEvent:
        return Vector<ArgumentDescription> {
            {"databaseConnectionIdentifier", "uint64_t", nullptr, false},
            {"requestIdentifier", "WebCore::IDBResourceIdentifier", nullptr, false},
            {"connectionClosedOnBehalfOfServer", "WebCore::IndexedDB::ConnectionClosedOnBehalfOfServer", nullptr, false},
        };
    case MessageName::NetworkStorageManager_DidFinishHandlingVersionChangeTransaction:
        return Vector<ArgumentDescription> {
            {"databaseConnectionIdentifier", "uint64_t", nullptr, false},
            {"transactionIdentifier", "WebCore::IDBResourceIdentifier", nullptr, false},
        };
    case MessageName::NetworkStorageManager_AbortTransaction:
        return Vector<ArgumentDescription> {
            {"transactionIdentifier", "WebCore::IDBResourceIdentifier", nullptr, false},
        };
    case MessageName::NetworkStorageManager_CommitTransaction:
        return Vector<ArgumentDescription> {
            {"transactionIdentifier", "WebCore::IDBResourceIdentifier", nullptr, false},
            {"pendingRequestCount", "uint64_t", nullptr, false},
        };
    case MessageName::NetworkStorageManager_CreateObjectStore:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"info", "WebCore::IDBObjectStoreInfo", nullptr, false},
        };
    case MessageName::NetworkStorageManager_DeleteObjectStore:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"objectStoreName", "String", nullptr, false},
        };
    case MessageName::NetworkStorageManager_RenameObjectStore:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"objectStoreIdentifier", "uint64_t", nullptr, false},
            {"newName", "String", nullptr, false},
        };
    case MessageName::NetworkStorageManager_ClearObjectStore:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"objectStoreIdentifier", "uint64_t", nullptr, false},
        };
    case MessageName::NetworkStorageManager_CreateIndex:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"info", "WebCore::IDBIndexInfo", nullptr, false},
        };
    case MessageName::NetworkStorageManager_DeleteIndex:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"objectStoreIdentifier", "uint64_t", nullptr, false},
            {"indexName", "String", nullptr, false},
        };
    case MessageName::NetworkStorageManager_RenameIndex:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"objectStoreIdentifier", "uint64_t", nullptr, false},
            {"indexIdentifier", "uint64_t", nullptr, false},
            {"newName", "String", nullptr, false},
        };
    case MessageName::NetworkStorageManager_PutOrAdd:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"key", "WebCore::IDBKeyData", nullptr, false},
            {"value", "WebCore::IDBValue", nullptr, false},
            {"overwriteMode", "WebCore::IndexedDB::ObjectStoreOverwriteMode", nullptr, false},
        };
    case MessageName::NetworkStorageManager_GetRecord:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"getRecordData", "WebCore::IDBGetRecordData", nullptr, false},
        };
    case MessageName::NetworkStorageManager_GetAllRecords:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"getAllRecordsData", "WebCore::IDBGetAllRecordsData", nullptr, false},
        };
    case MessageName::NetworkStorageManager_GetCount:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"range", "WebCore::IDBKeyRangeData", nullptr, false},
        };
    case MessageName::NetworkStorageManager_DeleteRecord:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"range", "WebCore::IDBKeyRangeData", nullptr, false},
        };
    case MessageName::NetworkStorageManager_OpenCursor:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"info", "WebCore::IDBCursorInfo", nullptr, false},
        };
    case MessageName::NetworkStorageManager_IterateCursor:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::IDBRequestData", nullptr, false},
            {"data", "WebCore::IDBIterateCursorData", nullptr, false},
        };
    case MessageName::NetworkStorageManager_GetAllDatabaseNamesAndVersions:
        return Vector<ArgumentDescription> {
            {"requestIdentifier", "WebCore::IDBResourceIdentifier", nullptr, false},
            {"origin", "WebCore::ClientOrigin", nullptr, false},
        };
#if ENABLE(WEB_RTC)
    case MessageName::NetworkMDNSRegister_UnregisterMDNSNames:
        return Vector<ArgumentDescription> {
            {"documentIdentifier", "WebCore::ScriptExecutionContextIdentifier", nullptr, false},
        };
    case MessageName::NetworkMDNSRegister_RegisterMDNSName:
        return Vector<ArgumentDescription> {
            {"requestIdentifier", "WebKit::MDNSRegisterIdentifier", nullptr, false},
            {"documentIdentifier", "WebCore::ScriptExecutionContextIdentifier", nullptr, false},
            {"ipAddress", "String", nullptr, false},
        };
#endif
#if USE(LIBWEBRTC)
    case MessageName::NetworkRTCMonitor_StartUpdatingIfNeeded:
        return Vector<ArgumentDescription> {
            {"enumerateAllInterfaces", "bool", nullptr, false},
        };
    case MessageName::NetworkRTCMonitor_StopUpdating:
        return Vector<ArgumentDescription> { };
#endif
#if USE(LIBWEBRTC)
    case MessageName::NetworkRTCProvider_CreateUDPSocket:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::LibWebRTCSocketIdentifier", nullptr, false},
            {"localAddress", "WebKit::RTCNetwork::SocketAddress", nullptr, false},
            {"minPort", "uint16_t", nullptr, false},
            {"maxPort", "uint16_t", nullptr, false},
            {"pageIdentifier", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"isFirstParty", "bool", nullptr, false},
            {"isRelayDisabled", "bool", nullptr, false},
            {"domain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkRTCProvider_CreateServerTCPSocket:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::LibWebRTCSocketIdentifier", nullptr, false},
            {"localAddress", "WebKit::RTCNetwork::SocketAddress", nullptr, false},
            {"minPort", "uint16_t", nullptr, false},
            {"maxPort", "uint16_t", nullptr, false},
            {"options", "int", nullptr, false},
        };
    case MessageName::NetworkRTCProvider_CreateClientTCPSocket:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::LibWebRTCSocketIdentifier", nullptr, false},
            {"localAddress", "WebKit::RTCNetwork::SocketAddress", nullptr, false},
            {"remoteAddress", "WebKit::RTCNetwork::SocketAddress", nullptr, false},
            {"userAgent", "String", nullptr, false},
            {"options", "int", nullptr, false},
            {"pageIdentifier", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"isFirstParty", "bool", nullptr, false},
            {"isRelayDisabled", "bool", nullptr, false},
            {"domain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkRTCProvider_WrapNewTCPConnection:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::LibWebRTCSocketIdentifier", nullptr, false},
            {"newConnectionSocketIdentifier", "WebCore::LibWebRTCSocketIdentifier", nullptr, false},
        };
    case MessageName::NetworkRTCProvider_SetPlatformTCPSocketsEnabled:
        return Vector<ArgumentDescription> {
            {"enabled", "bool", nullptr, false},
        };
    case MessageName::NetworkRTCProvider_SetPlatformUDPSocketsEnabled:
        return Vector<ArgumentDescription> {
            {"enabled", "bool", nullptr, false},
        };
    case MessageName::NetworkRTCProvider_CreateResolver:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::LibWebRTCResolverIdentifier", nullptr, false},
            {"address", "String", nullptr, false},
        };
    case MessageName::NetworkRTCProvider_StopResolver:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::LibWebRTCResolverIdentifier", nullptr, false},
        };
    case MessageName::NetworkRTCProvider_SendToSocket:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::LibWebRTCSocketIdentifier", nullptr, false},
            {"data", "IPC::DataReference", nullptr, false},
            {"address", "WebKit::RTCNetwork::SocketAddress", nullptr, false},
            {"options", "WebKit::RTCPacketOptions", nullptr, false},
        };
    case MessageName::NetworkRTCProvider_CloseSocket:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::LibWebRTCSocketIdentifier", nullptr, false},
        };
    case MessageName::NetworkRTCProvider_SetSocketOption:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::LibWebRTCSocketIdentifier", nullptr, false},
            {"option", "int", nullptr, false},
            {"value", "int", nullptr, false},
        };
#endif
#if ENABLE(WEB_RTC)
    case MessageName::RTCDataChannelRemoteManagerProxy_SendData:
        return Vector<ArgumentDescription> {
            {"source", "WebCore::RTCDataChannelIdentifier", nullptr, false},
            {"isRaw", "bool", nullptr, false},
            {"text", "IPC::DataReference", nullptr, false},
        };
    case MessageName::RTCDataChannelRemoteManagerProxy_Close:
        return Vector<ArgumentDescription> {
            {"source", "WebCore::RTCDataChannelIdentifier", nullptr, false},
        };
    case MessageName::RTCDataChannelRemoteManagerProxy_ChangeReadyState:
        return Vector<ArgumentDescription> {
            {"handler", "WebCore::RTCDataChannelIdentifier", nullptr, false},
            {"state", "uint8_t", "WebCore::RTCDataChannelState", false},
        };
    case MessageName::RTCDataChannelRemoteManagerProxy_ReceiveData:
        return Vector<ArgumentDescription> {
            {"handler", "WebCore::RTCDataChannelIdentifier", nullptr, false},
            {"isRaw", "bool", nullptr, false},
            {"data", "IPC::DataReference", nullptr, false},
        };
    case MessageName::RTCDataChannelRemoteManagerProxy_DetectError:
        return Vector<ArgumentDescription> {
            {"handler", "WebCore::RTCDataChannelIdentifier", nullptr, false},
            {"type", "uint8_t", "WebCore::RTCErrorDetailType", false},
            {"message", "String", nullptr, false},
        };
    case MessageName::RTCDataChannelRemoteManagerProxy_BufferedAmountIsDecreasing:
        return Vector<ArgumentDescription> {
            {"handler", "WebCore::RTCDataChannelIdentifier", nullptr, false},
            {"amount", "size_t", nullptr, false},
        };
#endif
    case MessageName::AuxiliaryProcess_ShutDown:
        return Vector<ArgumentDescription> { };
    case MessageName::AuxiliaryProcess_SetProcessSuppressionEnabled:
        return Vector<ArgumentDescription> {
            {"flag", "bool", nullptr, false},
        };
    case MessageName::AuxiliaryProcess_MainThreadPing:
        return Vector<ArgumentDescription> { };
#if OS(LINUX)
    case MessageName::AuxiliaryProcess_DidReceiveMemoryPressureEvent:
        return Vector<ArgumentDescription> {
            {"isCritical", "bool", nullptr, false},
        };
#endif
#if ENABLE(IPC_TESTING_API)
    case MessageName::IPCTester_StartMessageTesting:
        return Vector<ArgumentDescription> {
            {"driverName", "String", nullptr, false},
        };
    case MessageName::IPCTester_StopMessageTesting:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebConnection_HandleMessage:
        return Vector<ArgumentDescription> {
            {"messageName", "String", nullptr, false},
            {"messageBody", "WebKit::UserData", nullptr, false},
        };
    case MessageName::AuthenticationManager_CompleteAuthenticationChallenge:
        return Vector<ArgumentDescription> {
            {"challengeID", "WebKit::AuthenticationChallengeIdentifier", nullptr, false},
            {"disposition", "uint8_t", "WebKit::AuthenticationChallengeDisposition", false},
            {"credential", "WebCore::Credential", nullptr, false},
        };
    case MessageName::NotificationManagerMessageHandler_RequestSystemNotificationPermission:
        return Vector<ArgumentDescription> {
            {"originIdentifier", "String", nullptr, false},
        };
    case MessageName::NotificationManagerMessageHandler_ShowNotification:
        return Vector<ArgumentDescription> {
            {"notificationData", "WebCore::NotificationData", nullptr, false},
        };
    case MessageName::NotificationManagerMessageHandler_CancelNotification:
        return Vector<ArgumentDescription> {
            {"notificationID", "UUID", nullptr, false},
        };
    case MessageName::NotificationManagerMessageHandler_ClearNotifications:
        return Vector<ArgumentDescription> {
            {"notificationIDs", "Vector<UUID>", nullptr, false},
        };
    case MessageName::NotificationManagerMessageHandler_DidDestroyNotification:
        return Vector<ArgumentDescription> {
            {"notificationID", "UUID", nullptr, false},
        };
    case MessageName::DrawingAreaProxy_EnterAcceleratedCompositingMode:
        return Vector<ArgumentDescription> {
            {"backingStoreStateID", "uint64_t", nullptr, false},
            {"context", "WebKit::LayerTreeContext", nullptr, false},
        };
    case MessageName::DrawingAreaProxy_UpdateAcceleratedCompositingMode:
        return Vector<ArgumentDescription> {
            {"backingStoreStateID", "uint64_t", nullptr, false},
            {"context", "WebKit::LayerTreeContext", nullptr, false},
        };
    case MessageName::DrawingAreaProxy_DidFirstLayerFlush:
        return Vector<ArgumentDescription> {
            {"backingStoreStateID", "uint64_t", nullptr, false},
            {"context", "WebKit::LayerTreeContext", nullptr, false},
        };
    case MessageName::DrawingAreaProxy_DispatchPresentationCallbacksAfterFlushingLayers:
        return Vector<ArgumentDescription> {
            {"callbackIDs", "Vector<WebKit::CallbackID>", nullptr, false},
        };
#if PLATFORM(COCOA)
    case MessageName::DrawingAreaProxy_DidUpdateGeometry:
        return Vector<ArgumentDescription> { };
#endif
#if USE(COORDINATED_GRAPHICS) || USE(TEXTURE_MAPPER)
    case MessageName::DrawingAreaProxy_Update:
        return Vector<ArgumentDescription> {
            {"stateID", "uint64_t", nullptr, false},
            {"updateInfo", "WebKit::UpdateInfo", nullptr, false},
        };
    case MessageName::DrawingAreaProxy_DidUpdateBackingStoreState:
        return Vector<ArgumentDescription> {
            {"backingStoreStateID", "uint64_t", nullptr, false},
            {"updateInfo", "WebKit::UpdateInfo", nullptr, false},
            {"context", "WebKit::LayerTreeContext", nullptr, false},
        };
    case MessageName::DrawingAreaProxy_ExitAcceleratedCompositingMode:
        return Vector<ArgumentDescription> {
            {"backingStoreStateID", "uint64_t", nullptr, false},
            {"updateInfo", "WebKit::UpdateInfo", nullptr, false},
        };
#endif
#if ENABLE(MEDIA_SESSION_COORDINATOR)
    case MessageName::RemoteMediaSessionCoordinatorProxy_Join:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaSessionCoordinatorProxy_Leave:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaSessionCoordinatorProxy_CoordinateSeekTo:
        return Vector<ArgumentDescription> {
            {"time", "double", nullptr, false},
        };
    case MessageName::RemoteMediaSessionCoordinatorProxy_CoordinatePlay:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaSessionCoordinatorProxy_CoordinatePause:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaSessionCoordinatorProxy_CoordinateSetTrack:
        return Vector<ArgumentDescription> {
            {"trackIdentifier", "String", nullptr, false},
        };
    case MessageName::RemoteMediaSessionCoordinatorProxy_PositionStateChanged:
        return Vector<ArgumentDescription> {
            {"state", "WebCore::MediaPositionState", nullptr, true},
        };
    case MessageName::RemoteMediaSessionCoordinatorProxy_ReadyStateChanged:
        return Vector<ArgumentDescription> {
            {"state", "uint8_t", "WebCore::MediaSessionReadyState", false},
        };
    case MessageName::RemoteMediaSessionCoordinatorProxy_PlaybackStateChanged:
        return Vector<ArgumentDescription> {
            {"state", "uint8_t", "WebCore::MediaSessionPlaybackState", false},
        };
    case MessageName::RemoteMediaSessionCoordinatorProxy_TrackIdentifierChanged:
        return Vector<ArgumentDescription> {
            {"trackIdentifier", "String", nullptr, false},
        };
#endif
#if ENABLE(MEDIA_STREAM)
    case MessageName::SpeechRecognitionRemoteRealtimeMediaSourceManager_RemoteAudioSamplesAvailable:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::RealtimeMediaSourceIdentifier", nullptr, false},
            {"time", "MediaTime", nullptr, false},
            {"numberOfFrames", "uint64_t", nullptr, false},
        };
    case MessageName::SpeechRecognitionRemoteRealtimeMediaSourceManager_RemoteCaptureFailed:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::RealtimeMediaSourceIdentifier", nullptr, false},
        };
    case MessageName::SpeechRecognitionRemoteRealtimeMediaSourceManager_RemoteSourceStopped:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::RealtimeMediaSourceIdentifier", nullptr, false},
        };
#if PLATFORM(COCOA)
    case MessageName::SpeechRecognitionRemoteRealtimeMediaSourceManager_SetStorage:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::RealtimeMediaSourceIdentifier", nullptr, false},
            {"storageHandle", "WebKit::SharedMemory::IPCHandle", nullptr, false},
            {"description", "WebCore::CAAudioStreamDescription", nullptr, false},
            {"numberOfFrames", "uint64_t", nullptr, false},
        };
#endif
#endif
    case MessageName::SpeechRecognitionServer_Start:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::SpeechRecognitionConnectionClientIdentifier", nullptr, false},
            {"lang", "String", nullptr, false},
            {"continuous", "bool", nullptr, false},
            {"interimResults", "bool", nullptr, false},
            {"maxAlternatives", "uint64_t", nullptr, false},
            {"origin", "WebCore::ClientOrigin", nullptr, false},
            {"frameIdentifier", "WebCore::FrameIdentifier", nullptr, false},
        };
    case MessageName::SpeechRecognitionServer_Stop:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::SpeechRecognitionConnectionClientIdentifier", nullptr, false},
        };
    case MessageName::SpeechRecognitionServer_Abort:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::SpeechRecognitionConnectionClientIdentifier", nullptr, false},
        };
    case MessageName::SpeechRecognitionServer_Invalidate:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::SpeechRecognitionConnectionClientIdentifier", nullptr, false},
        };
    case MessageName::VisitedLinkStore_AddVisitedLinkHashFromPage:
        return Vector<ArgumentDescription> {
            {"pageProxyID", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"linkHash", "WebCore::SharedStringHash", nullptr, false},
        };
    case MessageName::WebCookieManagerProxy_CookiesDidChange:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
#if ENABLE(FULLSCREEN_API)
    case MessageName::WebFullScreenManagerProxy_SupportsFullScreen:
        return Vector<ArgumentDescription> {
            {"withKeyboard", "bool", nullptr, false},
        };
    case MessageName::WebFullScreenManagerProxy_EnterFullScreen:
        return Vector<ArgumentDescription> {
            {"blocksReturnToFullscreenFromPictureInPicture", "bool", nullptr, false},
        };
    case MessageName::WebFullScreenManagerProxy_ExitFullScreen:
        return Vector<ArgumentDescription> { };
    case MessageName::WebFullScreenManagerProxy_BeganEnterFullScreen:
        return Vector<ArgumentDescription> {
            {"initialRect", "WebCore::IntRect", nullptr, false},
            {"finalRect", "WebCore::IntRect", nullptr, false},
        };
    case MessageName::WebFullScreenManagerProxy_BeganExitFullScreen:
        return Vector<ArgumentDescription> {
            {"initialRect", "WebCore::IntRect", nullptr, false},
            {"finalRect", "WebCore::IntRect", nullptr, false},
        };
    case MessageName::WebFullScreenManagerProxy_Close:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebGeolocationManagerProxy_StartUpdating:
        return Vector<ArgumentDescription> {
            {"registrableDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"pageProxyID", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"authorizationToken", "String", nullptr, false},
            {"enableHighAccuracy", "bool", nullptr, false},
        };
    case MessageName::WebGeolocationManagerProxy_StopUpdating:
        return Vector<ArgumentDescription> {
            {"registrableDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::WebGeolocationManagerProxy_SetEnableHighAccuracy:
        return Vector<ArgumentDescription> {
            {"registrableDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"enabled", "bool", nullptr, false},
        };
    case MessageName::WebLockRegistryProxy_RequestLock:
        return Vector<ArgumentDescription> {
            {"clientOrigin", "WebCore::ClientOrigin", nullptr, false},
            {"identifier", "WebCore::WebLockIdentifier", nullptr, false},
            {"clientID", "WebCore::ScriptExecutionContextIdentifier", nullptr, false},
            {"name", "String", nullptr, false},
            {"mode", "bool", "WebCore::WebLockMode", false},
            {"steal", "bool", nullptr, false},
            {"ifAvailable", "bool", nullptr, false},
        };
    case MessageName::WebLockRegistryProxy_ReleaseLock:
        return Vector<ArgumentDescription> {
            {"clientOrigin", "WebCore::ClientOrigin", nullptr, false},
            {"identifier", "WebCore::WebLockIdentifier", nullptr, false},
            {"clientID", "WebCore::ScriptExecutionContextIdentifier", nullptr, false},
            {"name", "String", nullptr, false},
        };
    case MessageName::WebLockRegistryProxy_AbortLockRequest:
        return Vector<ArgumentDescription> {
            {"clientOrigin", "WebCore::ClientOrigin", nullptr, false},
            {"identifier", "WebCore::WebLockIdentifier", nullptr, false},
            {"clientID", "WebCore::ScriptExecutionContextIdentifier", nullptr, false},
            {"name", "String", nullptr, false},
        };
    case MessageName::WebLockRegistryProxy_Snapshot:
        return Vector<ArgumentDescription> {
            {"clientOrigin", "WebCore::ClientOrigin", nullptr, false},
        };
    case MessageName::WebLockRegistryProxy_ClientIsGoingAway:
        return Vector<ArgumentDescription> {
            {"clientOrigin", "WebCore::ClientOrigin", nullptr, false},
            {"clientId", "WebCore::ScriptExecutionContextIdentifier", nullptr, false},
        };
    case MessageName::WebPageProxy_CreateNewPage:
        return Vector<ArgumentDescription> {
            {"originatingFrameInfoData", "WebKit::FrameInfoData", nullptr, false},
            {"originatingPageID", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"request", "WebCore::ResourceRequest", nullptr, false},
            {"windowFeatures", "WebCore::WindowFeatures", nullptr, false},
            {"navigationActionData", "WebKit::NavigationActionData", nullptr, false},
        };
    case MessageName::WebPageProxy_ShowPage:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_ClosePage:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_RunJavaScriptAlert:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"frameInfo", "WebKit::FrameInfoData", nullptr, false},
            {"message", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_RunJavaScriptConfirm:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"frameInfo", "WebKit::FrameInfoData", nullptr, false},
            {"message", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_RunJavaScriptPrompt:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"frameInfo", "WebKit::FrameInfoData", nullptr, false},
            {"message", "String", nullptr, false},
            {"defaultValue", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_MouseDidMoveOverElement:
        return Vector<ArgumentDescription> {
            {"hitTestResultData", "WebKit::WebHitTestResultData", nullptr, false},
            {"modifiers", "uint32_t", nullptr, false},
            {"userData", "WebKit::UserData", nullptr, false},
        };
#if ENABLE(WEBGL)
    case MessageName::WebPageProxy_WebGLPolicyForURL:
        return Vector<ArgumentDescription> {
            {"url", "URL", nullptr, false},
        };
    case MessageName::WebPageProxy_ResolveWebGLPolicyForURL:
        return Vector<ArgumentDescription> {
            {"url", "URL", nullptr, false},
        };
#endif
    case MessageName::WebPageProxy_DidChangeViewportProperties:
        return Vector<ArgumentDescription> {
            {"attributes", "WebCore::ViewportAttributes", nullptr, false},
        };
    case MessageName::WebPageProxy_DidReceiveEvent:
        return Vector<ArgumentDescription> {
            {"type", "uint32_t", nullptr, false},
            {"handled", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_SetCursor:
        return Vector<ArgumentDescription> {
            {"cursor", "WebCore::Cursor", nullptr, false},
        };
    case MessageName::WebPageProxy_SetCursorHiddenUntilMouseMoves:
        return Vector<ArgumentDescription> {
            {"hiddenUntilMouseMoves", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_SetStatusText:
        return Vector<ArgumentDescription> {
            {"statusText", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_SetFocus:
        return Vector<ArgumentDescription> {
            {"focused", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_TakeFocus:
        return Vector<ArgumentDescription> {
            {"direction", "uint8_t", nullptr, false},
        };
    case MessageName::WebPageProxy_FocusedFrameChanged:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, true},
        };
    case MessageName::WebPageProxy_SetRenderTreeSize:
        return Vector<ArgumentDescription> {
            {"treeSize", "uint64_t", nullptr, false},
        };
    case MessageName::WebPageProxy_SetToolbarsAreVisible:
        return Vector<ArgumentDescription> {
            {"toolbarsAreVisible", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_GetToolbarsAreVisible:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_SetMenuBarIsVisible:
        return Vector<ArgumentDescription> {
            {"menuBarIsVisible", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_GetMenuBarIsVisible:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_SetStatusBarIsVisible:
        return Vector<ArgumentDescription> {
            {"statusBarIsVisible", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_GetStatusBarIsVisible:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_SetIsResizable:
        return Vector<ArgumentDescription> {
            {"isResizable", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_SetWindowFrame:
        return Vector<ArgumentDescription> {
            {"windowFrame", "WebCore::FloatRect", nullptr, false},
        };
    case MessageName::WebPageProxy_GetWindowFrame:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_ScreenToRootView:
        return Vector<ArgumentDescription> {
            {"screenPoint", "WebCore::IntPoint", nullptr, false},
        };
    case MessageName::WebPageProxy_RootViewToScreen:
        return Vector<ArgumentDescription> {
            {"rect", "WebCore::IntRect", nullptr, false},
        };
    case MessageName::WebPageProxy_AccessibilityScreenToRootView:
        return Vector<ArgumentDescription> {
            {"screenPoint", "WebCore::IntPoint", nullptr, false},
        };
    case MessageName::WebPageProxy_RootViewToAccessibilityScreen:
        return Vector<ArgumentDescription> {
            {"rect", "WebCore::IntRect", nullptr, false},
        };
#if PLATFORM(COCOA) || PLATFORM(GTK)
    case MessageName::WebPageProxy_ShowValidationMessage:
        return Vector<ArgumentDescription> {
            {"anchorRect", "WebCore::IntRect", nullptr, false},
            {"message", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_HideValidationMessage:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebPageProxy_RunBeforeUnloadConfirmPanel:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"frameInfo", "WebKit::FrameInfoData", nullptr, false},
            {"message", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_PageDidScroll:
        return Vector<ArgumentDescription> {
            {"scrollPosition", "WebCore::IntPoint", nullptr, false},
        };
    case MessageName::WebPageProxy_SetHasActiveAnimatedScrolls:
        return Vector<ArgumentDescription> {
            {"hasActiveAnimatedScrolls", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_RunOpenPanel:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"frameInfo", "WebKit::FrameInfoData", nullptr, false},
            {"parameters", "WebCore::FileChooserSettings", nullptr, false},
        };
    case MessageName::WebPageProxy_ShowShareSheet:
        return Vector<ArgumentDescription> {
            {"shareData", "WebCore::ShareDataWithParsedURL", nullptr, false},
        };
    case MessageName::WebPageProxy_ShowContactPicker:
        return Vector<ArgumentDescription> {
            {"requestData", "WebCore::ContactsRequestData", nullptr, false},
        };
    case MessageName::WebPageProxy_PrintFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"title", "String", nullptr, false},
            {"pdfFirstPageSize", "WebCore::FloatSize", nullptr, false},
        };
    case MessageName::WebPageProxy_RunModal:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_NotifyScrollerThumbIsVisibleInRect:
        return Vector<ArgumentDescription> {
            {"scrollerThumb", "WebCore::IntRect", nullptr, false},
        };
    case MessageName::WebPageProxy_RecommendedScrollbarStyleDidChange:
        return Vector<ArgumentDescription> {
            {"newStyle", "int32_t", nullptr, false},
        };
    case MessageName::WebPageProxy_DidChangeScrollbarsForMainFrame:
        return Vector<ArgumentDescription> {
            {"hasHorizontalScrollbar", "bool", nullptr, false},
            {"hasVerticalScrollbar", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_DidChangeScrollOffsetPinningForMainFrame:
        return Vector<ArgumentDescription> {
            {"pinnedState", "WebCore::RectEdges<bool>", nullptr, false},
        };
    case MessageName::WebPageProxy_DidChangePageCount:
        return Vector<ArgumentDescription> {
            {"pageCount", "unsigned", nullptr, false},
        };
    case MessageName::WebPageProxy_ThemeColorChanged:
        return Vector<ArgumentDescription> {
            {"themeColor", "WebCore::Color", nullptr, false},
        };
    case MessageName::WebPageProxy_PageExtendedBackgroundColorDidChange:
        return Vector<ArgumentDescription> {
            {"backgroundColor", "WebCore::Color", nullptr, false},
        };
    case MessageName::WebPageProxy_SampledPageTopColorChanged:
        return Vector<ArgumentDescription> {
            {"sampledPageTopColor", "WebCore::Color", nullptr, false},
        };
    case MessageName::WebPageProxy_SetCanShortCircuitHorizontalWheelEvents:
        return Vector<ArgumentDescription> {
            {"canShortCircuitHorizontalWheelEvents", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_DidChangeContentSize:
        return Vector<ArgumentDescription> {
            {"newSize", "WebCore::IntSize", nullptr, false},
        };
    case MessageName::WebPageProxy_DidChangeIntrinsicContentSize:
        return Vector<ArgumentDescription> {
            {"newIntrinsicContentSize", "WebCore::IntSize", nullptr, false},
        };
#if ENABLE(INPUT_TYPE_COLOR)
    case MessageName::WebPageProxy_ShowColorPicker:
        return Vector<ArgumentDescription> {
            {"initialColor", "WebCore::Color", nullptr, false},
            {"elementRect", "WebCore::IntRect", nullptr, false},
            {"suggestions", "Vector<WebCore::Color>", nullptr, false},
        };
    case MessageName::WebPageProxy_SetColorPickerColor:
        return Vector<ArgumentDescription> {
            {"color", "WebCore::Color", nullptr, false},
        };
    case MessageName::WebPageProxy_EndColorPicker:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(DATALIST_ELEMENT)
    case MessageName::WebPageProxy_ShowDataListSuggestions:
        return Vector<ArgumentDescription> {
            {"suggestionInformation", "WebCore::DataListSuggestionInformation", nullptr, false},
        };
    case MessageName::WebPageProxy_HandleKeydownInDataList:
        return Vector<ArgumentDescription> {
            {"key", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_EndDataListSuggestions:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(DATE_AND_TIME_INPUT_TYPES)
    case MessageName::WebPageProxy_ShowDateTimePicker:
        return Vector<ArgumentDescription> {
            {"params", "WebCore::DateTimeChooserParameters", nullptr, false},
        };
    case MessageName::WebPageProxy_EndDateTimePicker:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebPageProxy_DecidePolicyForResponse:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"frameInfo", "WebKit::FrameInfoData", nullptr, false},
            {"policyCheckIdentifier", "WebCore::PolicyCheckIdentifier", nullptr, false},
            {"navigationID", "uint64_t", nullptr, false},
            {"response", "WebCore::ResourceResponse", nullptr, false},
            {"request", "WebCore::ResourceRequest", nullptr, false},
            {"canShowMIMEType", "bool", nullptr, false},
            {"downloadAttribute", "String", nullptr, false},
            {"wasAllowedByInjectedBundle", "bool", nullptr, false},
            {"listenerID", "uint64_t", nullptr, false},
            {"userData", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebPageProxy_DecidePolicyForNavigationActionAsync:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"frameInfo", "WebKit::FrameInfoData", nullptr, false},
            {"policyCheckIdentifier", "WebCore::PolicyCheckIdentifier", nullptr, false},
            {"navigationID", "uint64_t", nullptr, false},
            {"navigationActionData", "WebKit::NavigationActionData", nullptr, false},
            {"originatingFrameInfoData", "WebKit::FrameInfoData", nullptr, false},
            {"originatingPageID", "WebKit::WebPageProxyIdentifier", nullptr, true},
            {"originalRequest", "WebCore::ResourceRequest", nullptr, false},
            {"request", "WebCore::ResourceRequest", nullptr, false},
            {"requestBody", "IPC::FormDataReference", nullptr, false},
            {"redirectResponse", "WebCore::ResourceResponse", nullptr, false},
            {"userData", "WebKit::UserData", nullptr, false},
            {"listenerID", "uint64_t", nullptr, false},
        };
    case MessageName::WebPageProxy_DecidePolicyForNavigationActionSync:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"isMainFrame", "bool", nullptr, false},
            {"frameInfo", "WebKit::FrameInfoData", nullptr, false},
            {"policyCheckIdentifier", "WebCore::PolicyCheckIdentifier", nullptr, false},
            {"navigationID", "uint64_t", nullptr, false},
            {"navigationActionData", "WebKit::NavigationActionData", nullptr, false},
            {"originatingFrameInfoData", "WebKit::FrameInfoData", nullptr, false},
            {"originatingPageID", "WebKit::WebPageProxyIdentifier", nullptr, true},
            {"originalRequest", "WebCore::ResourceRequest", nullptr, false},
            {"request", "WebCore::ResourceRequest", nullptr, false},
            {"requestBody", "IPC::FormDataReference", nullptr, false},
            {"redirectResponse", "WebCore::ResourceResponse", nullptr, false},
            {"userData", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebPageProxy_DecidePolicyForNewWindowAction:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"frameInfo", "WebKit::FrameInfoData", nullptr, false},
            {"policyCheckIdentifier", "WebCore::PolicyCheckIdentifier", nullptr, false},
            {"navigationActionData", "WebKit::NavigationActionData", nullptr, false},
            {"request", "WebCore::ResourceRequest", nullptr, false},
            {"frameName", "String", nullptr, false},
            {"listenerID", "uint64_t", nullptr, false},
            {"userData", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebPageProxy_UnableToImplementPolicy:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"error", "WebCore::ResourceError", nullptr, false},
            {"userData", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebPageProxy_DidChangeProgress:
        return Vector<ArgumentDescription> {
            {"value", "double", nullptr, false},
        };
    case MessageName::WebPageProxy_DidFinishProgress:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_DidStartProgress:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_SetNetworkRequestsInProgress:
        return Vector<ArgumentDescription> {
            {"networkRequestsInProgress", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_DidCreateMainFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
        };
    case MessageName::WebPageProxy_DidCreateSubframe:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
        };
    case MessageName::WebPageProxy_DidCreateWindow:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"windowIdentifier", "WebCore::GlobalWindowIdentifier", nullptr, false},
        };
    case MessageName::WebPageProxy_DidStartProvisionalLoadForFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"frameInfo", "WebKit::FrameInfoData", nullptr, false},
            {"request", "WebCore::ResourceRequest", nullptr, false},
            {"navigationID", "uint64_t", nullptr, false},
            {"url", "URL", nullptr, false},
            {"unreachableURL", "URL", nullptr, false},
            {"userData", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebPageProxy_DidReceiveServerRedirectForProvisionalLoadForFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"navigationID", "uint64_t", nullptr, false},
            {"request", "WebCore::ResourceRequest", nullptr, false},
            {"userData", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebPageProxy_WillPerformClientRedirectForFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"url", "String", nullptr, false},
            {"delay", "double", nullptr, false},
            {"lockBackForwardList", "bool", "WebCore::LockBackForwardList", false},
        };
    case MessageName::WebPageProxy_DidCancelClientRedirectForFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
        };
    case MessageName::WebPageProxy_DidChangeProvisionalURLForFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"navigationID", "uint64_t", nullptr, false},
            {"url", "URL", nullptr, false},
        };
    case MessageName::WebPageProxy_DidFailProvisionalLoadForFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"frameInfo", "WebKit::FrameInfoData", nullptr, false},
            {"request", "WebCore::ResourceRequest", nullptr, false},
            {"navigationID", "uint64_t", nullptr, false},
            {"provisionalURL", "String", nullptr, false},
            {"error", "WebCore::ResourceError", nullptr, false},
            {"willContinueLoading", "bool", "WebCore::WillContinueLoading", false},
            {"userData", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebPageProxy_DidCommitLoadForFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"frameInfo", "WebKit::FrameInfoData", nullptr, false},
            {"request", "WebCore::ResourceRequest", nullptr, false},
            {"navigationID", "uint64_t", nullptr, false},
            {"mimeType", "String", nullptr, false},
            {"hasCustomContentProvider", "bool", nullptr, false},
            {"loadType", "uint8_t", "WebCore::FrameLoadType", false},
            {"certificateInfo", "WebCore::CertificateInfo", nullptr, false},
            {"usedLegacyTLS", "bool", nullptr, false},
            {"containsPluginDocument", "bool", nullptr, false},
            {"forcedHasInsecureContent", "WebCore::HasInsecureContent", nullptr, true},
            {"mouseEventPolicy", "uint8_t", "WebCore::MouseEventPolicy", false},
            {"userData", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebPageProxy_DidFailLoadForFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"frameInfo", "WebKit::FrameInfoData", nullptr, false},
            {"request", "WebCore::ResourceRequest", nullptr, false},
            {"navigationID", "uint64_t", nullptr, false},
            {"error", "WebCore::ResourceError", nullptr, false},
            {"userData", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebPageProxy_DidFinishDocumentLoadForFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"navigationID", "uint64_t", nullptr, false},
            {"userData", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebPageProxy_DidFinishLoadForFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"frameInfo", "WebKit::FrameInfoData", nullptr, false},
            {"request", "WebCore::ResourceRequest", nullptr, false},
            {"navigationID", "uint64_t", nullptr, false},
            {"userData", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebPageProxy_DidFirstLayoutForFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"userData", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebPageProxy_DidFirstVisuallyNonEmptyLayoutForFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"userData", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebPageProxy_DidReachLayoutMilestone:
        return Vector<ArgumentDescription> {
            {"layoutMilestones", "OptionSet<WebCore::LayoutMilestone>", nullptr, false},
        };
    case MessageName::WebPageProxy_DidReceiveTitleForFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"title", "String", nullptr, false},
            {"userData", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebPageProxy_DidDisplayInsecureContentForFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"userData", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebPageProxy_DidRunInsecureContentForFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"userData", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebPageProxy_DidDetectXSSForFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"userData", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebPageProxy_DidSameDocumentNavigationForFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"navigationID", "uint64_t", nullptr, false},
            {"type", "uint32_t", nullptr, false},
            {"url", "URL", nullptr, false},
            {"userData", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebPageProxy_DidChangeMainDocument:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
        };
    case MessageName::WebPageProxy_DidExplicitOpenForFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"url", "URL", nullptr, false},
            {"mimeType", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_DidDestroyNavigation:
        return Vector<ArgumentDescription> {
            {"navigationID", "uint64_t", nullptr, false},
        };
    case MessageName::WebPageProxy_MainFramePluginHandlesPageScaleGestureDidChange:
        return Vector<ArgumentDescription> {
            {"mainFramePluginHandlesPageScaleGesture", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_DidNavigateWithNavigationData:
        return Vector<ArgumentDescription> {
            {"store", "WebKit::WebNavigationDataStore", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
        };
    case MessageName::WebPageProxy_DidPerformClientRedirect:
        return Vector<ArgumentDescription> {
            {"sourceURLString", "String", nullptr, false},
            {"destinationURLString", "String", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
        };
    case MessageName::WebPageProxy_DidPerformServerRedirect:
        return Vector<ArgumentDescription> {
            {"sourceURLString", "String", nullptr, false},
            {"destinationURLString", "String", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
        };
    case MessageName::WebPageProxy_DidUpdateHistoryTitle:
        return Vector<ArgumentDescription> {
            {"title", "String", nullptr, false},
            {"url", "String", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
        };
    case MessageName::WebPageProxy_DidFinishLoadingDataForCustomContentProvider:
        return Vector<ArgumentDescription> {
            {"suggestedFilename", "String", nullptr, false},
            {"data", "IPC::DataReference", nullptr, false},
        };
    case MessageName::WebPageProxy_WillSubmitForm:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"sourceFrameID", "WebCore::FrameIdentifier", nullptr, false},
            {"textFieldValues", "Vector<std::pair<String, String>>", nullptr, false},
            {"listenerID", "WebKit::FormSubmitListenerIdentifier", nullptr, false},
            {"userData", "WebKit::UserData", nullptr, false},
        };
#if PLATFORM(IOS_FAMILY)
    case MessageName::WebPageProxy_InterpretKeyEvent:
        return Vector<ArgumentDescription> {
            {"state", "WebKit::EditorState", nullptr, false},
            {"isCharEvent", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_DidReceivePositionInformation:
        return Vector<ArgumentDescription> {
            {"information", "WebKit::InteractionInformationAtPosition", nullptr, false},
        };
    case MessageName::WebPageProxy_SaveImageToLibrary:
        return Vector<ArgumentDescription> {
            {"handle", "WebKit::SharedMemory::IPCHandle", nullptr, false},
        };
    case MessageName::WebPageProxy_ShowPlaybackTargetPicker:
        return Vector<ArgumentDescription> {
            {"hasVideo", "bool", nullptr, false},
            {"elementRect", "WebCore::IntRect", nullptr, false},
            {"policy", "uint8_t", "WebCore::RouteSharingPolicy", false},
            {"routingContextUID", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_CommitPotentialTapFailed:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_DidNotHandleTapAsClick:
        return Vector<ArgumentDescription> {
            {"point", "WebCore::IntPoint", nullptr, false},
        };
    case MessageName::WebPageProxy_DidCompleteSyntheticClick:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_DisableDoubleTapGesturesDuringTapIfNecessary:
        return Vector<ArgumentDescription> {
            {"requestID", "WebKit::TapIdentifier", nullptr, false},
        };
    case MessageName::WebPageProxy_HandleSmartMagnificationInformationForPotentialTap:
        return Vector<ArgumentDescription> {
            {"requestID", "WebKit::TapIdentifier", nullptr, false},
            {"renderRect", "WebCore::FloatRect", nullptr, false},
            {"fitEntireRect", "bool", nullptr, false},
            {"viewportMinimumScale", "double", nullptr, false},
            {"viewportMaximumScale", "double", nullptr, false},
            {"nodeIsRootLevel", "bool", nullptr, false},
        };
#endif
#if ENABLE(DATA_DETECTION)
    case MessageName::WebPageProxy_SetDataDetectionResult:
        return Vector<ArgumentDescription> {
            {"dataDetectionResult", "WebKit::DataDetectionResult", nullptr, false},
        };
    case MessageName::WebPageProxy_HandleClickForDataDetectionResult:
        return Vector<ArgumentDescription> {
            {"info", "WebCore::DataDetectorElementInfo", nullptr, false},
            {"location", "WebCore::IntPoint", nullptr, false},
        };
#endif
    case MessageName::WebPageProxy_PageScaleFactorDidChange:
        return Vector<ArgumentDescription> {
            {"scaleFactor", "double", nullptr, false},
        };
    case MessageName::WebPageProxy_PluginScaleFactorDidChange:
        return Vector<ArgumentDescription> {
            {"zoomFactor", "double", nullptr, false},
        };
    case MessageName::WebPageProxy_PluginZoomFactorDidChange:
        return Vector<ArgumentDescription> {
            {"zoomFactor", "double", nullptr, false},
        };
#if PLATFORM(GTK) || PLATFORM(WPE)
    case MessageName::WebPageProxy_BindAccessibilityTree:
        return Vector<ArgumentDescription> {
            {"plugID", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_SetInputMethodState:
        return Vector<ArgumentDescription> {
            {"state", "WebKit::InputMethodState", nullptr, true},
        };
#endif
    case MessageName::WebPageProxy_BackForwardAddItem:
        return Vector<ArgumentDescription> {
            {"itemState", "WebKit::BackForwardListItemState", nullptr, false},
        };
    case MessageName::WebPageProxy_BackForwardGoToItem:
        return Vector<ArgumentDescription> {
            {"itemID", "WebCore::BackForwardItemIdentifier", nullptr, false},
        };
    case MessageName::WebPageProxy_BackForwardItemAtIndex:
        return Vector<ArgumentDescription> {
            {"itemIndex", "int32_t", nullptr, false},
        };
    case MessageName::WebPageProxy_BackForwardListCounts:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_BackForwardClear:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_WillGoToBackForwardListItem:
        return Vector<ArgumentDescription> {
            {"itemID", "WebCore::BackForwardItemIdentifier", nullptr, false},
            {"inBackForwardCache", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_RegisterEditCommandForUndo:
        return Vector<ArgumentDescription> {
            {"commandID", "uint64_t", nullptr, false},
            {"label", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_ClearAllEditCommands:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_RegisterInsertionUndoGrouping:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_CanUndoRedo:
        return Vector<ArgumentDescription> {
            {"undoOrRedo", "bool", "WebKit::UndoOrRedo", false},
        };
    case MessageName::WebPageProxy_ExecuteUndoRedo:
        return Vector<ArgumentDescription> {
            {"undoOrRedo", "bool", "WebKit::UndoOrRedo", false},
        };
    case MessageName::WebPageProxy_LogDiagnosticMessageFromWebProcess:
        return Vector<ArgumentDescription> {
            {"message", "String", nullptr, false},
            {"description", "String", nullptr, false},
            {"shouldSample", "bool", "WebCore::ShouldSample", false},
        };
    case MessageName::WebPageProxy_LogDiagnosticMessageWithResultFromWebProcess:
        return Vector<ArgumentDescription> {
            {"message", "String", nullptr, false},
            {"description", "String", nullptr, false},
            {"result", "uint32_t", nullptr, false},
            {"shouldSample", "bool", "WebCore::ShouldSample", false},
        };
    case MessageName::WebPageProxy_LogDiagnosticMessageWithValueFromWebProcess:
        return Vector<ArgumentDescription> {
            {"message", "String", nullptr, false},
            {"description", "String", nullptr, false},
            {"value", "double", nullptr, false},
            {"significantFigures", "unsigned", nullptr, false},
            {"shouldSample", "bool", "WebCore::ShouldSample", false},
        };
    case MessageName::WebPageProxy_LogDiagnosticMessageWithEnhancedPrivacyFromWebProcess:
        return Vector<ArgumentDescription> {
            {"message", "String", nullptr, false},
            {"description", "String", nullptr, false},
            {"shouldSample", "bool", "WebCore::ShouldSample", false},
        };
    case MessageName::WebPageProxy_LogDiagnosticMessageWithValueDictionaryFromWebProcess:
        return Vector<ArgumentDescription> {
            {"message", "String", nullptr, false},
            {"description", "String", nullptr, false},
            {"value", "WebCore::DiagnosticLoggingClient::ValueDictionary", nullptr, false},
            {"shouldSample", "bool", "WebCore::ShouldSample", false},
        };
    case MessageName::WebPageProxy_LogDiagnosticMessageWithDomainFromWebProcess:
        return Vector<ArgumentDescription> {
            {"message", "String", nullptr, false},
            {"domain", "WebCore::DiagnosticLoggingDomain", nullptr, false},
        };
    case MessageName::WebPageProxy_LogScrollingEvent:
        return Vector<ArgumentDescription> {
            {"eventType", "uint32_t", nullptr, false},
            {"timestamp", "MonotonicTime", nullptr, false},
            {"data", "uint64_t", nullptr, false},
        };
    case MessageName::WebPageProxy_EditorStateChanged:
        return Vector<ArgumentDescription> {
            {"editorState", "WebKit::EditorState", nullptr, false},
        };
    case MessageName::WebPageProxy_CompositionWasCanceled:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_SetHasHadSelectionChangesFromUserInteraction:
        return Vector<ArgumentDescription> {
            {"hasHadUserSelectionChanges", "bool", nullptr, false},
        };
#if ENABLE(IMAGE_ANALYSIS)
    case MessageName::WebPageProxy_RequestTextRecognition:
        return Vector<ArgumentDescription> {
            {"imageURL", "URL", nullptr, false},
            {"imageData", "WebKit::ShareableBitmap::Handle", nullptr, false},
            {"identifier", "String", nullptr, false},
        };
#endif
#if HAVE(TRANSLATION_UI_SERVICES) && ENABLE(CONTEXT_MENUS)
    case MessageName::WebPageProxy_HandleContextMenuTranslation:
        return Vector<ArgumentDescription> {
            {"info", "WebCore::TranslationContextMenuInfo", nullptr, false},
        };
#endif
#if ENABLE(MEDIA_CONTROLS_CONTEXT_MENUS) && USE(UICONTEXTMENU)
    case MessageName::WebPageProxy_ShowMediaControlsContextMenu:
        return Vector<ArgumentDescription> {
            {"targetFrame", "WebCore::FloatRect", nullptr, false},
            {"items", "Vector<WebCore::MediaControlsContextMenuItem>", nullptr, false},
        };
#endif
#if HAVE(TOUCH_BAR)
    case MessageName::WebPageProxy_SetIsTouchBarUpdateSupressedForHiddenContentEditable:
        return Vector<ArgumentDescription> {
            {"isTouchBarUpdateSupressed", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_SetIsNeverRichlyEditableForTouchBar:
        return Vector<ArgumentDescription> {
            {"isNeverRichlyEditable", "bool", nullptr, false},
        };
#endif
    case MessageName::WebPageProxy_RequestDOMPasteAccess:
        return Vector<ArgumentDescription> {
            {"pasteAccessCategory", "uint8_t", "WebCore::DOMPasteAccessCategory", false},
            {"elementRect", "WebCore::IntRect", nullptr, false},
            {"originIdentifier", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_DidCountStringMatches:
        return Vector<ArgumentDescription> {
            {"string", "String", nullptr, false},
            {"matchCount", "uint32_t", nullptr, false},
        };
    case MessageName::WebPageProxy_SetTextIndicator:
        return Vector<ArgumentDescription> {
            {"indicator", "WebCore::TextIndicatorData", nullptr, false},
            {"lifetime", "uint64_t", nullptr, false},
        };
    case MessageName::WebPageProxy_ClearTextIndicator:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_DidFindString:
        return Vector<ArgumentDescription> {
            {"string", "String", nullptr, false},
            {"matchRect", "Vector<WebCore::IntRect>", nullptr, false},
            {"matchCount", "uint32_t", nullptr, false},
            {"matchIndex", "int32_t", nullptr, false},
            {"didWrapAround", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_DidFailToFindString:
        return Vector<ArgumentDescription> {
            {"string", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_DidFindStringMatches:
        return Vector<ArgumentDescription> {
            {"string", "String", nullptr, false},
            {"matches", "Vector<Vector<WebCore::IntRect>>", nullptr, false},
            {"firstIndexAfterSelection", "int32_t", nullptr, false},
        };
    case MessageName::WebPageProxy_DidGetImageForFindMatch:
        return Vector<ArgumentDescription> {
            {"contentImageHandle", "WebKit::ShareableBitmap::Handle", nullptr, false},
            {"matchIndex", "uint32_t", nullptr, false},
        };
    case MessageName::WebPageProxy_ShowPopupMenu:
        return Vector<ArgumentDescription> {
            {"rect", "WebCore::IntRect", nullptr, false},
            {"textDirection", "uint64_t", nullptr, false},
            {"items", "Vector<WebKit::WebPopupItem>", nullptr, false},
            {"selectedIndex", "int32_t", nullptr, false},
            {"data", "WebKit::PlatformPopupMenuData", nullptr, false},
        };
    case MessageName::WebPageProxy_HidePopupMenu:
        return Vector<ArgumentDescription> { };
#if ENABLE(CONTEXT_MENUS)
    case MessageName::WebPageProxy_ShowContextMenu:
        return Vector<ArgumentDescription> {
            {"contextMenuContextData", "WebKit::ContextMenuContextData", nullptr, false},
            {"userData", "WebKit::UserData", nullptr, false},
        };
#endif
#if ENABLE(SERVICE_WORKER)
    case MessageName::WebPageProxy_DidFinishServiceWorkerPageRegistration:
        return Vector<ArgumentDescription> {
            {"success", "bool", nullptr, false},
        };
#endif
    case MessageName::WebPageProxy_ExceededDatabaseQuota:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"originIdentifier", "String", nullptr, false},
            {"databaseName", "String", nullptr, false},
            {"databaseDisplayName", "String", nullptr, false},
            {"currentQuota", "uint64_t", nullptr, false},
            {"currentOriginUsage", "uint64_t", nullptr, false},
            {"currentDatabaseUsage", "uint64_t", nullptr, false},
            {"expectedUsage", "uint64_t", nullptr, false},
        };
    case MessageName::WebPageProxy_ReachedApplicationCacheOriginQuota:
        return Vector<ArgumentDescription> {
            {"originIdentifier", "String", nullptr, false},
            {"currentQuota", "uint64_t", nullptr, false},
            {"totalBytesNeeded", "uint64_t", nullptr, false},
        };
    case MessageName::WebPageProxy_RequestGeolocationPermissionForFrame:
        return Vector<ArgumentDescription> {
            {"geolocationID", "WebKit::GeolocationIdentifier", nullptr, false},
            {"frameInfo", "WebKit::FrameInfoData", nullptr, false},
        };
    case MessageName::WebPageProxy_RevokeGeolocationAuthorizationToken:
        return Vector<ArgumentDescription> {
            {"authorizationToken", "String", nullptr, false},
        };
#if ENABLE(MEDIA_STREAM)
    case MessageName::WebPageProxy_RequestUserMediaPermissionForFrame:
        return Vector<ArgumentDescription> {
            {"userMediaID", "WebCore::UserMediaRequestIdentifier", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"userMediaDocumentOriginIdentifier", "WebCore::SecurityOriginData", nullptr, false},
            {"topLevelDocumentOriginIdentifier", "WebCore::SecurityOriginData", nullptr, false},
            {"request", "WebCore::MediaStreamRequest", nullptr, false},
        };
    case MessageName::WebPageProxy_EnumerateMediaDevicesForFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"userMediaDocumentOriginIdentifier", "WebCore::SecurityOriginData", nullptr, false},
            {"topLevelDocumentOriginIdentifier", "WebCore::SecurityOriginData", nullptr, false},
        };
    case MessageName::WebPageProxy_BeginMonitoringCaptureDevices:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(ENCRYPTED_MEDIA)
    case MessageName::WebPageProxy_RequestMediaKeySystemPermissionForFrame:
        return Vector<ArgumentDescription> {
            {"mediaKeySystemID", "WebCore::MediaKeySystemRequestIdentifier", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"topLevelDocumentOriginIdentifier", "WebCore::SecurityOriginData", nullptr, false},
            {"keySystem", "String", nullptr, false},
        };
#endif
    case MessageName::WebPageProxy_RequestNotificationPermission:
        return Vector<ArgumentDescription> {
            {"originIdentifier", "String", nullptr, false},
        };
#if USE(UNIFIED_TEXT_CHECKING)
    case MessageName::WebPageProxy_CheckTextOfParagraph:
        return Vector<ArgumentDescription> {
            {"text", "String", nullptr, false},
            {"checkingTypes", "OptionSet<WebCore::TextCheckingType>", nullptr, false},
            {"insertionPoint", "int32_t", nullptr, false},
        };
#endif
    case MessageName::WebPageProxy_CheckSpellingOfString:
        return Vector<ArgumentDescription> {
            {"text", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_CheckGrammarOfString:
        return Vector<ArgumentDescription> {
            {"text", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_SpellingUIIsShowing:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_UpdateSpellingUIWithMisspelledWord:
        return Vector<ArgumentDescription> {
            {"misspelledWord", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_UpdateSpellingUIWithGrammarString:
        return Vector<ArgumentDescription> {
            {"badGrammarPhrase", "String", nullptr, false},
            {"grammarDetail", "WebCore::GrammarDetail", nullptr, false},
        };
    case MessageName::WebPageProxy_GetGuessesForWord:
        return Vector<ArgumentDescription> {
            {"word", "String", nullptr, false},
            {"context", "String", nullptr, false},
            {"insertionPoint", "int32_t", nullptr, false},
        };
    case MessageName::WebPageProxy_LearnWord:
        return Vector<ArgumentDescription> {
            {"word", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_IgnoreWord:
        return Vector<ArgumentDescription> {
            {"word", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_RequestCheckingOfString:
        return Vector<ArgumentDescription> {
            {"requestID", "WebKit::TextCheckerRequestID", nullptr, false},
            {"request", "WebCore::TextCheckingRequestData", nullptr, false},
            {"insertionPoint", "int32_t", nullptr, false},
        };
#if ENABLE(DRAG_SUPPORT)
    case MessageName::WebPageProxy_DidPerformDragControllerAction:
        return Vector<ArgumentDescription> {
            {"dragOperation", "WebCore::DragOperation", nullptr, true},
            {"dragHandlingMethod", "uint8_t", "WebCore::DragHandlingMethod", false},
            {"mouseIsOverFileInput", "bool", nullptr, false},
            {"numberOfItemsToBeAccepted", "unsigned", nullptr, false},
            {"insertionRect", "WebCore::IntRect", nullptr, false},
            {"editableElementRect", "WebCore::IntRect", nullptr, false},
        };
    case MessageName::WebPageProxy_DidEndDragging:
        return Vector<ArgumentDescription> { };
#endif
#if PLATFORM(COCOA) && ENABLE(DRAG_SUPPORT)
    case MessageName::WebPageProxy_StartDrag:
        return Vector<ArgumentDescription> {
            {"dragItem", "WebCore::DragItem", nullptr, false},
            {"dragImage", "WebKit::ShareableBitmap::Handle", nullptr, false},
        };
    case MessageName::WebPageProxy_SetPromisedDataForImage:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
            {"imageHandle", "WebKit::SharedMemory::IPCHandle", nullptr, false},
            {"filename", "String", nullptr, false},
            {"extension", "String", nullptr, false},
            {"title", "String", nullptr, false},
            {"url", "String", nullptr, false},
            {"visibleURL", "String", nullptr, false},
            {"archiveHandle", "WebKit::SharedMemory::IPCHandle", nullptr, false},
            {"originIdentifier", "String", nullptr, false},
        };
#endif
#if PLATFORM(GTK) && ENABLE(DRAG_SUPPORT)
    case MessageName::WebPageProxy_StartDrag:
        return Vector<ArgumentDescription> {
            {"selectionData", "WebCore::SelectionData", nullptr, false},
            {"dragOperationMask", "OptionSet<WebCore::DragOperation>", nullptr, false},
            {"dragImage", "WebKit::ShareableBitmap::Handle", nullptr, false},
        };
#endif
#if ENABLE(DRAG_SUPPORT)
    case MessageName::WebPageProxy_DidPerformDragOperation:
        return Vector<ArgumentDescription> {
            {"handled", "bool", nullptr, false},
        };
#endif
#if PLATFORM(IOS_FAMILY) && ENABLE(DRAG_SUPPORT)
    case MessageName::WebPageProxy_DidHandleDragStartRequest:
        return Vector<ArgumentDescription> {
            {"started", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_DidHandleAdditionalDragItemsRequest:
        return Vector<ArgumentDescription> {
            {"added", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_WillReceiveEditDragSnapshot:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_DidReceiveEditDragSnapshot:
        return Vector<ArgumentDescription> {
            {"textIndicator", "WebCore::TextIndicatorData", nullptr, true},
        };
#endif
#if PLATFORM(COCOA)
    case MessageName::WebPageProxy_DidPerformDictionaryLookup:
        return Vector<ArgumentDescription> {
            {"dictionaryPopupInfo", "WebCore::DictionaryPopupInfo", nullptr, false},
        };
    case MessageName::WebPageProxy_ExecuteSavedCommandBySelector:
        return Vector<ArgumentDescription> {
            {"selector", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_RegisterWebProcessAccessibilityToken:
        return Vector<ArgumentDescription> {
            {"data", "IPC::DataReference", nullptr, false},
        };
    case MessageName::WebPageProxy_GetIsSpeaking:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_Speak:
        return Vector<ArgumentDescription> {
            {"string", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_StopSpeaking:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_MakeFirstResponder:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_AssistiveTechnologyMakeFirstResponder:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_SearchWithSpotlight:
        return Vector<ArgumentDescription> {
            {"string", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_SearchTheWeb:
        return Vector<ArgumentDescription> {
            {"string", "String", nullptr, false},
        };
#endif
#if HAVE(TOUCH_BAR)
    case MessageName::WebPageProxy_TouchBarMenuDataChanged:
        return Vector<ArgumentDescription> {
            {"touchBarMenuData", "WebKit::TouchBarMenuData", nullptr, false},
        };
    case MessageName::WebPageProxy_TouchBarMenuItemDataAdded:
        return Vector<ArgumentDescription> {
            {"touchBarMenuItemData", "WebKit::TouchBarMenuItemData", nullptr, false},
        };
    case MessageName::WebPageProxy_TouchBarMenuItemDataRemoved:
        return Vector<ArgumentDescription> {
            {"touchBarMenuItemData", "WebKit::TouchBarMenuItemData", nullptr, false},
        };
#endif
#if USE(APPKIT)
    case MessageName::WebPageProxy_SubstitutionsPanelIsShowing:
        return Vector<ArgumentDescription> { };
#endif
#if USE(AUTOMATIC_TEXT_REPLACEMENT)
    case MessageName::WebPageProxy_toggleSmartInsertDelete:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_toggleAutomaticQuoteSubstitution:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_toggleAutomaticLinkDetection:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_toggleAutomaticDashSubstitution:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_toggleAutomaticTextReplacement:
        return Vector<ArgumentDescription> { };
#endif
#if PLATFORM(MAC)
    case MessageName::WebPageProxy_ShowCorrectionPanel:
        return Vector<ArgumentDescription> {
            {"panelType", "int32_t", nullptr, false},
            {"boundingBoxOfReplacedString", "WebCore::FloatRect", nullptr, false},
            {"replacedString", "String", nullptr, false},
            {"replacementString", "String", nullptr, false},
            {"alternativeReplacementStrings", "Vector<String>", nullptr, false},
        };
    case MessageName::WebPageProxy_DismissCorrectionPanel:
        return Vector<ArgumentDescription> {
            {"reason", "int32_t", nullptr, false},
        };
    case MessageName::WebPageProxy_DismissCorrectionPanelSoon:
        return Vector<ArgumentDescription> {
            {"reason", "int32_t", nullptr, false},
        };
    case MessageName::WebPageProxy_RecordAutocorrectionResponse:
        return Vector<ArgumentDescription> {
            {"response", "int32_t", nullptr, false},
            {"replacedString", "String", nullptr, false},
            {"replacementString", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_SetEditableElementIsFocused:
        return Vector<ArgumentDescription> {
            {"editableElementIsFocused", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_HandleAcceptsFirstMouse:
        return Vector<ArgumentDescription> {
            {"acceptsFirstMouse", "bool", nullptr, false},
        };
#endif
    case MessageName::WebPageProxy_DidUpdateRenderingAfterCommittingLoad:
        return Vector<ArgumentDescription> { };
#if USE(DICTATION_ALTERNATIVES)
    case MessageName::WebPageProxy_ShowDictationAlternativeUI:
        return Vector<ArgumentDescription> {
            {"boundingBoxOfDictatedText", "WebCore::FloatRect", nullptr, false},
            {"dictationContext", "WebCore::DictationContext", nullptr, false},
        };
    case MessageName::WebPageProxy_RemoveDictationAlternatives:
        return Vector<ArgumentDescription> {
            {"dictationContext", "WebCore::DictationContext", nullptr, false},
        };
    case MessageName::WebPageProxy_DictationAlternatives:
        return Vector<ArgumentDescription> {
            {"dictationContext", "WebCore::DictationContext", nullptr, false},
        };
#endif
#if PLATFORM(IOS_FAMILY)
    case MessageName::WebPageProxy_CouldNotRestorePageState:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_RestorePageState:
        return Vector<ArgumentDescription> {
            {"scrollPosition", "WebCore::FloatPoint", nullptr, true},
            {"scrollOrigin", "WebCore::FloatPoint", nullptr, false},
            {"obscuredInsetsOnSave", "WebCore::RectEdges<float>", nullptr, false},
            {"scale", "double", nullptr, false},
        };
    case MessageName::WebPageProxy_RestorePageCenterAndScale:
        return Vector<ArgumentDescription> {
            {"unobscuredCenter", "WebCore::FloatPoint", nullptr, true},
            {"scale", "double", nullptr, false},
        };
    case MessageName::WebPageProxy_DidGetTapHighlightGeometries:
        return Vector<ArgumentDescription> {
            {"requestID", "WebKit::TapIdentifier", nullptr, false},
            {"color", "WebCore::Color", nullptr, false},
            {"geometries", "Vector<WebCore::FloatQuad>", nullptr, false},
            {"topLeftRadius", "WebCore::IntSize", nullptr, false},
            {"topRightRadius", "WebCore::IntSize", nullptr, false},
            {"bottomLeftRadius", "WebCore::IntSize", nullptr, false},
            {"bottomRightRadius", "WebCore::IntSize", nullptr, false},
            {"nodeHasBuiltInClickHandling", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_ElementDidFocus:
        return Vector<ArgumentDescription> {
            {"information", "WebKit::FocusedElementInformation", nullptr, false},
            {"userIsInteracting", "bool", nullptr, false},
            {"blurPreviousNode", "bool", nullptr, false},
            {"activityStateChanges", "OptionSet<WebCore::ActivityState::Flag>", nullptr, false},
            {"userData", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebPageProxy_ElementDidBlur:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_UpdateInputContextAfterBlurringAndRefocusingElement:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_FocusedElementDidChangeInputMode:
        return Vector<ArgumentDescription> {
            {"mode", "uint8_t", "WebCore::InputMode", false},
        };
    case MessageName::WebPageProxy_ScrollingNodeScrollWillStartScroll:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_ScrollingNodeScrollDidEndScroll:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_ShowInspectorHighlight:
        return Vector<ArgumentDescription> {
            {"highlight", "WebCore::InspectorOverlay::Highlight", nullptr, false},
        };
    case MessageName::WebPageProxy_HideInspectorHighlight:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_ShowInspectorIndication:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_HideInspectorIndication:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_EnableInspectorNodeSearch:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_DisableInspectorNodeSearch:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_UpdateStringForFind:
        return Vector<ArgumentDescription> {
            {"findString", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_HandleAutocorrectionContext:
        return Vector<ArgumentDescription> {
            {"context", "WebKit::WebAutocorrectionContext", nullptr, false},
        };
    case MessageName::WebPageProxy_ShowDataDetectorsUIForPositionInformation:
        return Vector<ArgumentDescription> {
            {"information", "WebKit::InteractionInformationAtPosition", nullptr, false},
        };
#endif
    case MessageName::WebPageProxy_DidChangeInspectorFrontendCount:
        return Vector<ArgumentDescription> {
            {"count", "uint64_t", nullptr, false},
        };
    case MessageName::WebPageProxy_CreateInspectorTarget:
        return Vector<ArgumentDescription> {
            {"targetId", "String", nullptr, false},
            {"type", "uint8_t", "Inspector::InspectorTargetType", false},
        };
    case MessageName::WebPageProxy_DestroyInspectorTarget:
        return Vector<ArgumentDescription> {
            {"targetId", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_SendMessageToInspectorFrontend:
        return Vector<ArgumentDescription> {
            {"targetId", "String", nullptr, false},
            {"message", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_SaveRecentSearches:
        return Vector<ArgumentDescription> {
            {"name", "String", nullptr, false},
            {"searchItems", "Vector<WebCore::RecentSearch>", nullptr, false},
        };
    case MessageName::WebPageProxy_LoadRecentSearches:
        return Vector<ArgumentDescription> {
            {"name", "String", nullptr, false},
        };
#if ENABLE(PDFKIT_PLUGIN) && !ENABLE(UI_PROCESS_PDF_HUD)
    case MessageName::WebPageProxy_SavePDFToFileInDownloadsFolder:
        return Vector<ArgumentDescription> {
            {"suggestedFilename", "String", nullptr, false},
            {"originatingURL", "URL", nullptr, false},
            {"data", "IPC::DataReference", nullptr, false},
        };
    case MessageName::WebPageProxy_SavePDFToTemporaryFolderAndOpenWithNativeApplication:
        return Vector<ArgumentDescription> {
            {"suggestedFilename", "String", nullptr, false},
            {"sourceFrameInfo", "WebKit::FrameInfoData", nullptr, false},
            {"data", "IPC::DataReference", nullptr, false},
            {"pdfUUID", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_OpenPDFFromTemporaryFolderWithNativeApplication:
        return Vector<ArgumentDescription> {
            {"sourceFrameInfo", "WebKit::FrameInfoData", nullptr, false},
            {"pdfUUID", "String", nullptr, false},
        };
#endif
#if ENABLE(PDFKIT_PLUGIN)
    case MessageName::WebPageProxy_ShowPDFContextMenu:
        return Vector<ArgumentDescription> {
            {"contextMenu", "WebKit::PDFContextMenu", nullptr, false},
            {"identifier", "WebKit::PDFPluginIdentifier", nullptr, false},
        };
#endif
    case MessageName::WebPageProxy_DidUpdateActivityState:
        return Vector<ArgumentDescription> { };
#if ENABLE(WEB_CRYPTO)
    case MessageName::WebPageProxy_WrapCryptoKey:
        return Vector<ArgumentDescription> {
            {"key", "Vector<uint8_t>", nullptr, false},
        };
    case MessageName::WebPageProxy_UnwrapCryptoKey:
        return Vector<ArgumentDescription> {
            {"wrappedKey", "Vector<uint8_t>", nullptr, false},
        };
#endif
#if (ENABLE(TELEPHONE_NUMBER_DETECTION) && PLATFORM(MAC))
    case MessageName::WebPageProxy_ShowTelephoneNumberMenu:
        return Vector<ArgumentDescription> {
            {"telephoneNumber", "String", nullptr, false},
            {"point", "WebCore::IntPoint", nullptr, false},
            {"rect", "WebCore::IntRect", nullptr, false},
        };
#endif
#if USE(QUICK_LOOK)
    case MessageName::WebPageProxy_DidStartLoadForQuickLookDocumentInMainFrame:
        return Vector<ArgumentDescription> {
            {"fileName", "String", nullptr, false},
            {"uti", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_DidFinishLoadForQuickLookDocumentInMainFrame:
        return Vector<ArgumentDescription> {
            {"resource", "WebKit::ShareableResource::Handle", nullptr, false},
        };
    case MessageName::WebPageProxy_RequestPasswordForQuickLookDocumentInMainFrame:
        return Vector<ArgumentDescription> {
            {"fileName", "String", nullptr, false},
        };
#endif
#if ENABLE(CONTENT_FILTERING)
    case MessageName::WebPageProxy_ContentFilterDidBlockLoadForFrame:
        return Vector<ArgumentDescription> {
            {"unblockHandler", "WebCore::ContentFilterUnblockHandler", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
        };
#endif
    case MessageName::WebPageProxy_IsPlayingMediaDidChange:
        return Vector<ArgumentDescription> {
            {"state", "OptionSet<WebCore::MediaProducerMediaState>", nullptr, false},
        };
    case MessageName::WebPageProxy_HandleAutoplayEvent:
        return Vector<ArgumentDescription> {
            {"event", "uint8_t", "WebCore::AutoplayEvent", false},
            {"flags", "OptionSet<WebCore::AutoplayEventFlags>", nullptr, false},
        };
#if PLATFORM(MAC)
    case MessageName::WebPageProxy_DidPerformImmediateActionHitTest:
        return Vector<ArgumentDescription> {
            {"result", "WebKit::WebHitTestResultData", nullptr, false},
            {"contentPreventsDefault", "bool", nullptr, false},
            {"userData", "WebKit::UserData", nullptr, false},
        };
#endif
    case MessageName::WebPageProxy_HandleMessage:
        return Vector<ArgumentDescription> {
            {"messageName", "String", nullptr, false},
            {"messageBody", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebPageProxy_HandleSynchronousMessage:
        return Vector<ArgumentDescription> {
            {"messageName", "String", nullptr, false},
            {"messageBody", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebPageProxy_HandleAutoFillButtonClick:
        return Vector<ArgumentDescription> {
            {"userData", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebPageProxy_DidResignInputElementStrongPasswordAppearance:
        return Vector<ArgumentDescription> {
            {"userData", "WebKit::UserData", nullptr, false},
        };
#if ENABLE(CONTENT_EXTENSIONS)
    case MessageName::WebPageProxy_ContentRuleListNotification:
        return Vector<ArgumentDescription> {
            {"url", "URL", nullptr, false},
            {"results", "WebCore::ContentRuleListResults", nullptr, false},
        };
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    case MessageName::WebPageProxy_AddPlaybackTargetPickerClient:
        return Vector<ArgumentDescription> {
            {"contextId", "WebCore::PlaybackTargetClientContextIdentifier", nullptr, false},
        };
    case MessageName::WebPageProxy_RemovePlaybackTargetPickerClient:
        return Vector<ArgumentDescription> {
            {"contextId", "WebCore::PlaybackTargetClientContextIdentifier", nullptr, false},
        };
    case MessageName::WebPageProxy_ShowPlaybackTargetPicker:
        return Vector<ArgumentDescription> {
            {"contextId", "WebCore::PlaybackTargetClientContextIdentifier", nullptr, false},
            {"pickerLocation", "WebCore::FloatRect", nullptr, false},
            {"hasVideo", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_PlaybackTargetPickerClientStateDidChange:
        return Vector<ArgumentDescription> {
            {"contextId", "WebCore::PlaybackTargetClientContextIdentifier", nullptr, false},
            {"mediaState", "OptionSet<WebCore::MediaProducerMediaState>", nullptr, false},
        };
    case MessageName::WebPageProxy_SetMockMediaPlaybackTargetPickerEnabled:
        return Vector<ArgumentDescription> {
            {"enabled", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_SetMockMediaPlaybackTargetPickerState:
        return Vector<ArgumentDescription> {
            {"name", "String", nullptr, false},
            {"pickerState", "uint8_t", "WebCore::MediaPlaybackTargetContext::MockState", false},
        };
    case MessageName::WebPageProxy_MockMediaPlaybackTargetPickerDismissPopup:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(VIDEO_PRESENTATION_MODE)
    case MessageName::WebPageProxy_SetMockVideoPresentationModeEnabled:
        return Vector<ArgumentDescription> {
            {"enabled", "bool", nullptr, false},
        };
#endif
#if ENABLE(POINTER_LOCK)
    case MessageName::WebPageProxy_RequestPointerLock:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_RequestPointerUnlock:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebPageProxy_DidFailToSuspendAfterProcessSwap:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_DidSuspendAfterProcessSwap:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_ImageOrMediaDocumentSizeChanged:
        return Vector<ArgumentDescription> {
            {"newSize", "WebCore::IntSize", nullptr, false},
        };
    case MessageName::WebPageProxy_UseFixedLayoutDidChange:
        return Vector<ArgumentDescription> {
            {"useFixedLayout", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_FixedLayoutSizeDidChange:
        return Vector<ArgumentDescription> {
            {"fixedLayoutSize", "WebCore::IntSize", nullptr, false},
        };
#if ENABLE(VIDEO) && USE(GSTREAMER)
    case MessageName::WebPageProxy_RequestInstallMissingMediaPlugins:
        return Vector<ArgumentDescription> {
            {"details", "String", nullptr, false},
            {"description", "String", nullptr, false},
        };
#endif
    case MessageName::WebPageProxy_DidRestoreScrollPosition:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_RequestScrollToRect:
        return Vector<ArgumentDescription> {
            {"targetRect", "WebCore::FloatRect", nullptr, false},
            {"origin", "WebCore::FloatPoint", nullptr, false},
        };
    case MessageName::WebPageProxy_GetLoadDecisionForIcon:
        return Vector<ArgumentDescription> {
            {"icon", "WebCore::LinkIcon", nullptr, false},
            {"callbackID", "WebKit::CallbackID", nullptr, false},
        };
#if PLATFORM(MAC)
    case MessageName::WebPageProxy_DidHandleAcceptedCandidate:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebPageProxy_SetIsUsingHighPerformanceWebGL:
        return Vector<ArgumentDescription> {
            {"isUsingHighPerformanceWebGL", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_StartURLSchemeTask:
        return Vector<ArgumentDescription> {
            {"parameters", "WebKit::URLSchemeTaskParameters", nullptr, false},
        };
    case MessageName::WebPageProxy_StopURLSchemeTask:
        return Vector<ArgumentDescription> {
            {"handlerIdentifier", "WebKit::WebURLSchemeHandlerIdentifier", nullptr, false},
            {"taskIdentifier", "WebCore::ResourceLoaderIdentifier", nullptr, false},
        };
    case MessageName::WebPageProxy_LoadSynchronousURLSchemeTask:
        return Vector<ArgumentDescription> {
            {"parameters", "WebKit::URLSchemeTaskParameters", nullptr, false},
        };
#if ENABLE(DEVICE_ORIENTATION)
    case MessageName::WebPageProxy_ShouldAllowDeviceOrientationAndMotionAccess:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"frameInfo", "WebKit::FrameInfoData", nullptr, false},
            {"mayPrompt", "bool", nullptr, false},
        };
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    case MessageName::WebPageProxy_RegisterAttachmentIdentifierFromData:
        return Vector<ArgumentDescription> {
            {"identifier", "String", nullptr, false},
            {"contentType", "String", nullptr, false},
            {"preferredFileName", "String", nullptr, false},
            {"data", "IPC::SharedBufferCopy", nullptr, false},
        };
    case MessageName::WebPageProxy_RegisterAttachmentIdentifierFromFilePath:
        return Vector<ArgumentDescription> {
            {"identifier", "String", nullptr, false},
            {"contentType", "String", nullptr, false},
            {"filePath", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_RegisterAttachmentIdentifier:
        return Vector<ArgumentDescription> {
            {"identifier", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_RegisterAttachmentsFromSerializedData:
        return Vector<ArgumentDescription> {
            {"data", "Vector<WebCore::SerializedAttachmentData>", nullptr, false},
        };
    case MessageName::WebPageProxy_CloneAttachmentData:
        return Vector<ArgumentDescription> {
            {"fromIdentifier", "String", nullptr, false},
            {"toIdentifier", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_DidInsertAttachmentWithIdentifier:
        return Vector<ArgumentDescription> {
            {"identifier", "String", nullptr, false},
            {"source", "String", nullptr, false},
            {"hasEnclosingImage", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_DidRemoveAttachmentWithIdentifier:
        return Vector<ArgumentDescription> {
            {"identifier", "String", nullptr, false},
        };
    case MessageName::WebPageProxy_SerializedAttachmentDataForIdentifiers:
        return Vector<ArgumentDescription> {
            {"identifiers", "Vector<String>", nullptr, false},
        };
    case MessageName::WebPageProxy_WritePromisedAttachmentToPasteboard:
        return Vector<ArgumentDescription> {
            {"info", "WebCore::PromisedAttachmentInfo", nullptr, false},
        };
    case MessageName::WebPageProxy_RequestAttachmentIcon:
        return Vector<ArgumentDescription> {
            {"identifier", "String", nullptr, false},
            {"contentType", "String", nullptr, false},
            {"path", "String", nullptr, false},
            {"title", "String", nullptr, false},
            {"size", "WebCore::FloatSize", nullptr, false},
        };
#endif
#if ENABLE(APP_HIGHLIGHTS)
    case MessageName::WebPageProxy_StoreAppHighlight:
        return Vector<ArgumentDescription> {
            {"info", "WebCore::AppHighlight", nullptr, false},
        };
#endif
    case MessageName::WebPageProxy_SignedPublicKeyAndChallengeString:
        return Vector<ArgumentDescription> {
            {"keySizeIndex", "unsigned", nullptr, false},
            {"challengeString", "String", nullptr, false},
            {"url", "URL", nullptr, false},
        };
#if ENABLE(SPEECH_SYNTHESIS)
    case MessageName::WebPageProxy_SpeechSynthesisVoiceList:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_SpeechSynthesisSpeak:
        return Vector<ArgumentDescription> {
            {"text", "String", nullptr, false},
            {"lang", "String", nullptr, false},
            {"volume", "float", nullptr, false},
            {"rate", "float", nullptr, false},
            {"pitch", "float", nullptr, false},
            {"startTime", "MonotonicTime", nullptr, false},
            {"voiceURI", "String", nullptr, false},
            {"voiceName", "String", nullptr, false},
            {"voiceLang", "String", nullptr, false},
            {"localService", "bool", nullptr, false},
            {"defaultVoice", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_SpeechSynthesisSetFinishedCallback:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_SpeechSynthesisCancel:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_SpeechSynthesisPause:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_SpeechSynthesisResume:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_SpeechSynthesisResetState:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(UI_PROCESS_PDF_HUD)
    case MessageName::WebPageProxy_CreatePDFHUD:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::PDFPluginIdentifier", nullptr, false},
            {"boundingBox", "WebCore::IntRect", nullptr, false},
        };
    case MessageName::WebPageProxy_UpdatePDFHUDLocation:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::PDFPluginIdentifier", nullptr, false},
            {"boundingBox", "WebCore::IntRect", nullptr, false},
        };
    case MessageName::WebPageProxy_RemovePDFHUD:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::PDFPluginIdentifier", nullptr, false},
        };
#endif
    case MessageName::WebPageProxy_ConfigureLoggingChannel:
        return Vector<ArgumentDescription> {
            {"channelName", "String", nullptr, false},
            {"state", "uint8_t", "WTFLogChannelState", false},
            {"level", "uint8_t", "WTFLogLevel", false},
        };
#if PLATFORM(GTK)
    case MessageName::WebPageProxy_ShowEmojiPicker:
        return Vector<ArgumentDescription> {
            {"caretRect", "WebCore::IntRect", nullptr, false},
        };
#endif
#if HAVE(VISIBILITY_PROPAGATION_VIEW)
    case MessageName::WebPageProxy_DidCreateContextInWebProcessForVisibilityPropagation:
        return Vector<ArgumentDescription> {
            {"contextID", "WebKit::LayerHostingContextID", nullptr, false},
        };
#endif
#if ENABLE(WEB_AUTHN)
    case MessageName::WebPageProxy_SetMockWebAuthenticationConfiguration:
        return Vector<ArgumentDescription> {
            {"configuration", "WebCore::MockWebAuthenticationConfiguration", nullptr, false},
        };
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    case MessageName::WebPageProxy_SendMessageToWebView:
        return Vector<ArgumentDescription> {
            {"userMessage", "WebKit::UserMessage", nullptr, false},
        };
    case MessageName::WebPageProxy_SendMessageToWebViewWithReply:
        return Vector<ArgumentDescription> {
            {"userMessage", "WebKit::UserMessage", nullptr, false},
        };
#endif
    case MessageName::WebPageProxy_DidFindTextManipulationItems:
        return Vector<ArgumentDescription> {
            {"items", "Vector<WebCore::TextManipulationController::ManipulationItem>", nullptr, false},
        };
#if ENABLE(MEDIA_USAGE)
    case MessageName::WebPageProxy_AddMediaUsageManagerSession:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::MediaSessionIdentifier", nullptr, false},
            {"bundleIdentifier", "String", nullptr, false},
            {"pageURL", "URL", nullptr, false},
        };
    case MessageName::WebPageProxy_UpdateMediaUsageManagerSessionState:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::MediaSessionIdentifier", nullptr, false},
            {"info", "WebCore::MediaUsageInfo", nullptr, false},
        };
    case MessageName::WebPageProxy_RemoveMediaUsageManagerSession:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::MediaSessionIdentifier", nullptr, false},
        };
#endif
    case MessageName::WebPageProxy_SetHasExecutedAppBoundBehaviorBeforeNavigation:
        return Vector<ArgumentDescription> { };
#if PLATFORM(MAC)
    case MessageName::WebPageProxy_ChangeUniversalAccessZoomFocus:
        return Vector<ArgumentDescription> {
            {"viewRect", "WebCore::IntRect", nullptr, false},
            {"caretRect", "WebCore::IntRect", nullptr, false},
        };
#endif
#if ENABLE(ARKIT_INLINE_PREVIEW_IOS)
    case MessageName::WebPageProxy_TakeModelElementFullscreen:
        return Vector<ArgumentDescription> {
            {"modelIdentifier", "WebKit::ModelIdentifier", nullptr, false},
        };
    case MessageName::WebPageProxy_ModelElementSetInteractionEnabled:
        return Vector<ArgumentDescription> {
            {"modelIdentifier", "WebKit::ModelIdentifier", nullptr, false},
            {"isInteractionEnabled", "bool", nullptr, false},
        };
#endif
#if ENABLE(ARKIT_INLINE_PREVIEW_MAC)
    case MessageName::WebPageProxy_ModelElementDidCreatePreview:
        return Vector<ArgumentDescription> {
            {"url", "URL", nullptr, false},
            {"uuid", "String", nullptr, false},
            {"size", "WebCore::FloatSize", nullptr, false},
        };
    case MessageName::WebPageProxy_ModelElementSizeDidChange:
        return Vector<ArgumentDescription> {
            {"uuid", "String", nullptr, false},
            {"size", "WebCore::FloatSize", nullptr, false},
        };
    case MessageName::WebPageProxy_HandleMouseDownForModelElement:
        return Vector<ArgumentDescription> {
            {"uuid", "String", nullptr, false},
            {"flippedLocationInElement", "WebCore::LayoutPoint", nullptr, false},
            {"timestamp", "MonotonicTime", nullptr, false},
        };
    case MessageName::WebPageProxy_HandleMouseMoveForModelElement:
        return Vector<ArgumentDescription> {
            {"uuid", "String", nullptr, false},
            {"flippedLocationInElement", "WebCore::LayoutPoint", nullptr, false},
            {"timestamp", "MonotonicTime", nullptr, false},
        };
    case MessageName::WebPageProxy_HandleMouseUpForModelElement:
        return Vector<ArgumentDescription> {
            {"uuid", "String", nullptr, false},
            {"flippedLocationInElement", "WebCore::LayoutPoint", nullptr, false},
            {"timestamp", "MonotonicTime", nullptr, false},
        };
#endif
#if ENABLE(ARKIT_INLINE_PREVIEW)
    case MessageName::WebPageProxy_ModelElementGetCamera:
        return Vector<ArgumentDescription> {
            {"modelIdentifier", "WebKit::ModelIdentifier", nullptr, false},
        };
    case MessageName::WebPageProxy_ModelElementSetCamera:
        return Vector<ArgumentDescription> {
            {"modelIdentifier", "WebKit::ModelIdentifier", nullptr, false},
            {"camera", "WebCore::HTMLModelElementCamera", nullptr, false},
        };
    case MessageName::WebPageProxy_ModelElementIsPlayingAnimation:
        return Vector<ArgumentDescription> {
            {"modelIdentifier", "WebKit::ModelIdentifier", nullptr, false},
        };
    case MessageName::WebPageProxy_ModelElementSetAnimationIsPlaying:
        return Vector<ArgumentDescription> {
            {"modelIdentifier", "WebKit::ModelIdentifier", nullptr, false},
            {"isPlaying", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_ModelElementIsLoopingAnimation:
        return Vector<ArgumentDescription> {
            {"modelIdentifier", "WebKit::ModelIdentifier", nullptr, false},
        };
    case MessageName::WebPageProxy_ModelElementSetIsLoopingAnimation:
        return Vector<ArgumentDescription> {
            {"modelIdentifier", "WebKit::ModelIdentifier", nullptr, false},
            {"isLooping", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_ModelElementAnimationDuration:
        return Vector<ArgumentDescription> {
            {"modelIdentifier", "WebKit::ModelIdentifier", nullptr, false},
        };
    case MessageName::WebPageProxy_ModelElementAnimationCurrentTime:
        return Vector<ArgumentDescription> {
            {"modelIdentifier", "WebKit::ModelIdentifier", nullptr, false},
        };
    case MessageName::WebPageProxy_ModelElementSetAnimationCurrentTime:
        return Vector<ArgumentDescription> {
            {"modelIdentifier", "WebKit::ModelIdentifier", nullptr, false},
            {"currentTime", "Seconds", nullptr, false},
        };
    case MessageName::WebPageProxy_ModelElementHasAudio:
        return Vector<ArgumentDescription> {
            {"modelIdentifier", "WebKit::ModelIdentifier", nullptr, false},
        };
    case MessageName::WebPageProxy_ModelElementIsMuted:
        return Vector<ArgumentDescription> {
            {"modelIdentifier", "WebKit::ModelIdentifier", nullptr, false},
        };
    case MessageName::WebPageProxy_ModelElementSetIsMuted:
        return Vector<ArgumentDescription> {
            {"modelIdentifier", "WebKit::ModelIdentifier", nullptr, false},
            {"isMuted", "bool", nullptr, false},
        };
#endif
    case MessageName::WebPageProxy_QueryPermission:
        return Vector<ArgumentDescription> {
            {"origin", "WebCore::ClientOrigin", nullptr, false},
            {"descriptor", "WebCore::PermissionDescriptor", nullptr, false},
        };
#if ENABLE(APPLE_PAY_AMS_UI)
    case MessageName::WebPageProxy_StartApplePayAMSUISession:
        return Vector<ArgumentDescription> {
            {"originatingURL", "URL", nullptr, false},
            {"request", "WebCore::ApplePayAMSUIRequest", nullptr, false},
        };
    case MessageName::WebPageProxy_AbortApplePayAMSUISession:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebPageProxy_RequestCookieConsent:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_ClassifyModalContainerControls:
        return Vector<ArgumentDescription> {
            {"texts", "Vector<String>", nullptr, false},
        };
    case MessageName::WebPageProxy_DecidePolicyForModalContainer:
        return Vector<ArgumentDescription> {
            {"types", "OptionSet<WebCore::ModalContainerControlType>", nullptr, false},
        };
#if PLATFORM(IOS_FAMILY)
    case MessageName::WebPasteboardProxy_WriteURLToPasteboard:
        return Vector<ArgumentDescription> {
            {"url", "WebCore::PasteboardURL", nullptr, false},
            {"pasteboardName", "String", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_WriteWebContentToPasteboard:
        return Vector<ArgumentDescription> {
            {"content", "WebCore::PasteboardWebContent", nullptr, false},
            {"pasteboardName", "String", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_WriteImageToPasteboard:
        return Vector<ArgumentDescription> {
            {"pasteboardImage", "WebCore::PasteboardImage", nullptr, false},
            {"pasteboardName", "String", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_WriteStringToPasteboard:
        return Vector<ArgumentDescription> {
            {"pasteboardType", "String", nullptr, false},
            {"text", "String", nullptr, false},
            {"pasteboardName", "String", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_UpdateSupportedTypeIdentifiers:
        return Vector<ArgumentDescription> {
            {"identifiers", "Vector<String>", nullptr, false},
            {"pasteboardName", "String", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
#endif
    case MessageName::WebPasteboardProxy_WriteCustomData:
        return Vector<ArgumentDescription> {
            {"data", "Vector<WebCore::PasteboardCustomData>", nullptr, false},
            {"pasteboardName", "String", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_TypesSafeForDOMToReadAndWrite:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
            {"origin", "String", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_AllPasteboardItemInfo:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
            {"changeCount", "int64_t", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_InformationForItemAtIndex:
        return Vector<ArgumentDescription> {
            {"index", "uint64_t", nullptr, false},
            {"pasteboardName", "String", nullptr, false},
            {"changeCount", "int64_t", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_GetPasteboardItemsCount:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_ReadStringFromPasteboard:
        return Vector<ArgumentDescription> {
            {"index", "uint64_t", nullptr, false},
            {"pasteboardType", "String", nullptr, false},
            {"pasteboardName", "String", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_ReadURLFromPasteboard:
        return Vector<ArgumentDescription> {
            {"index", "uint64_t", nullptr, false},
            {"pasteboardName", "String", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_ReadBufferFromPasteboard:
        return Vector<ArgumentDescription> {
            {"index", "uint64_t", nullptr, true},
            {"pasteboardType", "String", nullptr, false},
            {"pasteboardName", "String", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_ContainsStringSafeForDOMToReadForType:
        return Vector<ArgumentDescription> {
            {"type", "String", nullptr, false},
            {"pasteboardName", "String", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
#if PLATFORM(COCOA)
    case MessageName::WebPasteboardProxy_GetNumberOfFiles:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_GetPasteboardTypes:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_GetPasteboardPathnamesForType:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
            {"pasteboardType", "String", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_GetPasteboardStringForType:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
            {"pasteboardType", "String", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_GetPasteboardStringsForType:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
            {"pasteboardType", "String", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_GetPasteboardBufferForType:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
            {"pasteboardType", "String", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_GetPasteboardChangeCount:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_GetPasteboardColor:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_GetPasteboardURL:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_AddPasteboardTypes:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
            {"pasteboardTypes", "Vector<String>", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_SetPasteboardTypes:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
            {"pasteboardTypes", "Vector<String>", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_SetPasteboardURL:
        return Vector<ArgumentDescription> {
            {"pasteboardURL", "WebCore::PasteboardURL", nullptr, false},
            {"pasteboardName", "String", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_SetPasteboardColor:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
            {"color", "WebCore::Color", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_SetPasteboardStringForType:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
            {"pasteboardType", "String", nullptr, false},
            {"string", "String", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_SetPasteboardBufferForType:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
            {"pasteboardType", "String", nullptr, false},
            {"handle", "WebKit::SharedMemory::IPCHandle", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_ContainsURLStringSuitableForLoading:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_URLStringSuitableForLoading:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, true},
        };
#endif
#if PLATFORM(GTK)
    case MessageName::WebPasteboardProxy_GetTypes:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_ReadText:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_ReadFilePaths:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_ReadBuffer:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
            {"pasteboardType", "String", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_WriteToClipboard:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
            {"pasteboardContent", "WebCore::SelectionData", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_ClearClipboard:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
        };
#endif
#if USE(LIBWPE)
    case MessageName::WebPasteboardProxy_GetPasteboardTypes:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPasteboardProxy_WriteWebContentToPasteboard:
        return Vector<ArgumentDescription> {
            {"content", "WebCore::PasteboardWebContent", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_WriteStringToPasteboard:
        return Vector<ArgumentDescription> {
            {"pasteboardType", "String", nullptr, false},
            {"text", "String", nullptr, false},
        };
#endif
    case MessageName::WebProcessPool_HandleMessage:
        return Vector<ArgumentDescription> {
            {"messageName", "String", nullptr, false},
            {"messageBody", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebProcessPool_HandleSynchronousMessage:
        return Vector<ArgumentDescription> {
            {"messageName", "String", nullptr, false},
            {"messageBody", "WebKit::UserData", nullptr, false},
        };
#if ENABLE(GAMEPAD)
    case MessageName::WebProcessPool_StartedUsingGamepads:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcessPool_StoppedUsingGamepads:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebProcessPool_ReportWebContentCPUTime:
        return Vector<ArgumentDescription> {
            {"cpuTime", "Seconds", nullptr, false},
            {"activityState", "uint64_t", nullptr, false},
        };
    case MessageName::WebProcessProxy_UpdateBackForwardItem:
        return Vector<ArgumentDescription> {
            {"backForwardListItemState", "WebKit::BackForwardListItemState", nullptr, false},
        };
    case MessageName::WebProcessProxy_DidDestroyFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
        };
    case MessageName::WebProcessProxy_DidDestroyUserGestureToken:
        return Vector<ArgumentDescription> {
            {"userGestureTokenID", "uint64_t", nullptr, false},
        };
    case MessageName::WebProcessProxy_ShouldTerminate:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcessProxy_EnableSuddenTermination:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcessProxy_DisableSuddenTermination:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcessProxy_GetNetworkProcessConnection:
        return Vector<ArgumentDescription> { };
#if ENABLE(GPU_PROCESS)
    case MessageName::WebProcessProxy_GetGPUProcessConnection:
        return Vector<ArgumentDescription> {
            {"parameters", "WebKit::GPUProcessConnectionParameters", nullptr, false},
        };
#endif
#if ENABLE(WEB_AUTHN)
    case MessageName::WebProcessProxy_GetWebAuthnProcessConnection:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebProcessProxy_SetIsHoldingLockedFiles:
        return Vector<ArgumentDescription> {
            {"isHoldingLockedFiles", "bool", nullptr, false},
        };
    case MessageName::WebProcessProxy_DidExceedActiveMemoryLimit:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcessProxy_DidExceedInactiveMemoryLimit:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcessProxy_DidExceedCPULimit:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcessProxy_StopResponsivenessTimer:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcessProxy_DidReceiveBackgroundResponsivenessPing:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcessProxy_MemoryPressureStatusChanged:
        return Vector<ArgumentDescription> {
            {"isUnderMemoryPressure", "bool", nullptr, false},
        };
    case MessageName::WebProcessProxy_DidExceedInactiveMemoryLimitWhileActive:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcessProxy_DidCollectPrewarmInformation:
        return Vector<ArgumentDescription> {
            {"domain", "WebCore::RegistrableDomain", nullptr, false},
            {"prewarmInformation", "WebCore::PrewarmInformation", nullptr, false},
        };
#if PLATFORM(COCOA)
    case MessageName::WebProcessProxy_CacheMediaMIMETypes:
        return Vector<ArgumentDescription> {
            {"types", "Vector<String>", nullptr, false},
        };
#endif
#if PLATFORM(MAC)
    case MessageName::WebProcessProxy_RequestHighPerformanceGPU:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcessProxy_ReleaseHighPerformanceGPU:
        return Vector<ArgumentDescription> { };
#endif
#if HAVE(CVDISPLAYLINK)
    case MessageName::WebProcessProxy_StartDisplayLink:
        return Vector<ArgumentDescription> {
            {"observerID", "WebKit::DisplayLinkObserverID", nullptr, false},
            {"displayID", "uint32_t", nullptr, false},
            {"preferredFramesPerSecond", "unsigned", nullptr, false},
        };
    case MessageName::WebProcessProxy_StopDisplayLink:
        return Vector<ArgumentDescription> {
            {"observerID", "WebKit::DisplayLinkObserverID", nullptr, false},
            {"displayID", "uint32_t", nullptr, false},
        };
    case MessageName::WebProcessProxy_SetDisplayLinkPreferredFramesPerSecond:
        return Vector<ArgumentDescription> {
            {"observerID", "WebKit::DisplayLinkObserverID", nullptr, false},
            {"displayID", "uint32_t", nullptr, false},
            {"preferredFramesPerSecond", "unsigned", nullptr, false},
        };
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    case MessageName::WebProcessProxy_SendMessageToWebContext:
        return Vector<ArgumentDescription> {
            {"userMessage", "WebKit::UserMessage", nullptr, false},
        };
    case MessageName::WebProcessProxy_SendMessageToWebContextWithReply:
        return Vector<ArgumentDescription> {
            {"userMessage", "WebKit::UserMessage", nullptr, false},
        };
#endif
    case MessageName::WebProcessProxy_DidCreateSleepDisabler:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::SleepDisablerIdentifier", nullptr, false},
            {"reason", "String", nullptr, false},
            {"display", "bool", nullptr, false},
        };
    case MessageName::WebProcessProxy_DidDestroySleepDisabler:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::SleepDisablerIdentifier", nullptr, false},
        };
    case MessageName::WebProcessProxy_CreateSpeechRecognitionServer:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::PageIdentifier", nullptr, false},
        };
    case MessageName::WebProcessProxy_DestroySpeechRecognitionServer:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::PageIdentifier", nullptr, false},
        };
    case MessageName::WebProcessProxy_SystemBeep:
        return Vector<ArgumentDescription> { };
#if PLATFORM(MAC)
    case MessageName::WebProcessProxy_IsAXAuthenticated:
        return Vector<ArgumentDescription> {
            {"auditToken", "audit_token_t", nullptr, false},
        };
#endif
#if HAVE(MEDIA_ACCESSIBILITY_FRAMEWORK)
    case MessageName::WebProcessProxy_SetCaptionDisplayMode:
        return Vector<ArgumentDescription> {
            {"mode", "WebCore::CaptionUserPreferences::CaptionDisplayMode", nullptr, false},
        };
    case MessageName::WebProcessProxy_SetCaptionLanguage:
        return Vector<ArgumentDescription> {
            {"language", "String", nullptr, false},
        };
#endif
    case MessageName::WebAutomationSession_DidEvaluateJavaScriptFunction:
        return Vector<ArgumentDescription> {
            {"callbackID", "uint64_t", nullptr, false},
            {"result", "String", nullptr, false},
            {"errorType", "String", nullptr, false},
        };
    case MessageName::WebAutomationSession_DidTakeScreenshot:
        return Vector<ArgumentDescription> {
            {"callbackID", "uint64_t", nullptr, false},
            {"imageDataHandle", "WebKit::ShareableBitmap::Handle", nullptr, false},
            {"errorType", "String", nullptr, false},
        };
    case MessageName::DownloadProxy_DidStart:
        return Vector<ArgumentDescription> {
            {"request", "WebCore::ResourceRequest", nullptr, false},
            {"suggestedFilename", "AtomString", nullptr, false},
        };
    case MessageName::DownloadProxy_DidReceiveAuthenticationChallenge:
        return Vector<ArgumentDescription> {
            {"challenge", "WebCore::AuthenticationChallenge", nullptr, false},
            {"challengeID", "WebKit::AuthenticationChallengeIdentifier", nullptr, false},
        };
    case MessageName::DownloadProxy_WillSendRequest:
        return Vector<ArgumentDescription> {
            {"redirectRequest", "WebCore::ResourceRequest", nullptr, false},
            {"redirectResponse", "WebCore::ResourceResponse", nullptr, false},
        };
    case MessageName::DownloadProxy_DecideDestinationWithSuggestedFilename:
        return Vector<ArgumentDescription> {
            {"response", "WebCore::ResourceResponse", nullptr, false},
            {"suggestedFilename", "String", nullptr, false},
        };
    case MessageName::DownloadProxy_DidReceiveData:
        return Vector<ArgumentDescription> {
            {"bytesWritten", "uint64_t", nullptr, false},
            {"totalBytesWritten", "uint64_t", nullptr, false},
            {"totalBytesExpectedToWrite", "uint64_t", nullptr, false},
        };
    case MessageName::DownloadProxy_DidCreateDestination:
        return Vector<ArgumentDescription> {
            {"path", "String", nullptr, false},
        };
    case MessageName::DownloadProxy_DidFinish:
        return Vector<ArgumentDescription> { };
    case MessageName::DownloadProxy_DidFail:
        return Vector<ArgumentDescription> {
            {"error", "WebCore::ResourceError", nullptr, false},
            {"resumeData", "IPC::DataReference", nullptr, false},
        };
#if ENABLE(GPU_PROCESS)
#if HAVE(VISIBILITY_PROPAGATION_VIEW)
    case MessageName::GPUProcessProxy_DidCreateContextForVisibilityPropagation:
        return Vector<ArgumentDescription> {
            {"pageProxyID", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
            {"contextID", "WebKit::LayerHostingContextID", nullptr, false},
        };
#endif
    case MessageName::GPUProcessProxy_ProcessIsReadyToExit:
        return Vector<ArgumentDescription> { };
    case MessageName::GPUProcessProxy_TerminateWebProcess:
        return Vector<ArgumentDescription> {
            {"webProcessIdentifier", "WebCore::ProcessIdentifier", nullptr, false},
        };
#endif
    case MessageName::RemoteWebInspectorUIProxy_FrontendLoaded:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteWebInspectorUIProxy_FrontendDidClose:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteWebInspectorUIProxy_Reopen:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteWebInspectorUIProxy_ResetState:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteWebInspectorUIProxy_BringToFront:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteWebInspectorUIProxy_Save:
        return Vector<ArgumentDescription> {
            {"filename", "String", nullptr, false},
            {"content", "String", nullptr, false},
            {"base64Encoded", "bool", nullptr, false},
            {"forceSaveAs", "bool", nullptr, false},
        };
    case MessageName::RemoteWebInspectorUIProxy_Append:
        return Vector<ArgumentDescription> {
            {"filename", "String", nullptr, false},
            {"content", "String", nullptr, false},
        };
    case MessageName::RemoteWebInspectorUIProxy_SetForcedAppearance:
        return Vector<ArgumentDescription> {
            {"appearance", "WebCore::InspectorFrontendClient::Appearance", nullptr, false},
        };
    case MessageName::RemoteWebInspectorUIProxy_SetSheetRect:
        return Vector<ArgumentDescription> {
            {"rect", "WebCore::FloatRect", nullptr, false},
        };
    case MessageName::RemoteWebInspectorUIProxy_StartWindowDrag:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteWebInspectorUIProxy_OpenURLExternally:
        return Vector<ArgumentDescription> {
            {"url", "String", nullptr, false},
        };
    case MessageName::RemoteWebInspectorUIProxy_ShowCertificate:
        return Vector<ArgumentDescription> {
            {"certificateInfo", "WebCore::CertificateInfo", nullptr, false},
        };
    case MessageName::RemoteWebInspectorUIProxy_SendMessageToBackend:
        return Vector<ArgumentDescription> {
            {"message", "String", nullptr, false},
        };
    case MessageName::WebInspectorUIProxy_OpenLocalInspectorFrontend:
        return Vector<ArgumentDescription> {
            {"canAttach", "bool", nullptr, false},
            {"underTest", "bool", nullptr, false},
        };
    case MessageName::WebInspectorUIProxy_SetFrontendConnection:
        return Vector<ArgumentDescription> {
            {"connectionIdentifier", "IPC::Attachment", nullptr, false},
        };
    case MessageName::WebInspectorUIProxy_SendMessageToBackend:
        return Vector<ArgumentDescription> {
            {"message", "String", nullptr, false},
        };
    case MessageName::WebInspectorUIProxy_FrontendLoaded:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspectorUIProxy_DidClose:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspectorUIProxy_BringToFront:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspectorUIProxy_BringInspectedPageToFront:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspectorUIProxy_Reopen:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspectorUIProxy_ResetState:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspectorUIProxy_SetForcedAppearance:
        return Vector<ArgumentDescription> {
            {"appearance", "WebCore::InspectorFrontendClient::Appearance", nullptr, false},
        };
    case MessageName::WebInspectorUIProxy_OpenURLExternally:
        return Vector<ArgumentDescription> {
            {"url", "String", nullptr, false},
        };
    case MessageName::WebInspectorUIProxy_InspectedURLChanged:
        return Vector<ArgumentDescription> {
            {"urlString", "String", nullptr, false},
        };
    case MessageName::WebInspectorUIProxy_ShowCertificate:
        return Vector<ArgumentDescription> {
            {"certificateInfo", "WebCore::CertificateInfo", nullptr, false},
        };
    case MessageName::WebInspectorUIProxy_ElementSelectionChanged:
        return Vector<ArgumentDescription> {
            {"active", "bool", nullptr, false},
        };
    case MessageName::WebInspectorUIProxy_TimelineRecordingChanged:
        return Vector<ArgumentDescription> {
            {"active", "bool", nullptr, false},
        };
    case MessageName::WebInspectorUIProxy_SetDeveloperPreferenceOverride:
        return Vector<ArgumentDescription> {
            {"developerPreference", "WebCore::InspectorClient::DeveloperPreference", nullptr, false},
            {"overrideValue", "bool", nullptr, true},
        };
    case MessageName::WebInspectorUIProxy_Save:
        return Vector<ArgumentDescription> {
            {"filename", "String", nullptr, false},
            {"content", "String", nullptr, false},
            {"base64Encoded", "bool", nullptr, false},
            {"forceSaveAs", "bool", nullptr, false},
        };
    case MessageName::WebInspectorUIProxy_Append:
        return Vector<ArgumentDescription> {
            {"filename", "String", nullptr, false},
            {"content", "String", nullptr, false},
        };
    case MessageName::WebInspectorUIProxy_AttachBottom:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspectorUIProxy_AttachRight:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspectorUIProxy_AttachLeft:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspectorUIProxy_Detach:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspectorUIProxy_AttachAvailabilityChanged:
        return Vector<ArgumentDescription> {
            {"available", "bool", nullptr, false},
        };
    case MessageName::WebInspectorUIProxy_SetAttachedWindowHeight:
        return Vector<ArgumentDescription> {
            {"height", "unsigned", nullptr, false},
        };
    case MessageName::WebInspectorUIProxy_SetAttachedWindowWidth:
        return Vector<ArgumentDescription> {
            {"width", "unsigned", nullptr, false},
        };
    case MessageName::WebInspectorUIProxy_SetSheetRect:
        return Vector<ArgumentDescription> {
            {"rect", "WebCore::FloatRect", nullptr, false},
        };
    case MessageName::WebInspectorUIProxy_StartWindowDrag:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcessProxy_DidReceiveAuthenticationChallenge:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"pageID", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"topOrigin", "WebCore::SecurityOriginData", nullptr, true},
            {"challenge", "WebCore::AuthenticationChallenge", nullptr, false},
            {"negotiatedLegacyTLS", "bool", nullptr, false},
            {"challengeID", "WebKit::AuthenticationChallengeIdentifier", nullptr, false},
        };
    case MessageName::NetworkProcessProxy_NegotiatedLegacyTLS:
        return Vector<ArgumentDescription> {
            {"pageID", "WebKit::WebPageProxyIdentifier", nullptr, false},
        };
    case MessageName::NetworkProcessProxy_DidNegotiateModernTLS:
        return Vector<ArgumentDescription> {
            {"pageID", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"url", "URL", nullptr, false},
        };
    case MessageName::NetworkProcessProxy_TestProcessIncomingSyncMessagesWhenWaitingForSyncReply:
        return Vector<ArgumentDescription> {
            {"pageID", "WebKit::WebPageProxyIdentifier", nullptr, false},
        };
    case MessageName::NetworkProcessProxy_TerminateUnresponsiveServiceWorkerProcesses:
        return Vector<ArgumentDescription> {
            {"processIdentifier", "WebCore::ProcessIdentifier", nullptr, false},
        };
    case MessageName::NetworkProcessProxy_LogDiagnosticMessage:
        return Vector<ArgumentDescription> {
            {"pageID", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"message", "String", nullptr, false},
            {"description", "String", nullptr, false},
            {"shouldSample", "bool", "WebCore::ShouldSample", false},
        };
    case MessageName::NetworkProcessProxy_LogDiagnosticMessageWithResult:
        return Vector<ArgumentDescription> {
            {"pageID", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"message", "String", nullptr, false},
            {"description", "String", nullptr, false},
            {"result", "uint32_t", nullptr, false},
            {"shouldSample", "bool", "WebCore::ShouldSample", false},
        };
    case MessageName::NetworkProcessProxy_LogDiagnosticMessageWithValue:
        return Vector<ArgumentDescription> {
            {"pageID", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"message", "String", nullptr, false},
            {"description", "String", nullptr, false},
            {"value", "double", nullptr, false},
            {"significantFigures", "unsigned", nullptr, false},
            {"shouldSample", "bool", "WebCore::ShouldSample", false},
        };
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
    case MessageName::NetworkProcessProxy_LogTestingEvent:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"event", "String", nullptr, false},
        };
    case MessageName::NetworkProcessProxy_NotifyResourceLoadStatisticsProcessed:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcessProxy_NotifyWebsiteDataDeletionForRegistrableDomainsFinished:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcessProxy_NotifyWebsiteDataScanForRegistrableDomainsFinished:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcessProxy_RequestStorageAccessConfirm:
        return Vector<ArgumentDescription> {
            {"pageID", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"subFrameDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"topFrameDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
    case MessageName::NetworkProcessProxy_DeleteWebsiteDataInUIProcessForRegistrableDomains:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"dataTypes", "OptionSet<WebKit::WebsiteDataType>", nullptr, false},
            {"fetchOptions", "OptionSet<WebKit::WebsiteDataFetchOption>", nullptr, false},
            {"domains", "Vector<WebCore::RegistrableDomain>", nullptr, false},
        };
    case MessageName::NetworkProcessProxy_DidCommitCrossSiteLoadWithDataTransferFromPrevalentResource:
        return Vector<ArgumentDescription> {
            {"pageID", "WebKit::WebPageProxyIdentifier", nullptr, false},
        };
    case MessageName::NetworkProcessProxy_SetDomainsWithUserInteraction:
        return Vector<ArgumentDescription> {
            {"domains", "HashSet<WebCore::RegistrableDomain>", nullptr, false},
        };
    case MessageName::NetworkProcessProxy_SetDomainsWithCrossPageStorageAccess:
        return Vector<ArgumentDescription> {
            {"domains", "HashMap<WebCore::RegistrableDomain, WebCore::RegistrableDomain>", nullptr, false},
        };
#endif
#if ENABLE(CONTENT_EXTENSIONS)
    case MessageName::NetworkProcessProxy_ContentExtensionRules:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::UserContentControllerIdentifier", nullptr, false},
        };
#endif
    case MessageName::NetworkProcessProxy_RetrieveCacheStorageParameters:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcessProxy_TerminateWebProcess:
        return Vector<ArgumentDescription> {
            {"webProcessIdentifier", "WebCore::ProcessIdentifier", nullptr, false},
        };
#if ENABLE(SERVICE_WORKER)
    case MessageName::NetworkProcessProxy_EstablishServiceWorkerContextConnectionToNetworkProcess:
        return Vector<ArgumentDescription> {
            {"registrableDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"serviceWorkerPageIdentifier", "WebCore::ScriptExecutionContextIdentifier", nullptr, true},
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcessProxy_StartServiceWorkerBackgroundProcessing:
        return Vector<ArgumentDescription> {
            {"serviceWorkerProcessIdentifier", "WebCore::ProcessIdentifier", nullptr, false},
        };
    case MessageName::NetworkProcessProxy_EndServiceWorkerBackgroundProcessing:
        return Vector<ArgumentDescription> {
            {"serviceWorkerProcessIdentifier", "WebCore::ProcessIdentifier", nullptr, false},
        };
#endif
    case MessageName::NetworkProcessProxy_EstablishSharedWorkerContextConnectionToNetworkProcess:
        return Vector<ArgumentDescription> {
            {"registrableDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
    case MessageName::NetworkProcessProxy_RemoteWorkerContextConnectionNoLongerNeeded:
        return Vector<ArgumentDescription> {
            {"workerType", "uint32_t", "WebKit::RemoteWorkerType", false},
            {"identifier", "WebCore::ProcessIdentifier", nullptr, false},
        };
    case MessageName::NetworkProcessProxy_RegisterRemoteWorkerClientProcess:
        return Vector<ArgumentDescription> {
            {"workerType", "uint32_t", "WebKit::RemoteWorkerType", false},
            {"webProcessIdentifier", "WebCore::ProcessIdentifier", nullptr, false},
            {"remoteWorkerProcessIdentifier", "WebCore::ProcessIdentifier", nullptr, false},
        };
    case MessageName::NetworkProcessProxy_UnregisterRemoteWorkerClientProcess:
        return Vector<ArgumentDescription> {
            {"workerType", "uint32_t", "WebKit::RemoteWorkerType", false},
            {"webProcessIdentifier", "WebCore::ProcessIdentifier", nullptr, false},
            {"remoteWorkerProcessIdentifier", "WebCore::ProcessIdentifier", nullptr, false},
        };
    case MessageName::NetworkProcessProxy_SetWebProcessHasUploads:
        return Vector<ArgumentDescription> {
            {"processID", "WebCore::ProcessIdentifier", nullptr, false},
            {"hasUpload", "bool", nullptr, false},
        };
#if ENABLE(APP_BOUND_DOMAINS)
    case MessageName::NetworkProcessProxy_GetAppBoundDomains:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
        };
#endif
    case MessageName::NetworkProcessProxy_RequestStorageSpace:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"origin", "WebCore::ClientOrigin", nullptr, false},
            {"quota", "uint64_t", nullptr, false},
            {"currentSize", "uint64_t", nullptr, false},
            {"spaceRequired", "uint64_t", nullptr, false},
        };
    case MessageName::NetworkProcessProxy_IncreaseQuota:
        return Vector<ArgumentDescription> {
            {"sessionID", "PAL::SessionID", nullptr, false},
            {"origin", "WebCore::ClientOrigin", nullptr, false},
            {"identifier", "WebKit::QuotaIncreaseRequestIdentifier", nullptr, false},
            {"quota", "uint64_t", nullptr, false},
            {"currentSize", "uint64_t", nullptr, false},
            {"spaceRequested", "uint64_t", nullptr, false},
        };
    case MessageName::NetworkProcessProxy_ResourceLoadDidSendRequest:
        return Vector<ArgumentDescription> {
            {"pageIdentifier", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"resourceLoadInfo", "WebKit::ResourceLoadInfo", nullptr, false},
            {"request", "WebCore::ResourceRequest", nullptr, false},
            {"httpBody", "IPC::FormDataReference", nullptr, true},
        };
    case MessageName::NetworkProcessProxy_ResourceLoadDidPerformHTTPRedirection:
        return Vector<ArgumentDescription> {
            {"pageIdentifier", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"resourceLoadInfo", "WebKit::ResourceLoadInfo", nullptr, false},
            {"resourceResponse", "WebCore::ResourceResponse", nullptr, false},
            {"request", "WebCore::ResourceRequest", nullptr, false},
        };
    case MessageName::NetworkProcessProxy_ResourceLoadDidReceiveChallenge:
        return Vector<ArgumentDescription> {
            {"pageIdentifier", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"resourceLoadInfo", "WebKit::ResourceLoadInfo", nullptr, false},
            {"challenge", "WebCore::AuthenticationChallenge", nullptr, false},
        };
    case MessageName::NetworkProcessProxy_ResourceLoadDidReceiveResponse:
        return Vector<ArgumentDescription> {
            {"pageIdentifier", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"resourceLoadInfo", "WebKit::ResourceLoadInfo", nullptr, false},
            {"response", "WebCore::ResourceResponse", nullptr, false},
        };
    case MessageName::NetworkProcessProxy_ResourceLoadDidCompleteWithError:
        return Vector<ArgumentDescription> {
            {"pageIdentifier", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"resourceLoadInfo", "WebKit::ResourceLoadInfo", nullptr, false},
            {"response", "WebCore::ResourceResponse", nullptr, false},
            {"error", "WebCore::ResourceError", nullptr, false},
        };
#if ENABLE(CONTENT_FILTERING_IN_NETWORKING_PROCESS)
    case MessageName::NetworkProcessProxy_ReloadAfterUnblockedContentFilter:
        return Vector<ArgumentDescription> {
            {"pageIdentifier", "WebKit::WebPageProxyIdentifier", nullptr, false},
        };
#endif
    case MessageName::NetworkProcessProxy_TriggerBrowsingContextGroupSwitchForNavigation:
        return Vector<ArgumentDescription> {
            {"pageIdentifier", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"navigationID", "uint64_t", nullptr, false},
            {"browsingContextGroupSwitchDecision", "uint8_t", "WebCore::BrowsingContextGroupSwitchDecision", false},
            {"responseDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"existingNetworkResourceLoadIdentifierToResume", "WebKit::NetworkResourceLoadIdentifier", nullptr, false},
        };
#if USE(SOUP)
    case MessageName::NetworkProcessProxy_DidExceedMemoryLimit:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(APPLE_PAY_REMOTE_UI_USES_SCENE)
    case MessageName::NetworkProcessProxy_GetWindowSceneIdentifierForPaymentPresentation:
        return Vector<ArgumentDescription> {
            {"webPageProxyIdentifier", "WebKit::WebPageProxyIdentifier", nullptr, false},
        };
#endif
    case MessageName::WebUserContentControllerProxy_DidPostMessage:
        return Vector<ArgumentDescription> {
            {"pageID", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"frameInfoData", "WebKit::FrameInfoData", nullptr, false},
            {"messageHandlerID", "uint64_t", nullptr, false},
            {"message", "IPC::DataReference", nullptr, false},
        };
#if ENABLE(WEBXR)
    case MessageName::PlatformXRSystem_EnumerateImmersiveXRDevices:
        return Vector<ArgumentDescription> { };
    case MessageName::PlatformXRSystem_RequestPermissionOnSessionFeatures:
        return Vector<ArgumentDescription> {
            {"origin", "WebCore::SecurityOriginData", nullptr, false},
            {"mode", "PlatformXR::SessionMode", nullptr, false},
            {"granted", "Vector<PlatformXR::ReferenceSpaceType>", nullptr, false},
            {"consentRequired", "Vector<PlatformXR::ReferenceSpaceType>", nullptr, false},
            {"consentOptional", "Vector<PlatformXR::ReferenceSpaceType>", nullptr, false},
        };
    case MessageName::PlatformXRSystem_InitializeTrackingAndRendering:
        return Vector<ArgumentDescription> { };
    case MessageName::PlatformXRSystem_ShutDownTrackingAndRendering:
        return Vector<ArgumentDescription> { };
    case MessageName::PlatformXRSystem_RequestFrame:
        return Vector<ArgumentDescription> { };
    case MessageName::PlatformXRSystem_SubmitFrame:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebProcess_InitializeWebProcess:
        return Vector<ArgumentDescription> {
            {"processCreationParameters", "WebKit::WebProcessCreationParameters", nullptr, false},
        };
    case MessageName::WebProcess_SetWebsiteDataStoreParameters:
        return Vector<ArgumentDescription> {
            {"parameters", "WebKit::WebProcessDataStoreParameters", nullptr, false},
        };
    case MessageName::WebProcess_CreateWebPage:
        return Vector<ArgumentDescription> {
            {"newPageID", "WebCore::PageIdentifier", nullptr, false},
            {"pageCreationParameters", "WebKit::WebPageCreationParameters", nullptr, false},
        };
    case MessageName::WebProcess_PrewarmWithDomainInformation:
        return Vector<ArgumentDescription> {
            {"prewarmInformation", "WebCore::PrewarmInformation", nullptr, false},
        };
    case MessageName::WebProcess_SetCacheModel:
        return Vector<ArgumentDescription> {
            {"cacheModel", "uint8_t", "WebKit::CacheModel", false},
        };
    case MessageName::WebProcess_RegisterURLSchemeAsEmptyDocument:
        return Vector<ArgumentDescription> {
            {"scheme", "String", nullptr, false},
        };
    case MessageName::WebProcess_RegisterURLSchemeAsSecure:
        return Vector<ArgumentDescription> {
            {"scheme", "String", nullptr, false},
        };
    case MessageName::WebProcess_RegisterURLSchemeAsBypassingContentSecurityPolicy:
        return Vector<ArgumentDescription> {
            {"scheme", "String", nullptr, false},
        };
    case MessageName::WebProcess_SetDomainRelaxationForbiddenForURLScheme:
        return Vector<ArgumentDescription> {
            {"scheme", "String", nullptr, false},
        };
    case MessageName::WebProcess_RegisterURLSchemeAsLocal:
        return Vector<ArgumentDescription> {
            {"scheme", "String", nullptr, false},
        };
    case MessageName::WebProcess_RegisterURLSchemeAsNoAccess:
        return Vector<ArgumentDescription> {
            {"scheme", "String", nullptr, false},
        };
    case MessageName::WebProcess_RegisterURLSchemeAsDisplayIsolated:
        return Vector<ArgumentDescription> {
            {"scheme", "String", nullptr, false},
        };
    case MessageName::WebProcess_RegisterURLSchemeAsCORSEnabled:
        return Vector<ArgumentDescription> {
            {"scheme", "String", nullptr, false},
        };
    case MessageName::WebProcess_RegisterURLSchemeAsCachePartitioned:
        return Vector<ArgumentDescription> {
            {"scheme", "String", nullptr, false},
        };
    case MessageName::WebProcess_RegisterURLSchemeAsCanDisplayOnlyIfCanRequest:
        return Vector<ArgumentDescription> {
            {"scheme", "String", nullptr, false},
        };
    case MessageName::WebProcess_SetDefaultRequestTimeoutInterval:
        return Vector<ArgumentDescription> {
            {"timeoutInterval", "double", nullptr, false},
        };
    case MessageName::WebProcess_SetAlwaysUsesComplexTextCodePath:
        return Vector<ArgumentDescription> {
            {"alwaysUseComplexText", "bool", nullptr, false},
        };
    case MessageName::WebProcess_SetShouldUseFontSmoothing:
        return Vector<ArgumentDescription> {
            {"useFontSmoothing", "bool", nullptr, false},
        };
    case MessageName::WebProcess_SetResourceLoadStatisticsEnabled:
        return Vector<ArgumentDescription> {
            {"resourceLoadStatisticsEnabled", "bool", nullptr, false},
        };
    case MessageName::WebProcess_ClearResourceLoadStatistics:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcess_UserPreferredLanguagesChanged:
        return Vector<ArgumentDescription> {
            {"languages", "Vector<String>", nullptr, false},
        };
    case MessageName::WebProcess_FullKeyboardAccessModeChanged:
        return Vector<ArgumentDescription> {
            {"fullKeyboardAccessEnabled", "bool", nullptr, false},
        };
#if HAVE(MOUSE_DEVICE_OBSERVATION)
    case MessageName::WebProcess_SetHasMouseDevice:
        return Vector<ArgumentDescription> {
            {"hasMouseDevice", "bool", nullptr, false},
        };
#endif
#if HAVE(STYLUS_DEVICE_OBSERVATION)
    case MessageName::WebProcess_SetHasStylusDevice:
        return Vector<ArgumentDescription> {
            {"hasStylusDevice", "bool", nullptr, false},
        };
#endif
    case MessageName::WebProcess_RefreshPlugins:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcess_StartMemorySampler:
        return Vector<ArgumentDescription> {
            {"sampleLogFileHandle", "WebKit::SandboxExtension::Handle", nullptr, false},
            {"sampleLogFilePath", "String", nullptr, false},
            {"interval", "double", nullptr, false},
        };
    case MessageName::WebProcess_StopMemorySampler:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcess_SetTextCheckerState:
        return Vector<ArgumentDescription> {
            {"textCheckerState", "WebKit::TextCheckerState", nullptr, false},
        };
    case MessageName::WebProcess_SetEnhancedAccessibility:
        return Vector<ArgumentDescription> {
            {"flag", "bool", nullptr, false},
        };
    case MessageName::WebProcess_GarbageCollectJavaScriptObjects:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcess_SetJavaScriptGarbageCollectorTimerEnabled:
        return Vector<ArgumentDescription> {
            {"enable", "bool", nullptr, false},
        };
    case MessageName::WebProcess_SetInjectedBundleParameter:
        return Vector<ArgumentDescription> {
            {"parameter", "String", nullptr, false},
            {"value", "IPC::DataReference", nullptr, false},
        };
    case MessageName::WebProcess_SetInjectedBundleParameters:
        return Vector<ArgumentDescription> {
            {"parameters", "IPC::DataReference", nullptr, false},
        };
    case MessageName::WebProcess_HandleInjectedBundleMessage:
        return Vector<ArgumentDescription> {
            {"messageName", "String", nullptr, false},
            {"messageBody", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebProcess_FetchWebsiteData:
        return Vector<ArgumentDescription> {
            {"websiteDataTypes", "OptionSet<WebKit::WebsiteDataType>", nullptr, false},
        };
    case MessageName::WebProcess_DeleteWebsiteData:
        return Vector<ArgumentDescription> {
            {"websiteDataTypes", "OptionSet<WebKit::WebsiteDataType>", nullptr, false},
            {"modifiedSince", "WallTime", nullptr, false},
        };
    case MessageName::WebProcess_DeleteWebsiteDataForOrigins:
        return Vector<ArgumentDescription> {
            {"websiteDataTypes", "OptionSet<WebKit::WebsiteDataType>", nullptr, false},
            {"origins", "Vector<WebCore::SecurityOriginData>", nullptr, false},
        };
    case MessageName::WebProcess_SetHiddenPageDOMTimerThrottlingIncreaseLimit:
        return Vector<ArgumentDescription> {
            {"milliseconds", "int", nullptr, false},
        };
    case MessageName::WebProcess_SetMemoryCacheDisabled:
        return Vector<ArgumentDescription> {
            {"disabled", "bool", nullptr, false},
        };
#if ENABLE(SERVICE_CONTROLS)
    case MessageName::WebProcess_SetEnabledServices:
        return Vector<ArgumentDescription> {
            {"hasImageServices", "bool", nullptr, false},
            {"hasSelectionServices", "bool", nullptr, false},
            {"hasRichContentServices", "bool", nullptr, false},
        };
#endif
    case MessageName::WebProcess_EnsureAutomationSessionProxy:
        return Vector<ArgumentDescription> {
            {"sessionIdentifier", "String", nullptr, false},
        };
    case MessageName::WebProcess_DestroyAutomationSessionProxy:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcess_PrepareToSuspend:
        return Vector<ArgumentDescription> {
            {"isSuspensionImminent", "bool", nullptr, false},
        };
    case MessageName::WebProcess_ProcessDidResume:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcess_BackgroundResponsivenessPing:
        return Vector<ArgumentDescription> { };
#if ENABLE(GAMEPAD)
    case MessageName::WebProcess_SetInitialGamepads:
        return Vector<ArgumentDescription> {
            {"gamepadDatas", "Vector<WebKit::GamepadData>", nullptr, false},
        };
    case MessageName::WebProcess_GamepadConnected:
        return Vector<ArgumentDescription> {
            {"gamepadData", "WebKit::GamepadData", nullptr, false},
            {"eventVisibility", "bool", "WebCore::EventMakesGamepadsVisible", false},
        };
    case MessageName::WebProcess_GamepadDisconnected:
        return Vector<ArgumentDescription> {
            {"index", "unsigned", nullptr, false},
        };
#endif
    case MessageName::WebProcess_EstablishSharedWorkerContextConnectionToNetworkProcess:
        return Vector<ArgumentDescription> {
            {"pageGroupID", "WebKit::PageGroupIdentifier", nullptr, false},
            {"webPageProxyID", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
            {"store", "WebKit::WebPreferencesStore", nullptr, false},
            {"domain", "WebCore::RegistrableDomain", nullptr, false},
            {"initializationData", "WebKit::RemoteWorkerInitializationData", nullptr, false},
        };
#if ENABLE(SERVICE_WORKER)
    case MessageName::WebProcess_EstablishServiceWorkerContextConnectionToNetworkProcess:
        return Vector<ArgumentDescription> {
            {"pageGroupID", "WebKit::PageGroupIdentifier", nullptr, false},
            {"webPageProxyID", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
            {"store", "WebKit::WebPreferencesStore", nullptr, false},
            {"domain", "WebCore::RegistrableDomain", nullptr, false},
            {"serviceWorkerPageIdentifier", "WebCore::ScriptExecutionContextIdentifier", nullptr, true},
            {"initializationData", "WebKit::RemoteWorkerInitializationData", nullptr, false},
        };
#endif
    case MessageName::WebProcess_SetHasSuspendedPageProxy:
        return Vector<ArgumentDescription> {
            {"hasSuspendedPageProxy", "bool", nullptr, false},
        };
    case MessageName::WebProcess_SetIsInProcessCache:
        return Vector<ArgumentDescription> {
            {"isInProcessCache", "bool", nullptr, false},
        };
    case MessageName::WebProcess_MarkIsNoLongerPrewarmed:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcess_GetActivePagesOriginsForTesting:
        return Vector<ArgumentDescription> { };
#if PLATFORM(COCOA)
    case MessageName::WebProcess_SetScreenProperties:
        return Vector<ArgumentDescription> {
            {"screenProperties", "WebCore::ScreenProperties", nullptr, false},
        };
#endif
#if PLATFORM(MAC)
    case MessageName::WebProcess_ScrollerStylePreferenceChanged:
        return Vector<ArgumentDescription> {
            {"useOvelayScrollbars", "bool", nullptr, false},
        };
    case MessageName::WebProcess_DisplayConfigurationChanged:
        return Vector<ArgumentDescription> {
            {"displayID", "CGDirectDisplayID", nullptr, false},
            {"flags", "CGDisplayChangeSummaryFlags", nullptr, false},
        };
#endif
#if PLATFORM(IOS_FAMILY)
    case MessageName::WebProcess_UserInterfaceIdiomDidChange:
        return Vector<ArgumentDescription> {
            {"isPhoneOrWatch", "bool", nullptr, false},
        };
#endif
#if PLATFORM(IOS_FAMILY) && !PLATFORM(MACCATALYST)
    case MessageName::WebProcess_BacklightLevelDidChange:
        return Vector<ArgumentDescription> {
            {"backlightLevel", "float", nullptr, false},
        };
#endif
#if PLATFORM(MAC) || PLATFORM(MACCATALYST)
    case MessageName::WebProcess_ColorPreferencesDidChange:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebProcess_IsJITEnabled:
        return Vector<ArgumentDescription> { };
#if PLATFORM(COCOA)
    case MessageName::WebProcess_SetMediaMIMETypes:
        return Vector<ArgumentDescription> {
            {"types", "Vector<String>", nullptr, false},
        };
#endif
#if (PLATFORM(COCOA) && ENABLE(REMOTE_INSPECTOR))
    case MessageName::WebProcess_EnableRemoteWebInspector:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(MEDIA_STREAM)
    case MessageName::WebProcess_AddMockMediaDevice:
        return Vector<ArgumentDescription> {
            {"device", "WebCore::MockMediaDevice", nullptr, false},
        };
    case MessageName::WebProcess_ClearMockMediaDevices:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcess_RemoveMockMediaDevice:
        return Vector<ArgumentDescription> {
            {"persistentId", "String", nullptr, false},
        };
    case MessageName::WebProcess_ResetMockMediaDevices:
        return Vector<ArgumentDescription> { };
#endif
#if (ENABLE(MEDIA_STREAM) && ENABLE(SANDBOX_EXTENSIONS))
    case MessageName::WebProcess_GrantUserMediaDeviceSandboxExtensions:
        return Vector<ArgumentDescription> {
            {"sandboxExtensions", "WebKit::MediaDeviceSandboxExtensions", nullptr, false},
        };
    case MessageName::WebProcess_RevokeUserMediaDeviceSandboxExtensions:
        return Vector<ArgumentDescription> {
            {"sandboxExtensionIDs", "Vector<String>", nullptr, false},
        };
#endif
    case MessageName::WebProcess_ClearCurrentModifierStateForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcess_SetBackForwardCacheCapacity:
        return Vector<ArgumentDescription> {
            {"capacity", "unsigned", nullptr, false},
        };
    case MessageName::WebProcess_ClearCachedPage:
        return Vector<ArgumentDescription> {
            {"backForwardItemID", "WebCore::BackForwardItemIdentifier", nullptr, false},
        };
#if PLATFORM(GTK) || PLATFORM(WPE)
    case MessageName::WebProcess_SendMessageToWebExtension:
        return Vector<ArgumentDescription> {
            {"userMessage", "WebKit::UserMessage", nullptr, false},
        };
#endif
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
    case MessageName::WebProcess_SeedResourceLoadStatisticsForTesting:
        return Vector<ArgumentDescription> {
            {"firstPartyDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"thirdPartyDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"shouldScheduleNotification", "bool", nullptr, false},
        };
    case MessageName::WebProcess_SetThirdPartyCookieBlockingMode:
        return Vector<ArgumentDescription> {
            {"blockingMode", "uint8_t", "WebCore::ThirdPartyCookieBlockingMode", false},
        };
    case MessageName::WebProcess_SetDomainsWithUserInteraction:
        return Vector<ArgumentDescription> {
            {"domains", "HashSet<WebCore::RegistrableDomain>", nullptr, false},
        };
    case MessageName::WebProcess_SetDomainsWithCrossPageStorageAccess:
        return Vector<ArgumentDescription> {
            {"domains", "HashMap<WebCore::RegistrableDomain, WebCore::RegistrableDomain>", nullptr, false},
        };
    case MessageName::WebProcess_SendResourceLoadStatisticsDataImmediately:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebProcess_GrantAccessToAssetServices:
        return Vector<ArgumentDescription> {
            {"mobileAssetV2Handle", "WebKit::SandboxExtension::Handle", nullptr, false},
        };
    case MessageName::WebProcess_RevokeAccessToAssetServices:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcess_SwitchFromStaticFontRegistryToUserFontRegistry:
        return Vector<ArgumentDescription> {
            {"fontMachExtensionHandle", "WebKit::SandboxExtension::Handle", nullptr, false},
        };
#if PLATFORM(COCOA)
    case MessageName::WebProcess_UnblockServicesRequiredByAccessibility:
        return Vector<ArgumentDescription> {
            {"handleArray", "Vector<WebKit::SandboxExtension::Handle>", nullptr, false},
        };
#endif
#if (PLATFORM(COCOA) && ENABLE(CFPREFS_DIRECT_MODE))
    case MessageName::WebProcess_NotifyPreferencesChanged:
        return Vector<ArgumentDescription> {
            {"domain", "String", nullptr, false},
            {"key", "String", nullptr, false},
            {"encodedValue", "String", nullptr, true},
        };
    case MessageName::WebProcess_UnblockPreferenceService:
        return Vector<ArgumentDescription> {
            {"handleArray", "Vector<WebKit::SandboxExtension::Handle>", nullptr, false},
        };
#endif
#if PLATFORM(COCOA)
    case MessageName::WebProcess_PowerSourceDidChange:
        return Vector<ArgumentDescription> {
            {"hasAC", "bool", nullptr, false},
        };
#endif
#if PLATFORM(GTK) && !USE(GTK4)
    case MessageName::WebProcess_SetUseSystemAppearanceForScrollbars:
        return Vector<ArgumentDescription> {
            {"useSystemAppearanceForScrollbars", "bool", nullptr, false},
        };
#endif
#if PLATFORM(COCOA)
    case MessageName::WebProcess_DidWriteToPasteboardAsynchronously:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
        };
#endif
#if HAVE(CVDISPLAYLINK)
    case MessageName::WebProcess_DisplayWasRefreshed:
        return Vector<ArgumentDescription> {
            {"displayID", "uint32_t", nullptr, false},
            {"update", "WebCore::DisplayUpdate", nullptr, false},
        };
#endif
#if PLATFORM(MAC)
    case MessageName::WebProcess_SystemWillPowerOn:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcess_SystemWillSleep:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcess_SystemDidWake:
        return Vector<ArgumentDescription> { };
#endif
#if PLATFORM(COCOA)
    case MessageName::WebProcess_ConsumeAudioComponentRegistrations:
        return Vector<ArgumentDescription> {
            {"registrationData", "IPC::SharedBufferCopy", nullptr, false},
        };
    case MessageName::WebProcess_AccessibilityPreferencesDidChange:
        return Vector<ArgumentDescription> {
            {"accessibilityPreferences", "WebKit::AccessibilityPreferences", nullptr, false},
        };
#endif
#if HAVE(MEDIA_ACCESSIBILITY_FRAMEWORK)
    case MessageName::WebProcess_SetMediaAccessibilityPreferences:
        return Vector<ArgumentDescription> {
            {"displayMode", "WebCore::CaptionUserPreferences::CaptionDisplayMode", nullptr, false},
            {"languages", "Vector<String>", nullptr, false},
        };
#endif
    case MessageName::WebAutomationSessionProxy_EvaluateJavaScriptFunction:
        return Vector<ArgumentDescription> {
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, true},
            {"function", "String", nullptr, false},
            {"arguments", "Vector<String>", nullptr, false},
            {"expectsImplicitCallbackArgument", "bool", nullptr, false},
            {"callbackTimeout", "double", nullptr, true},
            {"callbackID", "uint64_t", nullptr, false},
        };
    case MessageName::WebAutomationSessionProxy_ResolveChildFrameWithOrdinal:
        return Vector<ArgumentDescription> {
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, true},
            {"ordinal", "uint32_t", nullptr, false},
        };
    case MessageName::WebAutomationSessionProxy_ResolveChildFrameWithNodeHandle:
        return Vector<ArgumentDescription> {
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, true},
            {"nodeHandle", "String", nullptr, false},
        };
    case MessageName::WebAutomationSessionProxy_ResolveChildFrameWithName:
        return Vector<ArgumentDescription> {
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, true},
            {"name", "String", nullptr, false},
        };
    case MessageName::WebAutomationSessionProxy_ResolveParentFrame:
        return Vector<ArgumentDescription> {
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, true},
        };
    case MessageName::WebAutomationSessionProxy_ComputeElementLayout:
        return Vector<ArgumentDescription> {
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, true},
            {"nodeHandle", "String", nullptr, false},
            {"scrollIntoViewIfNeeded", "bool", nullptr, false},
            {"coordinateSystem", "uint8_t", "WebKit::CoordinateSystem", false},
        };
    case MessageName::WebAutomationSessionProxy_SelectOptionElement:
        return Vector<ArgumentDescription> {
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, true},
            {"nodeHandle", "String", nullptr, false},
        };
    case MessageName::WebAutomationSessionProxy_SetFilesForInputFileUpload:
        return Vector<ArgumentDescription> {
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, true},
            {"nodeHandle", "String", nullptr, false},
            {"filenames", "Vector<String>", nullptr, false},
        };
    case MessageName::WebAutomationSessionProxy_TakeScreenshot:
        return Vector<ArgumentDescription> {
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, true},
            {"nodeHandle", "String", nullptr, false},
            {"scrollIntoViewIfNeeded", "bool", nullptr, false},
            {"clipToViewport", "bool", nullptr, false},
            {"callbackID", "uint64_t", nullptr, false},
        };
    case MessageName::WebAutomationSessionProxy_SnapshotRectForScreenshot:
        return Vector<ArgumentDescription> {
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, true},
            {"nodeHandle", "String", nullptr, false},
            {"scrollIntoViewIfNeeded", "bool", nullptr, false},
            {"clipToViewport", "bool", nullptr, false},
        };
    case MessageName::WebAutomationSessionProxy_GetCookiesForFrame:
        return Vector<ArgumentDescription> {
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, true},
        };
    case MessageName::WebAutomationSessionProxy_DeleteCookie:
        return Vector<ArgumentDescription> {
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, true},
            {"cookieName", "String", nullptr, false},
        };
    case MessageName::WebIDBConnectionToServer_DidDeleteDatabase:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::IDBResultData", nullptr, false},
        };
    case MessageName::WebIDBConnectionToServer_DidOpenDatabase:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::IDBResultData", nullptr, false},
        };
    case MessageName::WebIDBConnectionToServer_DidAbortTransaction:
        return Vector<ArgumentDescription> {
            {"transactionIdentifier", "WebCore::IDBResourceIdentifier", nullptr, false},
            {"error", "WebCore::IDBError", nullptr, false},
        };
    case MessageName::WebIDBConnectionToServer_DidCommitTransaction:
        return Vector<ArgumentDescription> {
            {"transactionIdentifier", "WebCore::IDBResourceIdentifier", nullptr, false},
            {"error", "WebCore::IDBError", nullptr, false},
        };
    case MessageName::WebIDBConnectionToServer_DidCreateObjectStore:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::IDBResultData", nullptr, false},
        };
    case MessageName::WebIDBConnectionToServer_DidDeleteObjectStore:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::IDBResultData", nullptr, false},
        };
    case MessageName::WebIDBConnectionToServer_DidRenameObjectStore:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::IDBResultData", nullptr, false},
        };
    case MessageName::WebIDBConnectionToServer_DidClearObjectStore:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::IDBResultData", nullptr, false},
        };
    case MessageName::WebIDBConnectionToServer_DidCreateIndex:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::IDBResultData", nullptr, false},
        };
    case MessageName::WebIDBConnectionToServer_DidDeleteIndex:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::IDBResultData", nullptr, false},
        };
    case MessageName::WebIDBConnectionToServer_DidRenameIndex:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::IDBResultData", nullptr, false},
        };
    case MessageName::WebIDBConnectionToServer_DidPutOrAdd:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::IDBResultData", nullptr, false},
        };
    case MessageName::WebIDBConnectionToServer_DidGetRecord:
        return Vector<ArgumentDescription> {
            {"result", "WebKit::WebIDBResult", nullptr, false},
        };
    case MessageName::WebIDBConnectionToServer_DidGetAllRecords:
        return Vector<ArgumentDescription> {
            {"result", "WebKit::WebIDBResult", nullptr, false},
        };
    case MessageName::WebIDBConnectionToServer_DidGetCount:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::IDBResultData", nullptr, false},
        };
    case MessageName::WebIDBConnectionToServer_DidDeleteRecord:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::IDBResultData", nullptr, false},
        };
    case MessageName::WebIDBConnectionToServer_DidOpenCursor:
        return Vector<ArgumentDescription> {
            {"result", "WebKit::WebIDBResult", nullptr, false},
        };
    case MessageName::WebIDBConnectionToServer_DidIterateCursor:
        return Vector<ArgumentDescription> {
            {"result", "WebKit::WebIDBResult", nullptr, false},
        };
    case MessageName::WebIDBConnectionToServer_FireVersionChangeEvent:
        return Vector<ArgumentDescription> {
            {"databaseConnectionIdentifier", "uint64_t", nullptr, false},
            {"requestIdentifier", "WebCore::IDBResourceIdentifier", nullptr, false},
            {"requestedVersion", "uint64_t", nullptr, false},
        };
    case MessageName::WebIDBConnectionToServer_DidStartTransaction:
        return Vector<ArgumentDescription> {
            {"transactionIdentifier", "WebCore::IDBResourceIdentifier", nullptr, false},
            {"error", "WebCore::IDBError", nullptr, false},
        };
    case MessageName::WebIDBConnectionToServer_DidCloseFromServer:
        return Vector<ArgumentDescription> {
            {"databaseConnectionIdentifier", "uint64_t", nullptr, false},
            {"error", "WebCore::IDBError", nullptr, false},
        };
    case MessageName::WebIDBConnectionToServer_NotifyOpenDBRequestBlocked:
        return Vector<ArgumentDescription> {
            {"requestIdentifier", "WebCore::IDBResourceIdentifier", nullptr, false},
            {"oldVersion", "uint64_t", nullptr, false},
            {"newVersion", "uint64_t", nullptr, false},
        };
    case MessageName::WebIDBConnectionToServer_DidGetAllDatabaseNamesAndVersions:
        return Vector<ArgumentDescription> {
            {"requestIdentifier", "WebCore::IDBResourceIdentifier", nullptr, false},
            {"databases", "Vector<WebCore::IDBDatabaseNameAndVersion>", nullptr, false},
        };
#if ENABLE(FULLSCREEN_API)
    case MessageName::WebFullScreenManager_RequestEnterFullScreen:
        return Vector<ArgumentDescription> { };
    case MessageName::WebFullScreenManager_RequestExitFullScreen:
        return Vector<ArgumentDescription> { };
    case MessageName::WebFullScreenManager_WillEnterFullScreen:
        return Vector<ArgumentDescription> { };
    case MessageName::WebFullScreenManager_DidEnterFullScreen:
        return Vector<ArgumentDescription> { };
    case MessageName::WebFullScreenManager_WillExitFullScreen:
        return Vector<ArgumentDescription> { };
    case MessageName::WebFullScreenManager_DidExitFullScreen:
        return Vector<ArgumentDescription> { };
    case MessageName::WebFullScreenManager_SetAnimatingFullScreen:
        return Vector<ArgumentDescription> {
            {"animating", "bool", nullptr, false},
        };
    case MessageName::WebFullScreenManager_SaveScrollPosition:
        return Vector<ArgumentDescription> { };
    case MessageName::WebFullScreenManager_RestoreScrollPosition:
        return Vector<ArgumentDescription> { };
    case MessageName::WebFullScreenManager_SetFullscreenInsets:
        return Vector<ArgumentDescription> {
            {"insets", "WebCore::RectEdges<float>", nullptr, false},
        };
    case MessageName::WebFullScreenManager_SetFullscreenAutoHideDuration:
        return Vector<ArgumentDescription> {
            {"duration", "Seconds", nullptr, false},
        };
    case MessageName::WebFullScreenManager_SetFullscreenControlsHidden:
        return Vector<ArgumentDescription> {
            {"hidden", "bool", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::GPUProcessConnection_DidReceiveRemoteCommand:
        return Vector<ArgumentDescription> {
            {"type", "uint8_t", "WebCore::PlatformMediaSession::RemoteControlCommandType", false},
            {"argument", "WebCore::PlatformMediaSession::RemoteCommandArgument", nullptr, false},
        };
#if ENABLE(ROUTING_ARBITRATION)
    case MessageName::GPUProcessConnection_BeginRoutingArbitrationWithCategory:
        return Vector<ArgumentDescription> {
            {"category", "uint8_t", "WebCore::AudioSession::CategoryType", false},
        };
    case MessageName::GPUProcessConnection_EndRoutingArbitration:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(MEDIA_STREAM) && PLATFORM(COCOA)
    case MessageName::GPUProcessConnection_ResetAudioMediaStreamTrackRendererInternalUnit:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::AudioMediaStreamTrackRendererInternalUnitIdentifier", nullptr, false},
        };
#endif
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(WEBGL)
    case MessageName::RemoteGraphicsContextGLProxy_WasCreated:
        return Vector<ArgumentDescription> {
            {"didSucceed", "bool", nullptr, false},
            {"streamWakeUpSemaphore", "IPC::Semaphore", nullptr, false},
            {"availableExtensions", "String", nullptr, false},
            {"requestableExtensions", "String", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGLProxy_WasLost:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteGraphicsContextGLProxy_WasChanged:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteRenderingBackendProxy_DidCreateImageBufferBackend:
        return Vector<ArgumentDescription> {
            {"handle", "WebKit::ImageBufferBackendHandle", nullptr, false},
            {"renderingResourceIdentifier", "WebCore::RenderingResourceIdentifier", nullptr, false},
        };
    case MessageName::RemoteRenderingBackendProxy_DidFlush:
        return Vector<ArgumentDescription> {
            {"flushIdentifier", "WebCore::GraphicsContextFlushIdentifier", nullptr, false},
            {"renderingResourceIdentifier", "WebCore::RenderingResourceIdentifier", nullptr, false},
        };
    case MessageName::RemoteRenderingBackendProxy_DidFinalizeRenderingUpdate:
        return Vector<ArgumentDescription> {
            {"didRenderingUpdateID", "WebKit::RenderingUpdateID", nullptr, false},
        };
    case MessageName::RemoteRenderingBackendProxy_DidCreateWakeUpSemaphoreForDisplayListStream:
        return Vector<ArgumentDescription> {
            {"wakeUpSemaphore", "IPC::Semaphore", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteGPUProxy_WasCreated:
        return Vector<ArgumentDescription> {
            {"didSucceed", "bool", nullptr, false},
            {"streamWakeUpSemaphore", "IPC::Semaphore", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteAudioHardwareListener_AudioHardwareDidBecomeActive:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteAudioHardwareListener_AudioHardwareDidBecomeInactive:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteAudioHardwareListener_AudioOutputDeviceChanged:
        return Vector<ArgumentDescription> {
            {"bufferSizeMinimum", "uint64_t", nullptr, false},
            {"bufferSizeMaximum", "uint64_t", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::MediaPlayerPrivateRemote_NetworkStateChanged:
        return Vector<ArgumentDescription> {
            {"state", "WebKit::RemoteMediaPlayerState", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_ReadyStateChanged:
        return Vector<ArgumentDescription> {
            {"state", "WebKit::RemoteMediaPlayerState", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_FirstVideoFrameAvailable:
        return Vector<ArgumentDescription> { };
    case MessageName::MediaPlayerPrivateRemote_VolumeChanged:
        return Vector<ArgumentDescription> {
            {"volume", "double", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_MuteChanged:
        return Vector<ArgumentDescription> {
            {"mute", "bool", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_TimeChanged:
        return Vector<ArgumentDescription> {
            {"state", "WebKit::RemoteMediaPlayerState", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_DurationChanged:
        return Vector<ArgumentDescription> {
            {"state", "WebKit::RemoteMediaPlayerState", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_RateChanged:
        return Vector<ArgumentDescription> {
            {"rate", "double", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_PlaybackStateChanged:
        return Vector<ArgumentDescription> {
            {"paused", "bool", nullptr, false},
            {"mediaTime", "MediaTime", nullptr, false},
            {"wallTime", "MonotonicTime", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_EngineFailedToLoad:
        return Vector<ArgumentDescription> {
            {"platformErrorCode", "int", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_UpdateCachedState:
        return Vector<ArgumentDescription> {
            {"state", "WebKit::RemoteMediaPlayerState", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_CharacteristicChanged:
        return Vector<ArgumentDescription> {
            {"state", "WebKit::RemoteMediaPlayerState", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_SizeChanged:
        return Vector<ArgumentDescription> {
            {"naturalSize", "WebCore::FloatSize", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_RenderingModeChanged:
        return Vector<ArgumentDescription> { };
    case MessageName::MediaPlayerPrivateRemote_CurrentTimeChanged:
        return Vector<ArgumentDescription> {
            {"mediaTime", "MediaTime", nullptr, false},
            {"wallTime", "MonotonicTime", nullptr, false},
            {"timeIsProgressing", "bool", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_AddRemoteAudioTrack:
        return Vector<ArgumentDescription> {
            {"trackID", "WebKit::TrackPrivateRemoteIdentifier", nullptr, false},
            {"configuration", "WebKit::AudioTrackPrivateRemoteConfiguration", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_RemoveRemoteAudioTrack:
        return Vector<ArgumentDescription> {
            {"trackID", "WebKit::TrackPrivateRemoteIdentifier", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_RemoteAudioTrackConfigurationChanged:
        return Vector<ArgumentDescription> {
            {"trackID", "WebKit::TrackPrivateRemoteIdentifier", nullptr, false},
            {"configuration", "WebKit::AudioTrackPrivateRemoteConfiguration", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_AddRemoteVideoTrack:
        return Vector<ArgumentDescription> {
            {"trackID", "WebKit::TrackPrivateRemoteIdentifier", nullptr, false},
            {"configuration", "WebKit::VideoTrackPrivateRemoteConfiguration", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_RemoveRemoteVideoTrack:
        return Vector<ArgumentDescription> {
            {"trackID", "WebKit::TrackPrivateRemoteIdentifier", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_RemoteVideoTrackConfigurationChanged:
        return Vector<ArgumentDescription> {
            {"trackID", "WebKit::TrackPrivateRemoteIdentifier", nullptr, false},
            {"configuration", "WebKit::VideoTrackPrivateRemoteConfiguration", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_AddRemoteTextTrack:
        return Vector<ArgumentDescription> {
            {"trackID", "WebKit::TrackPrivateRemoteIdentifier", nullptr, false},
            {"configuration", "WebKit::TextTrackPrivateRemoteConfiguration", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_RemoveRemoteTextTrack:
        return Vector<ArgumentDescription> {
            {"trackID", "WebKit::TrackPrivateRemoteIdentifier", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_RemoteTextTrackConfigurationChanged:
        return Vector<ArgumentDescription> {
            {"trackID", "WebKit::TrackPrivateRemoteIdentifier", nullptr, false},
            {"configuration", "WebKit::TextTrackPrivateRemoteConfiguration", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_ParseWebVTTFileHeader:
        return Vector<ArgumentDescription> {
            {"trackID", "WebKit::TrackPrivateRemoteIdentifier", nullptr, false},
            {"header", "String", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_ParseWebVTTCueData:
        return Vector<ArgumentDescription> {
            {"trackID", "WebKit::TrackPrivateRemoteIdentifier", nullptr, false},
            {"data", "IPC::DataReference", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_ParseWebVTTCueDataStruct:
        return Vector<ArgumentDescription> {
            {"trackID", "WebKit::TrackPrivateRemoteIdentifier", nullptr, false},
            {"cueData", "WebCore::ISOWebVTTCue", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_AddDataCue:
        return Vector<ArgumentDescription> {
            {"trackID", "WebKit::TrackPrivateRemoteIdentifier", nullptr, false},
            {"start", "MediaTime", nullptr, false},
            {"end", "MediaTime", nullptr, false},
            {"data", "IPC::DataReference", nullptr, false},
        };
#if ENABLE(DATACUE_VALUE)
    case MessageName::MediaPlayerPrivateRemote_AddDataCueWithType:
        return Vector<ArgumentDescription> {
            {"trackID", "WebKit::TrackPrivateRemoteIdentifier", nullptr, false},
            {"start", "MediaTime", nullptr, false},
            {"end", "MediaTime", nullptr, false},
            {"cueData", "WebCore::SerializedPlatformDataCueValue", nullptr, false},
            {"type", "String", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_UpdateDataCue:
        return Vector<ArgumentDescription> {
            {"trackID", "WebKit::TrackPrivateRemoteIdentifier", nullptr, false},
            {"start", "MediaTime", nullptr, false},
            {"end", "MediaTime", nullptr, false},
            {"cueData", "WebCore::SerializedPlatformDataCueValue", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_RemoveDataCue:
        return Vector<ArgumentDescription> {
            {"trackID", "WebKit::TrackPrivateRemoteIdentifier", nullptr, false},
            {"start", "MediaTime", nullptr, false},
            {"end", "MediaTime", nullptr, false},
            {"cueData", "WebCore::SerializedPlatformDataCueValue", nullptr, false},
        };
#endif
    case MessageName::MediaPlayerPrivateRemote_AddGenericCue:
        return Vector<ArgumentDescription> {
            {"trackID", "WebKit::TrackPrivateRemoteIdentifier", nullptr, false},
            {"cue", "WebCore::GenericCueData", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_UpdateGenericCue:
        return Vector<ArgumentDescription> {
            {"trackID", "WebKit::TrackPrivateRemoteIdentifier", nullptr, false},
            {"cue", "WebCore::GenericCueData", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_RemoveGenericCue:
        return Vector<ArgumentDescription> {
            {"trackID", "WebKit::TrackPrivateRemoteIdentifier", nullptr, false},
            {"cue", "WebCore::GenericCueData", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_RequestResource:
        return Vector<ArgumentDescription> {
            {"remoteMediaResourceIdentifier", "WebKit::RemoteMediaResourceIdentifier", nullptr, false},
            {"request", "WebCore::ResourceRequest", nullptr, false},
            {"options", "uint8_t", "WebCore::PlatformMediaResourceLoader::LoadOptions", false},
        };
    case MessageName::MediaPlayerPrivateRemote_RemoveResource:
        return Vector<ArgumentDescription> {
            {"remoteMediaResourceIdentifier", "WebKit::RemoteMediaResourceIdentifier", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_SendH2Ping:
        return Vector<ArgumentDescription> {
            {"url", "URL", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_ResourceNotSupported:
        return Vector<ArgumentDescription> { };
    case MessageName::MediaPlayerPrivateRemote_ActiveSourceBuffersChanged:
        return Vector<ArgumentDescription> { };
#if ENABLE(ENCRYPTED_MEDIA)
    case MessageName::MediaPlayerPrivateRemote_WaitingForKeyChanged:
        return Vector<ArgumentDescription> {
            {"waitingForKey", "bool", nullptr, false},
        };
    case MessageName::MediaPlayerPrivateRemote_InitializationDataEncountered:
        return Vector<ArgumentDescription> {
            {"initDataType", "String", nullptr, false},
            {"initData", "IPC::DataReference", nullptr, false},
        };
#endif
#if ENABLE(LEGACY_ENCRYPTED_MEDIA)
    case MessageName::MediaPlayerPrivateRemote_MediaPlayerKeyNeeded:
        return Vector<ArgumentDescription> {
            {"message", "IPC::DataReference", nullptr, false},
        };
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET)
    case MessageName::MediaPlayerPrivateRemote_CurrentPlaybackTargetIsWirelessChanged:
        return Vector<ArgumentDescription> {
            {"isCurrentPlaybackTargetWireless", "bool", nullptr, false},
        };
#endif
#if PLATFORM(IOS_FAMILY)
    case MessageName::MediaPlayerPrivateRemote_GetRawCookies:
        return Vector<ArgumentDescription> {
            {"url", "URL", nullptr, false},
        };
#endif
#if PLATFORM(COCOA)
    case MessageName::MediaPlayerPrivateRemote_PushVideoFrameMetadata:
        return Vector<ArgumentDescription> {
            {"metadata", "WebCore::VideoFrameMetadata", nullptr, false},
            {"buffer", "RetainPtr<CVPixelBufferRef>", nullptr, false},
        };
#endif
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)
    case MessageName::MediaSourcePrivateRemote_SeekToTime:
        return Vector<ArgumentDescription> {
            {"time", "MediaTime", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS) && USE(AUDIO_SESSION)
    case MessageName::RemoteAudioSession_ConfigurationChanged:
        return Vector<ArgumentDescription> {
            {"configuration", "WebKit::RemoteAudioSessionConfiguration", nullptr, false},
        };
    case MessageName::RemoteAudioSession_BeginInterruption:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteAudioSession_EndInterruption:
        return Vector<ArgumentDescription> {
            {"flags", "WebCore::AudioSession::MayResume", nullptr, false},
        };
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS)
    case MessageName::RemoteAudioSourceProviderManager_AudioStorageChanged:
        return Vector<ArgumentDescription> {
            {"id", "WebCore::MediaPlayerIdentifier", nullptr, false},
            {"storageHandle", "WebKit::SharedMemory::IPCHandle", nullptr, false},
            {"description", "WebCore::CAAudioStreamDescription", nullptr, false},
            {"numberOfFrames", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteAudioSourceProviderManager_AudioSamplesAvailable:
        return Vector<ArgumentDescription> {
            {"id", "WebCore::MediaPlayerIdentifier", nullptr, false},
            {"startFrame", "uint64_t", nullptr, false},
            {"numberOfFrames", "uint64_t", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
    case MessageName::RemoteCDMInstance_UnrequestedInitializationDataReceived:
        return Vector<ArgumentDescription> {
            {"type", "String", nullptr, false},
            {"initData", "IPC::SharedBufferCopy", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
    case MessageName::RemoteCDMInstanceSession_UpdateKeyStatuses:
        return Vector<ArgumentDescription> {
            {"keyStatuses", "WebCore::CDMInstanceSession::KeyStatusVector", nullptr, false},
        };
    case MessageName::RemoteCDMInstanceSession_SendMessage:
        return Vector<ArgumentDescription> {
            {"type", "uint8_t", "WebCore::CDMMessageType", false},
            {"message", "IPC::SharedBufferCopy", nullptr, false},
        };
    case MessageName::RemoteCDMInstanceSession_SessionIdChanged:
        return Vector<ArgumentDescription> {
            {"sessionId", "String", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(LEGACY_ENCRYPTED_MEDIA)
    case MessageName::RemoteLegacyCDMSession_SendMessage:
        return Vector<ArgumentDescription> {
            {"message", "IPC::SharedBufferCopy", nullptr, true},
            {"destinationURL", "String", nullptr, false},
        };
    case MessageName::RemoteLegacyCDMSession_SendError:
        return Vector<ArgumentDescription> {
            {"errorCode", "uint8_t", "WebCore::LegacyCDMSessionClient::MediaKeyErrorCode", false},
            {"systemCode", "uint32_t", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteRemoteCommandListener_DidReceiveRemoteControlCommand:
        return Vector<ArgumentDescription> {
            {"command", "uint8_t", "WebCore::PlatformMediaSession::RemoteControlCommandType", false},
            {"argument", "WebCore::PlatformMediaSession::RemoteCommandArgument", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)
    case MessageName::SourceBufferPrivateRemote_SourceBufferPrivateDidReceiveInitializationSegment:
        return Vector<ArgumentDescription> {
            {"segmentConfiguration", "WebKit::InitializationSegmentInfo", nullptr, false},
        };
    case MessageName::SourceBufferPrivateRemote_SourceBufferPrivateStreamEndedWithDecodeError:
        return Vector<ArgumentDescription> { };
    case MessageName::SourceBufferPrivateRemote_SourceBufferPrivateAppendError:
        return Vector<ArgumentDescription> {
            {"decodeError", "bool", nullptr, false},
        };
    case MessageName::SourceBufferPrivateRemote_SourceBufferPrivateAppendComplete:
        return Vector<ArgumentDescription> {
            {"appendResult", "WebCore::SourceBufferPrivateClient::AppendResult", nullptr, false},
            {"buffered", "WebCore::PlatformTimeRanges", nullptr, false},
            {"totalTrackBufferSizeInBytes", "uint64_t", nullptr, false},
            {"timeStampOffset", "MediaTime", nullptr, false},
        };
    case MessageName::SourceBufferPrivateRemote_SourceBufferPrivateHighestPresentationTimestampChanged:
        return Vector<ArgumentDescription> {
            {"timestamp", "MediaTime", nullptr, false},
        };
    case MessageName::SourceBufferPrivateRemote_SourceBufferPrivateDurationChanged:
        return Vector<ArgumentDescription> {
            {"duration", "MediaTime", nullptr, false},
        };
    case MessageName::SourceBufferPrivateRemote_SourceBufferPrivateDidParseSample:
        return Vector<ArgumentDescription> {
            {"sampleDuration", "double", nullptr, false},
        };
    case MessageName::SourceBufferPrivateRemote_SourceBufferPrivateDidDropSample:
        return Vector<ArgumentDescription> { };
    case MessageName::SourceBufferPrivateRemote_SourceBufferPrivateBufferedDirtyChanged:
        return Vector<ArgumentDescription> {
            {"dirty", "bool", nullptr, false},
        };
    case MessageName::SourceBufferPrivateRemote_SourceBufferPrivateDidReceiveRenderingError:
        return Vector<ArgumentDescription> {
            {"errorCode", "int64_t", nullptr, false},
        };
    case MessageName::SourceBufferPrivateRemote_SourceBufferPrivateReportExtraMemoryCost:
        return Vector<ArgumentDescription> {
            {"extraMemory", "uint64_t", nullptr, false},
        };
#endif
#if USE(LIBWEBRTC) && PLATFORM(COCOA) && ENABLE(GPU_PROCESS)
    case MessageName::LibWebRTCCodecs_FailedDecoding:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RTCDecoderIdentifier", nullptr, false},
        };
    case MessageName::LibWebRTCCodecs_CompletedDecoding:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RTCDecoderIdentifier", nullptr, false},
            {"timeStamp", "uint32_t", nullptr, false},
            {"sample", "WebCore::RemoteVideoSample", nullptr, false},
            {"remoteFrameIdentifier", "WebKit::RemoteVideoFrameIdentifier", nullptr, true},
        };
    case MessageName::LibWebRTCCodecs_CompletedEncoding:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RTCEncoderIdentifier", nullptr, false},
            {"data", "IPC::DataReference", nullptr, false},
            {"info", "webrtc::WebKitEncodedFrameInfo", nullptr, false},
        };
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(VIDEO)
    case MessageName::RemoteVideoFrameObjectHeapProxyProcessor_SetSharedVideoFrameSemaphore:
        return Vector<ArgumentDescription> {
            {"semaphore", "IPC::Semaphore", nullptr, false},
        };
    case MessageName::RemoteVideoFrameObjectHeapProxyProcessor_SetSharedVideoFrameMemory:
        return Vector<ArgumentDescription> {
            {"storageHandle", "WebKit::SharedMemory::IPCHandle", nullptr, false},
        };
    case MessageName::RemoteVideoFrameObjectHeapProxyProcessor_VideoFrameBufferNotFound:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RemoteVideoFrameIdentifier", nullptr, false},
        };
    case MessageName::RemoteVideoFrameObjectHeapProxyProcessor_NewVideoFrameBuffer:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RemoteVideoFrameIdentifier", nullptr, false},
        };
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
    case MessageName::SampleBufferDisplayLayer_SetDidFail:
        return Vector<ArgumentDescription> {
            {"value", "bool", nullptr, false},
        };
#endif
    case MessageName::WebGeolocationManager_DidChangePosition:
        return Vector<ArgumentDescription> {
            {"registrableDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"position", "WebCore::GeolocationPositionData", nullptr, false},
        };
    case MessageName::WebGeolocationManager_DidFailToDeterminePosition:
        return Vector<ArgumentDescription> {
            {"registrableDomain", "WebCore::RegistrableDomain", nullptr, false},
            {"errorMessage", "String", nullptr, false},
        };
#if PLATFORM(IOS_FAMILY)
    case MessageName::WebGeolocationManager_ResetPermissions:
        return Vector<ArgumentDescription> {
            {"registrableDomain", "WebCore::RegistrableDomain", nullptr, false},
        };
#endif
    case MessageName::RemoteWebInspectorUI_Initialize:
        return Vector<ArgumentDescription> {
            {"debuggableInfo", "WebKit::DebuggableInfoData", nullptr, false},
            {"backendCommandsURL", "String", nullptr, false},
        };
    case MessageName::RemoteWebInspectorUI_UpdateFindString:
        return Vector<ArgumentDescription> {
            {"findString", "String", nullptr, false},
        };
#if ENABLE(INSPECTOR_TELEMETRY)
    case MessageName::RemoteWebInspectorUI_SetDiagnosticLoggingAvailable:
        return Vector<ArgumentDescription> {
            {"available", "bool", nullptr, false},
        };
#endif
    case MessageName::RemoteWebInspectorUI_ShowConsole:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteWebInspectorUI_ShowResources:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteWebInspectorUI_DidSave:
        return Vector<ArgumentDescription> {
            {"url", "String", nullptr, false},
        };
    case MessageName::RemoteWebInspectorUI_DidAppend:
        return Vector<ArgumentDescription> {
            {"url", "String", nullptr, false},
        };
    case MessageName::RemoteWebInspectorUI_SendMessageToFrontend:
        return Vector<ArgumentDescription> {
            {"message", "String", nullptr, false},
        };
    case MessageName::WebInspector_Show:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspector_Close:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspector_SetAttached:
        return Vector<ArgumentDescription> {
            {"attached", "bool", nullptr, false},
        };
    case MessageName::WebInspector_ShowConsole:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspector_ShowResources:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspector_ShowMainResourceForFrame:
        return Vector<ArgumentDescription> {
            {"frameIdentifier", "WebCore::FrameIdentifier", nullptr, false},
        };
    case MessageName::WebInspector_StartPageProfiling:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspector_StopPageProfiling:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspector_StartElementSelection:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspector_StopElementSelection:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspector_SetFrontendConnection:
        return Vector<ArgumentDescription> {
            {"connectionIdentifier", "IPC::Attachment", nullptr, false},
        };
    case MessageName::WebInspectorInterruptDispatcher_NotifyNeedDebuggerBreak:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspectorUI_EstablishConnection:
        return Vector<ArgumentDescription> {
            {"inspectedPageIdentifier", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"debuggableInfo", "WebKit::DebuggableInfoData", nullptr, false},
            {"underTest", "bool", nullptr, false},
            {"inspectionLevel", "unsigned", nullptr, false},
        };
    case MessageName::WebInspectorUI_UpdateConnection:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspectorUI_AttachedBottom:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspectorUI_AttachedRight:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspectorUI_AttachedLeft:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspectorUI_Detached:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspectorUI_SetDockingUnavailable:
        return Vector<ArgumentDescription> {
            {"unavailable", "bool", nullptr, false},
        };
    case MessageName::WebInspectorUI_SetIsVisible:
        return Vector<ArgumentDescription> {
            {"visible", "bool", nullptr, false},
        };
    case MessageName::WebInspectorUI_UpdateFindString:
        return Vector<ArgumentDescription> {
            {"findString", "String", nullptr, false},
        };
#if ENABLE(INSPECTOR_TELEMETRY)
    case MessageName::WebInspectorUI_SetDiagnosticLoggingAvailable:
        return Vector<ArgumentDescription> {
            {"available", "bool", nullptr, false},
        };
#endif
    case MessageName::WebInspectorUI_ShowConsole:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspectorUI_ShowResources:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspectorUI_ShowMainResourceForFrame:
        return Vector<ArgumentDescription> {
            {"frameIdentifier", "String", nullptr, false},
        };
    case MessageName::WebInspectorUI_StartPageProfiling:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspectorUI_StopPageProfiling:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspectorUI_StartElementSelection:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspectorUI_StopElementSelection:
        return Vector<ArgumentDescription> { };
    case MessageName::WebInspectorUI_DidSave:
        return Vector<ArgumentDescription> {
            {"url", "String", nullptr, false},
        };
    case MessageName::WebInspectorUI_DidAppend:
        return Vector<ArgumentDescription> {
            {"url", "String", nullptr, false},
        };
    case MessageName::WebInspectorUI_SendMessageToFrontend:
        return Vector<ArgumentDescription> {
            {"message", "String", nullptr, false},
        };
    case MessageName::WebInspectorUI_EvaluateInFrontendForTesting:
        return Vector<ArgumentDescription> {
            {"expression", "String", nullptr, false},
        };
#if ENABLE(MEDIA_SESSION_COORDINATOR)
    case MessageName::RemoteMediaSessionCoordinator_SeekSessionToTime:
        return Vector<ArgumentDescription> {
            {"time", "double", nullptr, false},
        };
    case MessageName::RemoteMediaSessionCoordinator_PlaySession:
        return Vector<ArgumentDescription> {
            {"atTime", "double", nullptr, true},
            {"hostTime", "MonotonicTime", nullptr, true},
        };
    case MessageName::RemoteMediaSessionCoordinator_PauseSession:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaSessionCoordinator_SetSessionTrack:
        return Vector<ArgumentDescription> {
            {"trackIdentifier", "String", nullptr, false},
        };
    case MessageName::RemoteMediaSessionCoordinator_CoordinatorStateChanged:
        return Vector<ArgumentDescription> {
            {"state", "uint8_t", "WebCore::MediaSessionCoordinatorState", false},
        };
#endif
#if USE(LIBWEBRTC)
    case MessageName::LibWebRTCNetwork_SignalReadPacket:
        return Vector<ArgumentDescription> {
            {"socketIdentifier", "WebCore::LibWebRTCSocketIdentifier", nullptr, false},
            {"data", "IPC::DataReference", nullptr, false},
            {"address", "WebKit::RTCNetwork::IPAddress", nullptr, false},
            {"port", "uint16_t", nullptr, false},
            {"timestamp", "int64_t", nullptr, false},
        };
    case MessageName::LibWebRTCNetwork_SignalSentPacket:
        return Vector<ArgumentDescription> {
            {"socketIdentifier", "WebCore::LibWebRTCSocketIdentifier", nullptr, false},
            {"packetSize", "int", nullptr, false},
            {"timestamp", "int64_t", nullptr, false},
        };
    case MessageName::LibWebRTCNetwork_SignalAddressReady:
        return Vector<ArgumentDescription> {
            {"socketIdentifier", "WebCore::LibWebRTCSocketIdentifier", nullptr, false},
            {"address", "WebKit::RTCNetwork::SocketAddress", nullptr, false},
        };
    case MessageName::LibWebRTCNetwork_SignalConnect:
        return Vector<ArgumentDescription> {
            {"socketIdentifier", "WebCore::LibWebRTCSocketIdentifier", nullptr, false},
        };
    case MessageName::LibWebRTCNetwork_SignalClose:
        return Vector<ArgumentDescription> {
            {"socketIdentifier", "WebCore::LibWebRTCSocketIdentifier", nullptr, false},
            {"error", "int", nullptr, false},
        };
    case MessageName::LibWebRTCNetwork_SignalNewConnection:
        return Vector<ArgumentDescription> {
            {"socketIdentifier", "WebCore::LibWebRTCSocketIdentifier", nullptr, false},
            {"newSocketIdentifier", "WebCore::LibWebRTCSocketIdentifier", nullptr, false},
            {"remoteAddress", "WebKit::RTCNetwork::SocketAddress", nullptr, false},
        };
#endif
#if ENABLE(WEB_RTC)
    case MessageName::RTCDataChannelRemoteManager_SendData:
        return Vector<ArgumentDescription> {
            {"source", "WebCore::RTCDataChannelIdentifier", nullptr, false},
            {"isRaw", "bool", nullptr, false},
            {"text", "IPC::DataReference", nullptr, false},
        };
    case MessageName::RTCDataChannelRemoteManager_Close:
        return Vector<ArgumentDescription> {
            {"source", "WebCore::RTCDataChannelIdentifier", nullptr, false},
        };
    case MessageName::RTCDataChannelRemoteManager_ChangeReadyState:
        return Vector<ArgumentDescription> {
            {"handler", "WebCore::RTCDataChannelIdentifier", nullptr, false},
            {"state", "uint8_t", "WebCore::RTCDataChannelState", false},
        };
    case MessageName::RTCDataChannelRemoteManager_ReceiveData:
        return Vector<ArgumentDescription> {
            {"handler", "WebCore::RTCDataChannelIdentifier", nullptr, false},
            {"isRaw", "bool", nullptr, false},
            {"data", "IPC::DataReference", nullptr, false},
        };
    case MessageName::RTCDataChannelRemoteManager_DetectError:
        return Vector<ArgumentDescription> {
            {"handler", "WebCore::RTCDataChannelIdentifier", nullptr, false},
            {"type", "uint8_t", "WebCore::RTCErrorDetailType", false},
            {"message", "String", nullptr, false},
        };
    case MessageName::RTCDataChannelRemoteManager_BufferedAmountIsDecreasing:
        return Vector<ArgumentDescription> {
            {"handler", "WebCore::RTCDataChannelIdentifier", nullptr, false},
            {"amount", "size_t", nullptr, false},
        };
#endif
#if ENABLE(WEB_RTC)
    case MessageName::WebMDNSRegister_FinishedRegisteringMDNSName:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::MDNSRegisterIdentifier", nullptr, false},
            {"mdnsName", "String", nullptr, false},
            {"error", "WebCore::MDNSRegisterError", nullptr, true},
        };
#endif
#if USE(LIBWEBRTC)
    case MessageName::WebRTCMonitor_NetworksChanged:
        return Vector<ArgumentDescription> {
            {"networks", "Vector<WebKit::RTCNetwork>", nullptr, false},
            {"defaultIPV4Address", "WebKit::RTCNetwork::IPAddress", nullptr, false},
            {"defaultIPV6Address", "WebKit::RTCNetwork::IPAddress", nullptr, false},
        };
#endif
#if USE(LIBWEBRTC)
    case MessageName::WebRTCResolver_SetResolvedAddress:
        return Vector<ArgumentDescription> {
            {"addresses", "Vector<WebKit::RTCNetwork::IPAddress>", nullptr, false},
        };
    case MessageName::WebRTCResolver_ResolvedAddressError:
        return Vector<ArgumentDescription> {
            {"error", "int", nullptr, false},
        };
#endif
#if ENABLE(SHAREABLE_RESOURCE)
    case MessageName::NetworkProcessConnection_DidCacheResource:
        return Vector<ArgumentDescription> {
            {"request", "WebCore::ResourceRequest", nullptr, false},
            {"resource", "WebKit::ShareableResource::Handle", nullptr, false},
        };
#endif
    case MessageName::NetworkProcessConnection_DidFinishPingLoad:
        return Vector<ArgumentDescription> {
            {"pingLoadIdentifier", "WebCore::ResourceLoaderIdentifier", nullptr, false},
            {"error", "WebCore::ResourceError", nullptr, false},
            {"response", "WebCore::ResourceResponse", nullptr, false},
        };
    case MessageName::NetworkProcessConnection_DidFinishPreconnection:
        return Vector<ArgumentDescription> {
            {"preconnectionIdentifier", "WebCore::ResourceLoaderIdentifier", nullptr, false},
            {"error", "WebCore::ResourceError", nullptr, false},
        };
    case MessageName::NetworkProcessConnection_SetOnLineState:
        return Vector<ArgumentDescription> {
            {"isOnLine", "bool", nullptr, false},
        };
    case MessageName::NetworkProcessConnection_CookieAcceptPolicyChanged:
        return Vector<ArgumentDescription> {
            {"policy", "uint8_t", "WebCore::HTTPCookieAcceptPolicy", false},
        };
#if HAVE(COOKIE_CHANGE_LISTENER_API)
    case MessageName::NetworkProcessConnection_CookiesAdded:
        return Vector<ArgumentDescription> {
            {"host", "String", nullptr, false},
            {"cookies", "Vector<struct WebCore::Cookie>", nullptr, false},
        };
    case MessageName::NetworkProcessConnection_CookiesDeleted:
        return Vector<ArgumentDescription> {
            {"host", "String", nullptr, false},
            {"cookies", "Vector<struct WebCore::Cookie>", nullptr, false},
        };
    case MessageName::NetworkProcessConnection_AllCookiesDeleted:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(WEB_RTC)
    case MessageName::NetworkProcessConnection_ConnectToRTCDataChannelRemoteSource:
        return Vector<ArgumentDescription> {
            {"source", "WebCore::RTCDataChannelIdentifier", nullptr, false},
            {"handler", "WebCore::RTCDataChannelIdentifier", nullptr, false},
        };
#endif
    case MessageName::NetworkProcessConnection_CheckProcessLocalPortForActivity:
        return Vector<ArgumentDescription> {
            {"port", "WebCore::MessagePortIdentifier", nullptr, false},
        };
    case MessageName::NetworkProcessConnection_MessagesAvailableForPort:
        return Vector<ArgumentDescription> {
            {"port", "WebCore::MessagePortIdentifier", nullptr, false},
        };
    case MessageName::NetworkProcessConnection_BroadcastConsoleMessage:
        return Vector<ArgumentDescription> {
            {"messageSource", "uint8_t", "JSC::MessageSource", false},
            {"messageLevel", "uint8_t", "JSC::MessageLevel", false},
            {"message", "String", nullptr, false},
        };
    case MessageName::WebResourceLoader_WillSendRequest:
        return Vector<ArgumentDescription> {
            {"request", "WebCore::ResourceRequest", nullptr, false},
            {"requestBody", "IPC::FormDataReference", nullptr, false},
            {"redirectResponse", "WebCore::ResourceResponse", nullptr, false},
        };
    case MessageName::WebResourceLoader_DidSendData:
        return Vector<ArgumentDescription> {
            {"bytesSent", "uint64_t", nullptr, false},
            {"totalBytesToBeSent", "uint64_t", nullptr, false},
        };
    case MessageName::WebResourceLoader_DidReceiveResponse:
        return Vector<ArgumentDescription> {
            {"response", "WebCore::ResourceResponse", nullptr, false},
            {"privateRelayed", "bool", "WebKit::PrivateRelayed", false},
            {"needsContinueDidReceiveResponseMessage", "bool", nullptr, false},
        };
    case MessageName::WebResourceLoader_DidReceiveData:
        return Vector<ArgumentDescription> {
            {"data", "IPC::SharedBufferCopy", nullptr, false},
            {"encodedDataLength", "int64_t", nullptr, false},
        };
    case MessageName::WebResourceLoader_DidFinishResourceLoad:
        return Vector<ArgumentDescription> {
            {"networkLoadMetrics", "WebCore::NetworkLoadMetrics", nullptr, false},
        };
    case MessageName::WebResourceLoader_DidFailResourceLoad:
        return Vector<ArgumentDescription> {
            {"error", "WebCore::ResourceError", nullptr, false},
        };
    case MessageName::WebResourceLoader_DidFailServiceWorkerLoad:
        return Vector<ArgumentDescription> {
            {"error", "WebCore::ResourceError", nullptr, false},
        };
    case MessageName::WebResourceLoader_ServiceWorkerDidNotHandle:
        return Vector<ArgumentDescription> { };
    case MessageName::WebResourceLoader_DidBlockAuthenticationChallenge:
        return Vector<ArgumentDescription> { };
    case MessageName::WebResourceLoader_StopLoadingAfterXFrameOptionsOrContentSecurityPolicyDenied:
        return Vector<ArgumentDescription> {
            {"response", "WebCore::ResourceResponse", nullptr, false},
        };
#if ENABLE(SHAREABLE_RESOURCE)
    case MessageName::WebResourceLoader_DidReceiveResource:
        return Vector<ArgumentDescription> {
            {"resource", "WebKit::ShareableResource::Handle", nullptr, false},
        };
#endif
#if ENABLE(CONTENT_FILTERING_IN_NETWORKING_PROCESS)
    case MessageName::WebResourceLoader_ContentFilterDidBlockLoad:
        return Vector<ArgumentDescription> {
            {"unblockHandler", "WebCore::ContentFilterUnblockHandler", nullptr, false},
            {"unblockRequestDeniedScript", "String", nullptr, false},
        };
    case MessageName::WebResourceLoader_CancelMainResourceLoadForContentFilter:
        return Vector<ArgumentDescription> {
            {"error", "WebCore::ResourceError", nullptr, false},
        };
    case MessageName::WebResourceLoader_HandleProvisionalLoadFailureFromContentFilter:
        return Vector<ArgumentDescription> {
            {"blockedPageURL", "URL", nullptr, false},
            {"substituteData", "WebCore::SubstituteData", nullptr, false},
        };
#endif
    case MessageName::WebSocketChannel_DidConnect:
        return Vector<ArgumentDescription> {
            {"subprotocol", "String", nullptr, false},
            {"extensions", "String", nullptr, false},
        };
    case MessageName::WebSocketChannel_DidClose:
        return Vector<ArgumentDescription> {
            {"code", "unsigned short", nullptr, false},
            {"reason", "String", nullptr, false},
        };
    case MessageName::WebSocketChannel_DidReceiveText:
        return Vector<ArgumentDescription> {
            {"message", "String", nullptr, false},
        };
    case MessageName::WebSocketChannel_DidReceiveBinaryData:
        return Vector<ArgumentDescription> {
            {"data", "IPC::DataReference", nullptr, false},
        };
    case MessageName::WebSocketChannel_DidReceiveMessageError:
        return Vector<ArgumentDescription> {
            {"errorMessage", "String", nullptr, false},
        };
    case MessageName::WebSocketChannel_DidSendHandshakeRequest:
        return Vector<ArgumentDescription> {
            {"request", "WebCore::ResourceRequest", nullptr, false},
        };
    case MessageName::WebSocketChannel_DidReceiveHandshakeResponse:
        return Vector<ArgumentDescription> {
            {"response", "WebCore::ResourceResponse", nullptr, false},
        };
    case MessageName::WebSocketStream_DidOpenSocketStream:
        return Vector<ArgumentDescription> { };
    case MessageName::WebSocketStream_DidCloseSocketStream:
        return Vector<ArgumentDescription> { };
    case MessageName::WebSocketStream_DidReceiveSocketStreamData:
        return Vector<ArgumentDescription> {
            {"data", "IPC::DataReference", nullptr, false},
        };
    case MessageName::WebSocketStream_DidFailToReceiveSocketStreamData:
        return Vector<ArgumentDescription> { };
    case MessageName::WebSocketStream_DidUpdateBufferedAmount:
        return Vector<ArgumentDescription> {
            {"bufferedAmount", "uint64_t", nullptr, false},
        };
    case MessageName::WebSocketStream_DidFailSocketStream:
        return Vector<ArgumentDescription> {
            {"error", "WebCore::SocketStreamError", nullptr, false},
        };
    case MessageName::WebSocketStream_DidSendData:
        return Vector<ArgumentDescription> {
            {"identifier", "uint64_t", nullptr, false},
            {"success", "bool", nullptr, false},
        };
    case MessageName::WebSocketStream_DidSendHandshake:
        return Vector<ArgumentDescription> {
            {"identifier", "uint64_t", nullptr, false},
            {"success", "bool", nullptr, false},
            {"didAccessSecureCookies", "bool", nullptr, false},
        };
    case MessageName::WebNotificationManager_DidShowNotification:
        return Vector<ArgumentDescription> {
            {"notificationID", "UUID", nullptr, false},
        };
    case MessageName::WebNotificationManager_DidClickNotification:
        return Vector<ArgumentDescription> {
            {"notificationID", "UUID", nullptr, false},
        };
    case MessageName::WebNotificationManager_DidCloseNotifications:
        return Vector<ArgumentDescription> {
            {"notificationIDs", "Vector<UUID>", nullptr, false},
        };
    case MessageName::WebNotificationManager_DidUpdateNotificationDecision:
        return Vector<ArgumentDescription> {
            {"originString", "String", nullptr, false},
            {"allowed", "bool", nullptr, false},
        };
    case MessageName::WebNotificationManager_DidRemoveNotificationDecisions:
        return Vector<ArgumentDescription> {
            {"originStrings", "Vector<String>", nullptr, false},
        };
#if ENABLE(MEDIA_STREAM)
    case MessageName::SpeechRecognitionRealtimeMediaSourceManager_CreateSource:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::RealtimeMediaSourceIdentifier", nullptr, false},
            {"device", "WebCore::CaptureDevice", nullptr, false},
        };
    case MessageName::SpeechRecognitionRealtimeMediaSourceManager_DeleteSource:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::RealtimeMediaSourceIdentifier", nullptr, false},
        };
    case MessageName::SpeechRecognitionRealtimeMediaSourceManager_Start:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::RealtimeMediaSourceIdentifier", nullptr, false},
        };
    case MessageName::SpeechRecognitionRealtimeMediaSourceManager_Stop:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::RealtimeMediaSourceIdentifier", nullptr, false},
        };
#if ENABLE(SANDBOX_EXTENSIONS)
    case MessageName::SpeechRecognitionRealtimeMediaSourceManager_GrantSandboxExtensions:
        return Vector<ArgumentDescription> {
            {"sandboxExtensionHandleForTCCD", "WebKit::SandboxExtension::Handle", nullptr, false},
            {"sandboxExtensionHandleForMicrophone", "WebKit::SandboxExtension::Handle", nullptr, false},
        };
    case MessageName::SpeechRecognitionRealtimeMediaSourceManager_RevokeSandboxExtensions:
        return Vector<ArgumentDescription> { };
#endif
#endif
    case MessageName::WebSharedWorkerContextManagerConnection_LaunchSharedWorker:
        return Vector<ArgumentDescription> {
            {"origin", "WebCore::ClientOrigin", nullptr, false},
            {"sharedWorkerIdentifier", "WebCore::SharedWorkerIdentifier", nullptr, false},
            {"workerOptions", "WebCore::WorkerOptions", nullptr, false},
            {"workerFetchResult", "WebCore::WorkerFetchResult", nullptr, false},
        };
    case MessageName::WebSharedWorkerContextManagerConnection_PostConnectEvent:
        return Vector<ArgumentDescription> {
            {"sharedWorkerIdentifier", "WebCore::SharedWorkerIdentifier", nullptr, false},
            {"port", "WebCore::TransferredMessagePort", nullptr, false},
            {"sourceOrigin", "String", nullptr, false},
        };
    case MessageName::WebSharedWorkerContextManagerConnection_TerminateSharedWorker:
        return Vector<ArgumentDescription> {
            {"sharedWorkerIdentifier", "WebCore::SharedWorkerIdentifier", nullptr, false},
        };
    case MessageName::WebSharedWorkerContextManagerConnection_UpdatePreferencesStore:
        return Vector<ArgumentDescription> {
            {"store", "WebKit::WebPreferencesStore", nullptr, false},
        };
    case MessageName::WebSharedWorkerContextManagerConnection_SetUserAgent:
        return Vector<ArgumentDescription> {
            {"userAgent", "String", nullptr, false},
        };
    case MessageName::WebSharedWorkerContextManagerConnection_Close:
        return Vector<ArgumentDescription> { };
    case MessageName::WebSharedWorkerObjectConnection_FetchScriptInClient:
        return Vector<ArgumentDescription> {
            {"url", "URL", nullptr, false},
            {"sharedWorkerObjectIdentifier", "WebCore::SharedWorkerObjectIdentifier", nullptr, false},
            {"workerOptions", "WebCore::WorkerOptions", nullptr, false},
        };
    case MessageName::WebSharedWorkerObjectConnection_NotifyWorkerObjectOfLoadCompletion:
        return Vector<ArgumentDescription> {
            {"sharedWorkerObjectIdentifier", "WebCore::SharedWorkerObjectIdentifier", nullptr, false},
            {"error", "WebCore::ResourceError", nullptr, false},
        };
    case MessageName::WebSharedWorkerObjectConnection_PostExceptionToWorkerObject:
        return Vector<ArgumentDescription> {
            {"sharedWorkerObjectIdentifier", "WebCore::SharedWorkerObjectIdentifier", nullptr, false},
            {"errorMessage", "String", nullptr, false},
            {"lineNumber", "int", nullptr, false},
            {"columnNumber", "int", nullptr, false},
            {"sourceURL", "String", nullptr, false},
        };
#if ENABLE(SERVICE_WORKER)
    case MessageName::WebSWClientConnection_JobRejectedInServer:
        return Vector<ArgumentDescription> {
            {"jobDataIdentifier", "WebCore::ServiceWorkerJobIdentifier", nullptr, false},
            {"exception", "WebCore::ExceptionData", nullptr, false},
        };
    case MessageName::WebSWClientConnection_RegistrationJobResolvedInServer:
        return Vector<ArgumentDescription> {
            {"jobDataIdentifier", "WebCore::ServiceWorkerJobIdentifier", nullptr, false},
            {"registration", "WebCore::ServiceWorkerRegistrationData", nullptr, false},
            {"shouldNotifyWhenResolved", "bool", "WebCore::ShouldNotifyWhenResolved", false},
        };
    case MessageName::WebSWClientConnection_StartScriptFetchForServer:
        return Vector<ArgumentDescription> {
            {"jobDataIdentifier", "WebCore::ServiceWorkerJobIdentifier", nullptr, false},
            {"registrationKey", "WebCore::ServiceWorkerRegistrationKey", nullptr, false},
            {"cachePolicy", "WebCore::FetchOptions::Cache", nullptr, false},
        };
    case MessageName::WebSWClientConnection_UpdateRegistrationState:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::ServiceWorkerRegistrationIdentifier", nullptr, false},
            {"state", "uint8_t", "WebCore::ServiceWorkerRegistrationState", false},
            {"serviceWorkerIdentifier", "WebCore::ServiceWorkerData", nullptr, true},
        };
    case MessageName::WebSWClientConnection_UpdateWorkerState:
        return Vector<ArgumentDescription> {
            {"serviceWorkerIdentifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
            {"state", "uint8_t", "WebCore::ServiceWorkerState", false},
        };
    case MessageName::WebSWClientConnection_FireUpdateFoundEvent:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::ServiceWorkerRegistrationIdentifier", nullptr, false},
        };
    case MessageName::WebSWClientConnection_SetRegistrationLastUpdateTime:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::ServiceWorkerRegistrationIdentifier", nullptr, false},
            {"lastUpdateTime", "WallTime", nullptr, false},
        };
    case MessageName::WebSWClientConnection_SetRegistrationUpdateViaCache:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::ServiceWorkerRegistrationIdentifier", nullptr, false},
            {"updateViaCache", "uint8_t", "WebCore::ServiceWorkerUpdateViaCache", false},
        };
    case MessageName::WebSWClientConnection_NotifyClientsOfControllerChange:
        return Vector<ArgumentDescription> {
            {"contextIdentifiers", "HashSet<WebCore::ScriptExecutionContextIdentifier>", nullptr, false},
            {"newController", "WebCore::ServiceWorkerData", nullptr, false},
        };
    case MessageName::WebSWClientConnection_SetSWOriginTableIsImported:
        return Vector<ArgumentDescription> { };
    case MessageName::WebSWClientConnection_SetSWOriginTableSharedMemory:
        return Vector<ArgumentDescription> {
            {"handle", "WebKit::SharedMemory::IPCHandle", nullptr, false},
        };
    case MessageName::WebSWClientConnection_PostMessageToServiceWorkerClient:
        return Vector<ArgumentDescription> {
            {"destinationContextIdentifier", "WebCore::ScriptExecutionContextIdentifier", nullptr, false},
            {"message", "WebCore::MessageWithMessagePorts", nullptr, false},
            {"source", "WebCore::ServiceWorkerData", nullptr, false},
            {"sourceOrigin", "String", nullptr, false},
        };
    case MessageName::WebSWClientConnection_SetDocumentIsControlled:
        return Vector<ArgumentDescription> {
            {"temporaryDocumentIdentifier", "WebCore::ScriptExecutionContextIdentifier", nullptr, false},
            {"data", "WebCore::ServiceWorkerRegistrationData", nullptr, false},
        };
#endif
#if ENABLE(SERVICE_WORKER)
    case MessageName::WebSWContextManagerConnection_InstallServiceWorker:
        return Vector<ArgumentDescription> {
            {"contextData", "WebCore::ServiceWorkerContextData", nullptr, false},
            {"workerData", "WebCore::ServiceWorkerData", nullptr, false},
            {"userAgent", "String", nullptr, false},
            {"workerThreadMode", "bool", "WebCore::WorkerThreadMode", false},
        };
    case MessageName::WebSWContextManagerConnection_UpdateAppInitiatedValue:
        return Vector<ArgumentDescription> {
            {"serviceWorkerIdentifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
            {"lastNavigationWasAppInitiated", "bool", "WebCore::LastNavigationWasAppInitiated", false},
        };
    case MessageName::WebSWContextManagerConnection_StartFetch:
        return Vector<ArgumentDescription> {
            {"serverConnectionIdentifier", "WebCore::SWServerConnectionIdentifier", nullptr, false},
            {"serviceWorkerIdentifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
            {"fetchIdentifier", "WebCore::FetchIdentifier", nullptr, false},
            {"request", "WebCore::ResourceRequest", nullptr, false},
            {"options", "WebCore::FetchOptions", nullptr, false},
            {"requestBody", "IPC::FormDataReference", nullptr, false},
            {"referrer", "String", nullptr, false},
            {"isServiceWorkerNavigationPreloadEnabled", "bool", nullptr, false},
            {"clientIdentifer", "String", nullptr, false},
            {"resutlingClientIdentifier", "String", nullptr, false},
        };
    case MessageName::WebSWContextManagerConnection_CancelFetch:
        return Vector<ArgumentDescription> {
            {"serverConnectionIdentifier", "WebCore::SWServerConnectionIdentifier", nullptr, false},
            {"serviceWorkerIdentifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
            {"fetchIdentifier", "WebCore::FetchIdentifier", nullptr, false},
        };
    case MessageName::WebSWContextManagerConnection_ContinueDidReceiveFetchResponse:
        return Vector<ArgumentDescription> {
            {"serverConnectionIdentifier", "WebCore::SWServerConnectionIdentifier", nullptr, false},
            {"serviceWorkerIdentifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
            {"fetchIdentifier", "WebCore::FetchIdentifier", nullptr, false},
        };
    case MessageName::WebSWContextManagerConnection_PostMessageToServiceWorker:
        return Vector<ArgumentDescription> {
            {"destinationIdentifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
            {"message", "WebCore::MessageWithMessagePorts", nullptr, false},
            {"sourceData", "WebCore::ServiceWorkerOrClientData", nullptr, false},
        };
    case MessageName::WebSWContextManagerConnection_FireInstallEvent:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
        };
    case MessageName::WebSWContextManagerConnection_FireActivateEvent:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
        };
    case MessageName::WebSWContextManagerConnection_FirePushEvent:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
            {"data", "IPC::DataReference", nullptr, true},
        };
    case MessageName::WebSWContextManagerConnection_TerminateWorker:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
        };
#if ENABLE(SHAREABLE_RESOURCE) && PLATFORM(COCOA)
    case MessageName::WebSWContextManagerConnection_DidSaveScriptsToDisk:
        return Vector<ArgumentDescription> {
            {"serviceWorkerIdentifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
            {"script", "WebCore::ScriptBuffer", nullptr, false},
            {"importedScripts", "HashMap<URL, WebCore::ScriptBuffer>", nullptr, false},
        };
#endif
    case MessageName::WebSWContextManagerConnection_MatchAllCompleted:
        return Vector<ArgumentDescription> {
            {"matchAllRequestIdentifier", "uint64_t", nullptr, false},
            {"clientsData", "Vector<WebCore::ServiceWorkerClientData>", nullptr, false},
        };
    case MessageName::WebSWContextManagerConnection_SetUserAgent:
        return Vector<ArgumentDescription> {
            {"userAgent", "String", nullptr, false},
        };
    case MessageName::WebSWContextManagerConnection_UpdatePreferencesStore:
        return Vector<ArgumentDescription> {
            {"store", "WebKit::WebPreferencesStore", nullptr, false},
        };
    case MessageName::WebSWContextManagerConnection_Close:
        return Vector<ArgumentDescription> { };
    case MessageName::WebSWContextManagerConnection_SetThrottleState:
        return Vector<ArgumentDescription> {
            {"isThrottleable", "bool", nullptr, false},
        };
    case MessageName::WebSWContextManagerConnection_ConvertFetchToDownload:
        return Vector<ArgumentDescription> {
            {"serverConnectionIdentifier", "WebCore::SWServerConnectionIdentifier", nullptr, false},
            {"serviceWorkerIdentifier", "WebCore::ServiceWorkerIdentifier", nullptr, false},
            {"identifier", "WebCore::FetchIdentifier", nullptr, false},
        };
#endif
    case MessageName::WebUserContentController_AddContentWorlds:
        return Vector<ArgumentDescription> {
            {"worlds", "Vector<std::pair<WebKit::ContentWorldIdentifier, String>>", nullptr, false},
        };
    case MessageName::WebUserContentController_RemoveContentWorlds:
        return Vector<ArgumentDescription> {
            {"worldIdentifiers", "Vector<WebKit::ContentWorldIdentifier>", nullptr, false},
        };
    case MessageName::WebUserContentController_AddUserScripts:
        return Vector<ArgumentDescription> {
            {"userScripts", "Vector<struct WebKit::WebUserScriptData>", nullptr, false},
            {"immediately", "bool", "WebKit::InjectUserScriptImmediately", false},
        };
    case MessageName::WebUserContentController_RemoveUserScript:
        return Vector<ArgumentDescription> {
            {"worldIdentifier", "WebKit::ContentWorldIdentifier", nullptr, false},
            {"identifier", "uint64_t", nullptr, false},
        };
    case MessageName::WebUserContentController_RemoveAllUserScripts:
        return Vector<ArgumentDescription> {
            {"worldIdentifiers", "Vector<WebKit::ContentWorldIdentifier>", nullptr, false},
        };
    case MessageName::WebUserContentController_AddUserStyleSheets:
        return Vector<ArgumentDescription> {
            {"userStyleSheets", "Vector<struct WebKit::WebUserStyleSheetData>", nullptr, false},
        };
    case MessageName::WebUserContentController_RemoveUserStyleSheet:
        return Vector<ArgumentDescription> {
            {"worldIdentifier", "WebKit::ContentWorldIdentifier", nullptr, false},
            {"identifier", "uint64_t", nullptr, false},
        };
    case MessageName::WebUserContentController_RemoveAllUserStyleSheets:
        return Vector<ArgumentDescription> {
            {"worldIdentifiers", "Vector<WebKit::ContentWorldIdentifier>", nullptr, false},
        };
    case MessageName::WebUserContentController_AddUserScriptMessageHandlers:
        return Vector<ArgumentDescription> {
            {"scriptMessageHandlers", "Vector<struct WebKit::WebScriptMessageHandlerData>", nullptr, false},
        };
    case MessageName::WebUserContentController_RemoveUserScriptMessageHandler:
        return Vector<ArgumentDescription> {
            {"worldIdentifier", "WebKit::ContentWorldIdentifier", nullptr, false},
            {"identifier", "uint64_t", nullptr, false},
        };
    case MessageName::WebUserContentController_RemoveAllUserScriptMessageHandlersForWorlds:
        return Vector<ArgumentDescription> {
            {"worldIdentifiers", "Vector<WebKit::ContentWorldIdentifier>", nullptr, false},
        };
    case MessageName::WebUserContentController_RemoveAllUserScriptMessageHandlers:
        return Vector<ArgumentDescription> { };
#if ENABLE(CONTENT_EXTENSIONS)
    case MessageName::WebUserContentController_AddContentRuleLists:
        return Vector<ArgumentDescription> {
            {"contentFilters", "Vector<std::pair<WebKit::WebCompiledContentRuleListData, URL>>", nullptr, false},
        };
    case MessageName::WebUserContentController_RemoveContentRuleList:
        return Vector<ArgumentDescription> {
            {"name", "String", nullptr, false},
        };
    case MessageName::WebUserContentController_RemoveAllContentRuleLists:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::RemoteWebLockRegistry_DidCompleteLockRequest:
        return Vector<ArgumentDescription> {
            {"lockIdentifier", "WebCore::WebLockIdentifier", nullptr, false},
            {"clientID", "WebCore::ScriptExecutionContextIdentifier", nullptr, false},
            {"success", "bool", nullptr, false},
        };
    case MessageName::RemoteWebLockRegistry_DidStealLock:
        return Vector<ArgumentDescription> {
            {"lockIdentifier", "WebCore::WebLockIdentifier", nullptr, false},
            {"clientID", "WebCore::ScriptExecutionContextIdentifier", nullptr, false},
        };
    case MessageName::WebBroadcastChannelRegistry_PostMessageToRemote:
        return Vector<ArgumentDescription> {
            {"origin", "WebCore::ClientOrigin", nullptr, false},
            {"name", "String", nullptr, false},
            {"message", "WebCore::MessageWithMessagePorts", nullptr, false},
        };
    case MessageName::WebFileSystemStorageConnection_InvalidateAccessHandle:
        return Vector<ArgumentDescription> {
            {"identifier", "WebCore::FileSystemSyncAccessHandleIdentifier", nullptr, false},
        };
    case MessageName::WebSpeechRecognitionConnection_DidReceiveUpdate:
        return Vector<ArgumentDescription> {
            {"update", "WebCore::SpeechRecognitionUpdate", nullptr, false},
        };
#if USE(COORDINATED_GRAPHICS) || USE(TEXTURE_MAPPER)
    case MessageName::DrawingArea_UpdateBackingStoreState:
        return Vector<ArgumentDescription> {
            {"backingStoreStateID", "uint64_t", nullptr, false},
            {"respondImmediately", "bool", nullptr, false},
            {"deviceScaleFactor", "float", nullptr, false},
            {"size", "WebCore::IntSize", nullptr, false},
            {"scrollOffset", "WebCore::IntSize", nullptr, false},
        };
#endif
    case MessageName::DrawingArea_DidUpdate:
        return Vector<ArgumentDescription> { };
#if PLATFORM(COCOA)
    case MessageName::DrawingArea_UpdateGeometry:
        return Vector<ArgumentDescription> {
            {"viewSize", "WebCore::IntSize", nullptr, false},
            {"flushSynchronously", "bool", nullptr, false},
            {"fencePort", "MachSendRight", nullptr, false},
        };
    case MessageName::DrawingArea_SetDeviceScaleFactor:
        return Vector<ArgumentDescription> {
            {"deviceScaleFactor", "float", nullptr, false},
        };
    case MessageName::DrawingArea_SetColorSpace:
        return Vector<ArgumentDescription> {
            {"colorSpace", "WebCore::DestinationColorSpace", nullptr, true},
        };
    case MessageName::DrawingArea_SetViewExposedRect:
        return Vector<ArgumentDescription> {
            {"viewExposedRect", "WebCore::FloatRect", nullptr, true},
        };
    case MessageName::DrawingArea_AcceleratedAnimationDidStart:
        return Vector<ArgumentDescription> {
            {"layerID", "uint64_t", nullptr, false},
            {"key", "String", nullptr, false},
            {"startTime", "MonotonicTime", nullptr, false},
        };
    case MessageName::DrawingArea_AcceleratedAnimationDidEnd:
        return Vector<ArgumentDescription> {
            {"layerID", "uint64_t", nullptr, false},
            {"key", "String", nullptr, false},
        };
    case MessageName::DrawingArea_AddTransactionCallbackID:
        return Vector<ArgumentDescription> {
            {"callbackID", "WebKit::CallbackID", nullptr, false},
        };
#endif
#if USE(GRAPHICS_LAYER_WC)
    case MessageName::DrawingArea_UpdateGeometry:
        return Vector<ArgumentDescription> {
            {"backingStoreStateID", "uint64_t", nullptr, false},
            {"viewSize", "WebCore::IntSize", nullptr, false},
        };
#endif
#if PLATFORM(COCOA) || PLATFORM(GTK)
    case MessageName::DrawingArea_AdjustTransientZoom:
        return Vector<ArgumentDescription> {
            {"scale", "double", nullptr, false},
            {"origin", "WebCore::FloatPoint", nullptr, false},
        };
    case MessageName::DrawingArea_CommitTransientZoom:
        return Vector<ArgumentDescription> {
            {"scale", "double", nullptr, false},
            {"origin", "WebCore::FloatPoint", nullptr, false},
        };
#endif
    case MessageName::EventDispatcher_WheelEvent:
        return Vector<ArgumentDescription> {
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
            {"event", "WebKit::WebWheelEvent", nullptr, false},
            {"rubberBandableEdges", "WebCore::RectEdges<bool>", nullptr, false},
        };
#if ENABLE(IOS_TOUCH_EVENTS)
    case MessageName::EventDispatcher_TouchEvent:
        return Vector<ArgumentDescription> {
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
            {"event", "WebKit::WebTouchEvent", nullptr, false},
        };
    case MessageName::EventDispatcher_TouchEventWithoutCallback:
        return Vector<ArgumentDescription> {
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
            {"event", "WebKit::WebTouchEvent", nullptr, false},
        };
#endif
#if ENABLE(MAC_GESTURE_EVENTS)
    case MessageName::EventDispatcher_GestureEvent:
        return Vector<ArgumentDescription> {
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
            {"event", "WebKit::WebGestureEvent", nullptr, false},
        };
#endif
#if HAVE(CVDISPLAYLINK)
    case MessageName::EventDispatcher_DisplayWasRefreshed:
        return Vector<ArgumentDescription> {
            {"displayID", "uint32_t", nullptr, false},
            {"update", "WebCore::DisplayUpdate", nullptr, false},
            {"sendToMainThread", "bool", nullptr, false},
        };
#endif
#if ENABLE(MOMENTUM_EVENT_DISPATCHER)
    case MessageName::EventDispatcher_SetScrollingAccelerationCurve:
        return Vector<ArgumentDescription> {
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
            {"curve", "WebKit::ScrollingAccelerationCurve", nullptr, true},
        };
#endif
    case MessageName::EventDispatcher_PageScreenDidChange:
        return Vector<ArgumentDescription> {
            {"pageID", "WebCore::PageIdentifier", nullptr, false},
            {"displayID", "uint32_t", nullptr, false},
            {"nominalFramesPerSecond", "unsigned", nullptr, true},
        };
    case MessageName::VisitedLinkTableController_SetVisitedLinkTable:
        return Vector<ArgumentDescription> {
            {"ipcHandle", "WebKit::SharedMemory::IPCHandle", nullptr, false},
        };
    case MessageName::VisitedLinkTableController_VisitedLinkStateChanged:
        return Vector<ArgumentDescription> {
            {"linkHashes", "Vector<WebCore::SharedStringHash>", nullptr, false},
        };
    case MessageName::VisitedLinkTableController_AllVisitedLinkStateChanged:
        return Vector<ArgumentDescription> { };
    case MessageName::VisitedLinkTableController_RemoveAllVisitedLinks:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_SetInitialFocus:
        return Vector<ArgumentDescription> {
            {"forward", "bool", nullptr, false},
            {"isKeyboardEventValid", "bool", nullptr, false},
            {"event", "WebKit::WebKeyboardEvent", nullptr, false},
        };
    case MessageName::WebPage_SetActivityState:
        return Vector<ArgumentDescription> {
            {"activityState", "OptionSet<WebCore::ActivityState::Flag>", nullptr, false},
            {"activityStateChangeID", "WebKit::ActivityStateChangeID", nullptr, false},
        };
    case MessageName::WebPage_SetLayerHostingMode:
        return Vector<ArgumentDescription> {
            {"layerHostingMode", "uint8_t", "WebKit::LayerHostingMode", false},
        };
    case MessageName::WebPage_SetBackgroundColor:
        return Vector<ArgumentDescription> {
            {"color", "WebCore::Color", nullptr, true},
        };
    case MessageName::WebPage_AddConsoleMessage:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"messageSource", "uint8_t", "JSC::MessageSource", false},
            {"messageLevel", "uint8_t", "JSC::MessageLevel", false},
            {"message", "String", nullptr, false},
            {"requestID", "WebCore::ResourceLoaderIdentifier", nullptr, true},
        };
    case MessageName::WebPage_SendCSPViolationReport:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"reportURL", "URL", nullptr, false},
            {"reportData", "IPC::FormDataReference", nullptr, false},
        };
    case MessageName::WebPage_EnqueueSecurityPolicyViolationEvent:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"eventInit", "WebCore::SecurityPolicyViolationEventInit", nullptr, false},
        };
    case MessageName::WebPage_TestProcessIncomingSyncMessagesWhenWaitingForSyncReply:
        return Vector<ArgumentDescription> { };
#if PLATFORM(COCOA)
    case MessageName::WebPage_SetTopContentInsetFenced:
        return Vector<ArgumentDescription> {
            {"contentInset", "float", nullptr, false},
            {"machSendRight", "MachSendRight", nullptr, false},
        };
#endif
    case MessageName::WebPage_SetTopContentInset:
        return Vector<ArgumentDescription> {
            {"contentInset", "float", nullptr, false},
        };
    case MessageName::WebPage_SetUnderlayColor:
        return Vector<ArgumentDescription> {
            {"color", "WebCore::Color", nullptr, false},
        };
    case MessageName::WebPage_SetUnderPageBackgroundColorOverride:
        return Vector<ArgumentDescription> {
            {"underPageBackgroundColorOverride", "WebCore::Color", nullptr, false},
        };
    case MessageName::WebPage_ViewWillStartLiveResize:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_ViewWillEndLiveResize:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_ExecuteEditCommandWithCallback:
        return Vector<ArgumentDescription> {
            {"name", "String", nullptr, false},
            {"argument", "String", nullptr, false},
        };
    case MessageName::WebPage_KeyEvent:
        return Vector<ArgumentDescription> {
            {"event", "WebKit::WebKeyboardEvent", nullptr, false},
        };
    case MessageName::WebPage_MouseEvent:
        return Vector<ArgumentDescription> {
            {"event", "WebKit::WebMouseEvent", nullptr, false},
            {"sandboxExtensions", "Vector<WebKit::SandboxExtension::Handle>", nullptr, true},
        };
#if PLATFORM(IOS_FAMILY)
    case MessageName::WebPage_SetViewportConfigurationViewLayoutSize:
        return Vector<ArgumentDescription> {
            {"size", "WebCore::FloatSize", nullptr, false},
            {"scaleFactor", "double", nullptr, false},
            {"minimumEffectiveDeviceWidth", "double", nullptr, false},
        };
    case MessageName::WebPage_SetMinimumUnobscuredSize:
        return Vector<ArgumentDescription> {
            {"size", "WebCore::FloatSize", nullptr, false},
        };
    case MessageName::WebPage_SetMaximumUnobscuredSize:
        return Vector<ArgumentDescription> {
            {"size", "WebCore::FloatSize", nullptr, false},
        };
    case MessageName::WebPage_SetDeviceOrientation:
        return Vector<ArgumentDescription> {
            {"deviceOrientation", "int32_t", nullptr, false},
        };
    case MessageName::WebPage_SetOverrideViewportArguments:
        return Vector<ArgumentDescription> {
            {"arguments", "WebCore::ViewportArguments", nullptr, true},
        };
    case MessageName::WebPage_DynamicViewportSizeUpdate:
        return Vector<ArgumentDescription> {
            {"viewLayoutSize", "WebCore::FloatSize", nullptr, false},
            {"minimumUnobscuredSize", "WebCore::FloatSize", nullptr, false},
            {"maximumUnobscuredSize", "WebCore::FloatSize", nullptr, false},
            {"targetExposedContentRect", "WebCore::FloatRect", nullptr, false},
            {"targetUnobscuredRect", "WebCore::FloatRect", nullptr, false},
            {"targetUnobscuredRectInScrollViewCoordinates", "WebCore::FloatRect", nullptr, false},
            {"targetUnobscuredSafeAreaInsets", "WebCore::RectEdges<float>", nullptr, false},
            {"scale", "double", nullptr, false},
            {"deviceOrientation", "int32_t", nullptr, false},
            {"minimumEffectiveDeviceWidth", "double", nullptr, false},
            {"dynamicViewportSizeUpdateID", "uint64_t", nullptr, false},
        };
    case MessageName::WebPage_SetScreenIsBeingCaptured:
        return Vector<ArgumentDescription> {
            {"captured", "bool", nullptr, false},
        };
    case MessageName::WebPage_AttemptSyntheticClick:
        return Vector<ArgumentDescription> {
            {"point", "WebCore::IntPoint", nullptr, false},
            {"modifiers", "OptionSet<WebKit::WebEvent::Modifier>", nullptr, false},
            {"lastLayerTreeTransactionId", "WebKit::TransactionID", nullptr, false},
        };
    case MessageName::WebPage_PotentialTapAtPosition:
        return Vector<ArgumentDescription> {
            {"requestID", "WebKit::TapIdentifier", nullptr, false},
            {"point", "WebCore::FloatPoint", nullptr, false},
            {"shouldRequestMagnificationInformation", "bool", nullptr, false},
        };
    case MessageName::WebPage_CommitPotentialTap:
        return Vector<ArgumentDescription> {
            {"modifiers", "OptionSet<WebKit::WebEvent::Modifier>", nullptr, false},
            {"lastLayerTreeTransactionId", "WebKit::TransactionID", nullptr, false},
            {"pointerId", "WebCore::PointerID", nullptr, false},
        };
    case MessageName::WebPage_CancelPotentialTap:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_TapHighlightAtPosition:
        return Vector<ArgumentDescription> {
            {"requestID", "WebKit::TapIdentifier", nullptr, false},
            {"point", "WebCore::FloatPoint", nullptr, false},
        };
    case MessageName::WebPage_DidRecognizeLongPress:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_HandleDoubleTapForDoubleClickAtPoint:
        return Vector<ArgumentDescription> {
            {"point", "WebCore::IntPoint", nullptr, false},
            {"modifiers", "OptionSet<WebKit::WebEvent::Modifier>", nullptr, false},
            {"lastLayerTreeTransactionId", "WebKit::TransactionID", nullptr, false},
        };
    case MessageName::WebPage_InspectorNodeSearchMovedToPosition:
        return Vector<ArgumentDescription> {
            {"point", "WebCore::FloatPoint", nullptr, false},
        };
    case MessageName::WebPage_InspectorNodeSearchEndedAtPosition:
        return Vector<ArgumentDescription> {
            {"point", "WebCore::FloatPoint", nullptr, false},
        };
    case MessageName::WebPage_BlurFocusedElement:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_SelectWithGesture:
        return Vector<ArgumentDescription> {
            {"point", "WebCore::IntPoint", nullptr, false},
            {"gestureType", "uint8_t", "WebKit::GestureType", false},
            {"gestureState", "uint8_t", "WebKit::GestureRecognizerState", false},
            {"isInteractingWithFocusedElement", "bool", nullptr, false},
        };
    case MessageName::WebPage_UpdateSelectionWithTouches:
        return Vector<ArgumentDescription> {
            {"point", "WebCore::IntPoint", nullptr, false},
            {"touches", "uint8_t", "WebKit::SelectionTouch", false},
            {"baseIsStart", "bool", nullptr, false},
        };
    case MessageName::WebPage_SelectWithTwoTouches:
        return Vector<ArgumentDescription> {
            {"from", "WebCore::IntPoint", nullptr, false},
            {"to", "WebCore::IntPoint", nullptr, false},
            {"gestureType", "uint8_t", "WebKit::GestureType", false},
            {"gestureState", "uint8_t", "WebKit::GestureRecognizerState", false},
        };
    case MessageName::WebPage_ExtendSelection:
        return Vector<ArgumentDescription> {
            {"granularity", "uint8_t", "WebCore::TextGranularity", false},
        };
    case MessageName::WebPage_SelectWordBackward:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_MoveSelectionByOffset:
        return Vector<ArgumentDescription> {
            {"offset", "int32_t", nullptr, false},
        };
    case MessageName::WebPage_SelectTextWithGranularityAtPoint:
        return Vector<ArgumentDescription> {
            {"point", "WebCore::IntPoint", nullptr, false},
            {"granularity", "uint8_t", "WebCore::TextGranularity", false},
            {"isInteractingWithFocusedElement", "bool", nullptr, false},
        };
    case MessageName::WebPage_SelectPositionAtBoundaryWithDirection:
        return Vector<ArgumentDescription> {
            {"point", "WebCore::IntPoint", nullptr, false},
            {"granularity", "uint8_t", "WebCore::TextGranularity", false},
            {"direction", "uint8_t", "WebCore::SelectionDirection", false},
            {"isInteractingWithFocusedElement", "bool", nullptr, false},
        };
    case MessageName::WebPage_MoveSelectionAtBoundaryWithDirection:
        return Vector<ArgumentDescription> {
            {"granularity", "uint8_t", "WebCore::TextGranularity", false},
            {"direction", "uint8_t", "WebCore::SelectionDirection", false},
        };
    case MessageName::WebPage_SelectPositionAtPoint:
        return Vector<ArgumentDescription> {
            {"point", "WebCore::IntPoint", nullptr, false},
            {"isInteractingWithFocusedElement", "bool", nullptr, false},
        };
    case MessageName::WebPage_BeginSelectionInDirection:
        return Vector<ArgumentDescription> {
            {"direction", "uint8_t", "WebCore::SelectionDirection", false},
        };
    case MessageName::WebPage_UpdateSelectionWithExtentPoint:
        return Vector<ArgumentDescription> {
            {"point", "WebCore::IntPoint", nullptr, false},
            {"isInteractingWithFocusedElement", "bool", nullptr, false},
            {"respectSelectionAnchor", "bool", "WebKit::RespectSelectionAnchor", false},
        };
    case MessageName::WebPage_UpdateSelectionWithExtentPointAndBoundary:
        return Vector<ArgumentDescription> {
            {"point", "WebCore::IntPoint", nullptr, false},
            {"granularity", "uint8_t", "WebCore::TextGranularity", false},
            {"isInteractingWithFocusedElement", "bool", nullptr, false},
        };
    case MessageName::WebPage_RequestDictationContext:
        return Vector<ArgumentDescription> { };
#endif
#if (PLATFORM(IOS_FAMILY) && ENABLE(REVEAL))
    case MessageName::WebPage_RequestRVItemInCurrentSelectedRange:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_PrepareSelectionForContextMenuWithLocationInView:
        return Vector<ArgumentDescription> {
            {"point", "WebCore::IntPoint", nullptr, false},
        };
#endif
#if PLATFORM(IOS_FAMILY)
    case MessageName::WebPage_ReplaceDictatedText:
        return Vector<ArgumentDescription> {
            {"oldText", "String", nullptr, false},
            {"newText", "String", nullptr, false},
        };
    case MessageName::WebPage_ReplaceSelectedText:
        return Vector<ArgumentDescription> {
            {"oldText", "String", nullptr, false},
            {"newText", "String", nullptr, false},
        };
    case MessageName::WebPage_RequestAutocorrectionData:
        return Vector<ArgumentDescription> {
            {"textForAutocorrection", "String", nullptr, false},
        };
    case MessageName::WebPage_ApplyAutocorrection:
        return Vector<ArgumentDescription> {
            {"correction", "String", nullptr, false},
            {"originalText", "String", nullptr, false},
        };
    case MessageName::WebPage_SyncApplyAutocorrection:
        return Vector<ArgumentDescription> {
            {"correction", "String", nullptr, false},
            {"originalText", "String", nullptr, false},
        };
    case MessageName::WebPage_HandleAutocorrectionContextRequest:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_RequestEvasionRectsAboveSelection:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_GetPositionInformation:
        return Vector<ArgumentDescription> {
            {"request", "WebKit::InteractionInformationRequest", nullptr, false},
        };
    case MessageName::WebPage_RequestPositionInformation:
        return Vector<ArgumentDescription> {
            {"request", "WebKit::InteractionInformationRequest", nullptr, false},
        };
    case MessageName::WebPage_StartInteractionWithElementContextOrPosition:
        return Vector<ArgumentDescription> {
            {"elementContext", "WebCore::ElementContext", nullptr, true},
            {"point", "WebCore::IntPoint", nullptr, false},
        };
    case MessageName::WebPage_StopInteraction:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_PerformActionOnElement:
        return Vector<ArgumentDescription> {
            {"action", "uint32_t", nullptr, false},
        };
    case MessageName::WebPage_FocusNextFocusedElement:
        return Vector<ArgumentDescription> {
            {"isForward", "bool", nullptr, false},
        };
    case MessageName::WebPage_AutofillLoginCredentials:
        return Vector<ArgumentDescription> {
            {"username", "String", nullptr, false},
            {"password", "String", nullptr, false},
        };
    case MessageName::WebPage_SetFocusedElementValue:
        return Vector<ArgumentDescription> {
            {"context", "WebCore::ElementContext", nullptr, false},
            {"value", "String", nullptr, false},
        };
    case MessageName::WebPage_SetFocusedElementSelectedIndex:
        return Vector<ArgumentDescription> {
            {"context", "WebCore::ElementContext", nullptr, false},
            {"index", "uint32_t", nullptr, false},
            {"allowMultipleSelection", "bool", nullptr, false},
        };
    case MessageName::WebPage_ApplicationWillResignActive:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_ApplicationDidEnterBackground:
        return Vector<ArgumentDescription> {
            {"isSuspendedUnderLock", "bool", nullptr, false},
        };
    case MessageName::WebPage_ApplicationDidFinishSnapshottingAfterEnteringBackground:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_ApplicationWillEnterForeground:
        return Vector<ArgumentDescription> {
            {"isSuspendedUnderLock", "bool", nullptr, false},
        };
    case MessageName::WebPage_ApplicationDidBecomeActive:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_ApplicationDidEnterBackgroundForMedia:
        return Vector<ArgumentDescription> {
            {"isSuspendedUnderLock", "bool", nullptr, false},
        };
    case MessageName::WebPage_ApplicationWillEnterForegroundForMedia:
        return Vector<ArgumentDescription> {
            {"isSuspendedUnderLock", "bool", nullptr, false},
        };
    case MessageName::WebPage_ContentSizeCategoryDidChange:
        return Vector<ArgumentDescription> {
            {"contentSizeCategory", "String", nullptr, false},
        };
    case MessageName::WebPage_GetSelectionContext:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_SetAllowsMediaDocumentInlinePlayback:
        return Vector<ArgumentDescription> {
            {"allows", "bool", nullptr, false},
        };
    case MessageName::WebPage_HandleTwoFingerTapAtPoint:
        return Vector<ArgumentDescription> {
            {"point", "WebCore::IntPoint", nullptr, false},
            {"modifiers", "OptionSet<WebKit::WebEvent::Modifier>", nullptr, false},
            {"requestID", "WebKit::TapIdentifier", nullptr, false},
        };
    case MessageName::WebPage_SetForceAlwaysUserScalable:
        return Vector<ArgumentDescription> {
            {"userScalable", "bool", nullptr, false},
        };
    case MessageName::WebPage_GetRectsForGranularityWithSelectionOffset:
        return Vector<ArgumentDescription> {
            {"granularity", "uint8_t", "WebCore::TextGranularity", false},
            {"offset", "int32_t", nullptr, false},
        };
    case MessageName::WebPage_GetRectsAtSelectionOffsetWithText:
        return Vector<ArgumentDescription> {
            {"offset", "int32_t", nullptr, false},
            {"text", "String", nullptr, false},
        };
    case MessageName::WebPage_StoreSelectionForAccessibility:
        return Vector<ArgumentDescription> {
            {"shouldStore", "bool", nullptr, false},
        };
    case MessageName::WebPage_StartAutoscrollAtPosition:
        return Vector<ArgumentDescription> {
            {"positionInWindow", "WebCore::FloatPoint", nullptr, false},
        };
    case MessageName::WebPage_CancelAutoscroll:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_RequestFocusedElementInformation:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_HardwareKeyboardAvailabilityChanged:
        return Vector<ArgumentDescription> {
            {"keyboardIsAttached", "bool", nullptr, false},
        };
    case MessageName::WebPage_SetIsShowingInputViewForFocusedElement:
        return Vector<ArgumentDescription> {
            {"showingInputView", "bool", nullptr, false},
        };
    case MessageName::WebPage_UpdateSelectionWithDelta:
        return Vector<ArgumentDescription> {
            {"locationDelta", "int64_t", nullptr, false},
            {"lengthDelta", "int64_t", nullptr, false},
        };
    case MessageName::WebPage_RequestDocumentEditingContext:
        return Vector<ArgumentDescription> {
            {"request", "WebKit::DocumentEditingContextRequest", nullptr, false},
        };
    case MessageName::WebPage_GenerateSyntheticEditingCommand:
        return Vector<ArgumentDescription> {
            {"command", "uint8_t", "WebKit::SyntheticEditingCommandType", false},
        };
    case MessageName::WebPage_SetShouldRevealCurrentSelectionAfterInsertion:
        return Vector<ArgumentDescription> {
            {"shouldRevealCurrentSelectionAfterInsertion", "bool", nullptr, false},
        };
    case MessageName::WebPage_InsertTextPlaceholder:
        return Vector<ArgumentDescription> {
            {"size", "WebCore::IntSize", nullptr, false},
        };
    case MessageName::WebPage_RemoveTextPlaceholder:
        return Vector<ArgumentDescription> {
            {"placeholder", "WebCore::ElementContext", nullptr, false},
        };
    case MessageName::WebPage_TextInputContextsInRect:
        return Vector<ArgumentDescription> {
            {"rect", "WebCore::FloatRect", nullptr, false},
        };
    case MessageName::WebPage_FocusTextInputContextAndPlaceCaret:
        return Vector<ArgumentDescription> {
            {"context", "WebCore::ElementContext", nullptr, false},
            {"point", "WebCore::IntPoint", nullptr, false},
        };
    case MessageName::WebPage_ClearServiceWorkerEntitlementOverride:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebPage_RequestImageBitmap:
        return Vector<ArgumentDescription> {
            {"elementContext", "WebCore::ElementContext", nullptr, false},
        };
#if ENABLE(IMAGE_ANALYSIS_ENHANCEMENTS)
    case MessageName::WebPage_InstallCroppedImageOverlay:
        return Vector<ArgumentDescription> {
            {"elementContext", "WebCore::ElementContext", nullptr, false},
            {"imageData", "WebKit::SharedMemory::IPCHandle", nullptr, false},
            {"mimeType", "String", nullptr, false},
            {"normalizedCropRect", "WebCore::FloatRect", nullptr, false},
        };
    case MessageName::WebPage_SetCroppedImageOverlayVisibility:
        return Vector<ArgumentDescription> {
            {"visible", "bool", nullptr, false},
        };
#endif
    case MessageName::WebPage_SetControlledByAutomation:
        return Vector<ArgumentDescription> {
            {"controlled", "bool", nullptr, false},
        };
    case MessageName::WebPage_ConnectInspector:
        return Vector<ArgumentDescription> {
            {"targetId", "String", nullptr, false},
            {"connectionType", "Inspector::FrontendChannel::ConnectionType", nullptr, false},
        };
    case MessageName::WebPage_DisconnectInspector:
        return Vector<ArgumentDescription> {
            {"targetId", "String", nullptr, false},
        };
    case MessageName::WebPage_SendMessageToTargetBackend:
        return Vector<ArgumentDescription> {
            {"targetId", "String", nullptr, false},
            {"message", "String", nullptr, false},
        };
#if ENABLE(REMOTE_INSPECTOR)
    case MessageName::WebPage_SetIndicating:
        return Vector<ArgumentDescription> {
            {"indicating", "bool", nullptr, false},
        };
#endif
#if ENABLE(IOS_TOUCH_EVENTS)
    case MessageName::WebPage_ResetPotentialTapSecurityOrigin:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_TouchEventSync:
        return Vector<ArgumentDescription> {
            {"event", "WebKit::WebTouchEvent", nullptr, false},
        };
#endif
#if !ENABLE(IOS_TOUCH_EVENTS) && ENABLE(TOUCH_EVENTS)
    case MessageName::WebPage_TouchEvent:
        return Vector<ArgumentDescription> {
            {"event", "WebKit::WebTouchEvent", nullptr, false},
        };
#endif
    case MessageName::WebPage_CancelPointer:
        return Vector<ArgumentDescription> {
            {"pointerId", "WebCore::PointerID", nullptr, false},
            {"documentPoint", "WebCore::IntPoint", nullptr, false},
        };
    case MessageName::WebPage_TouchWithIdentifierWasRemoved:
        return Vector<ArgumentDescription> {
            {"pointerId", "WebCore::PointerID", nullptr, false},
        };
#if ENABLE(INPUT_TYPE_COLOR)
    case MessageName::WebPage_DidEndColorPicker:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_DidChooseColor:
        return Vector<ArgumentDescription> {
            {"color", "WebCore::Color", nullptr, false},
        };
#endif
#if ENABLE(DATALIST_ELEMENT)
    case MessageName::WebPage_DidSelectDataListOption:
        return Vector<ArgumentDescription> {
            {"selectedOption", "String", nullptr, false},
        };
    case MessageName::WebPage_DidCloseSuggestions:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(DATE_AND_TIME_INPUT_TYPES)
    case MessageName::WebPage_DidChooseDate:
        return Vector<ArgumentDescription> {
            {"date", "String", nullptr, false},
        };
    case MessageName::WebPage_DidEndDateTimePicker:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebPage_ScrollBy:
        return Vector<ArgumentDescription> {
            {"scrollDirection", "uint32_t", nullptr, false},
            {"scrollGranularity", "uint8_t", "WebCore::ScrollGranularity", false},
        };
    case MessageName::WebPage_CenterSelectionInVisibleArea:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_GoToBackForwardItem:
        return Vector<ArgumentDescription> {
            {"navigationID", "uint64_t", nullptr, false},
            {"backForwardItemID", "WebCore::BackForwardItemIdentifier", nullptr, false},
            {"backForwardType", "uint8_t", "WebCore::FrameLoadType", false},
            {"shouldTreatAsContinuingLoad", "uint8_t", "WebCore::ShouldTreatAsContinuingLoad", false},
            {"websitePolicies", "WebKit::WebsitePoliciesData", nullptr, true},
            {"lastNavigationWasAppInitiated", "bool", nullptr, false},
            {"existingNetworkResourceLoadIdentifierToResume", "WebKit::NetworkResourceLoadIdentifier", nullptr, true},
        };
    case MessageName::WebPage_TryRestoreScrollPosition:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_LoadURLInFrame:
        return Vector<ArgumentDescription> {
            {"url", "URL", nullptr, false},
            {"referrer", "String", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
        };
    case MessageName::WebPage_LoadDataInFrame:
        return Vector<ArgumentDescription> {
            {"data", "IPC::DataReference", nullptr, false},
            {"MIMEType", "String", nullptr, false},
            {"encodingName", "String", nullptr, false},
            {"baseURL", "URL", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
        };
    case MessageName::WebPage_LoadRequest:
        return Vector<ArgumentDescription> {
            {"loadParameters", "WebKit::LoadParameters", nullptr, false},
        };
    case MessageName::WebPage_LoadRequestWaitingForProcessLaunch:
        return Vector<ArgumentDescription> {
            {"loadParameters", "WebKit::LoadParameters", nullptr, false},
            {"resourceDirectoryURL", "URL", nullptr, false},
            {"pageID", "WebKit::WebPageProxyIdentifier", nullptr, false},
            {"checkAssumedReadAccessToResourceURL", "bool", nullptr, false},
        };
    case MessageName::WebPage_LoadData:
        return Vector<ArgumentDescription> {
            {"loadParameters", "WebKit::LoadParameters", nullptr, false},
        };
    case MessageName::WebPage_LoadSimulatedRequestAndResponse:
        return Vector<ArgumentDescription> {
            {"loadParameters", "WebKit::LoadParameters", nullptr, false},
            {"simulatedResponse", "WebCore::ResourceResponse", nullptr, false},
        };
    case MessageName::WebPage_LoadAlternateHTML:
        return Vector<ArgumentDescription> {
            {"loadParameters", "WebKit::LoadParameters", nullptr, false},
        };
    case MessageName::WebPage_NavigateToPDFLinkWithSimulatedClick:
        return Vector<ArgumentDescription> {
            {"url", "String", nullptr, false},
            {"documentPoint", "WebCore::IntPoint", nullptr, false},
            {"screenPoint", "WebCore::IntPoint", nullptr, false},
        };
    case MessageName::WebPage_GetPDFFirstPageSize:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
        };
    case MessageName::WebPage_Reload:
        return Vector<ArgumentDescription> {
            {"navigationID", "uint64_t", nullptr, false},
            {"reloadOptions", "uint32_t", nullptr, false},
            {"sandboxExtensionHandle", "WebKit::SandboxExtension::Handle", nullptr, false},
        };
    case MessageName::WebPage_StopLoading:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_StopLoadingFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
        };
    case MessageName::WebPage_RestoreSession:
        return Vector<ArgumentDescription> {
            {"itemStates", "Vector<WebKit::BackForwardListItemState>", nullptr, false},
        };
    case MessageName::WebPage_UpdateBackForwardListForReattach:
        return Vector<ArgumentDescription> {
            {"itemStates", "Vector<WebKit::BackForwardListItemState>", nullptr, false},
        };
    case MessageName::WebPage_SetCurrentHistoryItemForReattach:
        return Vector<ArgumentDescription> {
            {"itemState", "WebKit::BackForwardListItemState", nullptr, false},
        };
    case MessageName::WebPage_DidRemoveBackForwardItem:
        return Vector<ArgumentDescription> {
            {"backForwardItemID", "WebCore::BackForwardItemIdentifier", nullptr, false},
        };
    case MessageName::WebPage_UpdateWebsitePolicies:
        return Vector<ArgumentDescription> {
            {"websitePolicies", "WebKit::WebsitePoliciesData", nullptr, false},
        };
    case MessageName::WebPage_NotifyUserScripts:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_DidReceivePolicyDecision:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"listenerID", "uint64_t", nullptr, false},
            {"policyDecision", "WebKit::PolicyDecision", nullptr, false},
            {"networkExtensionsSandboxExtensions", "Vector<WebKit::SandboxExtension::Handle>", nullptr, false},
        };
    case MessageName::WebPage_ContinueWillSubmitForm:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"listenerID", "WebKit::FormSubmitListenerIdentifier", nullptr, false},
        };
    case MessageName::WebPage_ClearSelection:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_RestoreSelectionInFocusedEditableElement:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_GetContentsAsString:
        return Vector<ArgumentDescription> {
            {"inChildFrames", "bool", "WebKit::ContentAsStringIncludesChildFrames", false},
        };
    case MessageName::WebPage_GetAllFrames:
        return Vector<ArgumentDescription> { };
#if PLATFORM(COCOA)
    case MessageName::WebPage_GetContentsAsAttributedString:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(MHTML)
    case MessageName::WebPage_GetContentsAsMHTMLData:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebPage_GetMainResourceDataOfFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
        };
    case MessageName::WebPage_GetResourceDataFromFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"resourceURL", "String", nullptr, false},
        };
    case MessageName::WebPage_GetRenderTreeExternalRepresentation:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_GetSelectionOrContentsAsString:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_GetSelectionAsWebArchiveData:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_GetSourceForFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
        };
    case MessageName::WebPage_GetWebArchiveOfFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
        };
    case MessageName::WebPage_RunJavaScriptInFrameInScriptWorld:
        return Vector<ArgumentDescription> {
            {"parameters", "WebCore::RunJavaScriptParameters", nullptr, false},
            {"frameID", "WebCore::FrameIdentifier", nullptr, true},
            {"world", "std::pair<WebKit::ContentWorldIdentifier, String>", nullptr, false},
        };
    case MessageName::WebPage_ForceRepaint:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_SelectAll:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_ScheduleFullEditorStateUpdate:
        return Vector<ArgumentDescription> { };
#if PLATFORM(COCOA)
    case MessageName::WebPage_PerformDictionaryLookupOfCurrentSelection:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_PerformDictionaryLookupAtLocation:
        return Vector<ArgumentDescription> {
            {"point", "WebCore::FloatPoint", nullptr, false},
        };
#endif
#if ENABLE(DATA_DETECTION)
    case MessageName::WebPage_DetectDataInAllFrames:
        return Vector<ArgumentDescription> {
            {"types", "OptionSet<WebCore::DataDetectorType>", nullptr, false},
        };
    case MessageName::WebPage_RemoveDataDetectedLinks:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebPage_ChangeFont:
        return Vector<ArgumentDescription> {
            {"changes", "WebCore::FontChanges", nullptr, false},
        };
    case MessageName::WebPage_ChangeFontAttributes:
        return Vector<ArgumentDescription> {
            {"changes", "WebCore::FontAttributeChanges", nullptr, false},
        };
    case MessageName::WebPage_PreferencesDidChange:
        return Vector<ArgumentDescription> {
            {"store", "WebKit::WebPreferencesStore", nullptr, false},
        };
    case MessageName::WebPage_SetUserAgent:
        return Vector<ArgumentDescription> {
            {"userAgent", "String", nullptr, false},
        };
    case MessageName::WebPage_SetCustomTextEncodingName:
        return Vector<ArgumentDescription> {
            {"encodingName", "String", nullptr, false},
        };
    case MessageName::WebPage_SuspendActiveDOMObjectsAndAnimations:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_ResumeActiveDOMObjectsAndAnimations:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_Suspend:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_Resume:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_Close:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_TryClose:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_SetEditable:
        return Vector<ArgumentDescription> {
            {"editable", "bool", nullptr, false},
        };
    case MessageName::WebPage_ValidateCommand:
        return Vector<ArgumentDescription> {
            {"name", "String", nullptr, false},
        };
    case MessageName::WebPage_ExecuteEditCommand:
        return Vector<ArgumentDescription> {
            {"name", "String", nullptr, false},
            {"argument", "String", nullptr, false},
        };
    case MessageName::WebPage_IncreaseListLevel:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_DecreaseListLevel:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_ChangeListType:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_SetBaseWritingDirection:
        return Vector<ArgumentDescription> {
            {"direction", "uint8_t", "WebCore::WritingDirection", false},
        };
    case MessageName::WebPage_SetNeedsFontAttributes:
        return Vector<ArgumentDescription> {
            {"needsFontAttributes", "bool", nullptr, false},
        };
    case MessageName::WebPage_RequestFontAttributesAtSelectionStart:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_DidRemoveEditCommand:
        return Vector<ArgumentDescription> {
            {"commandID", "uint64_t", nullptr, false},
        };
    case MessageName::WebPage_ReapplyEditCommand:
        return Vector<ArgumentDescription> {
            {"commandID", "uint64_t", nullptr, false},
        };
    case MessageName::WebPage_UnapplyEditCommand:
        return Vector<ArgumentDescription> {
            {"commandID", "uint64_t", nullptr, false},
        };
    case MessageName::WebPage_SetPageAndTextZoomFactors:
        return Vector<ArgumentDescription> {
            {"pageZoomFactor", "double", nullptr, false},
            {"textZoomFactor", "double", nullptr, false},
        };
    case MessageName::WebPage_SetPageZoomFactor:
        return Vector<ArgumentDescription> {
            {"zoomFactor", "double", nullptr, false},
        };
    case MessageName::WebPage_SetTextZoomFactor:
        return Vector<ArgumentDescription> {
            {"zoomFactor", "double", nullptr, false},
        };
    case MessageName::WebPage_WindowScreenDidChange:
        return Vector<ArgumentDescription> {
            {"displayID", "uint32_t", nullptr, false},
            {"nominalFramesPerSecond", "unsigned", nullptr, true},
        };
    case MessageName::WebPage_AccessibilitySettingsDidChange:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_ScalePage:
        return Vector<ArgumentDescription> {
            {"scale", "double", nullptr, false},
            {"origin", "WebCore::IntPoint", nullptr, false},
        };
    case MessageName::WebPage_ScalePageInViewCoordinates:
        return Vector<ArgumentDescription> {
            {"scale", "double", nullptr, false},
            {"centerInViewCoordinates", "WebCore::IntPoint", nullptr, false},
        };
    case MessageName::WebPage_ScaleView:
        return Vector<ArgumentDescription> {
            {"scale", "double", nullptr, false},
        };
    case MessageName::WebPage_SetUseFixedLayout:
        return Vector<ArgumentDescription> {
            {"fixed", "bool", nullptr, false},
        };
    case MessageName::WebPage_SetFixedLayoutSize:
        return Vector<ArgumentDescription> {
            {"size", "WebCore::IntSize", nullptr, false},
        };
    case MessageName::WebPage_ListenForLayoutMilestones:
        return Vector<ArgumentDescription> {
            {"layoutMilestones", "OptionSet<WebCore::LayoutMilestone>", nullptr, false},
        };
    case MessageName::WebPage_SetSuppressScrollbarAnimations:
        return Vector<ArgumentDescription> {
            {"suppressAnimations", "bool", nullptr, false},
        };
    case MessageName::WebPage_SetEnableVerticalRubberBanding:
        return Vector<ArgumentDescription> {
            {"enableVerticalRubberBanding", "bool", nullptr, false},
        };
    case MessageName::WebPage_SetEnableHorizontalRubberBanding:
        return Vector<ArgumentDescription> {
            {"enableHorizontalRubberBanding", "bool", nullptr, false},
        };
    case MessageName::WebPage_SetBackgroundExtendsBeyondPage:
        return Vector<ArgumentDescription> {
            {"backgroundExtendsBeyondPage", "bool", nullptr, false},
        };
    case MessageName::WebPage_SetPaginationMode:
        return Vector<ArgumentDescription> {
            {"mode", "uint32_t", nullptr, false},
        };
    case MessageName::WebPage_SetPaginationBehavesLikeColumns:
        return Vector<ArgumentDescription> {
            {"behavesLikeColumns", "bool", nullptr, false},
        };
    case MessageName::WebPage_SetPageLength:
        return Vector<ArgumentDescription> {
            {"pageLength", "double", nullptr, false},
        };
    case MessageName::WebPage_SetGapBetweenPages:
        return Vector<ArgumentDescription> {
            {"gap", "double", nullptr, false},
        };
    case MessageName::WebPage_SetPaginationLineGridEnabled:
        return Vector<ArgumentDescription> {
            {"lineGridEnabled", "bool", nullptr, false},
        };
    case MessageName::WebPage_PostInjectedBundleMessage:
        return Vector<ArgumentDescription> {
            {"messageName", "String", nullptr, false},
            {"messageBody", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebPage_FindString:
        return Vector<ArgumentDescription> {
            {"string", "String", nullptr, false},
            {"findOptions", "OptionSet<WebKit::FindOptions>", nullptr, false},
            {"maxMatchCount", "unsigned", nullptr, false},
        };
    case MessageName::WebPage_FindStringMatches:
        return Vector<ArgumentDescription> {
            {"string", "String", nullptr, false},
            {"findOptions", "OptionSet<WebKit::FindOptions>", nullptr, false},
            {"maxMatchCount", "unsigned", nullptr, false},
        };
    case MessageName::WebPage_GetImageForFindMatch:
        return Vector<ArgumentDescription> {
            {"matchIndex", "uint32_t", nullptr, false},
        };
    case MessageName::WebPage_SelectFindMatch:
        return Vector<ArgumentDescription> {
            {"matchIndex", "uint32_t", nullptr, false},
        };
    case MessageName::WebPage_IndicateFindMatch:
        return Vector<ArgumentDescription> {
            {"matchIndex", "uint32_t", nullptr, false},
        };
    case MessageName::WebPage_HideFindUI:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_CountStringMatches:
        return Vector<ArgumentDescription> {
            {"string", "String", nullptr, false},
            {"findOptions", "OptionSet<WebKit::FindOptions>", nullptr, false},
            {"maxMatchCount", "unsigned", nullptr, false},
        };
    case MessageName::WebPage_ReplaceMatches:
        return Vector<ArgumentDescription> {
            {"matchIndices", "Vector<uint32_t>", nullptr, false},
            {"replacementText", "String", nullptr, false},
            {"selectionOnly", "bool", nullptr, false},
        };
    case MessageName::WebPage_FindRectsForStringMatches:
        return Vector<ArgumentDescription> {
            {"string", "String", nullptr, false},
            {"findOptions", "OptionSet<WebKit::FindOptions>", nullptr, false},
            {"maxMatchCount", "unsigned", nullptr, false},
        };
    case MessageName::WebPage_HideFindIndicator:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_FindTextRangesForStringMatches:
        return Vector<ArgumentDescription> {
            {"string", "String", nullptr, false},
            {"findOptions", "OptionSet<WebKit::FindOptions>", nullptr, false},
            {"maxMatchCount", "unsigned", nullptr, false},
        };
    case MessageName::WebPage_DecorateTextRangeWithStyle:
        return Vector<ArgumentDescription> {
            {"range", "WebKit::WebFoundTextRange", nullptr, false},
            {"style", "uint8_t", "WebKit::FindDecorationStyle", false},
        };
    case MessageName::WebPage_ScrollTextRangeToVisible:
        return Vector<ArgumentDescription> {
            {"range", "WebKit::WebFoundTextRange", nullptr, false},
        };
    case MessageName::WebPage_ClearAllDecoratedFoundText:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_DidBeginTextSearchOperation:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_DidEndTextSearchOperation:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_RequestRectForFoundTextRange:
        return Vector<ArgumentDescription> {
            {"range", "WebKit::WebFoundTextRange", nullptr, false},
        };
    case MessageName::WebPage_AddMIMETypeWithCustomContentProvider:
        return Vector<ArgumentDescription> {
            {"mimeType", "String", nullptr, false},
        };
#if PLATFORM(GTK) && ENABLE(DRAG_SUPPORT)
    case MessageName::WebPage_PerformDragControllerAction:
        return Vector<ArgumentDescription> {
            {"action", "uint8_t", "WebKit::DragControllerAction", false},
            {"clientPosition", "WebCore::IntPoint", nullptr, false},
            {"globalPosition", "WebCore::IntPoint", nullptr, false},
            {"draggingSourceOperationMask", "OptionSet<WebCore::DragOperation>", nullptr, false},
            {"selection", "WebCore::SelectionData", nullptr, false},
            {"flags", "OptionSet<WebCore::DragApplicationFlags>", nullptr, false},
        };
#endif
#if !PLATFORM(GTK) && ENABLE(DRAG_SUPPORT)
    case MessageName::WebPage_PerformDragControllerAction:
        return Vector<ArgumentDescription> {
            {"action", "uint8_t", "WebKit::DragControllerAction", false},
            {"dragData", "WebCore::DragData", nullptr, false},
            {"sandboxExtensionHandle", "WebKit::SandboxExtension::Handle", nullptr, false},
            {"sandboxExtensionsForUpload", "Vector<WebKit::SandboxExtension::Handle>", nullptr, false},
        };
#endif
#if ENABLE(DRAG_SUPPORT)
    case MessageName::WebPage_DidStartDrag:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_DragEnded:
        return Vector<ArgumentDescription> {
            {"clientPosition", "WebCore::IntPoint", nullptr, false},
            {"globalPosition", "WebCore::IntPoint", nullptr, false},
            {"dragOperationMask", "OptionSet<WebCore::DragOperation>", nullptr, false},
        };
    case MessageName::WebPage_DragCancelled:
        return Vector<ArgumentDescription> { };
#endif
#if PLATFORM(IOS_FAMILY) && ENABLE(DRAG_SUPPORT)
    case MessageName::WebPage_RequestDragStart:
        return Vector<ArgumentDescription> {
            {"clientPosition", "WebCore::IntPoint", nullptr, false},
            {"globalPosition", "WebCore::IntPoint", nullptr, false},
            {"allowedActionsMask", "OptionSet<WebCore::DragSourceAction>", nullptr, false},
        };
    case MessageName::WebPage_RequestAdditionalItemsForDragSession:
        return Vector<ArgumentDescription> {
            {"clientPosition", "WebCore::IntPoint", nullptr, false},
            {"globalPosition", "WebCore::IntPoint", nullptr, false},
            {"allowedActionsMask", "OptionSet<WebCore::DragSourceAction>", nullptr, false},
        };
    case MessageName::WebPage_InsertDroppedImagePlaceholders:
        return Vector<ArgumentDescription> {
            {"imageSize", "Vector<WebCore::IntSize>", nullptr, false},
        };
    case MessageName::WebPage_DidConcludeDrop:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebPage_DidChangeSelectedIndexForActivePopupMenu:
        return Vector<ArgumentDescription> {
            {"newIndex", "int32_t", nullptr, false},
        };
    case MessageName::WebPage_SetTextForActivePopupMenu:
        return Vector<ArgumentDescription> {
            {"index", "int32_t", nullptr, false},
        };
#if PLATFORM(GTK)
    case MessageName::WebPage_FailedToShowPopupMenu:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(CONTEXT_MENUS)
    case MessageName::WebPage_DidShowContextMenu:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_DidDismissContextMenu:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_DidSelectItemFromActiveContextMenu:
        return Vector<ArgumentDescription> {
            {"menuItem", "WebKit::WebContextMenuItemData", nullptr, false},
        };
    case MessageName::WebPage_ContextMenuForKeyEvent:
        return Vector<ArgumentDescription> { };
#endif
#if PLATFORM(IOS_FAMILY)
    case MessageName::WebPage_DidChooseFilesForOpenPanelWithDisplayStringAndIcon:
        return Vector<ArgumentDescription> {
            {"fileURLs", "Vector<String>", nullptr, false},
            {"displayString", "String", nullptr, false},
            {"iconData", "IPC::DataReference", nullptr, false},
            {"frontboardServicesSandboxExtension", "WebKit::SandboxExtension::Handle", nullptr, false},
            {"iconServicesSandboxExtension", "WebKit::SandboxExtension::Handle", nullptr, false},
        };
#endif
    case MessageName::WebPage_DidChooseFilesForOpenPanel:
        return Vector<ArgumentDescription> {
            {"fileURLs", "Vector<String>", nullptr, false},
            {"replacementURLs", "Vector<String>", nullptr, false},
        };
    case MessageName::WebPage_DidCancelForOpenPanel:
        return Vector<ArgumentDescription> { };
#if ENABLE(SANDBOX_EXTENSIONS)
    case MessageName::WebPage_ExtendSandboxForFilesFromOpenPanel:
        return Vector<ArgumentDescription> {
            {"sandboxExtensions", "Vector<WebKit::SandboxExtension::Handle>", nullptr, false},
        };
#endif
    case MessageName::WebPage_AdvanceToNextMisspelling:
        return Vector<ArgumentDescription> {
            {"startBeforeSelection", "bool", nullptr, false},
        };
    case MessageName::WebPage_ChangeSpellingToWord:
        return Vector<ArgumentDescription> {
            {"word", "String", nullptr, false},
        };
    case MessageName::WebPage_DidFinishCheckingText:
        return Vector<ArgumentDescription> {
            {"requestID", "WebKit::TextCheckerRequestID", nullptr, false},
            {"result", "Vector<WebCore::TextCheckingResult>", nullptr, false},
        };
    case MessageName::WebPage_DidCancelCheckingText:
        return Vector<ArgumentDescription> {
            {"requestID", "WebKit::TextCheckerRequestID", nullptr, false},
        };
#if USE(APPKIT)
    case MessageName::WebPage_UppercaseWord:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_LowercaseWord:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_CapitalizeWord:
        return Vector<ArgumentDescription> { };
#endif
#if PLATFORM(COCOA)
    case MessageName::WebPage_SetSmartInsertDeleteEnabled:
        return Vector<ArgumentDescription> {
            {"isSmartInsertDeleteEnabled", "bool", nullptr, false},
        };
#endif
#if ENABLE(GEOLOCATION)
    case MessageName::WebPage_DidReceiveGeolocationPermissionDecision:
        return Vector<ArgumentDescription> {
            {"geolocationID", "WebKit::GeolocationIdentifier", nullptr, false},
            {"authorizationToken", "String", nullptr, false},
        };
#endif
#if ENABLE(MEDIA_STREAM)
    case MessageName::WebPage_UserMediaAccessWasGranted:
        return Vector<ArgumentDescription> {
            {"userMediaID", "WebCore::UserMediaRequestIdentifier", nullptr, false},
            {"audioDevice", "WebCore::CaptureDevice", nullptr, false},
            {"videoDevice", "WebCore::CaptureDevice", nullptr, false},
            {"mediaDeviceIdentifierHashSalt", "String", nullptr, false},
            {"sandboxExtensionHandle", "WebKit::SandboxExtension::Handle", nullptr, false},
        };
    case MessageName::WebPage_UserMediaAccessWasDenied:
        return Vector<ArgumentDescription> {
            {"userMediaID", "WebCore::UserMediaRequestIdentifier", nullptr, false},
            {"reason", "uint64_t", nullptr, false},
            {"invalidConstraint", "String", nullptr, false},
        };
    case MessageName::WebPage_CaptureDevicesChanged:
        return Vector<ArgumentDescription> { };
#endif
#if (ENABLE(MEDIA_STREAM) && USE(GSTREAMER))
    case MessageName::WebPage_SetOrientationForMediaCapture:
        return Vector<ArgumentDescription> {
            {"rotation", "int", nullptr, false},
        };
    case MessageName::WebPage_SetMockCaptureDevicesInterrupted:
        return Vector<ArgumentDescription> {
            {"isCameraInterrupted", "bool", nullptr, false},
            {"isMicrophoneInterrupted", "bool", nullptr, false},
        };
#endif
#if ENABLE(ENCRYPTED_MEDIA)
    case MessageName::WebPage_MediaKeySystemWasGranted:
        return Vector<ArgumentDescription> {
            {"mediaKeySystemID", "WebCore::MediaKeySystemRequestIdentifier", nullptr, false},
        };
    case MessageName::WebPage_MediaKeySystemWasDenied:
        return Vector<ArgumentDescription> {
            {"mediaKeySystemID", "WebCore::MediaKeySystemRequestIdentifier", nullptr, false},
            {"message", "String", nullptr, false},
        };
#endif
    case MessageName::WebPage_RequestMediaPlaybackState:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_PauseAllMediaPlayback:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_SuspendAllMediaPlayback:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_ResumeAllMediaPlayback:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_FreezeLayerTreeDueToSwipeAnimation:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_UnfreezeLayerTreeDueToSwipeAnimation:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_IsLayerTreeFrozen:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_BeginPrinting:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"printInfo", "WebKit::PrintInfo", nullptr, false},
        };
    case MessageName::WebPage_EndPrinting:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_ComputePagesForPrinting:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"printInfo", "WebKit::PrintInfo", nullptr, false},
        };
#if PLATFORM(COCOA)
    case MessageName::WebPage_DrawRectToImage:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"printInfo", "WebKit::PrintInfo", nullptr, false},
            {"rect", "WebCore::IntRect", nullptr, false},
            {"imageSize", "WebCore::IntSize", nullptr, false},
        };
    case MessageName::WebPage_DrawPagesToPDF:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"printInfo", "WebKit::PrintInfo", nullptr, false},
            {"first", "uint32_t", nullptr, false},
            {"count", "uint32_t", nullptr, false},
        };
#endif
#if (PLATFORM(COCOA) && PLATFORM(IOS_FAMILY) && !HAVE(UIKIT_BACKGROUND_THREAD_PRINTING))
    case MessageName::WebPage_ComputePagesForPrintingiOS:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"printInfo", "WebKit::PrintInfo", nullptr, false},
        };
#endif
#if (PLATFORM(COCOA) && PLATFORM(IOS_FAMILY))
    case MessageName::WebPage_DrawToPDFiOS:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"printInfo", "WebKit::PrintInfo", nullptr, false},
            {"pageCount", "size_t", nullptr, false},
        };
#endif
#if PLATFORM(COCOA)
    case MessageName::WebPage_DrawToPDF:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"rect", "WebCore::FloatRect", nullptr, true},
        };
#endif
#if PLATFORM(GTK)
    case MessageName::WebPage_DrawPagesForPrinting:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"printInfo", "WebKit::PrintInfo", nullptr, false},
        };
#endif
    case MessageName::WebPage_SetMediaVolume:
        return Vector<ArgumentDescription> {
            {"volume", "float", nullptr, false},
        };
    case MessageName::WebPage_SetMuted:
        return Vector<ArgumentDescription> {
            {"muted", "OptionSet<WebCore::MediaProducerMutedState>", nullptr, false},
        };
    case MessageName::WebPage_SetMayStartMediaWhenInWindow:
        return Vector<ArgumentDescription> {
            {"mayStartMedia", "bool", nullptr, false},
        };
    case MessageName::WebPage_StopMediaCapture:
        return Vector<ArgumentDescription> {
            {"kind", "uint8_t", "WebCore::MediaProducerMediaCaptureKind", false},
        };
    case MessageName::WebPage_SetCanRunBeforeUnloadConfirmPanel:
        return Vector<ArgumentDescription> {
            {"canRunBeforeUnloadConfirmPanel", "bool", nullptr, false},
        };
    case MessageName::WebPage_SetCanRunModal:
        return Vector<ArgumentDescription> {
            {"canRunModal", "bool", nullptr, false},
        };
#if PLATFORM(GTK) || PLATFORM(WPE)
    case MessageName::WebPage_CancelComposition:
        return Vector<ArgumentDescription> {
            {"text", "String", nullptr, false},
        };
    case MessageName::WebPage_DeleteSurrounding:
        return Vector<ArgumentDescription> {
            {"offset", "int64_t", nullptr, false},
            {"characterCount", "unsigned", nullptr, false},
        };
#endif
#if PLATFORM(GTK)
    case MessageName::WebPage_CollapseSelectionInFrame:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
        };
#endif
#if PLATFORM(COCOA)
    case MessageName::WebPage_WindowAndViewFramesChanged:
        return Vector<ArgumentDescription> {
            {"windowFrameInScreenCoordinates", "WebCore::FloatRect", nullptr, false},
            {"windowFrameInUnflippedScreenCoordinates", "WebCore::FloatRect", nullptr, false},
            {"viewFrameInWindowCoordinates", "WebCore::FloatRect", nullptr, false},
            {"accessibilityViewCoordinates", "WebCore::FloatPoint", nullptr, false},
        };
    case MessageName::WebPage_SetMainFrameIsScrollable:
        return Vector<ArgumentDescription> {
            {"isScrollable", "bool", nullptr, false},
        };
    case MessageName::WebPage_RegisterUIProcessAccessibilityTokens:
        return Vector<ArgumentDescription> {
            {"elemenToken", "IPC::DataReference", nullptr, false},
            {"windowToken", "IPC::DataReference", nullptr, false},
        };
    case MessageName::WebPage_GetStringSelectionForPasteboard:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_GetDataSelectionForPasteboard:
        return Vector<ArgumentDescription> {
            {"pasteboardType", "String", nullptr, false},
        };
    case MessageName::WebPage_ReadSelectionFromPasteboard:
        return Vector<ArgumentDescription> {
            {"pasteboardName", "String", nullptr, false},
        };
    case MessageName::WebPage_ReplaceWithPasteboardData:
        return Vector<ArgumentDescription> {
            {"context", "WebCore::ElementContext", nullptr, false},
            {"types", "Vector<String>", nullptr, false},
            {"data", "IPC::DataReference", nullptr, false},
        };
    case MessageName::WebPage_ReplaceSelectionWithPasteboardData:
        return Vector<ArgumentDescription> {
            {"types", "Vector<String>", nullptr, false},
            {"data", "IPC::DataReference", nullptr, false},
        };
    case MessageName::WebPage_ShouldDelayWindowOrderingEvent:
        return Vector<ArgumentDescription> {
            {"event", "WebKit::WebMouseEvent", nullptr, false},
        };
    case MessageName::WebPage_SetTextAsync:
        return Vector<ArgumentDescription> {
            {"text", "String", nullptr, false},
        };
    case MessageName::WebPage_InsertTextAsync:
        return Vector<ArgumentDescription> {
            {"text", "String", nullptr, false},
            {"replacementRange", "WebKit::EditingRange", nullptr, false},
            {"options", "WebKit::InsertTextOptions", nullptr, false},
        };
    case MessageName::WebPage_InsertDictatedTextAsync:
        return Vector<ArgumentDescription> {
            {"text", "String", nullptr, false},
            {"replacementRange", "WebKit::EditingRange", nullptr, false},
            {"dictationAlternatives", "Vector<WebCore::DictationAlternative>", nullptr, false},
            {"options", "WebKit::InsertTextOptions", nullptr, false},
        };
    case MessageName::WebPage_HasMarkedText:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_GetMarkedRangeAsync:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_GetSelectedRangeAsync:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_CharacterIndexForPointAsync:
        return Vector<ArgumentDescription> {
            {"point", "WebCore::IntPoint", nullptr, false},
        };
    case MessageName::WebPage_FirstRectForCharacterRangeAsync:
        return Vector<ArgumentDescription> {
            {"range", "WebKit::EditingRange", nullptr, false},
        };
    case MessageName::WebPage_SetCompositionAsync:
        return Vector<ArgumentDescription> {
            {"text", "String", nullptr, false},
            {"underlines", "Vector<WebCore::CompositionUnderline>", nullptr, false},
            {"highlights", "Vector<WebCore::CompositionHighlight>", nullptr, false},
            {"selectionRange", "WebKit::EditingRange", nullptr, false},
            {"replacementRange", "WebKit::EditingRange", nullptr, false},
        };
    case MessageName::WebPage_ConfirmCompositionAsync:
        return Vector<ArgumentDescription> { };
#endif
#if PLATFORM(MAC)
    case MessageName::WebPage_AttributedSubstringForCharacterRangeAsync:
        return Vector<ArgumentDescription> {
            {"range", "WebKit::EditingRange", nullptr, false},
        };
    case MessageName::WebPage_RequestAcceptsFirstMouse:
        return Vector<ArgumentDescription> {
            {"eventNumber", "int", nullptr, false},
            {"event", "WebKit::WebMouseEvent", nullptr, false},
        };
#endif
    case MessageName::WebPage_SetAlwaysShowsHorizontalScroller:
        return Vector<ArgumentDescription> {
            {"alwaysShowsHorizontalScroller", "bool", nullptr, false},
        };
    case MessageName::WebPage_SetAlwaysShowsVerticalScroller:
        return Vector<ArgumentDescription> {
            {"alwaysShowsVerticalScroller", "bool", nullptr, false},
        };
    case MessageName::WebPage_SetMinimumSizeForAutoLayout:
        return Vector<ArgumentDescription> {
            {"size", "WebCore::IntSize", nullptr, false},
        };
    case MessageName::WebPage_SetSizeToContentAutoSizeMaximumSize:
        return Vector<ArgumentDescription> {
            {"size", "WebCore::IntSize", nullptr, false},
        };
    case MessageName::WebPage_SetAutoSizingShouldExpandToViewHeight:
        return Vector<ArgumentDescription> {
            {"shouldExpand", "bool", nullptr, false},
        };
    case MessageName::WebPage_SetViewportSizeForCSSViewportUnits:
        return Vector<ArgumentDescription> {
            {"viewportSize", "WebCore::FloatSize", nullptr, true},
        };
#if PLATFORM(COCOA)
    case MessageName::WebPage_HandleAlternativeTextUIResult:
        return Vector<ArgumentDescription> {
            {"result", "String", nullptr, false},
        };
#endif
#if PLATFORM(IOS_FAMILY)
    case MessageName::WebPage_WillStartUserTriggeredZooming:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebPage_SetScrollPinningBehavior:
        return Vector<ArgumentDescription> {
            {"pinning", "uint32_t", nullptr, false},
        };
    case MessageName::WebPage_SetScrollbarOverlayStyle:
        return Vector<ArgumentDescription> {
            {"scrollbarStyle", "uint32_t", nullptr, true},
        };
    case MessageName::WebPage_GetBytecodeProfile:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_GetSamplingProfilerOutput:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_TakeSnapshot:
        return Vector<ArgumentDescription> {
            {"snapshotRect", "WebCore::IntRect", nullptr, false},
            {"bitmapSize", "WebCore::IntSize", nullptr, false},
            {"options", "uint32_t", nullptr, false},
        };
#if PLATFORM(MAC)
    case MessageName::WebPage_PerformImmediateActionHitTestAtLocation:
        return Vector<ArgumentDescription> {
            {"location", "WebCore::FloatPoint", nullptr, false},
        };
    case MessageName::WebPage_ImmediateActionDidUpdate:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_ImmediateActionDidCancel:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_ImmediateActionDidComplete:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_DataDetectorsDidPresentUI:
        return Vector<ArgumentDescription> {
            {"pageOverlay", "WebCore::PageOverlay::PageOverlayID", nullptr, false},
        };
    case MessageName::WebPage_DataDetectorsDidChangeUI:
        return Vector<ArgumentDescription> {
            {"pageOverlay", "WebCore::PageOverlay::PageOverlayID", nullptr, false},
        };
    case MessageName::WebPage_DataDetectorsDidHideUI:
        return Vector<ArgumentDescription> {
            {"pageOverlay", "WebCore::PageOverlay::PageOverlayID", nullptr, false},
        };
    case MessageName::WebPage_HandleAcceptedCandidate:
        return Vector<ArgumentDescription> {
            {"acceptedCandidate", "WebCore::TextCheckingResult", nullptr, false},
        };
    case MessageName::WebPage_SetUseSystemAppearance:
        return Vector<ArgumentDescription> {
            {"useSystemAppearance", "bool", nullptr, false},
        };
    case MessageName::WebPage_SetHeaderBannerHeightForTesting:
        return Vector<ArgumentDescription> {
            {"height", "int", nullptr, false},
        };
    case MessageName::WebPage_SetFooterBannerHeightForTesting:
        return Vector<ArgumentDescription> {
            {"height", "int", nullptr, false},
        };
    case MessageName::WebPage_DidEndMagnificationGesture:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebPage_EffectiveAppearanceDidChange:
        return Vector<ArgumentDescription> {
            {"useDarkAppearance", "bool", nullptr, false},
            {"useElevatedUserInterfaceLevel", "bool", nullptr, false},
        };
#if HAVE(APP_ACCENT_COLORS)
    case MessageName::WebPage_SetAccentColor:
        return Vector<ArgumentDescription> {
            {"color", "WebCore::Color", nullptr, false},
        };
#endif
#if PLATFORM(COCOA)
    case MessageName::WebPage_RequestActiveNowPlayingSessionInfo:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebPage_SetShouldDispatchFakeMouseMoveEvents:
        return Vector<ArgumentDescription> {
            {"shouldDispatchFakeMouseMoveEvents", "bool", nullptr, false},
        };
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    case MessageName::WebPage_PlaybackTargetSelected:
        return Vector<ArgumentDescription> {
            {"contextId", "WebCore::PlaybackTargetClientContextIdentifier", nullptr, false},
            {"target", "WebCore::MediaPlaybackTargetContext", nullptr, false},
        };
    case MessageName::WebPage_PlaybackTargetAvailabilityDidChange:
        return Vector<ArgumentDescription> {
            {"contextId", "WebCore::PlaybackTargetClientContextIdentifier", nullptr, false},
            {"available", "bool", nullptr, false},
        };
    case MessageName::WebPage_SetShouldPlayToPlaybackTarget:
        return Vector<ArgumentDescription> {
            {"contextId", "WebCore::PlaybackTargetClientContextIdentifier", nullptr, false},
            {"shouldPlay", "bool", nullptr, false},
        };
    case MessageName::WebPage_PlaybackTargetPickerWasDismissed:
        return Vector<ArgumentDescription> {
            {"contextId", "WebCore::PlaybackTargetClientContextIdentifier", nullptr, false},
        };
#endif
#if ENABLE(POINTER_LOCK)
    case MessageName::WebPage_DidAcquirePointerLock:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_DidNotAcquirePointerLock:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_DidLosePointerLock:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebPage_ClearWheelEventTestMonitor:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_SetShouldScaleViewToFitDocument:
        return Vector<ArgumentDescription> {
            {"shouldScaleViewToFitDocument", "bool", nullptr, false},
        };
#if ENABLE(VIDEO) && USE(GSTREAMER)
    case MessageName::WebPage_DidEndRequestInstallMissingMediaPlugins:
        return Vector<ArgumentDescription> {
            {"result", "uint32_t", nullptr, false},
        };
#endif
    case MessageName::WebPage_SetUserInterfaceLayoutDirection:
        return Vector<ArgumentDescription> {
            {"direction", "uint32_t", nullptr, false},
        };
    case MessageName::WebPage_DidGetLoadDecisionForIcon:
        return Vector<ArgumentDescription> {
            {"decision", "bool", nullptr, false},
            {"loadIdentifier", "WebKit::CallbackID", nullptr, false},
        };
    case MessageName::WebPage_SetUseIconLoadingClient:
        return Vector<ArgumentDescription> {
            {"useIconLoadingClient", "bool", nullptr, false},
        };
#if ENABLE(GAMEPAD)
    case MessageName::WebPage_GamepadActivity:
        return Vector<ArgumentDescription> {
            {"gamepadDatas", "Vector<WebKit::GamepadData>", nullptr, false},
            {"eventVisibility", "bool", "WebCore::EventMakesGamepadsVisible", false},
        };
#endif
    case MessageName::WebPage_FrameBecameRemote:
        return Vector<ArgumentDescription> {
            {"frameID", "WebCore::FrameIdentifier", nullptr, false},
            {"remoteFrameIdentifier", "WebCore::GlobalFrameIdentifier", nullptr, false},
            {"remoteWindowIdentifier", "WebCore::GlobalWindowIdentifier", nullptr, false},
        };
    case MessageName::WebPage_RegisterURLSchemeHandler:
        return Vector<ArgumentDescription> {
            {"handlerIdentifier", "WebKit::WebURLSchemeHandlerIdentifier", nullptr, false},
            {"scheme", "String", nullptr, false},
        };
    case MessageName::WebPage_URLSchemeTaskWillPerformRedirection:
        return Vector<ArgumentDescription> {
            {"handlerIdentifier", "WebKit::WebURLSchemeHandlerIdentifier", nullptr, false},
            {"taskIdentifier", "WebCore::ResourceLoaderIdentifier", nullptr, false},
            {"response", "WebCore::ResourceResponse", nullptr, false},
            {"proposedRequest", "WebCore::ResourceRequest", nullptr, false},
        };
    case MessageName::WebPage_URLSchemeTaskDidPerformRedirection:
        return Vector<ArgumentDescription> {
            {"handlerIdentifier", "WebKit::WebURLSchemeHandlerIdentifier", nullptr, false},
            {"taskIdentifier", "WebCore::ResourceLoaderIdentifier", nullptr, false},
            {"response", "WebCore::ResourceResponse", nullptr, false},
            {"proposedRequest", "WebCore::ResourceRequest", nullptr, false},
        };
    case MessageName::WebPage_URLSchemeTaskDidReceiveResponse:
        return Vector<ArgumentDescription> {
            {"handlerIdentifier", "WebKit::WebURLSchemeHandlerIdentifier", nullptr, false},
            {"taskIdentifier", "WebCore::ResourceLoaderIdentifier", nullptr, false},
            {"response", "WebCore::ResourceResponse", nullptr, false},
        };
    case MessageName::WebPage_URLSchemeTaskDidReceiveData:
        return Vector<ArgumentDescription> {
            {"handlerIdentifier", "WebKit::WebURLSchemeHandlerIdentifier", nullptr, false},
            {"taskIdentifier", "WebCore::ResourceLoaderIdentifier", nullptr, false},
            {"data", "IPC::SharedBufferCopy", nullptr, false},
        };
    case MessageName::WebPage_URLSchemeTaskDidComplete:
        return Vector<ArgumentDescription> {
            {"handlerIdentifier", "WebKit::WebURLSchemeHandlerIdentifier", nullptr, false},
            {"taskIdentifier", "WebCore::ResourceLoaderIdentifier", nullptr, false},
            {"error", "WebCore::ResourceError", nullptr, false},
        };
    case MessageName::WebPage_SetIsSuspended:
        return Vector<ArgumentDescription> {
            {"suspended", "bool", nullptr, false},
        };
#if ENABLE(ATTACHMENT_ELEMENT)
    case MessageName::WebPage_InsertAttachment:
        return Vector<ArgumentDescription> {
            {"identifier", "String", nullptr, false},
            {"fileSize", "uint64_t", nullptr, true},
            {"fileName", "String", nullptr, false},
            {"contentType", "String", nullptr, false},
        };
    case MessageName::WebPage_UpdateAttachmentAttributes:
        return Vector<ArgumentDescription> {
            {"identifier", "String", nullptr, false},
            {"fileSize", "uint64_t", nullptr, true},
            {"contentType", "String", nullptr, false},
            {"fileName", "String", nullptr, false},
            {"enclosingImageData", "IPC::SharedBufferCopy", nullptr, false},
        };
    case MessageName::WebPage_UpdateAttachmentThumbnail:
        return Vector<ArgumentDescription> {
            {"identifier", "String", nullptr, false},
            {"qlThumbnailHandle", "WebKit::ShareableBitmap::Handle", nullptr, false},
        };
    case MessageName::WebPage_UpdateAttachmentIcon:
        return Vector<ArgumentDescription> {
            {"identifier", "String", nullptr, false},
            {"icon", "WebKit::ShareableBitmap::Handle", nullptr, false},
            {"size", "WebCore::FloatSize", nullptr, false},
        };
#endif
#if ENABLE(APPLICATION_MANIFEST)
    case MessageName::WebPage_GetApplicationManifest:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebPage_SetDefersLoading:
        return Vector<ArgumentDescription> {
            {"defersLoading", "bool", nullptr, false},
        };
#if ENABLE(UI_PROCESS_PDF_HUD)
    case MessageName::WebPage_ZoomPDFIn:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::PDFPluginIdentifier", nullptr, false},
        };
    case MessageName::WebPage_ZoomPDFOut:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::PDFPluginIdentifier", nullptr, false},
        };
    case MessageName::WebPage_SavePDF:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::PDFPluginIdentifier", nullptr, false},
        };
    case MessageName::WebPage_OpenPDFWithPreview:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::PDFPluginIdentifier", nullptr, false},
        };
#endif
    case MessageName::WebPage_UpdateCurrentModifierState:
        return Vector<ArgumentDescription> {
            {"modifiers", "OptionSet<WebCore::PlatformEvent::Modifier>", nullptr, false},
        };
    case MessageName::WebPage_SimulateDeviceOrientationChange:
        return Vector<ArgumentDescription> {
            {"alpha", "double", nullptr, false},
            {"beta", "double", nullptr, false},
            {"gamma", "double", nullptr, false},
        };
#if ENABLE(SPEECH_SYNTHESIS)
    case MessageName::WebPage_SpeakingErrorOccurred:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_BoundaryEventOccurred:
        return Vector<ArgumentDescription> {
            {"wordBoundary", "bool", nullptr, false},
            {"charIndex", "unsigned", nullptr, false},
        };
    case MessageName::WebPage_VoicesDidChange:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebPage_SetCanShowPlaceholder:
        return Vector<ArgumentDescription> {
            {"context", "WebCore::ElementContext", nullptr, false},
            {"canShowPlaceholder", "bool", nullptr, false},
        };
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
    case MessageName::WebPage_WasLoadedWithDataTransferFromPrevalentResource:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_ClearLoadedSubresourceDomains:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_GetLoadedSubresourceDomains:
        return Vector<ArgumentDescription> { };
#endif
#if USE(SYSTEM_PREVIEW)
    case MessageName::WebPage_SystemPreviewActionTriggered:
        return Vector<ArgumentDescription> {
            {"previewInfo", "WebCore::SystemPreviewInfo", nullptr, false},
            {"message", "String", nullptr, false},
        };
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    case MessageName::WebPage_SendMessageToWebExtension:
        return Vector<ArgumentDescription> {
            {"userMessage", "WebKit::UserMessage", nullptr, false},
        };
    case MessageName::WebPage_SendMessageToWebExtensionWithReply:
        return Vector<ArgumentDescription> {
            {"userMessage", "WebKit::UserMessage", nullptr, false},
        };
#endif
    case MessageName::WebPage_StartTextManipulations:
        return Vector<ArgumentDescription> {
            {"exclusionRules", "Vector<WebCore::TextManipulationController::ExclusionRule>", nullptr, false},
        };
    case MessageName::WebPage_CompleteTextManipulation:
        return Vector<ArgumentDescription> {
            {"items", "Vector<WebCore::TextManipulationController::ManipulationItem>", nullptr, false},
        };
    case MessageName::WebPage_SetOverriddenMediaType:
        return Vector<ArgumentDescription> {
            {"mediaType", "String", nullptr, false},
        };
    case MessageName::WebPage_GetProcessDisplayName:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_UpdateCORSDisablingPatterns:
        return Vector<ArgumentDescription> {
            {"patterns", "Vector<String>", nullptr, false},
        };
    case MessageName::WebPage_SetIsTakingSnapshotsForApplicationSuspension:
        return Vector<ArgumentDescription> {
            {"isTakingSnapshotsForApplicationSuspension", "bool", nullptr, false},
        };
    case MessageName::WebPage_SetNeedsDOMWindowResizeEvent:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_SetHasResourceLoadClient:
        return Vector<ArgumentDescription> {
            {"has", "bool", nullptr, false},
        };
    case MessageName::WebPage_SetCanUseCredentialStorage:
        return Vector<ArgumentDescription> {
            {"canUse", "bool", nullptr, false},
        };
#if ENABLE(APP_HIGHLIGHTS)
    case MessageName::WebPage_CreateAppHighlightInSelectedRange:
        return Vector<ArgumentDescription> {
            {"createNewGroup", "bool", "WebCore::CreateNewGroupForHighlight", false},
            {"requestOrigin", "bool", "WebCore::HighlightRequestOriginatedInApp", false},
        };
    case MessageName::WebPage_RestoreAppHighlightsAndScrollToIndex:
        return Vector<ArgumentDescription> {
            {"memoryHandles", "Vector<WebKit::SharedMemory::IPCHandle>", nullptr, false},
            {"index", "unsigned", nullptr, true},
        };
    case MessageName::WebPage_SetAppHighlightsVisibility:
        return Vector<ArgumentDescription> {
            {"highlightVisibility", "bool", "WebCore::HighlightVisibility", false},
        };
#endif
    case MessageName::WebPage_DispatchWheelEventWithoutScrolling:
        return Vector<ArgumentDescription> {
            {"event", "WebKit::WebWheelEvent", nullptr, false},
        };
    case MessageName::WebPage_LastNavigationWasAppInitiated:
        return Vector<ArgumentDescription> { };
#if ENABLE(MEDIA_SESSION_COORDINATOR)
    case MessageName::WebPage_CreateMediaSessionCoordinator:
        return Vector<ArgumentDescription> {
            {"identifier", "String", nullptr, false},
        };
    case MessageName::WebPage_InvalidateMediaSessionCoordinator:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(IMAGE_ANALYSIS)
    case MessageName::WebPage_UpdateWithTextRecognitionResult:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::TextRecognitionResult", nullptr, false},
            {"element", "WebCore::ElementContext", nullptr, false},
            {"location", "WebCore::FloatPoint", nullptr, false},
        };
    case MessageName::WebPage_StartImageAnalysis:
        return Vector<ArgumentDescription> {
            {"identifier", "String", nullptr, false},
        };
#endif
    case MessageName::WebPage_ScrollToRect:
        return Vector<ArgumentDescription> {
            {"targetRect", "WebCore::FloatRect", nullptr, false},
            {"origin", "WebCore::FloatPoint", nullptr, false},
        };
    case MessageName::WebPage_InteractableRegionsInRootViewCoordinates:
        return Vector<ArgumentDescription> {
            {"rect", "WebCore::FloatRect", nullptr, false},
        };
    case MessageName::StorageAreaMap_DispatchStorageEvent:
        return Vector<ArgumentDescription> {
            {"storageAreaImplID", "WebKit::StorageAreaImplIdentifier", nullptr, true},
            {"key", "String", nullptr, false},
            {"oldValue", "String", nullptr, false},
            {"newValue", "String", nullptr, false},
            {"urlString", "String", nullptr, false},
            {"messageIdentifier", "uint64_t", nullptr, false},
        };
    case MessageName::StorageAreaMap_ClearCache:
        return Vector<ArgumentDescription> {
            {"messageIdentifier", "uint64_t", nullptr, false},
        };
#if ENABLE(WEBXR)
    case MessageName::PlatformXRSystemProxy_SessionDidEnd:
        return Vector<ArgumentDescription> {
            {"deviceIdentifier", "WebKit::XRDeviceIdentifier", nullptr, false},
        };
    case MessageName::PlatformXRSystemProxy_SessionDidUpdateVisibilityState:
        return Vector<ArgumentDescription> {
            {"deviceIdentifier", "WebKit::XRDeviceIdentifier", nullptr, false},
            {"visibilityState", "PlatformXR::VisibilityState", nullptr, false},
        };
#endif
#if PLATFORM(MAC)
    case MessageName::ViewGestureController_DidCollectGeometryForSmartMagnificationGesture:
        return Vector<ArgumentDescription> {
            {"origin", "WebCore::FloatPoint", nullptr, false},
            {"renderRect", "WebCore::FloatRect", nullptr, false},
            {"visibleContentBounds", "WebCore::FloatRect", nullptr, false},
            {"fitEntireRect", "bool", nullptr, false},
            {"viewportMinimumScale", "double", nullptr, false},
            {"viewportMaximumScale", "double", nullptr, false},
        };
#endif
#if !PLATFORM(IOS_FAMILY)
    case MessageName::ViewGestureController_DidCollectGeometryForMagnificationGesture:
        return Vector<ArgumentDescription> {
            {"visibleContentBounds", "WebCore::FloatRect", nullptr, false},
            {"frameHandlesMagnificationGesture", "bool", nullptr, false},
        };
    case MessageName::ViewGestureController_DidHitRenderTreeSizeThreshold:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::GtkSettingsManagerProxy_SettingsDidChange:
        return Vector<ArgumentDescription> {
            {"settingsState", "WebKit::GtkSettingsState", nullptr, false},
        };
#if PLATFORM(COCOA)
    case MessageName::ViewGestureGeometryCollector_CollectGeometryForSmartMagnificationGesture:
        return Vector<ArgumentDescription> {
            {"origin", "WebCore::FloatPoint", nullptr, false},
        };
#endif
#if !PLATFORM(IOS_FAMILY)
    case MessageName::ViewGestureGeometryCollector_CollectGeometryForMagnificationGesture:
        return Vector<ArgumentDescription> { };
    case MessageName::ViewGestureGeometryCollector_SetRenderTreeSizeNotificationThreshold:
        return Vector<ArgumentDescription> {
            {"size", "uint64_t", nullptr, false},
        };
#endif
    default:
        break;
    }
    return std::nullopt;
}

std::optional<Vector<ArgumentDescription>> messageReplyArgumentDescriptions(MessageName name)
{
    switch (name) {
#if ENABLE(GPU_PROCESS)
#if USE(AUDIO_SESSION)
    case MessageName::GPUConnectionToWebProcess_EnsureAudioSession:
        return Vector<ArgumentDescription> {
            {"configuration", "WebKit::RemoteAudioSessionConfiguration", nullptr, false},
        };
#endif
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::GPUProcess_CreateGPUConnectionToWebProcess:
        return Vector<ArgumentDescription> {
            {"connectionIdentifier", "IPC::Attachment", nullptr, true},
            {"parameters", "WebKit::GPUProcessConnectionInitializationParameters", nullptr, false},
        };
    case MessageName::GPUProcess_PrepareToSuspend:
        return Vector<ArgumentDescription> { };
#if ENABLE(MEDIA_STREAM)
    case MessageName::GPUProcess_UpdateCaptureAccess:
        return Vector<ArgumentDescription> { };
#endif
#if HAVE(SC_CONTENT_SHARING_SESSION)
    case MessageName::GPUProcess_ShowWindowPicker:
        return Vector<ArgumentDescription> {
            {"device", "WebCore::CaptureDevice", nullptr, true},
        };
    case MessageName::GPUProcess_ShowScreenPicker:
        return Vector<ArgumentDescription> {
            {"device", "WebCore::CaptureDevice", nullptr, true},
        };
#endif
    case MessageName::GPUProcess_RequestBitmapImageForCurrentTime:
        return Vector<ArgumentDescription> {
            {"handle", "WebKit::ShareableBitmap::Handle", nullptr, false},
        };
    case MessageName::GPUProcess_WebProcessConnectionCountForTesting:
        return Vector<ArgumentDescription> {
            {"count", "uint64_t", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(WEBGL)
#if PLATFORM(COCOA)
    case MessageName::RemoteGraphicsContextGL_PrepareForDisplay:
        return Vector<ArgumentDescription> {
            {"displayBuffer", "MachSendRight", nullptr, false},
        };
#endif
#if USE(GRAPHICS_LAYER_WC)
    case MessageName::RemoteGraphicsContextGL_PrepareForDisplay:
        return Vector<ArgumentDescription> {
            {"contentBuffer", "WebKit::WCContentBufferIdentifier", nullptr, true},
        };
#endif
#if !PLATFORM(COCOA) && !USE(GRAPHICS_LAYER_WC)
    case MessageName::RemoteGraphicsContextGL_PrepareForDisplay:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::RemoteGraphicsContextGL_GetError:
        return Vector<ArgumentDescription> {
            {"returnValue", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_PaintRenderingResultsToCanvas:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteGraphicsContextGL_PaintCompositedResultsToCanvas:
        return Vector<ArgumentDescription> { };
#if ENABLE(VIDEO)
    case MessageName::RemoteGraphicsContextGL_CopyTextureFromVideoFrame:
        return Vector<ArgumentDescription> {
            {"success", "bool", nullptr, false},
        };
#endif
#if ENABLE(MEDIA_STREAM)
    case MessageName::RemoteGraphicsContextGL_PaintCompositedResultsToMediaSample:
        return Vector<ArgumentDescription> {
            {"properties", "WebKit::RemoteVideoFrameProxy::Properties", nullptr, true},
        };
#endif
    case MessageName::RemoteGraphicsContextGL_MoveErrorsToSyntheticErrorList:
        return Vector<ArgumentDescription> {
            {"returnValue", "bool", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CheckFramebufferStatus:
        return Vector<ArgumentDescription> {
            {"returnValue", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CreateBuffer:
        return Vector<ArgumentDescription> {
            {"returnValue", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CreateFramebuffer:
        return Vector<ArgumentDescription> {
            {"returnValue", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CreateProgram:
        return Vector<ArgumentDescription> {
            {"returnValue", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CreateRenderbuffer:
        return Vector<ArgumentDescription> {
            {"returnValue", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CreateShader:
        return Vector<ArgumentDescription> {
            {"returnValue", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CreateTexture:
        return Vector<ArgumentDescription> {
            {"returnValue", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetActiveAttrib:
        return Vector<ArgumentDescription> {
            {"returnValue", "bool", nullptr, false},
            {"arg2", "WebCore::GraphicsContextGL::ActiveInfo", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetActiveUniform:
        return Vector<ArgumentDescription> {
            {"returnValue", "bool", nullptr, false},
            {"arg2", "WebCore::GraphicsContextGL::ActiveInfo", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetAttribLocation:
        return Vector<ArgumentDescription> {
            {"returnValue", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetBufferParameteri:
        return Vector<ArgumentDescription> {
            {"returnValue", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetString:
        return Vector<ArgumentDescription> {
            {"returnValue", "String", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetFloatv:
        return Vector<ArgumentDescription> {
            {"value", "IPC::ArrayReference<float>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetIntegerv:
        return Vector<ArgumentDescription> {
            {"value", "IPC::ArrayReference<int32_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetInteger64:
        return Vector<ArgumentDescription> {
            {"returnValue", "int64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetInteger64i:
        return Vector<ArgumentDescription> {
            {"returnValue", "int64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetProgrami:
        return Vector<ArgumentDescription> {
            {"returnValue", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetBooleanv:
        return Vector<ArgumentDescription> {
            {"value", "IPC::ArrayReference<bool>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetFramebufferAttachmentParameteri:
        return Vector<ArgumentDescription> {
            {"returnValue", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetProgramInfoLog:
        return Vector<ArgumentDescription> {
            {"returnValue", "String", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetRenderbufferParameteri:
        return Vector<ArgumentDescription> {
            {"returnValue", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetShaderi:
        return Vector<ArgumentDescription> {
            {"returnValue", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetShaderInfoLog:
        return Vector<ArgumentDescription> {
            {"returnValue", "String", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetShaderPrecisionFormat:
        return Vector<ArgumentDescription> {
            {"range", "IPC::ArrayReference<int32_t, 2>", nullptr, false},
            {"precision", "GCGLint", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetShaderSource:
        return Vector<ArgumentDescription> {
            {"returnValue", "String", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetTexParameterf:
        return Vector<ArgumentDescription> {
            {"returnValue", "float", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetTexParameteri:
        return Vector<ArgumentDescription> {
            {"returnValue", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetUniformfv:
        return Vector<ArgumentDescription> {
            {"value", "IPC::ArrayReference<float>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetUniformiv:
        return Vector<ArgumentDescription> {
            {"value", "IPC::ArrayReference<int32_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetUniformuiv:
        return Vector<ArgumentDescription> {
            {"value", "IPC::ArrayReference<uint32_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetUniformLocation:
        return Vector<ArgumentDescription> {
            {"returnValue", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetVertexAttribOffset:
        return Vector<ArgumentDescription> {
            {"returnValue", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_IsBuffer:
        return Vector<ArgumentDescription> {
            {"returnValue", "bool", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_IsEnabled:
        return Vector<ArgumentDescription> {
            {"returnValue", "bool", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_IsFramebuffer:
        return Vector<ArgumentDescription> {
            {"returnValue", "bool", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_IsProgram:
        return Vector<ArgumentDescription> {
            {"returnValue", "bool", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_IsRenderbuffer:
        return Vector<ArgumentDescription> {
            {"returnValue", "bool", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_IsShader:
        return Vector<ArgumentDescription> {
            {"returnValue", "bool", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_IsTexture:
        return Vector<ArgumentDescription> {
            {"returnValue", "bool", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_ReadnPixels0:
        return Vector<ArgumentDescription> {
            {"data", "IPC::ArrayReference<uint8_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CreateVertexArray:
        return Vector<ArgumentDescription> {
            {"returnValue", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_IsVertexArray:
        return Vector<ArgumentDescription> {
            {"returnValue", "bool", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetBufferSubData:
        return Vector<ArgumentDescription> {
            {"data", "IPC::ArrayReference<uint8_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetFragDataLocation:
        return Vector<ArgumentDescription> {
            {"returnValue", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CreateQuery:
        return Vector<ArgumentDescription> {
            {"returnValue", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_IsQuery:
        return Vector<ArgumentDescription> {
            {"returnValue", "bool", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetQuery:
        return Vector<ArgumentDescription> {
            {"returnValue", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetQueryObjectui:
        return Vector<ArgumentDescription> {
            {"returnValue", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CreateSampler:
        return Vector<ArgumentDescription> {
            {"returnValue", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_IsSampler:
        return Vector<ArgumentDescription> {
            {"returnValue", "bool", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetSamplerParameterf:
        return Vector<ArgumentDescription> {
            {"returnValue", "float", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetSamplerParameteri:
        return Vector<ArgumentDescription> {
            {"returnValue", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_FenceSync:
        return Vector<ArgumentDescription> {
            {"returnValue", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_IsSync:
        return Vector<ArgumentDescription> {
            {"returnValue", "bool", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_ClientWaitSync:
        return Vector<ArgumentDescription> {
            {"returnValue", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetSynci:
        return Vector<ArgumentDescription> {
            {"returnValue", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_CreateTransformFeedback:
        return Vector<ArgumentDescription> {
            {"returnValue", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_IsTransformFeedback:
        return Vector<ArgumentDescription> {
            {"returnValue", "bool", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetTransformFeedbackVarying:
        return Vector<ArgumentDescription> {
            {"arg2", "WebCore::GraphicsContextGL::ActiveInfo", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetUniformIndices:
        return Vector<ArgumentDescription> {
            {"returnValue", "Vector<uint32_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetActiveUniforms:
        return Vector<ArgumentDescription> {
            {"returnValue", "Vector<int32_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetUniformBlockIndex:
        return Vector<ArgumentDescription> {
            {"returnValue", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetActiveUniformBlockName:
        return Vector<ArgumentDescription> {
            {"returnValue", "String", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetActiveUniformBlockiv:
        return Vector<ArgumentDescription> {
            {"params", "IPC::ArrayReference<int32_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetGraphicsResetStatusARB:
        return Vector<ArgumentDescription> {
            {"returnValue", "int32_t", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetTranslatedShaderSourceANGLE:
        return Vector<ArgumentDescription> {
            {"returnValue", "String", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_GetInternalformativ:
        return Vector<ArgumentDescription> {
            {"params", "IPC::ArrayReference<int32_t>", nullptr, false},
        };
    case MessageName::RemoteGraphicsContextGL_PaintRenderingResultsToPixelBuffer:
        return Vector<ArgumentDescription> {
            {"returnValue", "WebCore::PixelBuffer", nullptr, true},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteRenderingBackend_GetPixelBufferForImageBuffer:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteRenderingBackend_GetPixelBufferForImageBufferWithNewMemory:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteRenderingBackend_GetDataURLForImageBuffer:
        return Vector<ArgumentDescription> {
            {"urlString", "String", nullptr, false},
        };
    case MessageName::RemoteRenderingBackend_GetDataForImageBuffer:
        return Vector<ArgumentDescription> {
            {"data", "Vector<uint8_t>", nullptr, false},
        };
    case MessageName::RemoteRenderingBackend_GetShareableBitmapForImageBuffer:
        return Vector<ArgumentDescription> {
            {"handle", "WebKit::ShareableBitmap::Handle", nullptr, false},
        };
    case MessageName::RemoteRenderingBackend_GetFilteredImageForImageBuffer:
        return Vector<ArgumentDescription> {
            {"handle", "WebKit::ShareableBitmap::Handle", nullptr, false},
        };
    case MessageName::RemoteRenderingBackend_MarkSurfaceNonVolatile:
        return Vector<ArgumentDescription> {
            {"backendHandle", "WebKit::ImageBufferBackendHandle", nullptr, true},
            {"bufferWasEmpty", "bool", nullptr, false},
        };
    case MessageName::RemoteRenderingBackend_SwapToValidFrontBuffer:
        return Vector<ArgumentDescription> {
            {"swappedBufferSet", "WebKit::BufferIdentifierSet", nullptr, false},
            {"frontBufferHandle", "WebKit::ImageBufferBackendHandle", nullptr, true},
            {"frontBufferWasEmpty", "bool", nullptr, false},
        };
    case MessageName::RemoteRenderingBackend_MarkSurfacesVolatile:
        return Vector<ArgumentDescription> {
            {"inUseBufferIdentifiers", "Vector<WebCore::RenderingResourceIdentifier>", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteAdapter_RequestDevice:
        return Vector<ArgumentDescription> {
            {"supportedFeatures", "WebKit::WebGPU::SupportedFeatures", nullptr, false},
            {"supportedLimits", "WebKit::WebGPU::SupportedLimits", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteBuffer_MapAsync:
        return Vector<ArgumentDescription> {
            {"data", "Vector<uint8_t>", nullptr, true},
        };
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteDevice_CreateComputePipelineAsync:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteDevice_CreateRenderPipelineAsync:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteDevice_PopErrorScope:
        return Vector<ArgumentDescription> {
            {"error", "WebKit::WebGPU::Error", nullptr, true},
        };
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteGPU_RequestAdapter:
        return Vector<ArgumentDescription> {
            {"response", "WebKit::RemoteGPU::RequestAdapterResponse", nullptr, true},
        };
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteQueue_OnSubmittedWorkDone:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteShaderModule_CompilationInfo:
        return Vector<ArgumentDescription> {
            {"messages", "Vector<WebKit::WebGPU::CompilationMessage>", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(WEB_AUDIO)
    case MessageName::RemoteAudioDestinationManager_CreateAudioDestination:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RemoteAudioDestinationIdentifier", nullptr, false},
        };
    case MessageName::RemoteAudioDestinationManager_DeleteAudioDestination:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteAudioDestinationManager_StartAudioDestination:
        return Vector<ArgumentDescription> {
            {"isPlaying", "bool", nullptr, false},
        };
    case MessageName::RemoteAudioDestinationManager_StopAudioDestination:
        return Vector<ArgumentDescription> {
            {"isPlaying", "bool", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS) && USE(AUDIO_SESSION)
    case MessageName::RemoteAudioSessionProxy_TryToSetActive:
        return Vector<ArgumentDescription> {
            {"suceeded", "bool", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
    case MessageName::RemoteCDMFactoryProxy_CreateCDM:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RemoteCDMIdentifier", nullptr, false},
            {"configuration", "WebKit::RemoteCDMConfiguration", nullptr, false},
        };
    case MessageName::RemoteCDMFactoryProxy_SupportsKeySystem:
        return Vector<ArgumentDescription> {
            {"result", "bool", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
    case MessageName::RemoteCDMInstanceProxy_CreateSession:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RemoteCDMInstanceSessionIdentifier", nullptr, false},
        };
    case MessageName::RemoteCDMInstanceProxy_InitializeWithConfiguration:
        return Vector<ArgumentDescription> {
            {"success", "bool", "WebCore::CDMInstance::SuccessValue", false},
        };
    case MessageName::RemoteCDMInstanceProxy_SetServerCertificate:
        return Vector<ArgumentDescription> {
            {"success", "bool", "WebCore::CDMInstance::SuccessValue", false},
        };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
    case MessageName::RemoteCDMInstanceSessionProxy_RequestLicense:
        return Vector<ArgumentDescription> {
            {"message", "IPC::SharedBufferCopy", nullptr, false},
            {"sessionId", "String", nullptr, false},
            {"needsIndividualization", "bool", nullptr, false},
            {"succeeded", "bool", nullptr, false},
        };
    case MessageName::RemoteCDMInstanceSessionProxy_UpdateLicense:
        return Vector<ArgumentDescription> {
            {"sessionWasClosed", "bool", nullptr, false},
            {"changedKeys", "WebCore::CDMInstanceSession::KeyStatusVector", nullptr, true},
            {"changedExpiration", "double", nullptr, true},
            {"message", "WebCore::CDMInstanceSession::Message", nullptr, true},
            {"succeeded", "bool", nullptr, false},
        };
    case MessageName::RemoteCDMInstanceSessionProxy_LoadSession:
        return Vector<ArgumentDescription> {
            {"changedKeys", "WebCore::CDMInstanceSession::KeyStatusVector", nullptr, true},
            {"changedExpiration", "double", nullptr, true},
            {"message", "WebCore::CDMInstanceSession::Message", nullptr, true},
            {"succeeded", "bool", nullptr, false},
            {"loadFailure", "uint8_t", "WebCore::CDMInstanceSession::SessionLoadFailure", false},
        };
    case MessageName::RemoteCDMInstanceSessionProxy_CloseSession:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteCDMInstanceSessionProxy_RemoveSessionData:
        return Vector<ArgumentDescription> {
            {"changedKeys", "WebCore::CDMInstanceSession::KeyStatusVector", nullptr, false},
            {"message", "IPC::SharedBufferCopy", nullptr, true},
            {"succeeded", "bool", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
    case MessageName::RemoteCDMProxy_GetSupportedConfiguration:
        return Vector<ArgumentDescription> {
            {"accumulatedConfiguration", "WebCore::CDMKeySystemConfiguration", nullptr, true},
        };
    case MessageName::RemoteCDMProxy_CreateInstance:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RemoteCDMInstanceIdentifier", nullptr, false},
            {"configuration", "WebKit::RemoteCDMInstanceConfiguration", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(LEGACY_ENCRYPTED_MEDIA)
    case MessageName::RemoteLegacyCDMFactoryProxy_CreateCDM:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RemoteLegacyCDMIdentifier", nullptr, false},
        };
    case MessageName::RemoteLegacyCDMFactoryProxy_SupportsKeySystem:
        return Vector<ArgumentDescription> {
            {"result", "bool", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(LEGACY_ENCRYPTED_MEDIA)
    case MessageName::RemoteLegacyCDMProxy_SupportsMIMEType:
        return Vector<ArgumentDescription> {
            {"supports", "bool", nullptr, false},
        };
    case MessageName::RemoteLegacyCDMProxy_CreateSession:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::RemoteLegacyCDMSessionIdentifier", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(LEGACY_ENCRYPTED_MEDIA)
    case MessageName::RemoteLegacyCDMSessionProxy_GenerateKeyRequest:
        return Vector<ArgumentDescription> {
            {"nextMessage", "IPC::SharedBufferCopy", nullptr, true},
            {"destinationURL", "String", nullptr, false},
            {"errorCode", "unsigned short", nullptr, false},
            {"systemCode", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteLegacyCDMSessionProxy_Update:
        return Vector<ArgumentDescription> {
            {"succeeded", "bool", nullptr, false},
            {"nextMessage", "IPC::SharedBufferCopy", nullptr, true},
            {"errorCode", "unsigned short", nullptr, false},
            {"systemCode", "uint32_t", nullptr, false},
        };
    case MessageName::RemoteLegacyCDMSessionProxy_CachedKeyForKeyID:
        return Vector<ArgumentDescription> {
            {"key", "IPC::SharedBufferCopy", nullptr, true},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteMediaEngineConfigurationFactoryProxy_CreateDecodingConfiguration:
        return Vector<ArgumentDescription> {
            {"decodingInfo", "WebCore::MediaCapabilitiesDecodingInfo", nullptr, false},
        };
    case MessageName::RemoteMediaEngineConfigurationFactoryProxy_CreateEncodingConfiguration:
        return Vector<ArgumentDescription> {
            {"decodingInfo", "WebCore::MediaCapabilitiesEncodingInfo", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteMediaPlayerManagerProxy_GetSupportedTypes:
        return Vector<ArgumentDescription> {
            {"types", "Vector<String>", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerManagerProxy_SupportsTypeAndCodecs:
        return Vector<ArgumentDescription> {
            {"support", "uint8_t", "WebCore::MediaPlayerEnums::SupportsType", false},
        };
    case MessageName::RemoteMediaPlayerManagerProxy_OriginsInMediaCache:
        return Vector<ArgumentDescription> {
            {"origins", "HashSet<WebCore::SecurityOriginData>", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerManagerProxy_SupportsKeySystem:
        return Vector<ArgumentDescription> {
            {"supports", "bool", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteMediaPlayerProxy_PrepareForPlayback:
        return Vector<ArgumentDescription> {
            {"inlineLayerHostingContextId", "WebKit::LayerHostingContextID", nullptr, true},
        };
    case MessageName::RemoteMediaPlayerProxy_Load:
        return Vector<ArgumentDescription> {
            {"playerConfiguration", "WebKit::RemoteMediaPlayerConfiguration", nullptr, false},
        };
#if ENABLE(MEDIA_SOURCE)
    case MessageName::RemoteMediaPlayerProxy_LoadMediaSource:
        return Vector<ArgumentDescription> {
            {"playerConfiguration", "WebKit::RemoteMediaPlayerConfiguration", nullptr, false},
        };
#endif
    case MessageName::RemoteMediaPlayerProxy_DidLoadingProgress:
        return Vector<ArgumentDescription> {
            {"flag", "bool", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_PerformTaskAtMediaTime:
        return Vector<ArgumentDescription> {
            {"mediaTime", "MediaTime", nullptr, true},
            {"monotonicTime", "MonotonicTime", nullptr, true},
        };
    case MessageName::RemoteMediaPlayerProxy_WouldTaintOrigin:
        return Vector<ArgumentDescription> {
            {"wouldTaint", "bool", nullptr, true},
        };
#if PLATFORM(IOS_FAMILY)
    case MessageName::RemoteMediaPlayerProxy_ErrorLog:
        return Vector<ArgumentDescription> {
            {"errorLog", "String", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_AccessLog:
        return Vector<ArgumentDescription> {
            {"accessLog", "String", nullptr, false},
        };
#endif
#if PLATFORM(COCOA)
    case MessageName::RemoteMediaPlayerProxy_NativeImageForCurrentTime:
        return Vector<ArgumentDescription> {
            {"sendRight", "MachSendRight", nullptr, true},
            {"colorSpace", "WebCore::DestinationColorSpace", nullptr, false},
        };
    case MessageName::RemoteMediaPlayerProxy_ColorSpace:
        return Vector<ArgumentDescription> {
            {"colorSpace", "WebCore::DestinationColorSpace", nullptr, false},
        };
#endif
    case MessageName::RemoteMediaPlayerProxy_VideoFrameForCurrentTimeIfChanged:
        return Vector<ArgumentDescription> {
            {"videoFrame", "WebKit::RemoteVideoFrameProxy::Properties", nullptr, true},
            {"changed", "bool", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::RemoteMediaResourceManager_ResponseReceived:
        return Vector<ArgumentDescription> {
            {"shouldContinue", "bool", "WebCore::ShouldContinuePolicyCheck", false},
        };
    case MessageName::RemoteMediaResourceManager_RedirectReceived:
        return Vector<ArgumentDescription> {
            {"returnRequest", "WebCore::ResourceRequest", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)
    case MessageName::RemoteMediaSourceProxy_AddSourceBuffer:
        return Vector<ArgumentDescription> {
            {"status", "uint8_t", "WebCore::MediaSourcePrivate::AddStatus", false},
            {"remoteSourceBufferIdentifier", "WebKit::RemoteSourceBufferIdentifier", nullptr, true},
        };
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)
    case MessageName::RemoteSourceBufferProxy_CanSwitchToType:
        return Vector<ArgumentDescription> {
            {"canSwitch", "bool", nullptr, false},
        };
    case MessageName::RemoteSourceBufferProxy_UpdateBufferedFromTrackBuffers:
        return Vector<ArgumentDescription> {
            {"buffered", "WebCore::PlatformTimeRanges", nullptr, false},
        };
    case MessageName::RemoteSourceBufferProxy_RemoveCodedFrames:
        return Vector<ArgumentDescription> {
            {"buffered", "WebCore::PlatformTimeRanges", nullptr, false},
            {"totalTrackBufferSizeInBytes", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteSourceBufferProxy_EvictCodedFrames:
        return Vector<ArgumentDescription> {
            {"totalTrackBufferSizeInBytes", "uint64_t", nullptr, false},
        };
    case MessageName::RemoteSourceBufferProxy_BufferedSamplesForTrackId:
        return Vector<ArgumentDescription> {
            {"samples", "Vector<String>", nullptr, false},
        };
    case MessageName::RemoteSourceBufferProxy_EnqueuedSamplesForTrackID:
        return Vector<ArgumentDescription> {
            {"samples", "Vector<String>", nullptr, false},
        };
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(VIDEO)
#endif
#if USE(LIBWEBRTC) && PLATFORM(COCOA) && ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
    case MessageName::RemoteAudioMediaStreamTrackRendererInternalUnitManager_CreateUnit:
        return Vector<ArgumentDescription> {
            {"description", "WebCore::CAAudioStreamDescription", nullptr, false},
            {"frameChunkSize", "size_t", nullptr, false},
        };
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
    case MessageName::RemoteMediaRecorder_FetchData:
        return Vector<ArgumentDescription> {
            {"buffer", "IPC::DataReference", nullptr, false},
            {"timeCode", "double", nullptr, false},
        };
    case MessageName::RemoteMediaRecorder_StopRecording:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaRecorder_Pause:
        return Vector<ArgumentDescription> { };
    case MessageName::RemoteMediaRecorder_Resume:
        return Vector<ArgumentDescription> { };
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
    case MessageName::RemoteMediaRecorderManager_CreateRecorder:
        return Vector<ArgumentDescription> {
            {"creationError", "WebCore::ExceptionData", nullptr, true},
            {"mimeType", "String", nullptr, false},
            {"audioBitRate", "unsigned", nullptr, false},
            {"videoBitRate", "unsigned", nullptr, false},
        };
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
    case MessageName::RemoteSampleBufferDisplayLayerManager_CreateLayer:
        return Vector<ArgumentDescription> {
            {"contextID", "WebKit::LayerHostingContextID", nullptr, true},
        };
#endif
    case MessageName::WebCookieManager_GetHostnamesWithCookies:
        return Vector<ArgumentDescription> {
            {"hostnames", "Vector<String>", nullptr, false},
        };
    case MessageName::WebCookieManager_SetCookie:
        return Vector<ArgumentDescription> { };
    case MessageName::WebCookieManager_SetCookies:
        return Vector<ArgumentDescription> { };
    case MessageName::WebCookieManager_GetAllCookies:
        return Vector<ArgumentDescription> {
            {"cookies", "Vector<WebCore::Cookie>", nullptr, false},
        };
    case MessageName::WebCookieManager_GetCookies:
        return Vector<ArgumentDescription> {
            {"cookies", "Vector<WebCore::Cookie>", nullptr, false},
        };
    case MessageName::WebCookieManager_DeleteCookie:
        return Vector<ArgumentDescription> { };
    case MessageName::WebCookieManager_DeleteAllCookiesModifiedSince:
        return Vector<ArgumentDescription> { };
    case MessageName::WebCookieManager_SetHTTPCookieAcceptPolicy:
        return Vector<ArgumentDescription> { };
    case MessageName::WebCookieManager_GetHTTPCookieAcceptPolicy:
        return Vector<ArgumentDescription> {
            {"policy", "uint8_t", "WebCore::HTTPCookieAcceptPolicy", false},
        };
    case MessageName::NetworkBroadcastChannelRegistry_PostMessage:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkConnectionToWebProcess_PerformSynchronousLoad:
        return Vector<ArgumentDescription> {
            {"error", "WebCore::ResourceError", nullptr, false},
            {"response", "WebCore::ResourceResponse", nullptr, false},
            {"data", "Vector<uint8_t>", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_TestProcessIncomingSyncMessagesWhenWaitingForSyncReply:
        return Vector<ArgumentDescription> {
            {"handled", "bool", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_SendH2Ping:
        return Vector<ArgumentDescription> {
            {"result", "Expected<Seconds, WebCore::ResourceError>", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_IsResourceLoadFinished:
        return Vector<ArgumentDescription> {
            {"isFinished", "bool", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_CookiesForDOM:
        return Vector<ArgumentDescription> {
            {"cookieString", "String", nullptr, false},
            {"didAccessSecureCookies", "bool", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_CookieRequestHeaderFieldValue:
        return Vector<ArgumentDescription> {
            {"cookieString", "String", nullptr, false},
            {"didAccessSecureCookies", "bool", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_GetRawCookies:
        return Vector<ArgumentDescription> {
            {"cookies", "Vector<WebCore::Cookie>", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_DomCookiesForHost:
        return Vector<ArgumentDescription> {
            {"cookies", "Vector<WebCore::Cookie>", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_BlobSize:
        return Vector<ArgumentDescription> {
            {"resultSize", "uint64_t", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_WriteBlobsToTemporaryFilesForIndexedDB:
        return Vector<ArgumentDescription> {
            {"fileNames", "Vector<String>", nullptr, false},
        };
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
    case MessageName::NetworkConnectionToWebProcess_ResourceLoadStatisticsUpdated:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkConnectionToWebProcess_HasStorageAccess:
        return Vector<ArgumentDescription> {
            {"hasStorageAccess", "bool", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_RequestStorageAccess:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::RequestStorageAccessResult", nullptr, false},
        };
#endif
    case MessageName::NetworkConnectionToWebProcess_GetNetworkLoadInformationResponse:
        return Vector<ArgumentDescription> {
            {"response", "WebCore::ResourceResponse", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_GetNetworkLoadIntermediateInformation:
        return Vector<ArgumentDescription> {
            {"transactions", "Vector<WebCore::NetworkTransactionInformation>", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_TakeNetworkLoadInformationMetrics:
        return Vector<ArgumentDescription> {
            {"networkMetrics", "WebCore::NetworkLoadMetrics", nullptr, false},
        };
#if ENABLE(SERVICE_WORKER)
    case MessageName::NetworkConnectionToWebProcess_EstablishSWContextConnection:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::NetworkConnectionToWebProcess_EstablishSharedWorkerContextConnection:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkConnectionToWebProcess_CreateRTCProvider:
        return Vector<ArgumentDescription> { };
#if ENABLE(WEB_RTC)
    case MessageName::NetworkConnectionToWebProcess_ConnectToRTCDataChannelRemoteSource:
        return Vector<ArgumentDescription> {
            {"result", "bool", nullptr, true},
        };
#endif
    case MessageName::NetworkConnectionToWebProcess_TakeAllMessagesForPort:
        return Vector<ArgumentDescription> {
            {"messages", "Vector<WebCore::MessageWithMessagePorts>", nullptr, false},
            {"messageBatchIdentifier", "uint64_t", nullptr, false},
        };
    case MessageName::NetworkConnectionToWebProcess_CheckRemotePortForActivity:
        return Vector<ArgumentDescription> {
            {"hasActivity", "bool", nullptr, false},
        };
#if PLATFORM(MAC)
    case MessageName::NetworkConnectionToWebProcess_GetProcessDisplayName:
        return Vector<ArgumentDescription> {
            {"displayName", "String", nullptr, false},
        };
#endif
#if ENABLE(CONTENT_EXTENSIONS)
#endif
    case MessageName::NetworkProcess_CreateNetworkConnectionToWebProcess:
        return Vector<ArgumentDescription> {
            {"connectionIdentifier", "IPC::Attachment", nullptr, true},
            {"cookieAcceptPolicy", "uint8_t", "WebCore::HTTPCookieAcceptPolicy", false},
        };
    case MessageName::NetworkProcess_FetchWebsiteData:
        return Vector<ArgumentDescription> {
            {"websiteData", "WebKit::WebsiteData", nullptr, false},
        };
    case MessageName::NetworkProcess_DeleteWebsiteData:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_DeleteWebsiteDataForOrigins:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_RenameOriginInWebsiteData:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_CancelDownload:
        return Vector<ArgumentDescription> {
            {"resumeData", "IPC::DataReference", nullptr, false},
        };
    case MessageName::NetworkProcess_RequestResource:
        return Vector<ArgumentDescription> {
            {"data", "IPC::DataReference", nullptr, false},
            {"response", "WebCore::ResourceResponse", nullptr, false},
            {"error", "WebCore::ResourceError", nullptr, false},
        };
    case MessageName::NetworkProcess_SetAllowsAnySSLCertificateForWebSocket:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_FlushCookies:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetCacheModelSynchronouslyForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_ProcessWillSuspendImminentlyForTestingSync:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_PrepareToSuspend:
        return Vector<ArgumentDescription> { };
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
    case MessageName::NetworkProcess_ClearPrevalentResource:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_ClearUserInteraction:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_DumpResourceLoadStatistics:
        return Vector<ArgumentDescription> {
            {"dumpedStatistics", "String", nullptr, false},
        };
    case MessageName::NetworkProcess_UpdatePrevalentDomainsToBlockCookiesFor:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_IsGrandfathered:
        return Vector<ArgumentDescription> {
            {"isGrandfathered", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_IsPrevalentResource:
        return Vector<ArgumentDescription> {
            {"isPrevalent", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_IsVeryPrevalentResource:
        return Vector<ArgumentDescription> {
            {"isVeryPrevalent", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_SetAgeCapForClientSideCookies:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetLastSeen:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_MergeStatisticForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_InsertExpiredStatisticForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetPrevalentResource:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetPrevalentResourceForDebugMode:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_IsResourceLoadStatisticsEphemeral:
        return Vector<ArgumentDescription> {
            {"isEphemeral", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_HadUserInteraction:
        return Vector<ArgumentDescription> {
            {"hadUserInteraction", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_IsRelationshipOnlyInDatabaseOnce:
        return Vector<ArgumentDescription> {
            {"hadUserInteraction", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_HasLocalStorage:
        return Vector<ArgumentDescription> {
            {"hadUserInteraction", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_GetAllStorageAccessEntries:
        return Vector<ArgumentDescription> {
            {"domains", "Vector<String>", nullptr, false},
        };
    case MessageName::NetworkProcess_IsRegisteredAsRedirectingTo:
        return Vector<ArgumentDescription> {
            {"isRedirectingTo", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_IsRegisteredAsSubFrameUnder:
        return Vector<ArgumentDescription> {
            {"isSubframeUnder", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_IsRegisteredAsSubresourceUnder:
        return Vector<ArgumentDescription> {
            {"isSubresourceUnder", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_DomainIDExistsInDatabase:
        return Vector<ArgumentDescription> {
            {"exists", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_LogUserInteraction:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_ResetParametersToDefaultValues:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_ScheduleClearInMemoryAndPersistent:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_ScheduleCookieBlockingUpdate:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_ScheduleStatisticsAndDataRecordsProcessing:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_StatisticsDatabaseHasAllTables:
        return Vector<ArgumentDescription> {
            {"hasAllTables", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_SetCacheMaxAgeCapForPrevalentResources:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetGrandfathered:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_GetResourceLoadStatisticsDataSummary:
        return Vector<ArgumentDescription> {
            {"thirdPartyData", "Vector<WebKit::WebResourceLoadStatisticsStore::ThirdPartyData>", nullptr, false},
        };
    case MessageName::NetworkProcess_SetGrandfatheringTime:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetMaxStatisticsEntries:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetMinimumTimeBetweenDataRecordsRemoval:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetPruneEntriesDownTo:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetShouldClassifyResourcesBeforeDataRecordsRemoval:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetNotifyPagesWhenDataRecordsWereScanned:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetIsRunningResourceLoadStatisticsTest:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetResourceLoadStatisticsDebugMode:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetVeryPrevalentResource:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetSubframeUnderTopFrameDomain:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetSubresourceUnderTopFrameDomain:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetSubresourceUniqueRedirectTo:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetSubresourceUniqueRedirectFrom:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetTimeToLiveUserInteraction:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetTopFrameUniqueRedirectTo:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetTopFrameUniqueRedirectFrom:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_ResetCacheMaxAgeCapForPrevalentResources:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetCrossSiteLoadWithLinkDecorationForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_ResetCrossSiteLoadsWithLinkDecorationForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_DeleteCookiesForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_HasIsolatedSession:
        return Vector<ArgumentDescription> {
            {"hasIsolatedSession", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_CloseITPDatabase:
        return Vector<ArgumentDescription> { };
#endif
#if (ENABLE(INTELLIGENT_TRACKING_PREVENTION) && ENABLE(APP_BOUND_DOMAINS))
    case MessageName::NetworkProcess_SetAppBoundDomainsForResourceLoadStatistics:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
    case MessageName::NetworkProcess_SetShouldDowngradeReferrerForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetThirdPartyCookieBlockingMode:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetShouldEnbleSameSiteStrictEnforcementForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetFirstPartyWebsiteDataRemovalModeForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetToSameSiteStrictCookiesForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetFirstPartyHostCNAMEDomainForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetThirdPartyCNAMEDomainForTesting:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::NetworkProcess_SyncLocalStorage:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_DumpPrivateClickMeasurement:
        return Vector<ArgumentDescription> {
            {"privateClickMeasurementState", "String", nullptr, false},
        };
    case MessageName::NetworkProcess_ClearPrivateClickMeasurement:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetPrivateClickMeasurementOverrideTimerForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_MarkAttributedPrivateClickMeasurementsAsExpiredForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetPrivateClickMeasurementEphemeralMeasurementForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SimulatePrivateClickMeasurementSessionRestart:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetPrivateClickMeasurementTokenPublicKeyURLForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetPrivateClickMeasurementTokenSignatureURLForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetPrivateClickMeasurementAttributionReportURLsForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_MarkPrivateClickMeasurementsAsExpiredForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetPCMFraudPreventionValuesForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetPrivateClickMeasurementAppBundleIDForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_ClosePCMDatabase:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_SetServiceWorkerFetchTimeoutForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_ResetServiceWorkerFetchTimeoutForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_ResetQuota:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_ClearStorage:
        return Vector<ArgumentDescription> { };
#if ENABLE(APP_BOUND_DOMAINS)
    case MessageName::NetworkProcess_HasAppBoundSession:
        return Vector<ArgumentDescription> {
            {"hasAppBoundSession", "bool", nullptr, false},
        };
    case MessageName::NetworkProcess_ClearAppBoundSession:
        return Vector<ArgumentDescription> { };
#endif
#if PLATFORM(IOS_FAMILY) && !PLATFORM(MACCATALYST)
    case MessageName::NetworkProcess_ClearServiceWorkerEntitlementOverride:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::NetworkProcess_UpdateBundleIdentifier:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkProcess_ClearBundleIdentifier:
        return Vector<ArgumentDescription> { };
#if PLATFORM(COCOA)
    case MessageName::NetworkProcess_AppPrivacyReportTestingData:
        return Vector<ArgumentDescription> {
            {"data", "WebKit::AppPrivacyReportTestingData", nullptr, false},
        };
    case MessageName::NetworkProcess_ClearAppPrivacyReportTestingData:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::NetworkProcess_CountNonDefaultSessionSets:
        return Vector<ArgumentDescription> {
            {"count", "size_t", nullptr, false},
        };
#if ENABLE(SERVICE_WORKER)
    case MessageName::NetworkProcess_GetPendingPushMessages:
        return Vector<ArgumentDescription> {
            {"messages", "Vector<WebKit::WebPushMessage>", nullptr, false},
        };
    case MessageName::NetworkProcess_ProcessPushMessage:
        return Vector<ArgumentDescription> {
            {"didSucceed", "bool", nullptr, false},
        };
#endif
    case MessageName::NetworkProcess_DeletePushAndNotificationRegistration:
        return Vector<ArgumentDescription> {
            {"errorMessage", "String", nullptr, false},
        };
    case MessageName::NetworkProcess_GetOriginsWithPushAndNotificationPermissions:
        return Vector<ArgumentDescription> {
            {"origins", "Vector<WebCore::SecurityOriginData>", nullptr, false},
        };
    case MessageName::NetworkSocketChannel_SendString:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkSocketChannel_SendData:
        return Vector<ArgumentDescription> { };
#if ENABLE(SERVICE_WORKER)
#endif
#if ENABLE(SERVICE_WORKER)
#endif
#if ENABLE(SERVICE_WORKER)
    case MessageName::WebSWServerConnection_ScheduleUnregisterJobInServer:
        return Vector<ArgumentDescription> {
            {"result", "Expected<bool, WebCore::ExceptionData>", nullptr, false},
        };
    case MessageName::WebSWServerConnection_MatchRegistration:
        return Vector<ArgumentDescription> {
            {"registration", "WebCore::ServiceWorkerRegistrationData", nullptr, true},
        };
    case MessageName::WebSWServerConnection_WhenRegistrationReady:
        return Vector<ArgumentDescription> {
            {"registration", "WebCore::ServiceWorkerRegistrationData", nullptr, true},
        };
    case MessageName::WebSWServerConnection_GetRegistrations:
        return Vector<ArgumentDescription> {
            {"registrations", "Vector<WebCore::ServiceWorkerRegistrationData>", nullptr, false},
        };
    case MessageName::WebSWServerConnection_TerminateWorkerFromClient:
        return Vector<ArgumentDescription> { };
    case MessageName::WebSWServerConnection_WhenServiceWorkerIsTerminatedForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::WebSWServerConnection_StoreRegistrationsOnDisk:
        return Vector<ArgumentDescription> { };
    case MessageName::WebSWServerConnection_SubscribeToPushService:
        return Vector<ArgumentDescription> {
            {"result", "Expected<WebCore::PushSubscriptionData, WebCore::ExceptionData>", nullptr, false},
        };
    case MessageName::WebSWServerConnection_UnsubscribeFromPushService:
        return Vector<ArgumentDescription> {
            {"result", "Expected<bool, WebCore::ExceptionData>", nullptr, false},
        };
    case MessageName::WebSWServerConnection_GetPushSubscription:
        return Vector<ArgumentDescription> {
            {"result", "Expected<std::optional<WebCore::PushSubscriptionData>, WebCore::ExceptionData>", nullptr, false},
        };
    case MessageName::WebSWServerConnection_GetPushPermissionState:
        return Vector<ArgumentDescription> {
            {"result", "Expected<uint8_t, WebCore::ExceptionData>", nullptr, false},
        };
    case MessageName::WebSWServerConnection_EnableNavigationPreload:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::ExceptionData", nullptr, true},
        };
    case MessageName::WebSWServerConnection_DisableNavigationPreload:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::ExceptionData", nullptr, true},
        };
    case MessageName::WebSWServerConnection_SetNavigationPreloadHeaderValue:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::ExceptionData", nullptr, true},
        };
    case MessageName::WebSWServerConnection_GetNavigationPreloadState:
        return Vector<ArgumentDescription> {
            {"result", "Expected<WebCore::NavigationPreloadState, WebCore::ExceptionData>", nullptr, false},
        };
#endif
#if ENABLE(SERVICE_WORKER)
    case MessageName::WebSWServerToContextConnection_SkipWaiting:
        return Vector<ArgumentDescription> { };
    case MessageName::WebSWServerToContextConnection_FindClientByVisibleIdentifier:
        return Vector<ArgumentDescription> {
            {"data", "WebCore::ServiceWorkerClientData", nullptr, true},
        };
    case MessageName::WebSWServerToContextConnection_Claim:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::ExceptionData", nullptr, true},
        };
#endif
    case MessageName::StorageManagerSet_ConnectToLocalStorageArea:
        return Vector<ArgumentDescription> {
            {"storageAreaID", "WebKit::StorageAreaIdentifier", nullptr, true},
        };
    case MessageName::StorageManagerSet_ConnectToTransientLocalStorageArea:
        return Vector<ArgumentDescription> {
            {"storageAreaID", "WebKit::StorageAreaIdentifier", nullptr, true},
        };
    case MessageName::StorageManagerSet_ConnectToSessionStorageArea:
        return Vector<ArgumentDescription> {
            {"storageAreaID", "WebKit::StorageAreaIdentifier", nullptr, true},
        };
    case MessageName::StorageManagerSet_GetValues:
        return Vector<ArgumentDescription> {
            {"values", "HashMap<String, String>", nullptr, false},
        };
    case MessageName::StorageManagerSet_SetItem:
        return Vector<ArgumentDescription> {
            {"quotaException", "bool", nullptr, false},
        };
    case MessageName::StorageManagerSet_RemoveItem:
        return Vector<ArgumentDescription> { };
    case MessageName::StorageManagerSet_Clear:
        return Vector<ArgumentDescription> { };
    case MessageName::CacheStorageEngineConnection_Open:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::DOMCacheEngine::CacheIdentifierOrError", nullptr, false},
        };
    case MessageName::CacheStorageEngineConnection_Remove:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::DOMCacheEngine::CacheIdentifierOrError", nullptr, false},
        };
    case MessageName::CacheStorageEngineConnection_Caches:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::DOMCacheEngine::CacheInfosOrError", nullptr, false},
        };
    case MessageName::CacheStorageEngineConnection_RetrieveRecords:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::DOMCacheEngine::RecordsOrError", nullptr, false},
        };
    case MessageName::CacheStorageEngineConnection_DeleteMatchingRecords:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::DOMCacheEngine::RecordIdentifiersOrError", nullptr, false},
        };
    case MessageName::CacheStorageEngineConnection_PutRecords:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::DOMCacheEngine::RecordIdentifiersOrError", nullptr, false},
        };
    case MessageName::CacheStorageEngineConnection_ClearMemoryRepresentation:
        return Vector<ArgumentDescription> {
            {"error", "WebCore::DOMCacheEngine::Error", nullptr, true},
        };
    case MessageName::CacheStorageEngineConnection_EngineRepresentation:
        return Vector<ArgumentDescription> {
            {"representation", "String", nullptr, false},
        };
    case MessageName::NetworkStorageManager_Persisted:
        return Vector<ArgumentDescription> {
            {"persisted", "bool", nullptr, false},
        };
    case MessageName::NetworkStorageManager_Persist:
        return Vector<ArgumentDescription> {
            {"persisted", "bool", nullptr, false},
        };
    case MessageName::NetworkStorageManager_FileSystemGetDirectory:
        return Vector<ArgumentDescription> {
            {"result", "Expected<WebCore::FileSystemHandleIdentifier, WebKit::FileSystemStorageError>", nullptr, false},
        };
    case MessageName::NetworkStorageManager_IsSameEntry:
        return Vector<ArgumentDescription> {
            {"result", "bool", nullptr, false},
        };
    case MessageName::NetworkStorageManager_GetFileHandle:
        return Vector<ArgumentDescription> {
            {"result", "Expected<WebCore::FileSystemHandleIdentifier, WebKit::FileSystemStorageError>", nullptr, false},
        };
    case MessageName::NetworkStorageManager_GetDirectoryHandle:
        return Vector<ArgumentDescription> {
            {"result", "Expected<WebCore::FileSystemHandleIdentifier, WebKit::FileSystemStorageError>", nullptr, false},
        };
    case MessageName::NetworkStorageManager_RemoveEntry:
        return Vector<ArgumentDescription> {
            {"result", "WebKit::FileSystemStorageError", nullptr, true},
        };
    case MessageName::NetworkStorageManager_Resolve:
        return Vector<ArgumentDescription> {
            {"result", "Expected<Vector<String>, WebKit::FileSystemStorageError>", nullptr, false},
        };
    case MessageName::NetworkStorageManager_Move:
        return Vector<ArgumentDescription> {
            {"result", "WebKit::FileSystemStorageError", nullptr, true},
        };
    case MessageName::NetworkStorageManager_GetFile:
        return Vector<ArgumentDescription> {
            {"result", "Expected<String, WebKit::FileSystemStorageError>", nullptr, false},
        };
    case MessageName::NetworkStorageManager_CreateSyncAccessHandle:
        return Vector<ArgumentDescription> {
            {"result", "Expected<std::pair<WebCore::FileSystemSyncAccessHandleIdentifier, IPC::SharedFileHandle>, WebKit::FileSystemStorageError>", nullptr, false},
        };
    case MessageName::NetworkStorageManager_CloseSyncAccessHandle:
        return Vector<ArgumentDescription> {
            {"result", "WebKit::FileSystemStorageError", nullptr, true},
        };
    case MessageName::NetworkStorageManager_GetHandleNames:
        return Vector<ArgumentDescription> {
            {"result", "Expected<Vector<String>, WebKit::FileSystemStorageError>", nullptr, false},
        };
    case MessageName::NetworkStorageManager_GetHandle:
        return Vector<ArgumentDescription> {
            {"result", "Expected<std::pair<WebCore::FileSystemHandleIdentifier, bool>, WebKit::FileSystemStorageError>", nullptr, false},
        };
    case MessageName::NetworkStorageManager_ConnectToStorageArea:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::StorageAreaIdentifier", nullptr, false},
            {"items", "HashMap<String, String>", nullptr, false},
            {"messageIdentifier", "uint64_t", nullptr, false},
        };
    case MessageName::NetworkStorageManager_ConnectToStorageAreaSync:
        return Vector<ArgumentDescription> {
            {"identifier", "WebKit::StorageAreaIdentifier", nullptr, false},
            {"items", "HashMap<String, String>", nullptr, false},
            {"messageIdentifier", "uint64_t", nullptr, false},
        };
    case MessageName::NetworkStorageManager_SetItem:
        return Vector<ArgumentDescription> {
            {"quotaException", "bool", nullptr, false},
        };
    case MessageName::NetworkStorageManager_RemoveItem:
        return Vector<ArgumentDescription> { };
    case MessageName::NetworkStorageManager_Clear:
        return Vector<ArgumentDescription> { };
#if ENABLE(WEB_RTC)
#endif
#if USE(LIBWEBRTC)
#endif
#if USE(LIBWEBRTC)
#endif
#if ENABLE(WEB_RTC)
#endif
    case MessageName::AuxiliaryProcess_MainThreadPing:
        return Vector<ArgumentDescription> { };
#if ENABLE(IPC_TESTING_API)
    case MessageName::IPCTester_StopMessageTesting:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::NotificationManagerMessageHandler_RequestSystemNotificationPermission:
        return Vector<ArgumentDescription> {
            {"allowed", "bool", nullptr, false},
        };
#if ENABLE(MEDIA_SESSION_COORDINATOR)
    case MessageName::RemoteMediaSessionCoordinatorProxy_Join:
        return Vector<ArgumentDescription> {
            {"error", "WebCore::ExceptionData", nullptr, true},
        };
    case MessageName::RemoteMediaSessionCoordinatorProxy_CoordinateSeekTo:
        return Vector<ArgumentDescription> {
            {"error", "WebCore::ExceptionData", nullptr, true},
        };
    case MessageName::RemoteMediaSessionCoordinatorProxy_CoordinatePlay:
        return Vector<ArgumentDescription> {
            {"error", "WebCore::ExceptionData", nullptr, true},
        };
    case MessageName::RemoteMediaSessionCoordinatorProxy_CoordinatePause:
        return Vector<ArgumentDescription> {
            {"error", "WebCore::ExceptionData", nullptr, true},
        };
    case MessageName::RemoteMediaSessionCoordinatorProxy_CoordinateSetTrack:
        return Vector<ArgumentDescription> {
            {"error", "WebCore::ExceptionData", nullptr, true},
        };
#endif
#if ENABLE(MEDIA_STREAM)
#endif
#if ENABLE(FULLSCREEN_API)
    case MessageName::WebFullScreenManagerProxy_SupportsFullScreen:
        return Vector<ArgumentDescription> {
            {"supportsFullScreen", "bool", nullptr, false},
        };
#endif
    case MessageName::WebLockRegistryProxy_AbortLockRequest:
        return Vector<ArgumentDescription> {
            {"wasAborted", "bool", nullptr, false},
        };
    case MessageName::WebLockRegistryProxy_Snapshot:
        return Vector<ArgumentDescription> {
            {"snapshot", "WebCore::WebLockManagerSnapshot", nullptr, false},
        };
    case MessageName::WebPageProxy_CreateNewPage:
        return Vector<ArgumentDescription> {
            {"newPageID", "WebCore::PageIdentifier", nullptr, true},
            {"newPageParameters", "WebKit::WebPageCreationParameters", nullptr, true},
        };
    case MessageName::WebPageProxy_RunJavaScriptAlert:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_RunJavaScriptConfirm:
        return Vector<ArgumentDescription> {
            {"result", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_RunJavaScriptPrompt:
        return Vector<ArgumentDescription> {
            {"result", "String", nullptr, false},
        };
#if ENABLE(WEBGL)
    case MessageName::WebPageProxy_WebGLPolicyForURL:
        return Vector<ArgumentDescription> {
            {"loadPolicy", "uint8_t", "WebCore::WebGLLoadPolicy", false},
        };
    case MessageName::WebPageProxy_ResolveWebGLPolicyForURL:
        return Vector<ArgumentDescription> {
            {"loadPolicy", "uint8_t", "WebCore::WebGLLoadPolicy", false},
        };
#endif
    case MessageName::WebPageProxy_GetToolbarsAreVisible:
        return Vector<ArgumentDescription> {
            {"toolbarsAreVisible", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_GetMenuBarIsVisible:
        return Vector<ArgumentDescription> {
            {"menuBarIsVisible", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_GetStatusBarIsVisible:
        return Vector<ArgumentDescription> {
            {"statusBarIsVisible", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_GetWindowFrame:
        return Vector<ArgumentDescription> {
            {"windowFrame", "WebCore::FloatRect", nullptr, false},
        };
    case MessageName::WebPageProxy_ScreenToRootView:
        return Vector<ArgumentDescription> {
            {"windowPoint", "WebCore::IntPoint", nullptr, false},
        };
    case MessageName::WebPageProxy_RootViewToScreen:
        return Vector<ArgumentDescription> {
            {"screenFrame", "WebCore::IntRect", nullptr, false},
        };
    case MessageName::WebPageProxy_AccessibilityScreenToRootView:
        return Vector<ArgumentDescription> {
            {"windowPoint", "WebCore::IntPoint", nullptr, false},
        };
    case MessageName::WebPageProxy_RootViewToAccessibilityScreen:
        return Vector<ArgumentDescription> {
            {"screenFrame", "WebCore::IntRect", nullptr, false},
        };
    case MessageName::WebPageProxy_RunBeforeUnloadConfirmPanel:
        return Vector<ArgumentDescription> {
            {"shouldClose", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_ShowShareSheet:
        return Vector<ArgumentDescription> {
            {"granted", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_ShowContactPicker:
        return Vector<ArgumentDescription> {
            {"info", "Vector<WebCore::ContactInfo>", nullptr, true},
        };
    case MessageName::WebPageProxy_PrintFrame:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_DecidePolicyForNavigationActionSync:
        return Vector<ArgumentDescription> {
            {"PolicyDecision", "WebKit::PolicyDecision", nullptr, false},
        };
#if PLATFORM(IOS_FAMILY)
    case MessageName::WebPageProxy_InterpretKeyEvent:
        return Vector<ArgumentDescription> {
            {"handled", "bool", nullptr, false},
        };
#endif
    case MessageName::WebPageProxy_BackForwardGoToItem:
        return Vector<ArgumentDescription> {
            {"counts", "WebKit::WebBackForwardListCounts", nullptr, false},
        };
    case MessageName::WebPageProxy_BackForwardItemAtIndex:
        return Vector<ArgumentDescription> {
            {"itemID", "WebCore::BackForwardItemIdentifier", nullptr, true},
        };
    case MessageName::WebPageProxy_BackForwardListCounts:
        return Vector<ArgumentDescription> {
            {"counts", "WebKit::WebBackForwardListCounts", nullptr, false},
        };
    case MessageName::WebPageProxy_CanUndoRedo:
        return Vector<ArgumentDescription> {
            {"result", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_ExecuteUndoRedo:
        return Vector<ArgumentDescription> { };
#if ENABLE(IMAGE_ANALYSIS)
    case MessageName::WebPageProxy_RequestTextRecognition:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::TextRecognitionResult", nullptr, false},
        };
#endif
#if ENABLE(MEDIA_CONTROLS_CONTEXT_MENUS) && USE(UICONTEXTMENU)
    case MessageName::WebPageProxy_ShowMediaControlsContextMenu:
        return Vector<ArgumentDescription> {
            {"selectedItemID", "WebCore::MediaControlsContextMenuItem::ID", nullptr, false},
        };
#endif
    case MessageName::WebPageProxy_RequestDOMPasteAccess:
        return Vector<ArgumentDescription> {
            {"response", "uint8_t", "WebCore::DOMPasteAccessResponse", false},
        };
    case MessageName::WebPageProxy_ExceededDatabaseQuota:
        return Vector<ArgumentDescription> {
            {"newQuota", "uint64_t", nullptr, false},
        };
    case MessageName::WebPageProxy_ReachedApplicationCacheOriginQuota:
        return Vector<ArgumentDescription> {
            {"newQuota", "uint64_t", nullptr, false},
        };
#if ENABLE(MEDIA_STREAM)
    case MessageName::WebPageProxy_EnumerateMediaDevicesForFrame:
        return Vector<ArgumentDescription> {
            {"devices", "Vector<WebCore::CaptureDevice>", nullptr, false},
            {"mediaDeviceIdentifierHashSalt", "String", nullptr, false},
        };
#endif
    case MessageName::WebPageProxy_RequestNotificationPermission:
        return Vector<ArgumentDescription> {
            {"allowed", "bool", nullptr, false},
        };
#if USE(UNIFIED_TEXT_CHECKING)
    case MessageName::WebPageProxy_CheckTextOfParagraph:
        return Vector<ArgumentDescription> {
            {"results", "Vector<WebCore::TextCheckingResult>", nullptr, false},
        };
#endif
    case MessageName::WebPageProxy_CheckSpellingOfString:
        return Vector<ArgumentDescription> {
            {"misspellingLocation", "int32_t", nullptr, false},
            {"misspellingLength", "int32_t", nullptr, false},
        };
    case MessageName::WebPageProxy_CheckGrammarOfString:
        return Vector<ArgumentDescription> {
            {"results", "Vector<WebCore::GrammarDetail>", nullptr, false},
            {"badGrammarLocation", "int32_t", nullptr, false},
            {"badGrammarLength", "int32_t", nullptr, false},
        };
    case MessageName::WebPageProxy_SpellingUIIsShowing:
        return Vector<ArgumentDescription> {
            {"isShowing", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_GetGuessesForWord:
        return Vector<ArgumentDescription> {
            {"guesses", "Vector<String>", nullptr, false},
        };
#if PLATFORM(COCOA)
    case MessageName::WebPageProxy_ExecuteSavedCommandBySelector:
        return Vector<ArgumentDescription> {
            {"handled", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_GetIsSpeaking:
        return Vector<ArgumentDescription> {
            {"isSpeaking", "bool", nullptr, false},
        };
#endif
#if USE(APPKIT)
    case MessageName::WebPageProxy_SubstitutionsPanelIsShowing:
        return Vector<ArgumentDescription> {
            {"isShowing", "bool", nullptr, false},
        };
#endif
#if PLATFORM(MAC)
    case MessageName::WebPageProxy_DismissCorrectionPanelSoon:
        return Vector<ArgumentDescription> {
            {"result", "String", nullptr, false},
        };
#endif
#if USE(DICTATION_ALTERNATIVES)
    case MessageName::WebPageProxy_DictationAlternatives:
        return Vector<ArgumentDescription> {
            {"alternatives", "Vector<String>", nullptr, false},
        };
#endif
    case MessageName::WebPageProxy_LoadRecentSearches:
        return Vector<ArgumentDescription> {
            {"result", "Vector<WebCore::RecentSearch>", nullptr, false},
        };
#if ENABLE(PDFKIT_PLUGIN)
    case MessageName::WebPageProxy_ShowPDFContextMenu:
        return Vector<ArgumentDescription> {
            {"selectedItem", "int32_t", nullptr, true},
        };
#endif
#if ENABLE(WEB_CRYPTO)
    case MessageName::WebPageProxy_WrapCryptoKey:
        return Vector<ArgumentDescription> {
            {"succeeded", "bool", nullptr, false},
            {"wrappedKey", "Vector<uint8_t>", nullptr, false},
        };
    case MessageName::WebPageProxy_UnwrapCryptoKey:
        return Vector<ArgumentDescription> {
            {"succeeded", "bool", nullptr, false},
            {"key", "Vector<uint8_t>", nullptr, false},
        };
#endif
#if USE(QUICK_LOOK)
    case MessageName::WebPageProxy_RequestPasswordForQuickLookDocumentInMainFrame:
        return Vector<ArgumentDescription> {
            {"password", "String", nullptr, false},
        };
#endif
    case MessageName::WebPageProxy_HandleSynchronousMessage:
        return Vector<ArgumentDescription> {
            {"returnData", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebPageProxy_LoadSynchronousURLSchemeTask:
        return Vector<ArgumentDescription> {
            {"response", "WebCore::ResourceResponse", nullptr, false},
            {"error", "WebCore::ResourceError", nullptr, false},
            {"data", "Vector<uint8_t>", nullptr, false},
        };
#if ENABLE(DEVICE_ORIENTATION)
    case MessageName::WebPageProxy_ShouldAllowDeviceOrientationAndMotionAccess:
        return Vector<ArgumentDescription> {
            {"permissionState", "uint8_t", "WebCore::DeviceOrientationOrMotionPermissionState", false},
        };
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    case MessageName::WebPageProxy_SerializedAttachmentDataForIdentifiers:
        return Vector<ArgumentDescription> {
            {"seralizedData", "Vector<WebCore::SerializedAttachmentData>", nullptr, false},
        };
#endif
    case MessageName::WebPageProxy_SignedPublicKeyAndChallengeString:
        return Vector<ArgumentDescription> {
            {"result", "String", nullptr, false},
        };
#if ENABLE(SPEECH_SYNTHESIS)
    case MessageName::WebPageProxy_SpeechSynthesisVoiceList:
        return Vector<ArgumentDescription> {
            {"voiceList", "Vector<WebKit::WebSpeechSynthesisVoice>", nullptr, false},
        };
    case MessageName::WebPageProxy_SpeechSynthesisSpeak:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_SpeechSynthesisSetFinishedCallback:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_SpeechSynthesisPause:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPageProxy_SpeechSynthesisResume:
        return Vector<ArgumentDescription> { };
#endif
#if PLATFORM(GTK)
    case MessageName::WebPageProxy_ShowEmojiPicker:
        return Vector<ArgumentDescription> {
            {"result", "String", nullptr, false},
        };
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    case MessageName::WebPageProxy_SendMessageToWebViewWithReply:
        return Vector<ArgumentDescription> {
            {"replyMessage", "WebKit::UserMessage", nullptr, false},
        };
#endif
#if ENABLE(ARKIT_INLINE_PREVIEW_MAC)
    case MessageName::WebPageProxy_ModelElementDidCreatePreview:
        return Vector<ArgumentDescription> {
            {"result", "Expected<std::pair<String, uint32_t>, WebCore::ResourceError>", nullptr, false},
        };
    case MessageName::WebPageProxy_ModelElementSizeDidChange:
        return Vector<ArgumentDescription> {
            {"result", "Expected<MachSendRight, WebCore::ResourceError>", nullptr, false},
        };
#endif
#if ENABLE(ARKIT_INLINE_PREVIEW)
    case MessageName::WebPageProxy_ModelElementGetCamera:
        return Vector<ArgumentDescription> {
            {"result", "Expected<WebCore::HTMLModelElementCamera, WebCore::ResourceError>", nullptr, false},
        };
    case MessageName::WebPageProxy_ModelElementSetCamera:
        return Vector<ArgumentDescription> {
            {"success", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_ModelElementIsPlayingAnimation:
        return Vector<ArgumentDescription> {
            {"result", "Expected<bool, WebCore::ResourceError>", nullptr, false},
        };
    case MessageName::WebPageProxy_ModelElementSetAnimationIsPlaying:
        return Vector<ArgumentDescription> {
            {"success", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_ModelElementIsLoopingAnimation:
        return Vector<ArgumentDescription> {
            {"result", "Expected<bool, WebCore::ResourceError>", nullptr, false},
        };
    case MessageName::WebPageProxy_ModelElementSetIsLoopingAnimation:
        return Vector<ArgumentDescription> {
            {"success", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_ModelElementAnimationDuration:
        return Vector<ArgumentDescription> {
            {"result", "Expected<Seconds, WebCore::ResourceError>", nullptr, false},
        };
    case MessageName::WebPageProxy_ModelElementAnimationCurrentTime:
        return Vector<ArgumentDescription> {
            {"result", "Expected<Seconds, WebCore::ResourceError>", nullptr, false},
        };
    case MessageName::WebPageProxy_ModelElementSetAnimationCurrentTime:
        return Vector<ArgumentDescription> {
            {"success", "bool", nullptr, false},
        };
    case MessageName::WebPageProxy_ModelElementHasAudio:
        return Vector<ArgumentDescription> {
            {"result", "Expected<bool, WebCore::ResourceError>", nullptr, false},
        };
    case MessageName::WebPageProxy_ModelElementIsMuted:
        return Vector<ArgumentDescription> {
            {"result", "Expected<bool, WebCore::ResourceError>", nullptr, false},
        };
    case MessageName::WebPageProxy_ModelElementSetIsMuted:
        return Vector<ArgumentDescription> {
            {"success", "bool", nullptr, false},
        };
#endif
    case MessageName::WebPageProxy_QueryPermission:
        return Vector<ArgumentDescription> {
            {"state", "WebCore::PermissionState", nullptr, true},
            {"shouldCache", "bool", nullptr, false},
        };
#if ENABLE(APPLE_PAY_AMS_UI)
    case MessageName::WebPageProxy_StartApplePayAMSUISession:
        return Vector<ArgumentDescription> {
            {"result", "bool", nullptr, true},
        };
#endif
    case MessageName::WebPageProxy_RequestCookieConsent:
        return Vector<ArgumentDescription> {
            {"result", "uint8_t", "WebCore::CookieConsentDecisionResult", false},
        };
    case MessageName::WebPageProxy_ClassifyModalContainerControls:
        return Vector<ArgumentDescription> {
            {"types", "Vector<WebCore::ModalContainerControlType>", nullptr, false},
        };
    case MessageName::WebPageProxy_DecidePolicyForModalContainer:
        return Vector<ArgumentDescription> {
            {"decision", "uint8_t", "WebCore::ModalContainerDecision", false},
        };
    case MessageName::WebPasteboardProxy_WriteCustomData:
        return Vector<ArgumentDescription> {
            {"changeCount", "int64_t", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_TypesSafeForDOMToReadAndWrite:
        return Vector<ArgumentDescription> {
            {"types", "Vector<String>", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_AllPasteboardItemInfo:
        return Vector<ArgumentDescription> {
            {"allInfo", "Vector<WebCore::PasteboardItemInfo>", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_InformationForItemAtIndex:
        return Vector<ArgumentDescription> {
            {"info", "WebCore::PasteboardItemInfo", nullptr, true},
        };
    case MessageName::WebPasteboardProxy_GetPasteboardItemsCount:
        return Vector<ArgumentDescription> {
            {"itemsCount", "uint64_t", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_ReadStringFromPasteboard:
        return Vector<ArgumentDescription> {
            {"string", "String", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_ReadURLFromPasteboard:
        return Vector<ArgumentDescription> {
            {"url", "String", nullptr, false},
            {"title", "String", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_ReadBufferFromPasteboard:
        return Vector<ArgumentDescription> {
            {"handle", "WebKit::SharedMemory::IPCHandle", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_ContainsStringSafeForDOMToReadForType:
        return Vector<ArgumentDescription> {
            {"result", "bool", nullptr, false},
        };
#if PLATFORM(COCOA)
    case MessageName::WebPasteboardProxy_GetNumberOfFiles:
        return Vector<ArgumentDescription> {
            {"numberOfFiles", "uint64_t", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_GetPasteboardTypes:
        return Vector<ArgumentDescription> {
            {"types", "Vector<String>", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_GetPasteboardPathnamesForType:
        return Vector<ArgumentDescription> {
            {"pathnames", "Vector<String>", nullptr, false},
            {"sandboxExtensions", "Vector<WebKit::SandboxExtension::Handle>", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_GetPasteboardStringForType:
        return Vector<ArgumentDescription> {
            {"string", "String", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_GetPasteboardStringsForType:
        return Vector<ArgumentDescription> {
            {"strings", "Vector<String>", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_GetPasteboardBufferForType:
        return Vector<ArgumentDescription> {
            {"handle", "WebKit::SharedMemory::IPCHandle", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_GetPasteboardChangeCount:
        return Vector<ArgumentDescription> {
            {"changeCount", "int64_t", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_GetPasteboardColor:
        return Vector<ArgumentDescription> {
            {"color", "WebCore::Color", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_GetPasteboardURL:
        return Vector<ArgumentDescription> {
            {"urlString", "String", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_AddPasteboardTypes:
        return Vector<ArgumentDescription> {
            {"changeCount", "int64_t", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_SetPasteboardTypes:
        return Vector<ArgumentDescription> {
            {"changeCount", "int64_t", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_SetPasteboardURL:
        return Vector<ArgumentDescription> {
            {"changeCount", "int64_t", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_SetPasteboardColor:
        return Vector<ArgumentDescription> {
            {"changeCount", "int64_t", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_SetPasteboardStringForType:
        return Vector<ArgumentDescription> {
            {"changeCount", "int64_t", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_SetPasteboardBufferForType:
        return Vector<ArgumentDescription> {
            {"changeCount", "int64_t", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_ContainsURLStringSuitableForLoading:
        return Vector<ArgumentDescription> {
            {"result", "bool", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_URLStringSuitableForLoading:
        return Vector<ArgumentDescription> {
            {"url", "String", nullptr, false},
            {"title", "String", nullptr, false},
        };
#endif
#if PLATFORM(GTK)
    case MessageName::WebPasteboardProxy_GetTypes:
        return Vector<ArgumentDescription> {
            {"types", "Vector<String>", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_ReadText:
        return Vector<ArgumentDescription> {
            {"text", "String", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_ReadFilePaths:
        return Vector<ArgumentDescription> {
            {"types", "Vector<String>", nullptr, false},
        };
    case MessageName::WebPasteboardProxy_ReadBuffer:
        return Vector<ArgumentDescription> {
            {"data", "IPC::SharedBufferCopy", nullptr, false},
        };
#endif
#if USE(LIBWPE)
    case MessageName::WebPasteboardProxy_GetPasteboardTypes:
        return Vector<ArgumentDescription> {
            {"types", "Vector<String>", nullptr, false},
        };
#endif
    case MessageName::WebProcessPool_HandleSynchronousMessage:
        return Vector<ArgumentDescription> {
            {"returnData", "WebKit::UserData", nullptr, false},
        };
    case MessageName::WebProcessProxy_ShouldTerminate:
        return Vector<ArgumentDescription> {
            {"shouldTerminate", "bool", nullptr, false},
        };
    case MessageName::WebProcessProxy_GetNetworkProcessConnection:
        return Vector<ArgumentDescription> {
            {"connectionInfo", "WebKit::NetworkProcessConnectionInfo", nullptr, false},
        };
#if ENABLE(GPU_PROCESS)
    case MessageName::WebProcessProxy_GetGPUProcessConnection:
        return Vector<ArgumentDescription> {
            {"connectionInfo", "WebKit::GPUProcessConnectionInfo", nullptr, false},
        };
#endif
#if ENABLE(WEB_AUTHN)
    case MessageName::WebProcessProxy_GetWebAuthnProcessConnection:
        return Vector<ArgumentDescription> {
            {"connectionInfo", "WebKit::WebAuthnProcessConnectionInfo", nullptr, false},
        };
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    case MessageName::WebProcessProxy_SendMessageToWebContextWithReply:
        return Vector<ArgumentDescription> {
            {"replyMessage", "WebKit::UserMessage", nullptr, false},
        };
#endif
#if PLATFORM(MAC)
    case MessageName::WebProcessProxy_IsAXAuthenticated:
        return Vector<ArgumentDescription> {
            {"authenticated", "bool", nullptr, false},
        };
#endif
    case MessageName::DownloadProxy_DecideDestinationWithSuggestedFilename:
        return Vector<ArgumentDescription> {
            {"filename", "String", nullptr, false},
            {"handle", "WebKit::SandboxExtension::Handle", nullptr, false},
            {"allowOverwrite", "bool", "WebKit::AllowOverwrite", false},
        };
#if ENABLE(GPU_PROCESS)
#endif
    case MessageName::NetworkProcessProxy_TestProcessIncomingSyncMessagesWhenWaitingForSyncReply:
        return Vector<ArgumentDescription> {
            {"handled", "bool", nullptr, false},
        };
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
    case MessageName::NetworkProcessProxy_RequestStorageAccessConfirm:
        return Vector<ArgumentDescription> {
            {"userDidGrantAccess", "bool", nullptr, false},
        };
    case MessageName::NetworkProcessProxy_DeleteWebsiteDataInUIProcessForRegistrableDomains:
        return Vector<ArgumentDescription> {
            {"domainsWithMatchingDataRecords", "HashSet<WebCore::RegistrableDomain>", nullptr, false},
        };
    case MessageName::NetworkProcessProxy_SetDomainsWithCrossPageStorageAccess:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::NetworkProcessProxy_RetrieveCacheStorageParameters:
        return Vector<ArgumentDescription> {
            {"cacheStorageDirectory", "String", nullptr, false},
            {"handle", "WebKit::SandboxExtension::Handle", nullptr, false},
        };
#if ENABLE(SERVICE_WORKER)
    case MessageName::NetworkProcessProxy_EstablishServiceWorkerContextConnectionToNetworkProcess:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::NetworkProcessProxy_EstablishSharedWorkerContextConnectionToNetworkProcess:
        return Vector<ArgumentDescription> { };
#if ENABLE(APP_BOUND_DOMAINS)
    case MessageName::NetworkProcessProxy_GetAppBoundDomains:
        return Vector<ArgumentDescription> {
            {"appBoundDomains", "HashSet<WebCore::RegistrableDomain>", nullptr, false},
        };
#endif
    case MessageName::NetworkProcessProxy_RequestStorageSpace:
        return Vector<ArgumentDescription> {
            {"newQuota", "uint64_t", nullptr, true},
        };
    case MessageName::NetworkProcessProxy_TriggerBrowsingContextGroupSwitchForNavigation:
        return Vector<ArgumentDescription> {
            {"success", "bool", nullptr, false},
        };
#if ENABLE(APPLE_PAY_REMOTE_UI_USES_SCENE)
    case MessageName::NetworkProcessProxy_GetWindowSceneIdentifierForPaymentPresentation:
        return Vector<ArgumentDescription> {
            {"sceneID", "String", nullptr, false},
        };
#endif
    case MessageName::WebUserContentControllerProxy_DidPostMessage:
        return Vector<ArgumentDescription> {
            {"resultValue", "IPC::DataReference", nullptr, false},
            {"errorMessage", "String", nullptr, false},
        };
#if ENABLE(WEBXR)
    case MessageName::PlatformXRSystem_EnumerateImmersiveXRDevices:
        return Vector<ArgumentDescription> {
            {"devicesInfos", "Vector<WebKit::XRDeviceInfo>", nullptr, false},
        };
    case MessageName::PlatformXRSystem_RequestPermissionOnSessionFeatures:
        return Vector<ArgumentDescription> {
            {"userGranted", "Vector<PlatformXR::ReferenceSpaceType>", nullptr, true},
        };
    case MessageName::PlatformXRSystem_RequestFrame:
        return Vector<ArgumentDescription> {
            {"frameData", "PlatformXR::Device::FrameData", nullptr, false},
        };
#endif
    case MessageName::WebProcess_FetchWebsiteData:
        return Vector<ArgumentDescription> {
            {"websiteData", "WebKit::WebsiteData", nullptr, false},
        };
    case MessageName::WebProcess_DeleteWebsiteData:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcess_DeleteWebsiteDataForOrigins:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcess_PrepareToSuspend:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcess_EstablishSharedWorkerContextConnectionToNetworkProcess:
        return Vector<ArgumentDescription> { };
#if ENABLE(SERVICE_WORKER)
    case MessageName::WebProcess_EstablishServiceWorkerContextConnectionToNetworkProcess:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebProcess_GetActivePagesOriginsForTesting:
        return Vector<ArgumentDescription> {
            {"activeOrigins", "Vector<String>", nullptr, false},
        };
    case MessageName::WebProcess_IsJITEnabled:
        return Vector<ArgumentDescription> {
            {"enabled", "bool", nullptr, false},
        };
    case MessageName::WebProcess_ClearCachedPage:
        return Vector<ArgumentDescription> { };
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
    case MessageName::WebProcess_SeedResourceLoadStatisticsForTesting:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcess_SetThirdPartyCookieBlockingMode:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcess_SetDomainsWithCrossPageStorageAccess:
        return Vector<ArgumentDescription> { };
    case MessageName::WebProcess_SendResourceLoadStatisticsDataImmediately:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebAutomationSessionProxy_ResolveChildFrameWithOrdinal:
        return Vector<ArgumentDescription> {
            {"errorType", "String", nullptr, true},
            {"frameID", "WebCore::FrameIdentifier", nullptr, true},
        };
    case MessageName::WebAutomationSessionProxy_ResolveChildFrameWithNodeHandle:
        return Vector<ArgumentDescription> {
            {"errorType", "String", nullptr, true},
            {"frameID", "WebCore::FrameIdentifier", nullptr, true},
        };
    case MessageName::WebAutomationSessionProxy_ResolveChildFrameWithName:
        return Vector<ArgumentDescription> {
            {"errorType", "String", nullptr, true},
            {"frameID", "WebCore::FrameIdentifier", nullptr, true},
        };
    case MessageName::WebAutomationSessionProxy_ResolveParentFrame:
        return Vector<ArgumentDescription> {
            {"errorType", "String", nullptr, true},
            {"frameID", "WebCore::FrameIdentifier", nullptr, true},
        };
    case MessageName::WebAutomationSessionProxy_ComputeElementLayout:
        return Vector<ArgumentDescription> {
            {"errorType", "String", nullptr, true},
            {"rect", "WebCore::IntRect", nullptr, false},
            {"inViewCenterPoint", "WebCore::IntPoint", nullptr, true},
            {"isObscured", "bool", nullptr, false},
        };
    case MessageName::WebAutomationSessionProxy_SelectOptionElement:
        return Vector<ArgumentDescription> {
            {"errorType", "String", nullptr, true},
        };
    case MessageName::WebAutomationSessionProxy_SetFilesForInputFileUpload:
        return Vector<ArgumentDescription> {
            {"errorType", "String", nullptr, true},
        };
    case MessageName::WebAutomationSessionProxy_SnapshotRectForScreenshot:
        return Vector<ArgumentDescription> {
            {"errorType", "String", nullptr, true},
            {"rect", "WebCore::IntRect", nullptr, false},
        };
    case MessageName::WebAutomationSessionProxy_GetCookiesForFrame:
        return Vector<ArgumentDescription> {
            {"errorType", "String", nullptr, true},
            {"cookies", "Vector<WebCore::Cookie>", nullptr, false},
        };
    case MessageName::WebAutomationSessionProxy_DeleteCookie:
        return Vector<ArgumentDescription> {
            {"errorType", "String", nullptr, true},
        };
#if ENABLE(FULLSCREEN_API)
#endif
#if ENABLE(GPU_PROCESS)
#if ENABLE(ROUTING_ARBITRATION)
    case MessageName::GPUProcessConnection_BeginRoutingArbitrationWithCategory:
        return Vector<ArgumentDescription> {
            {"error", "uint8_t", "WebKit::AudioSessionRoutingArbitratorProxy::RoutingArbitrationError", false},
            {"defaultRouteChanged", "bool", "WebKit::AudioSessionRoutingArbitratorProxy::DefaultRouteChanged", false},
        };
#endif
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(WEBGL)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS)
    case MessageName::MediaPlayerPrivateRemote_RequestResource:
        return Vector<ArgumentDescription> { };
    case MessageName::MediaPlayerPrivateRemote_SendH2Ping:
        return Vector<ArgumentDescription> {
            {"result", "Expected<Seconds, WebCore::ResourceError>", nullptr, false},
        };
#if PLATFORM(IOS_FAMILY)
    case MessageName::MediaPlayerPrivateRemote_GetRawCookies:
        return Vector<ArgumentDescription> {
            {"result", "Vector<WebCore::Cookie>", nullptr, false},
        };
#endif
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)
#endif
#if ENABLE(GPU_PROCESS) && USE(AUDIO_SESSION)
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(ENCRYPTED_MEDIA)
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(LEGACY_ENCRYPTED_MEDIA)
#endif
#if ENABLE(GPU_PROCESS)
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)
    case MessageName::SourceBufferPrivateRemote_SourceBufferPrivateDidReceiveInitializationSegment:
        return Vector<ArgumentDescription> { };
#endif
#if USE(LIBWEBRTC) && PLATFORM(COCOA) && ENABLE(GPU_PROCESS)
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(VIDEO)
#endif
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
#endif
#if ENABLE(MEDIA_SESSION_COORDINATOR)
    case MessageName::RemoteMediaSessionCoordinator_SeekSessionToTime:
        return Vector<ArgumentDescription> {
            {"result", "bool", nullptr, false},
        };
    case MessageName::RemoteMediaSessionCoordinator_PlaySession:
        return Vector<ArgumentDescription> {
            {"result", "bool", nullptr, false},
        };
    case MessageName::RemoteMediaSessionCoordinator_PauseSession:
        return Vector<ArgumentDescription> {
            {"result", "bool", nullptr, false},
        };
    case MessageName::RemoteMediaSessionCoordinator_SetSessionTrack:
        return Vector<ArgumentDescription> {
            {"result", "bool", nullptr, false},
        };
#endif
#if USE(LIBWEBRTC)
#endif
#if ENABLE(WEB_RTC)
#endif
#if ENABLE(WEB_RTC)
#endif
#if USE(LIBWEBRTC)
#endif
#if USE(LIBWEBRTC)
#endif
#if ENABLE(WEB_RTC)
    case MessageName::NetworkProcessConnection_ConnectToRTCDataChannelRemoteSource:
        return Vector<ArgumentDescription> {
            {"result", "bool", nullptr, true},
        };
#endif
    case MessageName::NetworkProcessConnection_CheckProcessLocalPortForActivity:
        return Vector<ArgumentDescription> {
            {"hasActivity", "WebCore::MessagePortChannelProvider::HasActivity", nullptr, false},
        };
#if ENABLE(MEDIA_STREAM)
#endif
    case MessageName::WebSharedWorkerObjectConnection_FetchScriptInClient:
        return Vector<ArgumentDescription> {
            {"fetchResult", "WebCore::WorkerFetchResult", nullptr, false},
        };
#if ENABLE(SERVICE_WORKER)
    case MessageName::WebSWClientConnection_SetDocumentIsControlled:
        return Vector<ArgumentDescription> {
            {"isSuccess", "bool", nullptr, false},
        };
#endif
#if ENABLE(SERVICE_WORKER)
    case MessageName::WebSWContextManagerConnection_FirePushEvent:
        return Vector<ArgumentDescription> {
            {"result", "bool", nullptr, false},
        };
#endif
    case MessageName::WebBroadcastChannelRegistry_PostMessageToRemote:
        return Vector<ArgumentDescription> { };
#if ENABLE(IOS_TOUCH_EVENTS)
    case MessageName::EventDispatcher_TouchEvent:
        return Vector<ArgumentDescription> {
            {"handled", "bool", nullptr, false},
        };
#endif
    case MessageName::WebPage_SetInitialFocus:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_SetActivityState:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_TestProcessIncomingSyncMessagesWhenWaitingForSyncReply:
        return Vector<ArgumentDescription> {
            {"handled", "bool", nullptr, false},
        };
    case MessageName::WebPage_ExecuteEditCommandWithCallback:
        return Vector<ArgumentDescription> { };
#if PLATFORM(IOS_FAMILY)
    case MessageName::WebPage_SelectWithGesture:
        return Vector<ArgumentDescription> {
            {"point", "WebCore::IntPoint", nullptr, false},
            {"gestureType", "uint8_t", "WebKit::GestureType", false},
            {"gestureState", "uint8_t", "WebKit::GestureRecognizerState", false},
            {"flags", "OptionSet<WebKit::SelectionFlags>", nullptr, false},
        };
    case MessageName::WebPage_UpdateSelectionWithTouches:
        return Vector<ArgumentDescription> {
            {"point", "WebCore::IntPoint", nullptr, false},
            {"touch", "uint8_t", "WebKit::SelectionTouch", false},
            {"selectionFlags", "OptionSet<WebKit::SelectionFlags>", nullptr, false},
        };
    case MessageName::WebPage_SelectWithTwoTouches:
        return Vector<ArgumentDescription> {
            {"point", "WebCore::IntPoint", nullptr, false},
            {"gestureType", "uint8_t", "WebKit::GestureType", false},
            {"gestureState", "uint8_t", "WebKit::GestureRecognizerState", false},
            {"selectionFlags", "OptionSet<WebKit::SelectionFlags>", nullptr, false},
        };
    case MessageName::WebPage_ExtendSelection:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_MoveSelectionByOffset:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_SelectTextWithGranularityAtPoint:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_SelectPositionAtBoundaryWithDirection:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_MoveSelectionAtBoundaryWithDirection:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_SelectPositionAtPoint:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_BeginSelectionInDirection:
        return Vector<ArgumentDescription> {
            {"endIsMoving", "bool", nullptr, false},
        };
    case MessageName::WebPage_UpdateSelectionWithExtentPoint:
        return Vector<ArgumentDescription> {
            {"endIsMoving", "bool", nullptr, false},
        };
    case MessageName::WebPage_UpdateSelectionWithExtentPointAndBoundary:
        return Vector<ArgumentDescription> {
            {"endIsMoving", "bool", nullptr, false},
        };
    case MessageName::WebPage_RequestDictationContext:
        return Vector<ArgumentDescription> {
            {"selectedText", "String", nullptr, false},
            {"textBefore", "String", nullptr, false},
            {"textAfter", "String", nullptr, false},
        };
#endif
#if (PLATFORM(IOS_FAMILY) && ENABLE(REVEAL))
    case MessageName::WebPage_RequestRVItemInCurrentSelectedRange:
        return Vector<ArgumentDescription> {
            {"item", "WebKit::RevealItem", nullptr, false},
        };
    case MessageName::WebPage_PrepareSelectionForContextMenuWithLocationInView:
        return Vector<ArgumentDescription> {
            {"shouldShowMenu", "bool", nullptr, false},
            {"item", "WebKit::RevealItem", nullptr, false},
        };
#endif
#if PLATFORM(IOS_FAMILY)
    case MessageName::WebPage_RequestAutocorrectionData:
        return Vector<ArgumentDescription> {
            {"data", "WebKit::WebAutocorrectionData", nullptr, false},
        };
    case MessageName::WebPage_ApplyAutocorrection:
        return Vector<ArgumentDescription> {
            {"string", "String", nullptr, false},
        };
    case MessageName::WebPage_SyncApplyAutocorrection:
        return Vector<ArgumentDescription> {
            {"autocorrectionApplied", "bool", nullptr, false},
        };
    case MessageName::WebPage_RequestEvasionRectsAboveSelection:
        return Vector<ArgumentDescription> {
            {"rects", "Vector<WebCore::FloatRect>", nullptr, false},
        };
    case MessageName::WebPage_GetPositionInformation:
        return Vector<ArgumentDescription> {
            {"information", "WebKit::InteractionInformationAtPosition", nullptr, false},
        };
    case MessageName::WebPage_FocusNextFocusedElement:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_GetSelectionContext:
        return Vector<ArgumentDescription> {
            {"selectedText", "String", nullptr, false},
            {"textBefore", "String", nullptr, false},
            {"textAfter", "String", nullptr, false},
        };
    case MessageName::WebPage_GetRectsForGranularityWithSelectionOffset:
        return Vector<ArgumentDescription> {
            {"rect", "Vector<WebCore::SelectionGeometry>", nullptr, false},
        };
    case MessageName::WebPage_GetRectsAtSelectionOffsetWithText:
        return Vector<ArgumentDescription> {
            {"rect", "Vector<WebCore::SelectionGeometry>", nullptr, false},
        };
    case MessageName::WebPage_RequestFocusedElementInformation:
        return Vector<ArgumentDescription> {
            {"info", "WebKit::FocusedElementInformation", nullptr, true},
        };
    case MessageName::WebPage_UpdateSelectionWithDelta:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_RequestDocumentEditingContext:
        return Vector<ArgumentDescription> {
            {"response", "WebKit::DocumentEditingContext", nullptr, false},
        };
    case MessageName::WebPage_InsertTextPlaceholder:
        return Vector<ArgumentDescription> {
            {"placeholder", "WebCore::ElementContext", nullptr, true},
        };
    case MessageName::WebPage_RemoveTextPlaceholder:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_TextInputContextsInRect:
        return Vector<ArgumentDescription> {
            {"contexts", "Vector<struct WebCore::ElementContext>", nullptr, false},
        };
    case MessageName::WebPage_FocusTextInputContextAndPlaceCaret:
        return Vector<ArgumentDescription> {
            {"success", "bool", nullptr, false},
        };
    case MessageName::WebPage_ClearServiceWorkerEntitlementOverride:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebPage_RequestImageBitmap:
        return Vector<ArgumentDescription> {
            {"image", "WebKit::ShareableBitmap::Handle", nullptr, false},
            {"sourceMIMEType", "String", nullptr, false},
        };
#if ENABLE(IOS_TOUCH_EVENTS)
    case MessageName::WebPage_TouchEventSync:
        return Vector<ArgumentDescription> {
            {"handled", "bool", nullptr, false},
        };
#endif
    case MessageName::WebPage_GetPDFFirstPageSize:
        return Vector<ArgumentDescription> {
            {"size", "WebCore::FloatSize", nullptr, false},
        };
    case MessageName::WebPage_GetContentsAsString:
        return Vector<ArgumentDescription> {
            {"string", "String", nullptr, false},
        };
    case MessageName::WebPage_GetAllFrames:
        return Vector<ArgumentDescription> {
            {"mainFrame", "WebKit::FrameTreeNodeData", nullptr, false},
        };
#if PLATFORM(COCOA)
    case MessageName::WebPage_GetContentsAsAttributedString:
        return Vector<ArgumentDescription> {
            {"result", "WebCore::AttributedString", nullptr, false},
        };
#endif
#if ENABLE(MHTML)
    case MessageName::WebPage_GetContentsAsMHTMLData:
        return Vector<ArgumentDescription> {
            {"data", "IPC::SharedBufferCopy", nullptr, false},
        };
#endif
    case MessageName::WebPage_GetMainResourceDataOfFrame:
        return Vector<ArgumentDescription> {
            {"buffer", "IPC::SharedBufferCopy", nullptr, true},
        };
    case MessageName::WebPage_GetResourceDataFromFrame:
        return Vector<ArgumentDescription> {
            {"buffer", "IPC::SharedBufferCopy", nullptr, true},
        };
    case MessageName::WebPage_GetRenderTreeExternalRepresentation:
        return Vector<ArgumentDescription> {
            {"string", "String", nullptr, false},
        };
    case MessageName::WebPage_GetSelectionOrContentsAsString:
        return Vector<ArgumentDescription> {
            {"string", "String", nullptr, false},
        };
    case MessageName::WebPage_GetSelectionAsWebArchiveData:
        return Vector<ArgumentDescription> {
            {"data", "IPC::SharedBufferCopy", nullptr, true},
        };
    case MessageName::WebPage_GetSourceForFrame:
        return Vector<ArgumentDescription> {
            {"string", "String", nullptr, false},
        };
    case MessageName::WebPage_GetWebArchiveOfFrame:
        return Vector<ArgumentDescription> {
            {"dataReference", "IPC::SharedBufferCopy", nullptr, true},
        };
    case MessageName::WebPage_RunJavaScriptInFrameInScriptWorld:
        return Vector<ArgumentDescription> {
            {"resultData", "IPC::DataReference", nullptr, false},
            {"details", "WebCore::ExceptionDetails", nullptr, true},
        };
    case MessageName::WebPage_ForceRepaint:
        return Vector<ArgumentDescription> { };
#if ENABLE(DATA_DETECTION)
    case MessageName::WebPage_DetectDataInAllFrames:
        return Vector<ArgumentDescription> {
            {"result", "WebKit::DataDetectionResult", nullptr, false},
        };
    case MessageName::WebPage_RemoveDataDetectedLinks:
        return Vector<ArgumentDescription> {
            {"result", "WebKit::DataDetectionResult", nullptr, false},
        };
#endif
    case MessageName::WebPage_Suspend:
        return Vector<ArgumentDescription> {
            {"success", "bool", nullptr, false},
        };
    case MessageName::WebPage_Resume:
        return Vector<ArgumentDescription> {
            {"success", "bool", nullptr, false},
        };
    case MessageName::WebPage_TryClose:
        return Vector<ArgumentDescription> {
            {"shouldClose", "bool", nullptr, false},
        };
    case MessageName::WebPage_ValidateCommand:
        return Vector<ArgumentDescription> {
            {"isEnabled", "bool", nullptr, false},
            {"state", "int32_t", nullptr, false},
        };
    case MessageName::WebPage_RequestFontAttributesAtSelectionStart:
        return Vector<ArgumentDescription> {
            {"attributes", "WebCore::FontAttributes", nullptr, false},
        };
    case MessageName::WebPage_FindString:
        return Vector<ArgumentDescription> {
            {"found", "bool", nullptr, false},
        };
    case MessageName::WebPage_ReplaceMatches:
        return Vector<ArgumentDescription> {
            {"numberOfReplacements", "uint64_t", nullptr, false},
        };
    case MessageName::WebPage_FindRectsForStringMatches:
        return Vector<ArgumentDescription> {
            {"matches", "Vector<WebCore::FloatRect>", nullptr, false},
        };
    case MessageName::WebPage_FindTextRangesForStringMatches:
        return Vector<ArgumentDescription> {
            {"ranges", "Vector<WebKit::WebFoundTextRange>", nullptr, false},
        };
    case MessageName::WebPage_RequestRectForFoundTextRange:
        return Vector<ArgumentDescription> {
            {"rect", "WebCore::FloatRect", nullptr, false},
        };
#if PLATFORM(IOS_FAMILY) && ENABLE(DRAG_SUPPORT)
    case MessageName::WebPage_InsertDroppedImagePlaceholders:
        return Vector<ArgumentDescription> {
            {"dropPreviewRects", "Vector<WebCore::IntRect>", nullptr, false},
            {"textIndicator", "WebCore::TextIndicatorData", nullptr, true},
        };
#endif
#if ENABLE(MEDIA_STREAM)
    case MessageName::WebPage_UserMediaAccessWasGranted:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(ENCRYPTED_MEDIA)
    case MessageName::WebPage_MediaKeySystemWasGranted:
        return Vector<ArgumentDescription> { };
#endif
    case MessageName::WebPage_RequestMediaPlaybackState:
        return Vector<ArgumentDescription> {
            {"state", "uint8_t", "WebKit::MediaPlaybackState", false},
        };
    case MessageName::WebPage_PauseAllMediaPlayback:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_SuspendAllMediaPlayback:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_ResumeAllMediaPlayback:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_IsLayerTreeFrozen:
        return Vector<ArgumentDescription> {
            {"isFrozen", "bool", nullptr, false},
        };
    case MessageName::WebPage_ComputePagesForPrinting:
        return Vector<ArgumentDescription> {
            {"pageRects", "Vector<WebCore::IntRect>", nullptr, false},
            {"totalScaleFactorForPrinting", "double", nullptr, false},
            {"computedPageMargin", "WebCore::RectEdges<float>", nullptr, false},
        };
#if PLATFORM(COCOA)
    case MessageName::WebPage_DrawRectToImage:
        return Vector<ArgumentDescription> {
            {"image", "WebKit::ShareableBitmap::Handle", nullptr, false},
        };
    case MessageName::WebPage_DrawPagesToPDF:
        return Vector<ArgumentDescription> {
            {"data", "IPC::SharedBufferCopy", nullptr, false},
        };
#endif
#if (PLATFORM(COCOA) && PLATFORM(IOS_FAMILY) && !HAVE(UIKIT_BACKGROUND_THREAD_PRINTING))
    case MessageName::WebPage_ComputePagesForPrintingiOS:
        return Vector<ArgumentDescription> {
            {"pageCount", "size_t", nullptr, false},
        };
#endif
#if (PLATFORM(COCOA) && PLATFORM(IOS_FAMILY))
    case MessageName::WebPage_DrawToPDFiOS:
        return Vector<ArgumentDescription> {
            {"data", "IPC::SharedBufferCopy", nullptr, false},
        };
#endif
#if PLATFORM(COCOA)
    case MessageName::WebPage_DrawToPDF:
        return Vector<ArgumentDescription> {
            {"data", "IPC::SharedBufferCopy", nullptr, false},
        };
#endif
#if PLATFORM(GTK)
    case MessageName::WebPage_DrawPagesForPrinting:
        return Vector<ArgumentDescription> {
            {"error", "WebCore::ResourceError", nullptr, false},
        };
#endif
    case MessageName::WebPage_SetMuted:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_StopMediaCapture:
        return Vector<ArgumentDescription> { };
#if PLATFORM(COCOA)
    case MessageName::WebPage_GetStringSelectionForPasteboard:
        return Vector<ArgumentDescription> {
            {"stringValue", "String", nullptr, false},
        };
    case MessageName::WebPage_GetDataSelectionForPasteboard:
        return Vector<ArgumentDescription> {
            {"ipcHandle", "WebKit::SharedMemory::IPCHandle", nullptr, false},
        };
    case MessageName::WebPage_ReadSelectionFromPasteboard:
        return Vector<ArgumentDescription> {
            {"result", "bool", nullptr, false},
        };
    case MessageName::WebPage_ShouldDelayWindowOrderingEvent:
        return Vector<ArgumentDescription> {
            {"result", "bool", nullptr, false},
        };
    case MessageName::WebPage_HasMarkedText:
        return Vector<ArgumentDescription> {
            {"hasMarkedText", "bool", nullptr, false},
        };
    case MessageName::WebPage_GetMarkedRangeAsync:
        return Vector<ArgumentDescription> {
            {"range", "WebKit::EditingRange", nullptr, false},
        };
    case MessageName::WebPage_GetSelectedRangeAsync:
        return Vector<ArgumentDescription> {
            {"range", "WebKit::EditingRange", nullptr, false},
        };
    case MessageName::WebPage_CharacterIndexForPointAsync:
        return Vector<ArgumentDescription> {
            {"location", "uint64_t", nullptr, false},
        };
    case MessageName::WebPage_FirstRectForCharacterRangeAsync:
        return Vector<ArgumentDescription> {
            {"rect", "WebCore::IntRect", nullptr, false},
            {"actualRange", "WebKit::EditingRange", nullptr, false},
        };
#endif
#if PLATFORM(MAC)
    case MessageName::WebPage_AttributedSubstringForCharacterRangeAsync:
        return Vector<ArgumentDescription> {
            {"string", "WebCore::AttributedString", nullptr, false},
            {"range", "WebKit::EditingRange", nullptr, false},
        };
#endif
    case MessageName::WebPage_GetBytecodeProfile:
        return Vector<ArgumentDescription> {
            {"string", "String", nullptr, false},
        };
    case MessageName::WebPage_GetSamplingProfilerOutput:
        return Vector<ArgumentDescription> {
            {"string", "String", nullptr, false},
        };
    case MessageName::WebPage_TakeSnapshot:
        return Vector<ArgumentDescription> {
            {"image", "WebKit::ShareableBitmap::Handle", nullptr, false},
        };
#if PLATFORM(COCOA)
    case MessageName::WebPage_RequestActiveNowPlayingSessionInfo:
        return Vector<ArgumentDescription> {
            {"active", "bool", nullptr, false},
            {"registeredAsNowPlayingApplication", "bool", nullptr, false},
            {"title", "String", nullptr, false},
            {"duration", "double", nullptr, false},
            {"elapsedTime", "double", nullptr, false},
            {"uniqueIdentifier", "uint64_t", nullptr, false},
        };
#endif
    case MessageName::WebPage_DidGetLoadDecisionForIcon:
        return Vector<ArgumentDescription> {
            {"iconData", "IPC::SharedBufferCopy", nullptr, false},
        };
    case MessageName::WebPage_URLSchemeTaskWillPerformRedirection:
        return Vector<ArgumentDescription> {
            {"actualRequest", "WebCore::ResourceRequest", nullptr, false},
        };
#if ENABLE(ATTACHMENT_ELEMENT)
    case MessageName::WebPage_InsertAttachment:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_UpdateAttachmentAttributes:
        return Vector<ArgumentDescription> { };
#endif
#if ENABLE(APPLICATION_MANIFEST)
    case MessageName::WebPage_GetApplicationManifest:
        return Vector<ArgumentDescription> {
            {"manifest", "WebCore::ApplicationManifest", nullptr, true},
        };
#endif
#if ENABLE(UI_PROCESS_PDF_HUD)
    case MessageName::WebPage_SavePDF:
        return Vector<ArgumentDescription> {
            {"filename", "String", nullptr, false},
            {"url", "URL", nullptr, false},
            {"data", "IPC::DataReference", nullptr, false},
        };
    case MessageName::WebPage_OpenPDFWithPreview:
        return Vector<ArgumentDescription> {
            {"filename", "String", nullptr, false},
            {"frameInfo", "WebKit::FrameInfoData", nullptr, false},
            {"data", "IPC::DataReference", nullptr, false},
            {"uuid", "String", nullptr, false},
        };
#endif
#if ENABLE(INTELLIGENT_TRACKING_PREVENTION)
    case MessageName::WebPage_GetLoadedSubresourceDomains:
        return Vector<ArgumentDescription> {
            {"domains", "Vector<WebCore::RegistrableDomain>", nullptr, false},
        };
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    case MessageName::WebPage_SendMessageToWebExtensionWithReply:
        return Vector<ArgumentDescription> {
            {"replyMessage", "WebKit::UserMessage", nullptr, false},
        };
#endif
    case MessageName::WebPage_StartTextManipulations:
        return Vector<ArgumentDescription> { };
    case MessageName::WebPage_CompleteTextManipulation:
        return Vector<ArgumentDescription> {
            {"allFailed", "bool", nullptr, false},
            {"failures", "Vector<WebCore::TextManipulationController::ManipulationFailure>", nullptr, false},
        };
    case MessageName::WebPage_GetProcessDisplayName:
        return Vector<ArgumentDescription> {
            {"displayName", "String", nullptr, false},
        };
    case MessageName::WebPage_DispatchWheelEventWithoutScrolling:
        return Vector<ArgumentDescription> {
            {"handled", "bool", nullptr, false},
        };
    case MessageName::WebPage_LastNavigationWasAppInitiated:
        return Vector<ArgumentDescription> {
            {"wasAppBound", "bool", nullptr, false},
        };
#if ENABLE(MEDIA_SESSION_COORDINATOR)
    case MessageName::WebPage_CreateMediaSessionCoordinator:
        return Vector<ArgumentDescription> {
            {"success", "bool", nullptr, false},
        };
#endif
#if ENABLE(IMAGE_ANALYSIS)
    case MessageName::WebPage_UpdateWithTextRecognitionResult:
        return Vector<ArgumentDescription> {
            {"result", "uint8_t", "WebKit::TextRecognitionUpdateResult", false},
        };
#endif
    case MessageName::WebPage_InteractableRegionsInRootViewCoordinates:
        return Vector<ArgumentDescription> {
            {"rects", "Vector<WebCore::FloatRect>", nullptr, false},
        };
#if ENABLE(WEBXR)
#endif
    default:
        break;
    }
    return std::nullopt;
}

} // namespace WebKit

#endif // ENABLE(IPC_TESTING_API) || !LOG_DISABLED
